@@ -36,7 +36,7 @@ QString JobInfo::stateAsString() const
     switch( state )
     {
         case Initial:
-            return QLatin1String("Waiting");
+            return QLatin1String("Initial");
         case Running:
             return QLatin1String("Running");
         case Ended:
@@ -53,7 +53,7 @@ class JobTracker::Private
 {
 public:
   Private( JobTracker *_q )
-  :lastId( 42 ), timer( _q ),disabled( false ), q( _q )
+  :lastId( 42 ), timer( _q ), q( _q )
   {
     timer.setSingleShot( true );
     timer.setInterval( 200 );
@@ -75,7 +75,7 @@ public:
   QHash<QString, int> idToSequence;
   QHash<int, QString> sequenceToId;
   QHash<QString, QStringList> jobs;
-  QHash<QString, JobInfo> infoList;
+  QHash<QString, JobInfo> infos;
   int lastId;
   QTimer timer;
   bool disabled;
@@ -107,21 +107,21 @@ JobTracker::JobTracker( const char *name, QObject* parent )
     JobInfo info;
     info.id = "eins";
     info.parent = -2;
-    d->infoList.insert( "eins", info );
+    d->infos.insert( "eins", info );
 
     d->jobs.insert( "sub-eins", QStringList() );
     d->idToSequence.insert( "sub-eins", 1 );
     d->sequenceToId.insert( 1, "sub-eins" );
     info.id = "sub-eins";
     info.parent = 0;
-    d->infoList.insert( "sub-eins", info );
+    d->infos.insert( "sub-eins", info );
 
     d->jobs.insert( "sub-zwei", QStringList() );
     d->idToSequence.insert( "sub-zwei", 2 );
     d->sequenceToId.insert( 2, "sub-zwei" );
     info.id = "sub-zwei";
     info.parent = 0;
-    d->infoList.insert( "sub-zwei", info );
+    d->infos.insert( "sub-zwei", info );
 #endif
 }
 
@@ -130,14 +130,14 @@ JobTracker::~JobTracker()
   delete d;
 }
 
-void JobTracker::jobCreated( const QString & session, const QString & job, const QString & parent, const QString & jobType, const QString & debugString )
+void JobTracker::jobCreated( const QString & session, const QString & job, const QString & parent, const QString & jobType )
 {
   if ( d->disabled || session.isEmpty() || job.isEmpty() ) return;
 
   if ( !parent.isEmpty() && !d->jobs.contains( parent ) )
   {
-    qWarning() << "JobTracker: Job arrived before its parent! Fix the library!";
-    jobCreated( session, parent, QString(), "dummy job type", QString() );
+    qWarning() << "JobTracker: Job arrived before it's parent! Fix the library!";
+    jobCreated( session, parent, QString(),"dummy job type" );
   }
   // check if it's a new session, if so, add it
   if ( d->sessions.isEmpty() || !d->sessions.contains( session ) ) {
@@ -147,11 +147,7 @@ void JobTracker::jobCreated( const QString & session, const QString & job, const
   }
 
   // deal with the job
-  if ( d->jobs.contains( job ) ) {
-    if ( d->infoList.value( job ).state == JobInfo::Running )
-      qDebug() << "Job was already known and still running:" << job << "from" << d->infoList.value( job ).timestamp.secsTo( QDateTime::currentDateTime() ) << "s ago";
-    // otherwise it just means the pointer got reused... replace old job
-  }
+  if ( d->jobs.contains( job ) ) return; // duplicate?
 
   d->jobs.insert( job, QStringList() );
 
@@ -164,8 +160,7 @@ void JobTracker::jobCreated( const QString & session, const QString & job, const
   info.state = JobInfo::Initial;
   info.timestamp = QDateTime::currentDateTime();
   info.type = jobType;
-  info.debugString = debugString;
-  d->infoList.insert( job, info );
+  d->infos.insert( job, info );
   const int id = d->lastId++;
   d->idToSequence.insert( job, id );
   d->sequenceToId.insert( id, job );
@@ -189,17 +184,16 @@ void JobTracker::jobCreated( const QString & session, const QString & job, const
 void JobTracker::jobEnded( const QString& job, const QString& error )
 {
   // this is called from dbus, so better be defensive
-  if ( d->disabled || !d->jobs.contains( job ) || !d->infoList.contains( job ) ) return;
+  if ( d->disabled || !d->jobs.contains( job ) || !d->infos.contains( job ) ) return;
 
-  JobInfo info = d->infoList[job];
+  JobInfo info = d->infos[job];
   if ( error.isEmpty() ) {
     info.state = JobInfo::Ended;
   } else {
     info.state = JobInfo::Failed;
     info.error = error;
   }
-  info.endedTimestamp = QDateTime::currentDateTime();
-  d->infoList[job] = info;
+  d->infos[job] = info;
 
   d->unpublishedUpdates << QPair<int, int>( d->jobs[jobForId(info.parent)].size()-1, info.parent );
   d->emitUpdated();
@@ -208,12 +202,11 @@ void JobTracker::jobEnded( const QString& job, const QString& error )
 void JobTracker::jobStarted( const QString & job )
 {
   // this is called from dbus, so better be defensive
-  if ( d->disabled || !d->jobs.contains( job ) || !d->infoList.contains( job ) ) return;
+  if ( d->disabled || !d->jobs.contains( job ) || !d->infos.contains( job ) ) return;
 
-  JobInfo info = d->infoList[job];
+  JobInfo info = d->infos[job];
   info.state = JobInfo::Running;
-  info.startedTimestamp = QDateTime::currentDateTime();
-  d->infoList[job] = info;
+  d->infos[job] = info;
 
   d->unpublishedUpdates << QPair<int, int>( d->jobs[jobForId(info.parent)].size()-1, info.parent );
   d->emitUpdated();
@@ -235,11 +228,11 @@ QList<JobInfo> JobTracker::jobs( const QString & parent ) const
 {
   assert( d->jobs.contains(parent) );
   const QStringList jobs = d->jobs.value(parent);
-  QList<JobInfo> infoList;
+  QList<JobInfo> infos;
   Q_FOREACH( const QString &job, jobs ) {
-    infoList << d->infoList.value(job);
+    infos << d->infos.value(job);
   }
-  return infoList;
+  return infos;
 }
 
 QStringList JobTracker::jobNames(int id) const
@@ -294,7 +287,7 @@ int JobTracker::parentId( int id ) const
   else
   {
     const QString job = d->sequenceToId.value(id);
-    return d->infoList[job].parent;
+    return d->infos[job].parent;
   }
 
 }
@@ -306,8 +299,8 @@ JobInfo JobTracker::info( int id) const
 
 JobInfo JobTracker::info(const QString & job) const
 {
-  assert( d->infoList.contains(job) );
-  return d->infoList.value(job);
+  assert( d->infos.contains(job) );
+  return d->infos.value(job);
 }
 
 void JobTracker::triggerReset()
@@ -316,7 +309,7 @@ void JobTracker::triggerReset()
   d->idToSequence.clear();
   d->sequenceToId.clear();
   d->jobs.clear();
-  d->infoList.clear();
+  d->infos.clear();
 
   emit reset();
 }
@@ -339,3 +332,4 @@ void JobTracker::signalUpdates()
   d->unpublishedUpdates.clear();
 }
 
+#include "jobtracker.moc"
