@@ -19,13 +19,11 @@
     USA.
 */
 
-#ifndef AKONADICONSOLE_JOBTRACKERWIDGET_H
-#define AKONADICONSOLE_JOBTRACKERWIDGET_H
+#ifndef JOBTRACKERWIDGET_H
+#define JOBTRACKERWIDGET_H
 
-#include <QWidget>
+#include <QtGui/QWidget>
 
-class QModelIndex;
-class QFile;
 class JobTrackerWidget : public QWidget
 {
   Q_OBJECT
@@ -35,11 +33,8 @@ class JobTrackerWidget : public QWidget
     ~JobTrackerWidget();
   private slots:
     void contextMenu(const QPoint& pos);
-    void slotSaveToFile();
 
   private:
-    void writeRows( const QModelIndex &parent, QFile &file, int indentLevel );
-
     class Private;
     Private* const d;
 };
