@@ -18,26 +18,26 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
     USA.
 */
-#ifndef AKONADICONSOLE_SEARCHDIALOG_H
-#define AKONADICONSOLE_SEARCHDIALOG_H
+#ifndef SEARCHDIALOG_H
+#define SEARCHDIALOG_H
 
 #include <kdialog.h>
 
-class KLineEdit;
-class KTextEdit;
+class QLineEdit;
+class QTextEdit;
 
 class SearchDialog : public KDialog
 {
   public:
-    explicit SearchDialog( QWidget *parent = 0 );
+    SearchDialog( QWidget *parent = 0 );
     ~SearchDialog();
 
     QString searchName() const;
     QString searchQuery() const;
 
   private:
-    KLineEdit *mName;
-    KTextEdit *mEdit;
+    QLineEdit* mName;
+    QTextEdit* mEdit;
 };
 
 #endif
