@@ -23,15 +23,16 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include "aboutdata.h"
-#include "actionmanagerimpl.h"
 #include "akregatorconfig.h"
 #include "akregator_part.h"
+#include "aboutdata.h"
+#include "actionmanagerimpl.h"
 #include "article.h"
 #include "fetchqueue.h"
 #include "feediconmanager.h"
 #include "framemanager.h"
 #include "kernel.h"
+#include "loadfeedlistcommand.h"
 #include "mainwidget.h"
 #include "notificationmanager.h"
 #include "plugin.h"
@@ -42,9 +43,14 @@
 #include "trayicon.h"
 #include "dummystorage/storagefactorydummyimpl.h"
 
+#include <libkdepim/broadcaststatus.h>
+#include "kdepim-version.h"
+
+#include <KActionCollection>
 #include <knotifyconfigwidget.h>
 #include <kaboutdata.h>
 #include <kapplication.h>
+#include <KCmdLineArgs>
 #include <kconfig.h>
 #include <kconfigdialog.h>
 #include <kfiledialog.h>
@@ -56,7 +62,7 @@
 #include <kservice.h>
 #include <kxmlguifactory.h>
 #include <kio/netaccess.h>
-#include <KParts/GenericFactory>
+#include <KPluginFactory>
 #include <KParts/Plugin>
 #include <KCMultiDialog>
 #include <kstandardaction.h>
@@ -70,6 +76,80 @@
 #include <QDomDocument>
 #include "partadaptor.h"
 
+#include <memory>
+
+using namespace boost;
+
+namespace {
+
+    static QDomDocument createDefaultFeedList() {
+        QDomDocument doc;
+        QDomProcessingInstruction z = doc.createProcessingInstruction("xml","version=\"1.0\" encoding=\"UTF-8\"");
+        doc.appendChild( z );
+
+        QDomElement root = doc.createElement( "opml" );
+        root.setAttribute("version","1.0");
+        doc.appendChild( root );
+
+        QDomElement head = doc.createElement( "head" );
+        root.appendChild(head);
+
+        QDomElement text = doc.createElement( "text" );
+        text.appendChild(doc.createTextNode(i18n("Feeds")));
+        head.appendChild(text);
+
+        QDomElement body = doc.createElement( "body" );
+        root.appendChild(body);
+
+        QDomElement mainFolder = doc.createElement( "outline" );
+        mainFolder.setAttribute("text","KDE");
+        body.appendChild(mainFolder);
+
+        /* 
+        // NOTE: If these feeds ever get updated again, reenable them.
+        //       For now I (Bertjan, July 2010) just disable them to
+        //       make the default feeds non-embarassing (these are
+        //       still updated regularly.
+        QDomElement ak = doc.createElement( "outline" );
+        ak.setAttribute("text",i18n("Akregator News"));
+        ak.setAttribute("xmlUrl","http://akregator.sf.net/rss2.php");
+        mainFolder.appendChild(ak);
+
+        QDomElement akb = doc.createElement( "outline" );
+        akb.setAttribute("text",i18n("Akregator Blog"));
+        akb.setAttribute("xmlUrl","http://akregator.pwsp.net/blog/?feed=rss2");
+        mainFolder.appendChild(akb);
+        */
+
+        QDomElement dot = doc.createElement( "outline" );
+        dot.setAttribute("text",i18n("KDE Dot News"));
+        dot.setAttribute("xmlUrl","http://www.kde.org/dotkdeorg.rdf");
+        mainFolder.appendChild(dot);
+
+        QDomElement planetkde = doc.createElement( "outline" );
+        planetkde.setAttribute("text",i18n("Planet KDE"));
+        planetkde.setAttribute("xmlUrl","http://planetkde.org/rss20.xml");
+        mainFolder.appendChild(planetkde);
+
+        QDomElement planetkdepim = doc.createElement( "outline" );
+        planetkdepim.setAttribute("text",i18n("Planet KDE PIM"));
+        planetkdepim.setAttribute("xmlUrl","http://pim.planetkde.org/rss20.xml");
+        mainFolder.appendChild(planetkdepim);
+
+        QDomElement apps = doc.createElement( "outline" );
+        apps.setAttribute("text",i18n("KDE Apps"));
+        apps.setAttribute("xmlUrl","http://www.kde.org/dot/kde-apps-content.rdf");
+        mainFolder.appendChild(apps);
+
+        QDomElement look = doc.createElement( "outline" );
+        look.setAttribute("text",i18n("KDE Look"));
+        look.setAttribute("xmlUrl","http://www.kde.org/kde-look-content.rdf");
+        mainFolder.appendChild(look);
+
+        return doc;
+    }
+}
+
 namespace Akregator {
 
 static const KAboutData &createAboutData()
@@ -97,6 +177,7 @@ Part::Part( QWidget *parentWidget, QObject *parent, const QVariantList& )
     : inherited(parent)
     , m_standardListLoaded(false)
     , m_shuttingDown(false)
+    , m_doCrashSave(true)
     , m_backedUpList(false)
     , m_mainWidget(0)
     , m_storage(0)
@@ -120,8 +201,11 @@ Part::Part( QWidget *parentWidget, QObject *parent, const QVariantList& )
     m_standardFeedList = KGlobal::dirs()->saveLocation("data", "akregator/data") + "/feeds.opml";
 
     Backend::StorageFactoryDummyImpl* dummyFactory = new Backend::StorageFactoryDummyImpl();
-    Backend::StorageFactoryRegistry::self()->registerFactory(dummyFactory, dummyFactory->key());
-    loadStoragePlugins(); // FIXME: also unload them!
+    if (!Backend::StorageFactoryRegistry::self()->registerFactory(dummyFactory, dummyFactory->key())) {
+        // There was already a dummy factory registered.
+        delete dummyFactory;
+    }
+    loadPlugins( QLatin1String("storage") ); // FIXME: also unload them!
 
     m_storage = 0;
     Backend::StorageFactory* storageFactory = Backend::StorageFactoryRegistry::self()->getFactory(Settings::archiveBackend());
@@ -144,32 +228,35 @@ Part::Part( QWidget *parentWidget, QObject *parent, const QVariantList& )
     m_mainWidget = new Akregator::MainWidget(this, parentWidget, m_actionManager, "akregator_view");
     m_extension = new BrowserExtension(this, "ak_extension");
 
-    connect(Kernel::self()->frameManager(), SIGNAL(signalCaptionChanged(const QString&)), this, SIGNAL(setWindowCaption(const QString&)));
-    connect(Kernel::self()->frameManager(), SIGNAL(signalStatusText(const QString&)), this, SIGNAL(setStatusBarText(const QString&)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalCaptionChanged(QString)), this, SIGNAL(setWindowCaption(QString)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalStatusText(QString)), this, SLOT(slotSetStatusText(QString)));
     connect(Kernel::self()->frameManager(), SIGNAL(signalLoadingProgress(int)), m_extension, SIGNAL(loadingProgress(int)));
-    connect(Kernel::self()->frameManager(), SIGNAL(signalCanceled(const QString&)), this, SIGNAL(canceled(const QString&)));
+    connect(Kernel::self()->frameManager(), SIGNAL(signalCanceled(QString)), this, SIGNAL(canceled(QString)));
     connect(Kernel::self()->frameManager(), SIGNAL(signalStarted()), this, SLOT(slotStarted()));
     connect(Kernel::self()->frameManager(), SIGNAL(signalCompleted()), this, SIGNAL(completed()));
 
     // notify the part that this is our internal widget
     setWidget(m_mainWidget);
 
-    TrayIcon* trayIcon = new TrayIcon( m_mainWidget->window() );
-    TrayIcon::setInstance(trayIcon);
-    m_actionManager->initTrayIcon(trayIcon);
+    if ( Settings::showTrayIcon() && !TrayIcon::getInstance() )
+    {
+        TrayIcon* trayIcon = new TrayIcon( m_mainWidget->window() );
+        TrayIcon::setInstance(trayIcon);
+        m_actionManager->setTrayIcon(trayIcon);
 
-    connect(trayIcon, SIGNAL(toggleShowPart()), this, SIGNAL(toggleShowPart()));
+        if ( isTrayIconEnabled() )
+            trayIcon->setStatus( KStatusNotifierItem::Active );
 
-    if ( isTrayIconEnabled() )
-        trayIcon->show();
+        QWidget* const notificationParent = isTrayIconEnabled() ? m_mainWidget->window() : 0;
+        NotificationManager::self()->setWidget(notificationParent, componentData());
 
-    QWidget* const notificationParent = isTrayIconEnabled() ? m_mainWidget->window() : 0;
-    NotificationManager::self()->setWidget(notificationParent, componentData());
+        QAction* action = TrayIcon::getInstance()->actionCollection()->action(KStandardAction::name(KStandardAction::Quit));
+        connect(action, SIGNAL(triggered(bool)), kapp, SLOT(quit()));
 
-    connect( trayIcon, SIGNAL(quitSelected()),
-            kapp, SLOT(quit())) ;
-
-    connect( m_mainWidget, SIGNAL(signalUnreadCountChanged(int)), trayIcon, SLOT(slotSetUnread(int)) );
+        connect( m_mainWidget, SIGNAL(signalUnreadCountChanged(int)), trayIcon, SLOT(slotSetUnread(int)) );
+        connect( m_mainWidget, SIGNAL(signalArticlesSelected(QList<Akregator::Article>)),
+                this, SIGNAL(signalArticlesSelected(QList<Akregator::Article>)) );
+    }
 
     connect(kapp, SIGNAL(aboutToQuit()), this, SLOT(slotOnShutdown()));
 
@@ -177,23 +264,29 @@ Part::Part( QWidget *parentWidget, QObject *parent, const QVariantList& )
     connect(m_autosaveTimer, SIGNAL(timeout()), this, SLOT(slotSaveFeedList()));
     m_autosaveTimer->start(5*60*1000); // 5 minutes
 
-    QString useragent = QString( "Akregator/%1; syndication" ).arg( AKREGATOR_VERSION );
+    QString useragent = QString( "Akregator/%1; syndication" ).arg( KDEPIM_VERSION );
 
     if( !Settings::customUserAgent().isEmpty() )
         useragent = Settings::customUserAgent();
 
     Syndication::FileRetriever::setUserAgent( useragent );
+
+    loadPlugins( QLatin1String("extension") ); // FIXME: also unload them!
+
+    if (!readCrashProperties())
+            autoReadProperties();
 }
 
-
-void Part::loadStoragePlugins()
+void Part::loadPlugins( const QString& type )
 {
-    KService::List offers = PluginManager::query( "[X-KDE-akregator-plugintype] == 'storage'" );
-    for ( KService::List::ConstIterator it = offers.constBegin(), end = offers.constEnd(); it != end; ++it )
-    {
-        Akregator::Plugin* plugin = PluginManager::createFromService(*it);
-        if (plugin)
-            plugin->initialize();
+    const KService::List offers = PluginManager::query( QString::fromLatin1("[X-KDE-akregator-plugintype] == '%1'").arg( type ) );
+
+    Q_FOREACH ( const KService::Ptr& i, offers ) {
+        Akregator::Plugin* plugin = PluginManager::createFromService( i, this );
+        if ( !plugin )
+            continue;
+        plugin->initialize();
+        plugin->insertGuiClients( this );
     }
 }
 
@@ -204,6 +297,7 @@ void Part::slotStarted()
 
 void Part::slotOnShutdown()
 {
+    autoSaveProperties();
     m_shuttingDown = true;
     m_autosaveTimer->stop();
     saveSettings();
@@ -221,6 +315,33 @@ void Part::slotSettingsChanged()
 {
     NotificationManager::self()->setWidget(isTrayIconEnabled() ? m_mainWidget->window() : 0, componentData());
 
+    if ( Settings::showTrayIcon() && !TrayIcon::getInstance() )
+    {
+        TrayIcon* trayIcon = new TrayIcon( m_mainWidget->window() );
+        TrayIcon::setInstance(trayIcon);
+        m_actionManager->setTrayIcon(trayIcon);
+
+        if ( isTrayIconEnabled() )
+            trayIcon->setStatus( KStatusNotifierItem::Active );
+
+        QAction *action;
+        action = TrayIcon::getInstance()->actionCollection()->action(KStandardAction::name(KStandardAction::Quit));
+        connect(action, SIGNAL(triggered(bool)), kapp, SLOT(quit()));
+
+        connect( m_mainWidget, SIGNAL(signalUnreadCountChanged(int)), trayIcon, SLOT(slotSetUnread(int)) );
+        connect( m_mainWidget, SIGNAL(signalArticlesSelected(QList<Akregator::Article>)),
+                this, SIGNAL(signalArticlesSelected(QList<Akregator::Article>)) );
+
+        m_mainWidget->slotSetTotalUnread();
+    }
+    if ( !Settings::showTrayIcon() )
+    {
+        TrayIcon::getInstance()->disconnect();
+        delete TrayIcon::getInstance();
+        TrayIcon::setInstance(0);
+        m_actionManager->setTrayIcon(0);
+    }
+
     Syndication::FileRetriever::setUseCache(Settings::useHTMLCache());
 
     QStringList fonts;
@@ -238,6 +359,12 @@ void Part::slotSettingsChanged()
     saveSettings();
     emit signalSettingsChanged();
 }
+
+void Part::slotSetStatusText( const QString& statusText )
+{
+  KPIM::BroadcastStatus::instance()->setStatusMsg( statusText );
+}
+
 void Part::saveSettings()
 {
     m_mainWidget->saveSettings();
@@ -272,140 +399,28 @@ void Part::saveProperties(KConfigGroup & config)
 
 bool Part::openUrl(const KUrl& url)
 {
-    setLocalFilePath(url.path());
+    setLocalFilePath(url.toLocalFile());
     return openFile();
 }
 
 void Part::openStandardFeedList()
 {
-    if ( !m_standardFeedList.isEmpty() && openUrl(KUrl::fromPath(m_standardFeedList)) )
-        m_standardListLoaded = true;
+    if ( !m_standardFeedList.isEmpty() )
+        openUrl( KUrl::fromPath( m_standardFeedList ) );
 }
 
-QDomDocument Part::createDefaultFeedList()
-{
-    QDomDocument doc;
-    QDomProcessingInstruction z = doc.createProcessingInstruction("xml","version=\"1.0\" encoding=\"UTF-8\"");
-    doc.appendChild( z );
-
-    QDomElement root = doc.createElement( "opml" );
-    root.setAttribute("version","1.0");
-    doc.appendChild( root );
-
-    QDomElement head = doc.createElement( "head" );
-    root.appendChild(head);
-
-    QDomElement text = doc.createElement( "text" );
-    text.appendChild(doc.createTextNode(i18n("Feeds")));
-    head.appendChild(text);
-
-    QDomElement body = doc.createElement( "body" );
-    root.appendChild(body);
-
-    QDomElement mainFolder = doc.createElement( "outline" );
-    mainFolder.setAttribute("text","KDE");
-    body.appendChild(mainFolder);
-
-    QDomElement ak = doc.createElement( "outline" );
-    ak.setAttribute("text",i18n("Akregator News"));
-    ak.setAttribute("xmlUrl","http://akregator.sf.net/rss2.php");
-    mainFolder.appendChild(ak);
-
-    QDomElement akb = doc.createElement( "outline" );
-    akb.setAttribute("text",i18n("Akregator Blog"));
-    akb.setAttribute("xmlUrl","http://akregator.pwsp.net/blog/?feed=rss2");
-    mainFolder.appendChild(akb);
-
-    QDomElement dot = doc.createElement( "outline" );
-    dot.setAttribute("text",i18n("KDE Dot News"));
-    dot.setAttribute("xmlUrl","http://www.kde.org/dotkdeorg.rdf");
-    mainFolder.appendChild(dot);
-
-    QDomElement plan = doc.createElement( "outline" );
-    plan.setAttribute("text",i18n("Planet KDE"));
-    plan.setAttribute("xmlUrl","http://planetkde.org/rss20.xml");
-    mainFolder.appendChild(plan);
-
-    QDomElement apps = doc.createElement( "outline" );
-    apps.setAttribute("text",i18n("KDE Apps"));
-    apps.setAttribute("xmlUrl","http://www.kde.org/dot/kde-apps-content.rdf");
-    mainFolder.appendChild(apps);
-
-    QDomElement look = doc.createElement( "outline" );
-    look.setAttribute("text",i18n("KDE Look"));
-    look.setAttribute("xmlUrl","http://www.kde.org/kde-look-content.rdf");
-    mainFolder.appendChild(look);
-
-    return doc;
-}
-
-bool Part::openFile()
-{
-    emit setStatusBarText(i18n("Opening Feed List...") );
-
-    QString str;
-    // m_file is always local so we can use QFile on it
-    QFile file(localFilePath());
-
-    bool fileExists = file.exists();
-    QString listBackup = m_storage->restoreFeedList();
-
-    QDomDocument doc;
-
-    if (!fileExists)
-    {
-        doc = createDefaultFeedList();
-    }
-    else
-    {
-        if (file.open(QIODevice::ReadOnly))
-        {
-            // Read OPML feeds list and build QDom tree.
-            QTextStream stream(&file);
-            stream.setCodec("UTF-8"); // FIXME not all opmls are in utf8
-            str = stream.readAll();
-            file.close();
-        }
-
-        if (!doc.setContent(str))
-        {
-
-            QString backup = localFilePath()
-                + QLatin1String("-backup.")
-                + QString::number(QDateTime::currentDateTime().toTime_t());
-
-            if ( QFile::copy( localFilePath(), backup ) )
-                KMessageBox::error(m_mainWidget, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%1</b></p></qt>", backup), i18n("XML Parsing Error") );
-            else
-                KMessageBox::error(m_mainWidget, i18n("<qt>The standard feed list is corrupted (invalid XML). Could not create a backup!</p></qt>" ), i18n("XML Parsing Error") );
-
-            if (!doc.setContent(listBackup))
-                doc = createDefaultFeedList();
-        }
-    }
-
-    if (!m_mainWidget->loadFeeds(doc))
-    {
-        QString backup = localFilePath()
-            + QLatin1String("-backup.")
-            + QString::number(QDateTime::currentDateTime().toTime_t());
-
-        if ( QFile::copy( localFilePath(), backup ) )
-            KMessageBox::error(m_mainWidget, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup of the previous list was created:<p><b>%1</b></p></qt>", backup), i18n("OPML Parsing Error") );
-        else
-            KMessageBox::error(m_mainWidget, i18n("<qt>The standard feed list is corrupted (no valid OPML). Could not create a backup!></p></qt>" ), i18n("OPML Parsing Error") );
-        m_mainWidget->loadFeeds(createDefaultFeedList());
-    }
-
-    emit setStatusBarText(QString::null);	//krazy:exclude=nullstrassign for old broken gcc
-
-
-    if( Settings::markAllFeedsReadOnStartup() )
-        m_mainWidget->slotMarkAllFeedsRead();
-
-    if (Settings::fetchOnStartup())
-            m_mainWidget->slotFetchAllFeeds();
-
+bool Part::openFile() {
+    if ( m_loadFeedListCommand || m_standardListLoaded )
+        return true;
+    std::auto_ptr<LoadFeedListCommand> cmd( new LoadFeedListCommand( m_mainWidget ) );
+    cmd->setParentWidget( m_mainWidget );
+    cmd->setStorage( Kernel::self()->storage() );
+    cmd->setFileName( localFilePath() );
+    cmd->setDefaultFeedList( createDefaultFeedList() );
+    connect( cmd.get(), SIGNAL(result(boost::shared_ptr<Akregator::FeedList>)),
+             this, SLOT(feedListLoaded(boost::shared_ptr<Akregator::FeedList>)) );
+    m_loadFeedListCommand = cmd.release();
+    m_loadFeedListCommand->start();
     return true;
 }
 
@@ -419,6 +434,29 @@ bool Part::writeToTextFile( const QString& data, const QString& filename ) const
     return file.finalize();
 }
 
+void Part::feedListLoaded( const shared_ptr<FeedList>& list ) {
+    assert( !m_standardListLoaded );
+    m_mainWidget->setFeedList( list );
+    m_standardListLoaded = list != 0;
+
+    if( Settings::markAllFeedsReadOnStartup() )
+        m_mainWidget->slotMarkAllFeedsRead();
+
+    if ( m_standardListLoaded )
+        QTimer::singleShot( 0, this, SLOT(flushAddFeedRequests()) );
+
+    if (Settings::fetchOnStartup())
+        m_mainWidget->slotFetchAllFeeds();
+}
+
+void Part::flushAddFeedRequests() {
+    Q_FOREACH( const AddFeedRequest& i, m_requests ) {
+        Q_FOREACH ( const QString& j, i.urls )
+            m_mainWidget->addFeedToGroup( j, i.group );
+        NotificationManager::self()->slotNotifyFeeds( i.urls );
+    }
+    m_requests.clear();
+}
 
 void Part::slotSaveFeedList()
 {
@@ -441,7 +479,7 @@ void Part::slotSaveFeedList()
 
     KMessageBox::error( m_mainWidget,
                         i18n( "Access denied: Cannot save feed list to <b>%1</b>. Please check your permissions.", localFilePath() ),
-                        i18n( "Write error" ) );
+                        i18n( "Write Error" ) );
 }
 
 bool Part::isTrayIconEnabled() const
@@ -456,7 +494,7 @@ void Part::importFile(const KUrl& url)
     bool isRemote = false;
 
     if (url.isLocalFile())
-        filename = url.path();
+        filename = url.toLocalFile();
     else
     {
         isRemote = true;
@@ -474,7 +512,7 @@ void Part::importFile(const KUrl& url)
         // Read OPML feeds list and build QDom tree.
         QDomDocument doc;
         if (doc.setContent(file.readAll()))
-            m_mainWidget->importFeeds(doc);
+            m_mainWidget->importFeedList( doc );
         else
             KMessageBox::error(m_mainWidget, i18n("Could not import the file %1 (no valid OPML)", filename), i18n("OPML Parsing Error") );
     }
@@ -489,7 +527,7 @@ void Part::exportFile(const KUrl& url)
 {
     if (url.isLocalFile())
     {
-        const QString fname = url.path();
+        const QString fname = url.toLocalFile();
 
         if ( QFile::exists( fname ) &&
                 KMessageBox::questionYesNo(m_mainWidget,
@@ -552,12 +590,12 @@ void Part::fetchFeedUrl(const QString&s)
 
 void Part::addFeedsToGroup(const QStringList& urls, const QString& group)
 {
-    for (QStringList::ConstIterator it = urls.begin(); it != urls.end(); ++it)
-    {
-        kDebug() <<"Akregator::Part::addFeedToGroup adding feed with URL" << *it <<" to group" << group;
-        m_mainWidget->addFeedToGroup(*it, group);
-    }
-    NotificationManager::self()->slotNotifyFeeds(urls);
+    AddFeedRequest req;
+    req.group = group;
+    req.urls = urls;
+    m_requests.append( req );
+    if ( m_standardListLoaded )
+        flushAddFeedRequests();
 }
 
 void Part::addFeed()
@@ -565,11 +603,10 @@ void Part::addFeed()
     m_mainWidget->slotFeedAdd();
 }
 
-void Part::showKNotifyOptions()
+void Part::showNotificationOptions()
 {
-    KAboutData* about = new Akregator::AboutData;
-    KNotifyConfigWidget::configure(m_mainWidget, about->appName() );
-    delete about;
+    const Akregator::AboutData about;
+    KNotifyConfigWidget::configure(m_mainWidget, about.appName() );
 }
 
 void Part::showOptions()
@@ -579,23 +616,15 @@ void Part::showOptions()
     if ( !m_dialog ) {
         m_dialog = new KCMultiDialog( m_mainWidget );
         connect( m_dialog, SIGNAL(configCommitted()),
-                 this, SLOT(slotSettingsChanged()) );
+                this, SLOT(slotSettingsChanged()) );
         connect( m_dialog, SIGNAL(configCommitted()),
-                 TrayIcon::getInstance(), SLOT(settingsChanged()) );
+                TrayIcon::getInstance(), SLOT(settingsChanged()) );
 
-        QStringList modules;
-
-        modules.append( "akregator_config_general.desktop" );
-        modules.append( "akregator_config_onlinesync.desktop" );
-        modules.append( "akregator_config_archive.desktop" );
-        modules.append( "akregator_config_appearance.desktop" );
-        modules.append( "akregator_config_browser.desktop" );
-        modules.append( "akregator_config_advanced.desktop" );
-
-        // add them all
-        QStringList::iterator mit;
-        for ( mit = modules.begin(); mit != modules.end(); ++mit ) {
-            m_dialog->addModule( *mit );
+        // query for akregator's kcm modules
+        const QString constraint = "[X-KDE-ParentApp] == 'akregator'";
+        const KService::List offers = KServiceTypeTrader::self()->query( "KCModule", constraint );
+        foreach( const KService::Ptr &service, offers ) {
+            m_dialog->addModule( service->storageId() );
         }
     }
 
@@ -683,7 +712,107 @@ void Part::initFonts()
             underline = konq.readEntry("UnderlineLinks", false);
         Settings::setUnderlineLinks(underline);
     }
+}
 
+bool Part::handleCommandLine() {
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    QString addFeedGroup = !args->getOption("group").isEmpty() ?
+         args->getOption("group")
+         : i18n("Imported Folder");
+
+    QStringList feedsToAdd = args->getOptionList("addfeed");
+
+    if (feedsToAdd.isEmpty() && args->count() > 0) {
+        QString url = args->url(0).url();
+        if(!url.isEmpty())
+            feedsToAdd.append(url);
+    }
+
+    if (!feedsToAdd.isEmpty())
+        addFeedsToGroup( feedsToAdd, addFeedGroup );
+    return true;
+}
+
+void Part::clearCrashProperties()
+{
+    if (!m_doCrashSave)
+        return;
+    KConfig config("crashed", KConfig::SimpleConfig,
+        "appdata");
+    KConfigGroup configGroup(&config, "Part");
+    configGroup.writeEntry("crashed", false);
+}
+
+
+void Part::saveCrashProperties()
+{
+    if (!m_doCrashSave)
+        return;
+    KConfig config("crashed", KConfig::SimpleConfig,
+        "appdata");
+    KConfigGroup configGroup(&config, "Part");
+    configGroup.deleteGroup();
+
+    configGroup.writeEntry("crashed", true);
+
+    saveProperties(configGroup);
+}
+
+bool Part::readCrashProperties()
+{
+    KConfig config("crashed", KConfig::SimpleConfig,
+        "appdata");
+    KConfigGroup configGroup(&config, "Part");
+
+    if (!configGroup.readEntry("crashed", false))
+        return false;
+
+    const int choice = KMessageBox::questionYesNoCancel( m_mainWidget,
+            i18n("Akregator did not close correctly. Would you like to restore the previous session?"),
+            i18n("Restore Session?"),
+            KGuiItem(i18n("Restore Session"), "window-new"),
+            KGuiItem(i18n("Do Not Restore"), "dialog-close"),
+            KGuiItem(i18n("Ask Me Later"), "chronometer"),
+            "Restore session when akregator didn't close correctly" );
+    switch ( choice ) { 
+    case KMessageBox::Yes:
+        readProperties(configGroup);
+        return true;
+    case KMessageBox::No:
+        clearCrashProperties();
+        return false;
+    default:
+        break;
+    }
+    m_doCrashSave = false;
+    return false;
+}
+
+void Part::slotAutoSave()
+{
+    saveCrashProperties();
+}
+
+void Part::autoSaveProperties()
+{
+    KConfig config("autosaved", KConfig::SimpleConfig, "appdata");
+    KConfigGroup configGroup(&config, "Part");
+    configGroup.deleteGroup();
+
+    saveProperties(configGroup);
+
+    clearCrashProperties();
+}
+
+void Part::autoReadProperties()
+{
+    if(kapp->isSessionRestored())
+        return;
+
+    KConfig config("autosaved", KConfig::SimpleConfig, "appdata");
+    KConfigGroup configGroup(&config, "Part");
+
+    readProperties(configGroup);
 }
 
 } // namespace Akregator
