@@ -210,7 +210,11 @@ QVector<Feed*> Feed::feeds()
 
 Article Feed::findArticle(const QString& guid) const
 {
-    return d->articles[guid];
+  Article a;
+  if ( !d->articles.isEmpty() ) {
+    a = d->articles[guid];
+  }
+  return a;
 }
 
 QList<Article> Feed::articles()
@@ -230,7 +234,7 @@ void Feed::loadArticles()
     if (d->articlesLoaded)
         return;
 
-    if (!d->archive)
+    if (!d->archive && d->storage)
         d->archive = d->storage->archiveFor(xmlUrl());
 
     QStringList list = d->archive->articles();
@@ -607,7 +611,7 @@ void Feed::tryFetch()
     d->loader = Syndication::Loader::create( this, SLOT(fetchCompleted(Syndication::Loader*,
                                                                        Syndication::FeedPtr,
                                                                        Syndication::ErrorCode)) );
-    //connect(d->loader, SIGNAL(progress(unsigned long)), this, SLOT(slotSetProgress(unsigned long)));
+    //connect(d->loader, SIGNAL(progress(ulong)), this, SLOT(slotSetProgress(ulong)));
     d->loader->loadFrom( d->xmlUrl);
 }
 
@@ -663,7 +667,7 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
         if (false) // d->imagePixmap.isNull() && doc.image())
         {
             //d->image = *doc.image();
-            //connect(&d->image, SIGNAL(gotPixmap(const QPixmap&)), this, SLOT(slotImageFetched(const QPixmap&)));
+            //connect(&d->image, SIGNAL(gotPixmap(QPixmap)), this, SLOT(slotImageFetched(QPixmap)));
             //d->image.getPixmap();
         }
     }
