@@ -42,7 +42,8 @@
 #include <kmenu.h>
 #include <krun.h>
 #include <klocale.h>
-#include <KIcon>
+#include <khtmlview.h>
+#include <khtml_part.h>
 #include <kiconloader.h>
 #include <ktoolinvocation.h>
 #include <kurl.h>
@@ -67,7 +68,7 @@ private:
     TabWidget* const q;
 
 public:
-    explicit Private( TabWidget * qq ) : q( qq ), currentMaxLength( 30 ), currentItem( 0 ), tabsClose( 0 ) {}
+    explicit Private( TabWidget * qq ) : q( qq ), currentMaxLength( 30 ), currentItem( 0 ) {}
 
     QHash<QWidget*, Frame*> frames;
     QHash<int, Frame*> framesById;
@@ -112,13 +113,8 @@ TabWidget::TabWidget(QWidget * parent)
     d->tabsClose->setEnabled( false );
     d->tabsClose->adjustSize();
     d->tabsClose->setToolTip( i18n("Close the current tab"));
-
-#ifndef QT_NO_ACCESSIBILITY
-    d->tabsClose->setAccessibleName( i18n( "Close tab" ) );
-#endif
-
     setCornerWidget( d->tabsClose, Qt::TopRightCorner );
-    d->updateTabBarVisibility();    
+    d->updateTabBarVisibility();
 }
 
 TabWidget::~TabWidget()
@@ -244,9 +240,10 @@ void TabWidget::slotRemoveFrame(int frameId)
 // copied wholesale from KonqFrameTabs
 uint TabWidget::Private::tabBarWidthForMaxChars( int maxLength )
 {
-    int hframe;
+    int hframe, overlap;
     QStyleOption o;
     hframe = q->tabBar()->style()->pixelMetric( QStyle::PM_TabBarTabHSpace, &o, q );
+    overlap = q->tabBar()->style()->pixelMetric( QStyle::PM_TabBarTabOverlap, &o, q );
 
     QFontMetrics fm = q->tabBar()->fontMetrics();
     int x = 0;
@@ -415,26 +412,12 @@ void TabWidget::initiateDrag(int tab)
     }
 }
 
-void TabWidget::slotReloadAllTabs()
-{
-  Q_FOREACH(Frame* frame,d->frames.values())
-  {
-    frame->slotReload();
-  }
-}
-
-
 void TabWidget::slotCloseRequest(QWidget* widget)
 {
     if (d->frames.value(widget))
         emit signalRemoveFrameRequest(d->frames.value(widget)->id());
 }
 
-void TabWidget::slotActivateTab()
-{
-    setCurrentIndex( sender()->objectName().right( 2 ).toInt() -1 );
-}
-
-
 } // namespace Akregator
 
+#include "tabwidget.moc"
