@@ -34,10 +34,10 @@ public:
     explicit SendToBlogDialog( bool isNew, bool isPrivate, QWidget *parent = 0 );
     ~SendToBlogDialog();
 
-    bool isPrivate() const;
-    bool isNew() const;
+    bool isPrivate();
+    bool isNew();
 public slots:
-    void accept();
+    virtual void accept();
 private:
     class Private;
     Private * const d;
