@@ -3,7 +3,6 @@
 
     Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
     Copyright (C) 2008-2010 Golnaz Nilieh <g382nilieh@gmail.com>
-    Copyright (C) 2013-2015 Laurent Montel <montel@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -25,20 +24,7 @@
 //krazy:excludeall=qmethods due to use of KStatusBar::showMessage()
 
 #include "toolbox.h"
-#include "dbman.h"
-#include "entriescountdialog.h"
-#include "addeditblog.h"
-#include "backend.h"
-#include "bilbopost.h"
-#include "bilboblog.h"
-#include "catcheckbox.h"
-#include "settings.h"
 
-#include <KMenu>
-#include <KAction>
-#include <KToolInvocation>
-#include <QClipboard>
-#include <QTimer>
 #include <kstatusbar.h>
 #include <kdebug.h>
 #include <kxmlguiwindow.h>
@@ -46,6 +32,21 @@
 #include <kdatetime.h>
 #include <kurl.h>
 
+#include "dbman.h"
+#include "entriescountdialog.h"
+#include "addeditblog.h"
+#include "backend.h"
+#include "bilbopost.h"
+#include "bilboblog.h"
+// #include "blogradiobutton.h"
+#include "catcheckbox.h"
+#include <KMenu>
+#include <KAction>
+#include <KToolInvocation>
+#include <settings.h>
+#include <QClipboard>
+#include <QTimer>
+
 class Toolbox::Private
 {
 public:
@@ -54,30 +55,40 @@ public:
     KStatusBar *statusbar;
 };
 Toolbox::Toolbox( QWidget *parent )
-    : QWidget( parent ), d(new Private)
+        : QWidget( parent ), d(new Private)
 {
+    kDebug();
     d->mCurrentBlogId = -1;
     if ( parent )
-        d->statusbar = qobject_cast<KXmlGuiWindow*>( parent )->statusBar();
+        this->d->statusbar = qobject_cast<KXmlGuiWindow*>( parent )->statusBar();
     else
-        d->statusbar = new KStatusBar( this );
+        this->d->statusbar = new KStatusBar( this );
     setupUi( this );
     setButtonsIcon();
+//     frameBlog->layout()->setAlignment( Qt::AlignTop );
     frameCat->layout()->setAlignment( Qt::AlignTop );
+//     reloadBlogList();
     optionsDate->setDate( QDateTime::currentDateTime().date() );
     optionsTime->setTime( QDateTime::currentDateTime().time() );
+//     connect( btnBlogAdd, SIGNAL(clicked()), this, SLOT(slotAddBlog()) );
+//     connect( btnBlogEdit, SIGNAL(clicked()), this, SLOT(slotEditBlog()) );
+//     connect( btnBlogRemove, SIGNAL(clicked()), this, SLOT(slotRemoveBlog()) );
 
     connect( btnCatReload, SIGNAL(clicked()), this, SLOT(slotReloadCategoryList()) );
     connect( btnEntriesUpdate, SIGNAL(clicked()), this, SLOT(slotUpdateEntries()) );
     connect( btnEntriesClear, SIGNAL(clicked(bool)), this, SLOT(clearEntries()) );
 
+//     connect( this, SIGNAL(sigCurrentBlogChanged(int)), this, SLOT(slotCurrentBlogChanged(int)) );
+//     connect( &listBlogRadioButtons, SIGNAL(buttonClicked(int)), this, SLOT(slotSetCurrentBlog()) );
+
     connect( lstEntriesList, SIGNAL(itemDoubleClicked(QListWidgetItem*)),
              this, SLOT(slotEntrySelected(QListWidgetItem*)) );
+//     connect( btnEntriesCopyUrl, SIGNAL(clicked(bool)), this, SLOT(slotEntriesCopyUrl()) );
     connect( btnEntriesRemove, SIGNAL(clicked(bool)), this, SLOT(slotRemoveSelectedEntryFromServer()) );
 
     connect( btnOptionsNow, SIGNAL(clicked(bool)), this, SLOT(setDateTimeNow()) );
-    connect( localEntries, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
-             this, SLOT(slotLocalEntrySelected(QTreeWidgetItem*,int)) );
+    connect( localEntriesTable, SIGNAL(cellDoubleClicked(int,int)),
+             this, SLOT(slotLocalEntrySelected(int,int)) );
     connect( btnLocalRemove, SIGNAL(clicked(bool)) , this, SLOT(slotRemoveLocalEntry()) );
 
     lblOptionsTrackBack->setVisible( false );
@@ -91,18 +102,15 @@ Toolbox::Toolbox( QWidget *parent )
     QTimer::singleShot(1000, this, SLOT(reloadLocalPosts()));
 }
 
-Toolbox::~Toolbox()
-{
-    delete d;
-}
-
-
 void Toolbox::setCurrentBlogId( int blog_id )
 {
-    if ( d->mCurrentBlogId == blog_id )
+    kDebug()<<blog_id;
+    if( d->mCurrentBlogId == blog_id )
         return;
+//     btnBlogEdit->setEnabled( true );
+//     btnBlogRemove->setEnabled( true );
     d->mCurrentBlogId = blog_id;
-    if ( blog_id <= 0 )
+    if( blog_id <= 0 )
         return;
     slotLoadCategoryListFromDB( blog_id );
     slotLoadEntriesFromDB( blog_id );
@@ -113,8 +121,11 @@ void Toolbox::setCurrentBlogId( int blog_id )
 
 void Toolbox::slotReloadCategoryList()
 {
+    kDebug();
+//     QAbstractButton *btn = listBlogRadioButtons.checkedButton();
     if ( d->mCurrentBlogId == -1 ) {
-        KMessageBox::sorry( this, i18n( "No blog has been selected: you have to select a blog from the Blogs page before asking for the list of categories." ) );
+        KMessageBox::sorry( this, i18n( "No blog has been selected: \
+you have to select a blog from the Blogs page before asking for the list of categories." ) );
         return;
     }
 
@@ -124,22 +135,25 @@ void Toolbox::slotReloadCategoryList()
     emit sigBusy( true );
     d->statusbar->showMessage( i18n( "Requesting list of categories..." ) );
     b->getCategoryListFromServer();
+//     this->setCursor( Qt::BusyCursor );
 }
 
 void Toolbox::slotUpdateEntries(int count)
 {
+    kDebug();
     if ( d->mCurrentBlogId == -1 ) {
-        KMessageBox::sorry( this, i18n( "No blog has been selected: you have to select a blog from the Blogs page before asking for the list of entries." ) );
+        KMessageBox::sorry( this, i18n( "No blog has been selected: \
+you have to select a blog from the Blogs page before asking for the list of entries." ) );
+        kDebug() << "There isn't any selected blog.";
         return;
     }
-    if (count == 0) {
+    if(count == 0) {
         count = Settings::updateEntriesCount();
-        if ( Settings::showUpdateEntriesDialog() ) {
+        if( Settings::showUpdateEntriesDialog() ) {
             QPointer<EntriesCountDialog> dia = new EntriesCountDialog( this );
-            if ( !dia->exec() ) {
-                delete dia;
+            dia->setAttribute( Qt::WA_DeleteOnClose, false );
+            if( dia->exec() == 0 )
                 return;
-            }
             count = dia->count();
             dia->deleteLater();
         }
@@ -149,36 +163,39 @@ void Toolbox::slotUpdateEntries(int count)
     connect( entryB, SIGNAL(sigEntriesListFetched(int)), this, SLOT(slotLoadEntriesFromDB(int)) );
     connect( entryB, SIGNAL(sigError(QString)), this, SIGNAL(sigError(QString)) );
     d->statusbar->showMessage( i18n( "Requesting list of entries..." ) );
-    setCursor( Qt::BusyCursor );
+    this->setCursor( Qt::BusyCursor );
     emit sigBusy( true );
 }
 
 void Toolbox::slotLoadEntriesFromDB( int blog_id )
 {
+    kDebug();
     if ( blog_id == -1 ) {
         kDebug() << "Blog Id doesn't set correctly";
         return;
     }
     lstEntriesList->clear();
-    const QList<QVariantMap> listEntries = DBMan::self()->listPostsInfo( blog_id );
-    const int count = listEntries.count();
+    QList<QVariantMap> listEntries;
+    listEntries = DBMan::self()->listPostsInfo( blog_id );
+    int count = listEntries.count();
     for ( int i=0; i < count; ++i ) {
-        QListWidgetItem *lstItem = new QListWidgetItem( listEntries[i].value(QLatin1String("title")).toString() );
-        lstItem->setToolTip(listEntries.at(i).value(QLatin1String("c_time")).toDateTime().toString());
-        if (listEntries.at(i).value(QLatin1String("is_private")).toBool()) {
+        QListWidgetItem *lstItem = new QListWidgetItem( listEntries[i].value("title").toString() );
+        lstItem->setToolTip(listEntries[i].value("c_time").toDateTime().toString());
+        if(listEntries[i].value("is_private").toBool()) {
             lstItem->setForeground(QBrush(Qt::blue));
-            lstItem->setToolTip(i18n("%1 (Draft)",lstItem->toolTip()));
+            lstItem->setToolTip(lstItem->toolTip() + " (Draft)");
         }
-        lstItem->setData( BlogEntryID, listEntries.at(i).value(QLatin1String("id")).toInt() );
+        lstItem->setData( 32, listEntries[i].value("id").toInt() );
         lstEntriesList->addItem( lstItem );
     }
     d->statusbar->showMessage( i18n( "List of entries received." ), STATUSTIMEOUT );
-    unsetCursor();
+    this->unsetCursor();
     emit sigBusy( false );
 }
 
 void Toolbox::slotLoadCategoryListFromDB( int blog_id )
 {
+    kDebug();
     if ( blog_id == -1 ) {
         kDebug() << "Blog Id do not sets correctly";
         return;
@@ -196,18 +213,19 @@ void Toolbox::slotLoadCategoryListFromDB( int blog_id )
         frameCat->layout()->addWidget( cb );
     }
     d->statusbar->showMessage( i18n( "List of categories received." ), STATUSTIMEOUT );
-    unsetCursor();
+    this->unsetCursor();
     emit sigBusy( false );
 }
 
 void Toolbox::slotRemoveSelectedEntryFromServer()
 {
-    if (lstEntriesList->selectedItems().count() < 1)
+    if(lstEntriesList->selectedItems().count() < 1)
         return;
-    if ( KMessageBox::warningYesNoCancel(this, i18n( "Removing a post from your blog cannot be undone.\nAre you sure you want to remove the post with title \"%1\" from your blog?", lstEntriesList->currentItem()->text() ))
+    if( KMessageBox::warningYesNoCancel(this, i18n( "Removing a post from your blog cannot be undone.\
+\nAre you sure you want to remove the post with title \"%1\" from your blog?", lstEntriesList->currentItem()->text() ))
     == KMessageBox::Yes) {
         BilboPost *post = new BilboPost( DBMan::self()->getPostInfo( lstEntriesList->currentItem()->
-                                                                     data(BlogEntryID).toInt() ) );
+                                                                     data(32).toInt() ) );
         Backend *b = new Backend( d->mCurrentBlogId, this);
         connect(b, SIGNAL(sigPostRemoved(int,BilboPost)), this, SLOT(slotPostRemoved(int,BilboPost)) );
         connect(b, SIGNAL(sigError(QString)), this, SLOT(slotError(QString)));
@@ -234,6 +252,7 @@ void Toolbox::slotError(const QString& errorMessage)
 
 void Toolbox::clearFields()
 {
+    kDebug();
     clearCatList();
     lstEntriesList->clear();
     txtCatTags->clear();
@@ -250,6 +269,7 @@ void Toolbox::clearFields()
 
 void Toolbox::resetFields()
 {
+    kDebug();
     unCheckCatList();
     txtCatTags->clear();
     chkOptionsTime->setChecked( false );
@@ -265,6 +285,7 @@ void Toolbox::resetFields()
 
 void Toolbox::clearCatList()
 {
+    kDebug();
     foreach( CatCheckBox* cat, d->listCategoryCheckBoxes ){
         cat->deleteLater();
     }
@@ -273,9 +294,10 @@ void Toolbox::clearCatList()
 
 void Toolbox::getFieldsValue( BilboPost* currentPost )
 {
-    currentPost->setCategoryList( selectedCategories() );
-    currentPost->setTags( currentTags() );
-    currentPost->setModifyTimeStamp( chkOptionsTime->isChecked() );
+    kDebug();
+    currentPost->setCategoryList( this->selectedCategories() );
+    currentPost->setTags( this->currentTags() );
+    currentPost->setModifyTimeStamp( this->chkOptionsTime->isChecked() );
     if ( currentPost->status() == KBlog::BlogPost::New ) {
         if ( chkOptionsTime->isChecked() ) {
             currentPost->setModificationDateTime( KDateTime( optionsDate->date(), optionsTime->time() ) );
@@ -288,7 +310,7 @@ void Toolbox::getFieldsValue( BilboPost* currentPost )
         currentPost->setCreationDateTime( KDateTime( optionsDate->date(), optionsTime->time() ) );
         currentPost->setModificationDateTime( KDateTime( optionsDate->date(), optionsTime->time() ) );
     }
-    if ( currentPost->creationDateTime().isUtc() || currentPost->modificationDateTime().isUtc() ){
+    if( currentPost->creationDateTime().isUtc() || currentPost->modificationDateTime().isUtc() ){
         kDebug()<<"creationDateTime was UTC!";
         currentPost->setCreationDateTime( KDateTime( currentPost->creationDateTime().dateTime(),
                                                     KDateTime::LocalZone ) );
@@ -304,6 +326,9 @@ void Toolbox::getFieldsValue( BilboPost* currentPost )
 
 void Toolbox::setFieldsValue( BilboPost* post )
 {
+    kDebug();
+//     kDebug()<<"New Post is: "<<post.toString();
+    //delete currentPost;
     if ( post == 0 ) {
         resetFields();
         kDebug()<<"post is NULL";
@@ -311,7 +336,7 @@ void Toolbox::setFieldsValue( BilboPost* post )
     }
 
     setSelectedCategories( post->categories() );
-    txtCatTags->setText( post->tags().join( QLatin1String(", ") ) );
+    txtCatTags->setText( post->tags().join( ", " ) );
 //     kDebug() << "Post status is: " << post->status();
     if ( post->status() == KBlog::BlogPost::New )
         comboOptionsStatus->setCurrentIndex( 2 );
@@ -322,7 +347,7 @@ void Toolbox::setFieldsValue( BilboPost* post )
     chkOptionsComments->setChecked( post->isCommentAllowed() );
     chkOptionsTrackback->setChecked( post->isTrackBackAllowed() );
     chkOptionsTime->setChecked( post->isModifyTimeStamp() );
-    if ( post->creationDateTime().isUtc() || post->modificationDateTime().isUtc() ){
+    if( post->creationDateTime().isUtc() || post->modificationDateTime().isUtc() ){
         kDebug()<<"creationDateTime was UTC!";
         post->setCreationDateTime(KDateTime(post->creationDateTime().dateTime(), KDateTime::LocalZone));
         post->setModificationDateTime(KDateTime(post->modificationDateTime().dateTime(), KDateTime::LocalZone));
@@ -333,24 +358,26 @@ void Toolbox::setFieldsValue( BilboPost* post )
     txtSummary->setPlainText( post->summary() );
 }
 
-QList< Category > Toolbox::selectedCategories() const
+QList< Category > Toolbox::selectedCategories()
 {
+    kDebug();
     QList<Category> list;
-    const int count = d->listCategoryCheckBoxes.count();
+    int count = d->listCategoryCheckBoxes.count();
     for ( int i = 0; i < count; ++i ) {
-        if ( d->listCategoryCheckBoxes.at(i)->isChecked() )
-            list.append( d->listCategoryCheckBoxes.at(i)->category() );
+        if ( d->listCategoryCheckBoxes[i]->isChecked() )
+            list.append( d->listCategoryCheckBoxes[i]->category() );
     }
     return list;
 }
 
-QStringList Toolbox::selectedCategoriesTitle() const
+QStringList Toolbox::selectedCategoriesTitle()
 {
+    kDebug();
     QStringList list;
-    const int count = d->listCategoryCheckBoxes.count();
+    int count = d->listCategoryCheckBoxes.count();
     for ( int i = 0; i < count; ++i ) {
-        if ( d->listCategoryCheckBoxes.at(i)->isChecked() )
-            list.append( d->listCategoryCheckBoxes.at(i)->category().name );
+        if ( d->listCategoryCheckBoxes[i]->isChecked() )
+            list.append( d->listCategoryCheckBoxes[i]->category().name );
     }
     return list;
 }
@@ -360,14 +387,16 @@ void Toolbox::setSelectedCategories( const QStringList &list )
     unCheckCatList();
     int count = d->listCategoryCheckBoxes.count();
     for ( int i = 0; i < count; ++i ) {
-        if ( list.contains( d->listCategoryCheckBoxes.at(i)->category().name, Qt::CaseInsensitive ) )
-            d->listCategoryCheckBoxes.at(i)->setChecked( true );
+        if ( list.contains( d->listCategoryCheckBoxes[i]->category().name, Qt::CaseInsensitive ) )
+            d->listCategoryCheckBoxes[i]->setChecked( true );
     }
 }
 
 QStringList Toolbox::currentTags()
 {
-    QStringList t = txtCatTags->text().split( QRegExp( QString::fromUtf8(",|،") ), QString::SkipEmptyParts );
+    kDebug();
+    QStringList t;
+    t = txtCatTags->text().split( QRegExp( QString::fromUtf8(",|،") ), QString::SkipEmptyParts );
     for ( int i = 0; i < t.count() ; ++i ) {
         t[i] = t[i].trimmed();
     }
@@ -376,7 +405,9 @@ QStringList Toolbox::currentTags()
 
 void Toolbox::slotEntrySelected( QListWidgetItem * item )
 {
-    BilboPost post = DBMan::self()->getPostInfo( item->data( BlogEntryID ).toInt() );
+    kDebug();
+//     setFieldsValue(*post);
+    BilboPost post = DBMan::self()->getPostInfo( item->data( 32 ).toInt() );
     kDebug() << "Emiting sigEntrySelected...";
     Q_EMIT sigEntrySelected( post, d->mCurrentBlogId );
 }
@@ -391,8 +422,8 @@ void Toolbox::slotEntriesCopyUrl()
     if ( lstEntriesList->currentItem() == 0 ) {
         return;
     }
-    BilboPost post = DBMan::self()->getPostInfo( lstEntriesList->currentItem()->data( BlogEntryID ).toInt() );
-    if ( !post.permaLink().isEmpty() )
+    BilboPost post = DBMan::self()->getPostInfo( lstEntriesList->currentItem()->data( 32 ).toInt() );
+    if( !post.permaLink().isEmpty() )
         QApplication::clipboard()->setText( post.permaLink().prettyUrl() );
     else if ( !post.link().isEmpty() )
         QApplication::clipboard()->setText( post.link().prettyUrl() );
@@ -400,61 +431,84 @@ void Toolbox::slotEntriesCopyUrl()
         KMessageBox::sorry(this, i18n( "No link field is available in the database for this entry." ) );
 }
 
+Toolbox::~Toolbox()
+{
+    kDebug();
+    delete d;
+}
+
 void Toolbox::unCheckCatList()
 {
-    const int count = d->listCategoryCheckBoxes.count();
+    int count = d->listCategoryCheckBoxes.count();
     for ( int j = 0; j < count; ++j ) {
-        d->listCategoryCheckBoxes.at(j)->setChecked( false );
+        d->listCategoryCheckBoxes[j]->setChecked( false );
     }
 }
 
 void Toolbox::setButtonsIcon()
 {
-    btnEntriesUpdate->setIcon( KIcon( QLatin1String("view-refresh") ) );
-    btnEntriesRemove->setIcon( KIcon( QLatin1String("list-remove") ) );
-    btnEntriesClear->setIcon( KIcon( QLatin1String("edit-clear") ) );
-    btnCatReload->setIcon( KIcon( QLatin1String("view-refresh") ) );
-    btnCatAdd->setIcon( KIcon( QLatin1String("list-add") ) );
-    btnLocalRemove->setIcon( KIcon( QLatin1String("list-remove") ) );
+//     btnEntriesReload->setIcon( KIcon( "view-refresh" ) );
+    btnEntriesUpdate->setIcon( KIcon( "arrow-down" ) );
+    btnEntriesRemove->setIcon( KIcon( "list-remove" ) );
+    btnEntriesClear->setIcon( KIcon( "edit-clear" ) );
+    btnCatReload->setIcon( KIcon( "view-refresh" ) );
+    btnCatAdd->setIcon( KIcon( "list-add" ) );
+    btnLocalRemove->setIcon( KIcon( "list-remove" ) );
     ///TODO Add option for selecting only text or only Icon for Toolbox buttons!
+//     btnEntriesReload->setText( QString() );
+//     btnEntriesUpdate->setText( QString() );
+//     btnEntriesRemove->setText( QString() );
+//     btnEntriesClear->setText( QString() );
+//     btnCatReload->setText( QString() );
+//     btnCatAdd->setText( QString() );
+//     btnLocalRemove->setText( QString() );
 }
 
 void Toolbox::reloadLocalPosts()
 {
     kDebug();
-
-    localEntries->clear();
-
+    localEntriesTable->clearContents();
+    localEntriesTable->setRowCount(0);
     QList<QVariantMap> localList = DBMan::self()->listLocalPosts();
-    const int count = localList.count();
-
+//     QList<QVariantMap>::ConstIterator it = localList.constBegin();
+//     QList<QVariantMap>::ConstIterator endIt = localList.constEnd();
+    int count = localList.count();
+    kDebug()<<count;
     for (int i=0; i < count; ++i){
-        const QString postTitle = localList.at(i).value( QLatin1String("post_title") ).toString();
-        const QString blogTitle = localList.at(i).value( QLatin1String("blog_title") ).toString();
-
-        QTreeWidgetItem *item = new QTreeWidgetItem( localEntries, QStringList()<<postTitle<<blogTitle );
-        item->setData(0, LocalEntryID, localList.at(i).value( QLatin1String("local_id") ).toInt());
-        item->setData(1, LocalEntryID, localList.at(i).value( QLatin1String("blog_id") ).toInt());
+        int newRow = localEntriesTable->rowCount();
+        localEntriesTable->insertRow(newRow);
+        QString postTitle = localList[i].value( "post_title" ).toString();
+        QTableWidgetItem *item1 = new QTableWidgetItem( postTitle );
+        item1->setToolTip( postTitle );
+        item1->setData(32, localList[i].value( "local_id" ).toInt());//Post_id
+        localEntriesTable->setItem( newRow, 0, item1 );
+        QString blogTitle = localList[i].value( "blog_title" ).toString();
+        QTableWidgetItem *item2 = new QTableWidgetItem( blogTitle );
+        item2->setToolTip( blogTitle );
+        item2->setData(32, localList[i].value( "blog_id" ).toInt());//blog_id
+        localEntriesTable->setItem( newRow, 1, item2 );
     }
 }
 
-void Toolbox::slotLocalEntrySelected( QTreeWidgetItem* item,int column )
+void Toolbox::slotLocalEntrySelected( int row, int column )
 {
     kDebug()<<"Emitting sigEntrySelected...";
     Q_UNUSED(column);
-    BilboPost post = DBMan::self()->localPost(item->data(0, LocalEntryID).toInt());
-    emit sigEntrySelected( post, item->data(1, LocalEntryID).toInt() );
+    BilboPost post = DBMan::self()->localPost(localEntriesTable->item(row, 0)->data(32).toInt());
+    emit sigEntrySelected( post, localEntriesTable->item(row, 1)->data(32).toInt() );
 }
 
 void Toolbox::slotRemoveLocalEntry()
 {
-    if (localEntries->currentItem()) {
-        if ( KMessageBox::warningYesNo(this, i18n("Are you sure you want to remove the selected local entry?"))
+    kDebug();
+    if(localEntriesTable->selectedItems().count() > 0) {
+        int local_id = localEntriesTable->item(localEntriesTable->currentRow(), 0)->data(32).toInt();
+        if( KMessageBox::warningYesNo(this, i18n("Are you sure you want to remove the selected local entry?"))
             == KMessageBox::No )
             return;
-        const int local_id = localEntries->currentItem()->data(0,LocalEntryID).toInt();
-        if ( DBMan::self()->removeLocalEntry(local_id) ) {
-            delete localEntries->currentItem();
+
+        if( DBMan::self()->removeLocalEntry(local_id) ) {
+            localEntriesTable->removeRow(localEntriesTable->currentRow());
         } else {
             KMessageBox::detailedError(this, i18n("Cannot remove selected local entry."),
                                        DBMan::self()->lastErrorText());
@@ -466,7 +520,8 @@ void Toolbox::slotRemoveLocalEntry()
 
 void Toolbox::clearEntries()
 {
-    if ( d->mCurrentBlogId == -1 )
+    kDebug();
+    if( d->mCurrentBlogId == -1 )
         return;
     if ( KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to clear the list of entries?")) ==
          KMessageBox::Cancel )
@@ -485,33 +540,30 @@ void Toolbox::setDateTimeNow()
 
 void Toolbox::requestEntriesListContextMenu( const QPoint & pos )
 {
-    if ( lstEntriesList->selectedItems().isEmpty() )
-        return;
     Q_UNUSED(pos);
-    KMenu *entriesContextMenu = new KMenu;
-    KAction *actEntriesOpenInBrowser = new KAction( KIcon(QLatin1String("applications-internet")),
+    KMenu *entriesContextMenu = new KMenu( this );
+    KAction *actEntriesOpenInBrowser = new KAction( KIcon("applications-internet"),
                                                     i18n("Open in browser"), entriesContextMenu );
     connect( actEntriesOpenInBrowser, SIGNAL(triggered()), this, SLOT(openPostInBrowser()) );
-    KAction *actEntriesCopyUrl = new KAction( KIcon(QLatin1String("edit-copy")),
+    KAction *actEntriesCopyUrl = new KAction( KIcon("edit-copy"),
                                               i18n("Copy URL"), entriesContextMenu );
     connect( actEntriesCopyUrl, SIGNAL(triggered(bool)), this, SLOT(slotEntriesCopyUrl()) );
-    KAction *actEntriesCopyTitle = new KAction( KIcon(QLatin1String("edit-copy")),
+    KAction *actEntriesCopyTitle = new KAction( KIcon("edit-copy"),
                                                 i18n("Copy title"), entriesContextMenu );
     connect( actEntriesCopyTitle, SIGNAL(triggered(bool)), this, SLOT(copyPostTitle()) );
     entriesContextMenu->addAction( actEntriesOpenInBrowser );
     entriesContextMenu->addAction( actEntriesCopyUrl );
     entriesContextMenu->addAction( actEntriesCopyTitle );
     entriesContextMenu->exec( QCursor::pos() );
-    delete entriesContextMenu;
 }
 
 void Toolbox::openPostInBrowser()
 {
-    if ( lstEntriesList->selectedItems().isEmpty() )
+    if( lstEntriesList->selectedItems().count() <= 0 )
         return;
-    BilboPost post = DBMan::self()->getPostInfo( lstEntriesList->currentItem()->data( BlogEntryID ).toInt() );
+    BilboPost post = DBMan::self()->getPostInfo( lstEntriesList->currentItem()->data( 32 ).toInt() );
     QString url;
-    if ( !post.permaLink().isEmpty() )
+    if( !post.permaLink().isEmpty() )
         url = post.permaLink().pathOrUrl();
     else if ( !post.link().isEmpty() )
         url = post.link().pathOrUrl();
@@ -522,7 +574,8 @@ void Toolbox::openPostInBrowser()
 
 void Toolbox::copyPostTitle()
 {
-    if ( !lstEntriesList->selectedItems().isEmpty() )
+    if( lstEntriesList->selectedItems().count() > 0 )
         QApplication::clipboard()->setText( lstEntriesList->currentItem()->text() );
 }
 
+#include "toolbox.moc"
