@@ -28,7 +28,7 @@
 #include <KCompletionBox>
 #include <KDebug>
 #include <KDialog>
-#include <KLocalizedString>
+#include <KLocale>
 
 #include <QBoxLayout>
 #include <QKeyEvent>
@@ -457,16 +457,13 @@ void AttendeeLine::slotTextChanged( const QString &str )
 {
   Q_UNUSED( str );
   mModified = true;
-  emit changed(); // TODO: This doesn't seem connected to anywhere in incidenceattendee.cpp.
-                  // but the important code is run in slotHandleChange() anyway so we don't see any bug
+  emit changed();
 }
 
 void AttendeeLine::slotComboChanged()
 {
   mModified = true;
-  // If mUid is empty, we're still populating the widget, don't write fields to data yet
-  if ( !mUid.isEmpty() )
-    dataFromFields();
+  emit changed();
 }
 
 void AttendeeLine::aboutToBeDeleted()
@@ -478,4 +475,5 @@ void AttendeeLine::aboutToBeDeleted()
   emit changed( mData->attendee(), KCalCore::Attendee::Ptr( new KCalCore::Attendee( "", "" ) ) );
 }
 
+#include "attendeeline.moc"
 
