@@ -19,25 +19,33 @@
 */
 
 #include "mainwidget.h"
-#include <QPrinter>
-#include <QPrintDialog>
 
-#include <QtGui/QAction>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QHeaderView>
-#include <QtGui/QListView>
-#include <QtGui/QSortFilterProxyModel>
-#include <QtGui/QSplitter>
-#include <QtGui/QStackedWidget>
-#include <QtGui/QTextBrowser>
+#include "contactswitcher.h"
+#include "globalcontactmodel.h"
+#include "modelcolumnmanager.h"
+#include "printing/printingwizard.h"
+#include "quicksearchwidget.h"
+#include "settings.h"
+#include "xxportmanager.h"
 
+#ifdef GRANTLEE_FOUND
+#include "grantleecontactformatter.h"
+#include "grantleecontactgroupformatter.h"
+#endif
+
+#include "libkdepim/uistatesaver.h"
+
+#include <akonadi/etmviewstatesaver.h>
 #include <akonadi/collectionfilterproxymodel.h>
 #include <akonadi/collectionmodel.h>
 #include <akonadi/contact/contactdefaultactions.h>
 #include <akonadi/contact/contacteditordialog.h>
 #include <akonadi/contact/contactgroupeditordialog.h>
 #include <akonadi/contact/contactgroupviewer.h>
+#include <akonadi/contact/contactsfilterproxymodel.h>
+#include <akonadi/contact/contactstreemodel.h>
 #include <akonadi/contact/contactviewer.h>
+#include <akonadi/contact/standardcontactactionmanager.h>
 #include <akonadi/control.h>
 #include <akonadi/entitymimetypefiltermodel.h>
 #include <akonadi/entitytreeview.h>
@@ -45,34 +53,75 @@
 #include <akonadi/itemview.h>
 #include <akonadi/mimetypechecker.h>
 
-#include <kaction.h>
-#include <kactioncollection.h>
 #include <kabc/addressee.h>
 #include <kabc/contactgroup.h>
-#include "kdescendantsproxymodel_p.h"
+
+#include <kaction.h>
+#include <kactioncollection.h>
+#include <kapplication.h>
+#include <kcheckableproxymodel.h>
+#include <kdescendantsproxymodel.h>
 #include <kicon.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kselectionproxymodel.h>
+#include <kstandarddirs.h>
+#include <ktextbrowser.h>
 #include <ktoggleaction.h>
 #include <ktoolbar.h>
 #include <kxmlguiwindow.h>
-#include <libkdepim/contactstreemodel.h>
-#include <libkdepim/contactsfilterproxymodel.h>
-#include <libkdepim/uistatesaver.h>
 
-#include "contactswitcher.h"
-#include "globalcontactmodel.h"
-#include "modelcolumnmanager.h"
-#include "quicksearchwidget.h"
-#include "settings.h"
-#include "standardcontactactionmanager.h"
-#include "xxportmanager.h"
+#include <QtGui/QAction>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QHeaderView>
+#include <QtGui/QListView>
+#include <QtGui/QPrinter>
+#include <QtGui/QPrintDialog>
+#include <QtGui/QSortFilterProxyModel>
+#include <QtGui/QSplitter>
+#include <QtGui/QStackedWidget>
 
-#include "printing/printingwizard.h"
+
+
+namespace {
+static bool isStructuralCollection( const Akonadi::Collection &collection )
+{
+  QStringList mimeTypes;
+  mimeTypes << KABC::Addressee::mimeType() << KABC::ContactGroup::mimeType();
+  const QStringList collectionMimeTypes = collection.contentMimeTypes();
+  foreach ( const QString &mimeType, mimeTypes ) {
+    if ( collectionMimeTypes.contains( mimeType ) )
+      return false;
+  }
+  return true;
+}
+
+class StructuralCollectionsNotCheckableProxy : public KCheckableProxyModel {
+public:
+  StructuralCollectionsNotCheckableProxy(QObject* parent)
+      : KCheckableProxyModel(parent)
+  { }
+
+  /* reimp */ QVariant data( const QModelIndex &index, int role ) const
+  {
+    if ( !index.isValid() )
+      return QVariant();
+
+    if ( role == Qt::CheckStateRole ) {
+      // Don't show the checkbox if the collection can't contain incidences
+      const Akonadi::Collection collection = index.data( Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+      if ( collection.isValid() && isStructuralCollection( collection ) ) {
+        return QVariant();
+      }
+    }
+    return KCheckableProxyModel::data( index, role );
+  }
+};
+
+}
 
 MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
-  : QWidget( parent ), mAllContactsModel( 0 )
+  : QWidget( parent ), mAllContactsModel( 0 ), mXmlGuiClient( guiClient )
 {
   mXXPortManager = new XXPortManager( this );
 
@@ -94,8 +143,13 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
    *                                   |           mAllContactsModel
    *                                   |                  ^
    *                                   |                  |
-   *      mCollectionView  ->  selectionProxyModel  descendantsModel
-   *            ^                      ^                  ^
+   *      mCollectionView     selectionProxyModel  descendantsModel
+   *            ^               ^      ^                  ^
+   *            |               |      |                  |
+   *            |       selectionModel |                  |
+   *            |               |      |                  |
+   *        proxyModel ---------'      |                  |
+   *            ^                      |                  |
    *            |                      |                  |
    *      mCollectionTree              |                  |
    *            ^                      |                  |
@@ -106,9 +160,12 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
    *
    *  GlobalContactModel::instance():  The global contact model (contains collections and items)
    *                 mCollectionTree:  Filters out all items
+   *                      proxyModel:  Allows the user to select collections by checkboxes
+   *                  selectionModel:  Represents the selected collections that have been selected in
+   *                                   proxyModel
    *                 mCollectionView:  Shows the collections (address books) in a view
    *             selectionProxyModel:  Filters out all collections and items that are no children
-   *                                   of the collection currently selected in mCollectionView
+   *                                   of the collections currently selected in selectionModel
    *                       mItemTree:  Filters out all collections
    *            mContactsFilterModel:  Filters the contacts by the content of mQuickSearchWidget
    *                       mItemView:  Shows the items (contacts and contact groups) in a view
@@ -118,22 +175,27 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
    */
 
   mCollectionTree = new Akonadi::EntityMimeTypeFilterModel( this );
+  mCollectionTree->setDynamicSortFilter( true );
+  mCollectionTree->setSortCaseSensitivity( Qt::CaseInsensitive );
   mCollectionTree->setSourceModel( GlobalContactModel::instance()->model() );
   mCollectionTree->addMimeTypeInclusionFilter( Akonadi::Collection::mimeType() );
   mCollectionTree->setHeaderGroup( Akonadi::EntityTreeModel::CollectionTreeHeaders );
 
-  mXXPortManager->setItemModel( allContactsModel() );
+  mCollectionSelectionModel = new QItemSelectionModel( mCollectionTree );
+  StructuralCollectionsNotCheckableProxy *checkableProxyModel = new StructuralCollectionsNotCheckableProxy( this );
+  checkableProxyModel->setSelectionModel( mCollectionSelectionModel );
+  checkableProxyModel->setSourceModel( mCollectionTree );
 
-  mCollectionView->setModel( mCollectionTree );
+  mCollectionView->setModel( checkableProxyModel );
   mCollectionView->setXmlGuiClient( guiClient );
   mCollectionView->header()->setDefaultAlignment( Qt::AlignCenter );
   mCollectionView->header()->setSortIndicatorShown( false );
 
-  connect( mCollectionView, SIGNAL( currentChanged( const Akonadi::Collection& ) ),
-           mXXPortManager, SLOT( setDefaultAddressBook( const Akonadi::Collection& ) ) );
+  connect( mCollectionView, SIGNAL(currentChanged(Akonadi::Collection)),
+           mXXPortManager, SLOT(setDefaultAddressBook(Akonadi::Collection)) );
 
-  KSelectionProxyModel *selectionProxyModel = new KSelectionProxyModel( mCollectionView->selectionModel(),
-                                                                                        this );
+  KSelectionProxyModel *selectionProxyModel = new KSelectionProxyModel( mCollectionSelectionModel,
+                                                                        this );
   selectionProxyModel->setSourceModel( GlobalContactModel::instance()->model() );
   selectionProxyModel->setFilterBehavior( KSelectionProxyModel::ChildrenOfExactSelection );
 
@@ -142,14 +204,14 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
   mItemTree->addMimeTypeExclusionFilter( Akonadi::Collection::mimeType() );
   mItemTree->setHeaderGroup( Akonadi::EntityTreeModel::ItemListHeaders );
 
-  mContactsFilterModel = new AkonadiFuture::ContactsFilterModel( this );
+  mContactsFilterModel = new Akonadi::ContactsFilterProxyModel( this );
   mContactsFilterModel->setSourceModel( mItemTree );
-  connect( mQuickSearchWidget, SIGNAL( filterStringChanged( const QString& ) ),
-           mContactsFilterModel, SLOT( setFilterString( const QString& ) ) );
-  connect( mQuickSearchWidget, SIGNAL( filterStringChanged( const QString& ) ),
-           this, SLOT( selectFirstItem() ) );
-  connect( mQuickSearchWidget, SIGNAL( arrowDownKeyPressed() ),
-           mItemView, SLOT( setFocus() ) );
+  connect( mQuickSearchWidget, SIGNAL(filterStringChanged(QString)),
+           mContactsFilterModel, SLOT(setFilterString(QString)) );
+  connect( mQuickSearchWidget, SIGNAL(filterStringChanged(QString)),
+           this, SLOT(selectFirstItem()) );
+  connect( mQuickSearchWidget, SIGNAL(arrowDownKeyPressed()),
+           mItemView, SLOT(setFocus()) );
 
   mItemView->setModel( mContactsFilterModel );
   mItemView->setXmlGuiClient( guiClient );
@@ -159,12 +221,22 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
 
   mXXPortManager->setSelectionModel( mItemView->selectionModel() );
 
-  connect( mItemView, SIGNAL( currentChanged( const Akonadi::Item& ) ),
-           this, SLOT( itemSelected( const Akonadi::Item& ) ) );
-  connect( mItemView, SIGNAL( doubleClicked( const Akonadi::Item& ) ),
-           this, SLOT( editItem( const Akonadi::Item& ) ) );
-  connect( mItemView->selectionModel(), SIGNAL( currentChanged( const QModelIndex&, const QModelIndex& ) ),
-           this, SLOT( itemSelectionChanged( const QModelIndex&, const QModelIndex& ) ) );
+  mActionManager = new Akonadi::StandardContactActionManager( guiClient->actionCollection(), this );
+  mActionManager->setCollectionSelectionModel( mCollectionView->selectionModel() );
+  mActionManager->setItemSelectionModel( mItemView->selectionModel() );
+  mActionManager->createAllActions();
+  const QStringList pages =
+      QStringList() << QLatin1String( "Akonadi::CollectionGeneralPropertiesPage" )
+                    << QLatin1String( "Akonadi::CachePolicyPage" );
+
+  mActionManager->setCollectionPropertiesPageNames( pages );
+
+  connect( mItemView, SIGNAL(currentChanged(Akonadi::Item)),
+           this, SLOT(itemSelected(Akonadi::Item)) );
+  connect( mItemView, SIGNAL(doubleClicked(Akonadi::Item)),
+           mActionManager->action( Akonadi::StandardContactActionManager::EditItem ), SLOT(trigger()) );
+  connect( mItemView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
+           this, SLOT(itemSelectionChanged(QModelIndex,QModelIndex)) );
 
   // show the contact details view as default
   mDetailsViewStack->setCurrentWidget( mContactDetails );
@@ -173,23 +245,15 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
 
   Akonadi::Control::widgetNeedsAkonadi( this );
 
-  mActionManager = new AkonadiFuture::StandardContactActionManager( guiClient->actionCollection(), this );
-  mActionManager->setCollectionSelectionModel( mCollectionView->selectionModel() );
-  mActionManager->setItemSelectionModel( mItemView->selectionModel() );
-
-  mActionManager->createAllActions();
-
-  connect( mActionManager->action( AkonadiFuture::StandardContactActionManager::CreateContact ), SIGNAL( triggered( bool ) ),
-           this, SLOT( newContact() ) );
-  connect( mActionManager->action( AkonadiFuture::StandardContactActionManager::CreateContactGroup ), SIGNAL( triggered( bool ) ),
-           this, SLOT( newGroup() ) );
-  connect( mActionManager, SIGNAL( editItem( const Akonadi::Item& ) ),
-           this, SLOT( editItem( const Akonadi::Item& ) ) );
-
   mModelColumnManager = new ModelColumnManager( GlobalContactModel::instance()->model(), this );
   mModelColumnManager->setWidget( mItemView->header() );
   mModelColumnManager->load();
 
+  QMetaObject::invokeMethod( this, "delayedInit", Qt::QueuedConnection );
+}
+
+void MainWidget::delayedInit()
+{
   // restore previous state
   {
     const KConfigGroup group( Settings::self()->config(), "UiState_MainWidgetSplitter" );
@@ -199,36 +263,23 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
     const KConfigGroup group( Settings::self()->config(), "UiState_ContactView" );
     KPIM::UiStateSaver::restoreState( mItemView, group );
   }
-  {
-    const KConfigGroup group( Settings::self()->config(), "CollectionViewState" );
-    Akonadi::EntityTreeViewStateSaver *restorer = new Akonadi::EntityTreeViewStateSaver( mCollectionView );
-    restorer->restoreState( group );
-  }
-  {
-    const KConfigGroup group( Settings::self()->config(), "ItemViewState" );
-    Akonadi::EntityTreeViewStateSaver *restorer = new Akonadi::EntityTreeViewStateSaver( mItemView );
-    restorer->restoreState( group );
-  }
 
-  guiClient->actionCollection()->action( "options_show_simplegui" )->setChecked( Settings::self()->useSimpleMode() );
+  mXmlGuiClient->actionCollection()->action( "options_show_simplegui" )->setChecked( Settings::self()->useSimpleMode() );
+#if defined(HAVE_PRISON)
+  mXmlGuiClient->actionCollection()->action( "options_show_qrcodes" )->setChecked( showQRCodes() );
+#endif
+
+  connect( GlobalContactModel::instance()->model(), SIGNAL(modelAboutToBeReset()), SLOT(saveState()) );
+  connect( GlobalContactModel::instance()->model(), SIGNAL(modelReset()), SLOT(restoreState()) );
+  connect( kapp, SIGNAL(aboutToQuit()), SLOT(saveState()) );
+
+  restoreState();
 }
 
 MainWidget::~MainWidget()
 {
   mModelColumnManager->store();
 
-  {
-    KConfigGroup group( Settings::self()->config(), "CollectionViewState" );
-    Akonadi::EntityTreeViewStateSaver saver( mCollectionView );
-    saver.saveState( group );
-    group.sync();
-  }
-  {
-    KConfigGroup group( Settings::self()->config(), "ItemViewState" );
-    Akonadi::EntityTreeViewStateSaver saver( mItemView );
-    saver.saveState( group );
-    group.sync();
-  }
   {
     if ( !Settings::self()->useSimpleMode() ) {
       // Do not save the splitter values when in simple mode, because we can't
@@ -243,13 +294,81 @@ MainWidget::~MainWidget()
     KPIM::UiStateSaver::saveState( mItemView, group );
   }
 
+  saveState();
+
   Settings::self()->writeConfig();
 }
 
+void MainWidget::restoreState()
+{
+  // collection view
+  {
+    Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+    saver->setView( mCollectionView );
+
+    const KConfigGroup group( Settings::self()->config(), "CollectionViewState" );
+    saver->restoreState( group );
+  }
+
+  // collection view
+  {
+    Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+    saver->setSelectionModel( mCollectionSelectionModel );
+
+    const KConfigGroup group( Settings::self()->config(), "CollectionViewCheckState" );
+    saver->restoreState( group );
+  }
+
+  // item view
+  {
+    Akonadi::ETMViewStateSaver *saver = new Akonadi::ETMViewStateSaver;
+    saver->setView( mItemView );
+    saver->setSelectionModel( mItemView->selectionModel() );
+
+    const KConfigGroup group( Settings::self()->config(), "ItemViewState" );
+    saver->restoreState( group );
+  }
+}
+
+void MainWidget::saveState()
+{
+  // collection view
+  {
+    Akonadi::ETMViewStateSaver saver;
+    saver.setView( mCollectionView );
+
+    KConfigGroup group( Settings::self()->config(), "CollectionViewState" );
+    saver.saveState( group );
+    group.sync();
+  }
+
+  // collection view
+  {
+    Akonadi::ETMViewStateSaver saver;
+    saver.setSelectionModel( mCollectionSelectionModel );
+
+    KConfigGroup group( Settings::self()->config(), "CollectionViewCheckState" );
+    saver.saveState( group );
+    group.sync();
+  }
+
+  // item view
+  {
+    Akonadi::ETMViewStateSaver saver;
+    saver.setView( mItemView );
+    saver.setSelectionModel( mItemView->selectionModel() );
+
+    KConfigGroup group( Settings::self()->config(), "ItemViewState" );
+    saver.saveState( group );
+    group.sync();
+  }
+}
+
 void MainWidget::setupGui()
 {
   // the horizontal main layout
   QHBoxLayout *layout = new QHBoxLayout( this );
+  layout->setMargin( 0 );
 
   // The splitter that contains the three main parts of the gui
   //   - collection view on the left
@@ -291,7 +410,7 @@ void MainWidget::setupGui()
   mDetailsViewStack->addWidget( mContactGroupDetails );
 
   // the details widget for empty items
-  mEmptyDetails = new QTextBrowser( mDetailsViewStack );
+  mEmptyDetails = new KTextBrowser( mDetailsViewStack );
   mDetailsViewStack->addWidget( mEmptyDetails );
 
   // the contact switcher for the simple gui mode
@@ -306,6 +425,18 @@ void MainWidget::setupGui()
   Akonadi::ContactDefaultActions *actions = new Akonadi::ContactDefaultActions( this );
   actions->connectToView( mContactDetails );
   actions->connectToView( mContactGroupDetails );
+
+#if 0 // disabled because Grantlee supports no i18n for KDE 4.6 yet
+ Akonadi::GrantleeContactFormatter *formatter =
+       new Akonadi::GrantleeContactFormatter( KStandardDirs::locate( "data", QLatin1String( "kaddressbook/viewertemplates/" ) ) );
+
+ mContactDetails->setContactFormatter( formatter );
+
+ Akonadi::GrantleeContactGroupFormatter *groupFormatter =
+       new Akonadi::GrantleeContactGroupFormatter( KStandardDirs::locate( "data", QLatin1String( "kaddressbook/viewertemplates/" ) ) );
+
+ mContactGroupDetails->setContactGroupFormatter( groupFormatter );
+#endif
 }
 
 void MainWidget::setupActions( KActionCollection *collection )
@@ -313,7 +444,7 @@ void MainWidget::setupActions( KActionCollection *collection )
   KAction *action = 0;
   KToggleAction *toggleAction = 0;
 
-  action = KStandardAction::print( this, SLOT( print() ), collection );
+  action = KStandardAction::print( this, SLOT(print()), collection );
   action->setWhatsThis( i18n( "Print the complete address book or a selected number of contacts." ) );
 
   action = collection->addAction( "quick_search" );
@@ -324,33 +455,20 @@ void MainWidget::setupActions( KActionCollection *collection )
   action->setText( i18n( "Select All" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_A ) );
   action->setWhatsThis( i18n( "Select all contacts in the current address book view." ) );
-  connect( action, SIGNAL( triggered( bool ) ), mItemView, SLOT( selectAll() ) );
-
-  toggleAction = collection->add<KToggleAction>( "options_show_collectionview" );
-  toggleAction->setText( i18n( "Show Address Books View" ) );
-  toggleAction->setWhatsThis( i18n( "Toggle whether the address books view shall be visible." ) );
-  toggleAction->setCheckedState( KGuiItem( i18n( "Hide Address Books View" ) ) );
-  toggleAction->setChecked( true );
-  connect( toggleAction, SIGNAL( toggled( bool ) ), SLOT( setCollectionViewVisible( bool ) ) );
-
-  toggleAction = collection->add<KToggleAction>( "options_show_itemview" );
-  toggleAction->setText( i18n( "Show Contacts View" ) );
-  toggleAction->setWhatsThis( i18n( "Toggle whether the contacts view shall be visible." ) );
-  toggleAction->setCheckedState( KGuiItem( i18n( "Hide Contacts View" ) ) );
-  toggleAction->setChecked( true );
-  connect( toggleAction, SIGNAL( toggled( bool ) ), SLOT( setItemViewVisible( bool ) ) );
-
-  toggleAction = collection->add<KToggleAction>( "options_show_detailsview" );
-  toggleAction->setText( i18n( "Show Details View" ) );
-  toggleAction->setWhatsThis( i18n( "Toggle whether the details view shall be visible." ) );
-  toggleAction->setCheckedState( KGuiItem( i18n( "Hide Details View" ) ) );
-  toggleAction->setChecked( true );
-  connect( toggleAction, SIGNAL( toggled( bool ) ), SLOT( setDetailsViewVisible( bool ) ) );
+  connect( action, SIGNAL(triggered(bool)), mItemView, SLOT(selectAll()) );
 
   toggleAction = collection->add<KToggleAction>( "options_show_simplegui" );
   toggleAction->setText( i18n( "Show Simple View" ) );
-  action->setWhatsThis( i18n( "Show a simple mode of the address book view." ) );
-  connect( toggleAction, SIGNAL( toggled( bool ) ), SLOT( setSimpleGuiMode( bool ) ) );
+  toggleAction->setWhatsThis( i18n( "Show a simple mode of the address book view." ) );
+  connect( toggleAction, SIGNAL(toggled(bool)), SLOT(setSimpleGuiMode(bool)) );
+
+#if defined(HAVE_PRISON)
+  KToggleAction *qrtoggleAction;
+  qrtoggleAction = collection->add<KToggleAction>( "options_show_qrcodes" );
+  qrtoggleAction->setText( i18n( "Show QR Codes" ) );
+  qrtoggleAction->setWhatsThis( i18n( "Show QR Codes in the contact." ) );
+  connect( qrtoggleAction, SIGNAL(toggled(bool)), SLOT(setQRCodeShow(bool)) );
+#endif
 
   // import actions
   action = collection->addAction( "file_import_vcard" );
@@ -416,11 +534,10 @@ void MainWidget::print()
 
   QPrintDialog printDialog( &printer, this );
   printDialog.setWindowTitle( i18n( "Print Contacts" ) );
-  if ( !printDialog.exec() )
+  if ( !printDialog.exec() ) //krazy:exclude=crashy
     return;
 
-  KABPrinting::PrintingWizard wizard( &printer, allContactsModel(),
-                                      mItemView->selectionModel(), this );
+  KABPrinting::PrintingWizard wizard( &printer, mItemView->selectionModel(), this );
   wizard.setDefaultAddressBook( currentAddressBook() );
 
   wizard.exec();
@@ -428,27 +545,12 @@ void MainWidget::print()
 
 void MainWidget::newContact()
 {
-  Akonadi::ContactEditorDialog dlg( Akonadi::ContactEditorDialog::CreateMode, this );
-  dlg.setDefaultAddressBook( currentAddressBook() );
-
-  dlg.exec();
+  mActionManager->action( Akonadi::StandardContactActionManager::CreateContact )->trigger();
 }
 
 void MainWidget::newGroup()
 {
-  Akonadi::ContactGroupEditorDialog dlg( Akonadi::ContactGroupEditorDialog::CreateMode, this );
-  dlg.setDefaultAddressBook( currentAddressBook() );
-
-  dlg.exec();
-}
-
-void MainWidget::editItem( const Akonadi::Item &reference )
-{
-  if ( Akonadi::MimeTypeChecker::isWantedItem( reference, KABC::Addressee::mimeType() ) ) {
-    editContact( reference );
-  } else if ( Akonadi::MimeTypeChecker::isWantedItem( reference, KABC::ContactGroup::mimeType() ) ) {
-    editGroup( reference );
-  }
+  mActionManager->action( Akonadi::StandardContactActionManager::CreateContactGroup )->trigger();
 }
 
 /**
@@ -488,21 +590,6 @@ void MainWidget::selectFirstItem()
   }
 }
 
-void MainWidget::setCollectionViewVisible( bool visible )
-{
-  mCollectionView->setVisible( visible );
-}
-
-void MainWidget::setItemViewVisible( bool visible )
-{
-  mItemView->setVisible( visible );
-}
-
-void MainWidget::setDetailsViewVisible( bool visible )
-{
-  mDetailsPane->setVisible( visible );
-}
-
 void MainWidget::setSimpleGuiMode( bool on )
 {
   mCollectionView->setVisible( !on );
@@ -510,35 +597,36 @@ void MainWidget::setSimpleGuiMode( bool on )
   mDetailsPane->setVisible( true );
   mContactSwitcher->setVisible( on );
 
-  // If simple mode is on, we use a model that provides all available contacts
-  // in a list, otherwise we use the model that provides all contacts of the
-  // currently selected collection.
-  if ( on )
-    mContactsFilterModel->setSourceModel( allContactsModel() );
-  else
-    mContactsFilterModel->setSourceModel( mItemTree );
-
-  if ( mCollectionView->model() )
-    mCollectionView->setCurrentIndex( mCollectionView->model()->index( 0, 0 ) );
-
-  if ( mItemView->model() )
+  if ( mItemView->model() ) {
     mItemView->setCurrentIndex( mItemView->model()->index( 0, 0 ) );
+  }
 
   Settings::self()->setUseSimpleMode( on );
 }
 
-void MainWidget::editContact( const Akonadi::Item &contact )
+bool MainWidget::showQRCodes()
 {
-  Akonadi::ContactEditorDialog dlg( Akonadi::ContactEditorDialog::EditMode, this );
-  dlg.setContact( contact );
-  dlg.exec();
+#if defined(HAVE_PRISON)
+  KConfig config( QLatin1String( "akonadi_contactrc" ) );
+  KConfigGroup group( &config, QLatin1String( "View" ) );
+  return group.readEntry( "QRCodes", true );
+#else
+  return true;
+#endif
 }
 
-void MainWidget::editGroup( const Akonadi::Item &group )
+void MainWidget::setQRCodeShow( bool on )
 {
-  Akonadi::ContactGroupEditorDialog dlg( Akonadi::ContactGroupEditorDialog::EditMode, this );
-  dlg.setContactGroup( group );
-  dlg.exec();
+#if defined(HAVE_PRISON)
+  // must write the configuration setting first before updating the view.
+  KConfig config( QLatin1String( "akonadi_contactrc" ) );
+  KConfigGroup group( &config, QLatin1String( "View" ) );
+  group.writeEntry( "QRCodes", on );
+
+  if ( mItemView->model() ) {
+    mItemView->setCurrentIndex( mItemView->model()->index( 0, 0 ) );
+  }
+#endif
 }
 
 Akonadi::Collection MainWidget::currentAddressBook() const
