@@ -23,6 +23,7 @@
 #include "qcsvmodel.h"
 #include "templateselectiondialog.h"
 
+#include <QtCore/QPointer>
 #include <QtCore/QTextCodec>
 #include <QtCore/QThread>
 #include <QtCore/QUuid>
@@ -52,12 +53,12 @@
 
 enum { Local = 0, Latin1 = 1, Uni = 2, MSBug = 3, Codec = 4 };
 
-class ContactFieldComboBox : public QComboBox
+class ContactFieldComboBox : public KComboBox
 {
   public:
 
     ContactFieldComboBox( QWidget *parent = 0 )
-      : QComboBox( parent )
+      : KComboBox( parent )
     {
       fillFieldMap();
 
@@ -178,26 +179,26 @@ CSVImportDialog::CSVImportDialog( QWidget *parent )
 
   reloadCodecs();
 
-  connect( mUrlRequester, SIGNAL( returnPressed( const QString& ) ),
-           this, SLOT( setFile( const QString& ) ) );
-  connect( mUrlRequester, SIGNAL( urlSelected( const KUrl& ) ),
-           this, SLOT( setFile( const KUrl& ) ) );
-  connect( mUrlRequester->lineEdit(), SIGNAL( textChanged ( const QString& ) ),
-           this, SLOT( urlChanged( const QString& ) ) );
-  connect( mDelimiterGroup, SIGNAL( buttonClicked( int ) ),
-           this, SLOT( delimiterClicked( int ) ) );
-  connect( mDelimiterEdit, SIGNAL( returnPressed() ),
-           this, SLOT( customDelimiterChanged() ) );
-  connect( mDelimiterEdit, SIGNAL( textChanged( const QString& ) ),
-           this, SLOT( customDelimiterChanged( const QString& ) ) );
-  connect( mComboQuote, SIGNAL( activated( const QString& ) ),
-           this, SLOT( textQuoteChanged( const QString& ) ) );
-  connect( mCodecCombo, SIGNAL( activated( const QString& ) ),
-           this, SLOT( codecChanged() ) );
-  connect( mSkipFirstRow, SIGNAL( toggled( bool ) ),
-           this, SLOT( skipFirstRowChanged( bool ) ) );
+  connect( mUrlRequester, SIGNAL(returnPressed(QString)),
+           this, SLOT(setFile(QString)) );
+  connect( mUrlRequester, SIGNAL(urlSelected(KUrl)),
+           this, SLOT(setFile(KUrl)) );
+  connect( mUrlRequester->lineEdit(), SIGNAL(textChanged(QString)),
+           this, SLOT(urlChanged(QString)) );
+  connect( mDelimiterGroup, SIGNAL(buttonClicked(int)),
+           this, SLOT(delimiterClicked(int)) );
+  connect( mDelimiterEdit, SIGNAL(returnPressed()),
+           this, SLOT(customDelimiterChanged()) );
+  connect( mDelimiterEdit, SIGNAL(textChanged(QString)),
+           this, SLOT(customDelimiterChanged(QString)) );
+  connect( mComboQuote, SIGNAL(activated(QString)),
+           this, SLOT(textQuoteChanged(QString)) );
+  connect( mCodecCombo, SIGNAL(activated(QString)),
+           this, SLOT(codecChanged()) );
+  connect( mSkipFirstRow, SIGNAL(toggled(bool)),
+           this, SLOT(skipFirstRowChanged(bool)) );
 
-  connect( mModel, SIGNAL( finishedLoading() ), this, SLOT( modelFinishedLoading() ) );
+  connect( mModel, SIGNAL(finishedLoading()), this, SLOT(modelFinishedLoading()) );
 
   delimiterClicked( 0 );
   textQuoteChanged( "\"" );
@@ -274,6 +275,7 @@ void CSVImportDialog::initGUI()
 
   mUrlRequester = new KUrlRequester( page );
   mUrlRequester->setFilter( "*.csv" );
+  mUrlRequester->lineEdit()->setTrapReturnKey( true );
   hbox->addWidget( mUrlRequester );
 
   layout->addLayout( hbox, 0, 0, 1, 5 );
@@ -414,7 +416,9 @@ void CSVImportDialog::delimiterClicked( int id, bool reload )
       break;
     case 4: // other
       mDelimiterEdit->setFocus( Qt::OtherFocusReason );
-      mModel->setDelimiter( mDelimiterEdit->text().at( 0 ) );
+      if ( !mDelimiterEdit->text().isEmpty() ) {
+        mModel->setDelimiter( mDelimiterEdit->text().at( 0 ) );
+      }
       break;
     case 2: // tab
       mModel->setDelimiter( '\t' );
@@ -484,16 +488,20 @@ void CSVImportDialog::slotButtonClicked( int button )
 
 void CSVImportDialog::applyTemplate()
 {
-  TemplateSelectionDialog dlg( this );
-  if ( !dlg.templatesAvailable() ) {
-    KMessageBox::sorry( this, i18n( "There are no templates available yet." ), i18n( "No templates available" ) );
+  QPointer<TemplateSelectionDialog> dlg = new TemplateSelectionDialog( this );
+  if ( !dlg->templatesAvailable() ) {
+    KMessageBox::sorry( this, i18nc( "@label", "There are no templates available yet." ), i18nc( "@title:window", "No templates available" ) );
+    delete dlg;
     return;
   }
 
-  if ( !dlg.exec() )
+  if ( !dlg->exec() || !dlg ) {
+    delete dlg;
     return;
+  }
 
-  const QString templateFileName = dlg.selectedTemplate();
+  const QString templateFileName = dlg->selectedTemplate();
+  delete dlg;
 
   KConfig config( templateFileName, KConfig::SimpleConfig );
 
@@ -523,7 +531,7 @@ void CSVImportDialog::applyTemplate()
     mModel->load( mDevice );
 
   setProperty( "TemplateFileName", templateFileName );
-  connect( mModel, SIGNAL( finishedLoading() ), this, SLOT( finalizeApplyTemplate() ) );
+  connect( mModel, SIGNAL(finishedLoading()), this, SLOT(finalizeApplyTemplate()) );
 }
 
 void CSVImportDialog::finalizeApplyTemplate()
@@ -552,9 +560,9 @@ void CSVImportDialog::saveTemplate()
   if ( name.isEmpty() )
     return;
 
-  const QString fileName = KStandardDirs::locateLocal( "data", "kaddressbook/csv-templates/"
-                                                       + QUuid::createUuid()
-                                                       + ".desktop" );
+  const QString fileName = KStandardDirs::locateLocal( "data", QString("kaddressbook/csv-templates/"
+                                                       + QString(QUuid::createUuid())
+                                                       + ".desktop" ) );
 
   KConfig config( fileName  );
   KConfigGroup generalGroup( &config, "General" );
@@ -594,8 +602,7 @@ void CSVImportDialog::setFile( const QString &fileName )
     return;
   }
 
-  if ( mDevice )
-    delete mDevice;
+  delete mDevice;
 
   mDevice = file;
 
