@@ -29,7 +29,9 @@
 #include <akonadi/itemcreatejob.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kprogressdialog.h>
 
+#include <QtCore/QPointer>
 #include <QtCore/QSignalMapper>
 #include <QtGui/QAction>
 #include <QtGui/QItemSelectionModel>
@@ -37,15 +39,16 @@
 
 
 XXPortManager::XXPortManager( QWidget *parent )
-  : QObject( parent ), mItemModel( 0 ), mSelectionModel( 0 ), mParentWidget( parent )
+  : QObject( parent ), mSelectionModel( 0 ),
+    mParentWidget( parent ), mImportProgressDialog( 0 )
 {
   mImportMapper = new QSignalMapper( this );
   mExportMapper = new QSignalMapper( this );
 
-  connect( mImportMapper, SIGNAL( mapped( const QString& ) ),
-           this, SLOT( slotImport( const QString& ) ) );
-  connect( mExportMapper, SIGNAL( mapped( const QString& ) ),
-           this, SLOT( slotExport( const QString& ) ) );
+  connect( mImportMapper, SIGNAL(mapped(QString)),
+           this, SLOT(slotImport(QString)) );
+  connect( mExportMapper, SIGNAL(mapped(QString)),
+           this, SLOT(slotExport(QString)) );
 }
 
 XXPortManager::~XXPortManager()
@@ -55,18 +58,13 @@ XXPortManager::~XXPortManager()
 void XXPortManager::addImportAction( QAction *action, const QString &identifier )
 {
   mImportMapper->setMapping( action, identifier );
-  connect( action, SIGNAL( triggered( bool ) ), mImportMapper, SLOT( map() ) );
+  connect( action, SIGNAL(triggered(bool)), mImportMapper, SLOT(map()) );
 }
 
 void XXPortManager::addExportAction( QAction *action, const QString &identifier )
 {
   mExportMapper->setMapping( action, identifier );
-  connect( action, SIGNAL( triggered( bool ) ), mExportMapper, SLOT( map() ) );
-}
-
-void XXPortManager::setItemModel( QAbstractItemModel *itemModel )
-{
-  mItemModel = itemModel;
+  connect( action, SIGNAL(triggered(bool)), mExportMapper, SLOT(map()) );
 }
 
 void XXPortManager::setSelectionModel( QItemSelectionModel *selectionModel )
@@ -93,17 +91,32 @@ void XXPortManager::slotImport( const QString &identifier )
     return;
 
   const QStringList mimeTypes( KABC::Addressee::mimeType() );
-  Akonadi::CollectionDialog dlg( mParentWidget );
-  dlg.setMimeTypeFilter( mimeTypes );
-  dlg.setAccessRightsFilter( Akonadi::Collection::CanCreateItem );
-  dlg.setCaption( i18n( "Select Address Book" ) );
-  dlg.setDescription( i18n( "Select the address book the imported contact(s) shall be saved in:" ) );
-  dlg.setDefaultCollection( mDefaultAddressBook );
 
-  if ( !dlg.exec() )
+  QPointer<Akonadi::CollectionDialog> dlg = new Akonadi::CollectionDialog( mParentWidget );
+  dlg->setMimeTypeFilter( mimeTypes );
+  dlg->setAccessRightsFilter( Akonadi::Collection::CanCreateItem );
+  dlg->setCaption( i18n( "Select Address Book" ) );
+  dlg->setDescription( i18n( "Select the address book the imported contact(s) shall be saved in:" ) );
+  dlg->setDefaultCollection( mDefaultAddressBook );
+
+  if ( !dlg->exec() || !dlg ) {
+    delete dlg;
     return;
+  }
 
-  const Akonadi::Collection collection = dlg.selectedCollection();
+  const Akonadi::Collection collection = dlg->selectedCollection();
+  delete dlg;
+
+  if ( !mImportProgressDialog ) {
+    mImportProgressDialog = new KProgressDialog( mParentWidget, i18n( "Import Contacts" ) );
+    mImportProgressDialog->setLabelText( i18np( "Importing one contact to %2", "Importing %1 contacts to %2",
+                                                contacts.count(), collection.name() ) );
+    mImportProgressDialog->setAllowCancel( false );
+    mImportProgressDialog->setAutoClose( true );
+    mImportProgressDialog->progressBar()->setRange( 1, contacts.count() );
+  }
+
+  mImportProgressDialog->show();
 
   for ( int i = 0; i < contacts.count(); ++i ) {
     Akonadi::Item item;
@@ -111,22 +124,42 @@ void XXPortManager::slotImport( const QString &identifier )
     item.setMimeType( KABC::Addressee::mimeType() );
 
     Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob( item, collection );
-    job->exec();
+    connect( job, SIGNAL(result(KJob*)), SLOT(slotImportJobDone(KJob*)) );
+  }
+}
+
+void XXPortManager::slotImportJobDone( KJob* )
+{
+  if ( !mImportProgressDialog )
+    return;
+
+  QProgressBar *progressBar = mImportProgressDialog->progressBar();
+
+  progressBar->setValue( progressBar->value() + 1 );
+
+  // cleanup on last step
+  if ( progressBar->value() == progressBar->maximum() ) {
+    mImportProgressDialog->deleteLater();
+    mImportProgressDialog = 0;
   }
 }
 
 void XXPortManager::slotExport( const QString &identifier )
 {
-  if ( !mItemModel || !mSelectionModel )
+  if ( !mSelectionModel )
     return;
 
-  ContactSelectionDialog dlg( mItemModel, mSelectionModel, mParentWidget );
-  dlg.setMessageText( i18n( "Which contact do you want to export?" ) );
-  dlg.setDefaultAddressBook( mDefaultAddressBook );
-  if ( !dlg.exec() )
+  QPointer<ContactSelectionDialog> dlg = new ContactSelectionDialog( mSelectionModel, mParentWidget );
+  dlg->setMessageText( i18n( "Which contact do you want to export?" ) );
+  dlg->setDefaultAddressBook( mDefaultAddressBook );
+  if ( !dlg->exec() || !dlg ) {
+    delete dlg;
     return;
+  }
+
+  const KABC::AddresseeList contacts = dlg->selectedContacts();
+  delete dlg;
 
-  const KABC::AddresseeList contacts = dlg.selectedContacts();
   if ( contacts.isEmpty() ) {
     KMessageBox::sorry( 0, i18n( "You have not selected any contacts to export." ) );
     return;
