@@ -1,7 +1,7 @@
 /*
  *  birthdaydlg.cpp  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  Copyright © 2002-2012 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2011 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "birthdaydlg.h"
+#include "birthdaydlg.moc"
 
 #include "kalarm.h"
 #include "alarmcalendar.h"
@@ -63,7 +63,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     : KDialog(parent),
       mSpecialActionsButton(0)
 {
-    setObjectName(QLatin1String("BirthdayDlg"));    // used by LikeBack
+    setObjectName("BirthdayDlg");    // used by LikeBack
     setCaption(i18nc("@title:window", "Import Birthdays From KAddressBook"));
     setButtons(Ok | Cancel);
     setDefaultButton(Ok);
@@ -135,7 +135,6 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     mBirthdaySortModel->setSortCaseSensitivity(Qt::CaseInsensitive);
     mBirthdaySortModel->setPrefixSuffix(mPrefixText, mSuffixText);
     mListView = new QTreeView(group);
-    mListView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     mListView->setModel(mBirthdaySortModel);
     mListView->setRootIsDecorated(false);    // don't show expander icons
     mListView->setSortingEnabled(true);
@@ -233,16 +232,8 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     mSoundPicker->set(Preferences::defaultSoundType(), Preferences::defaultSoundFile(),
                       Preferences::defaultSoundVolume(), -1, 0, Preferences::defaultSoundRepeat());
     if (mSpecialActionsButton)
-    {
-        KAEvent::ExtraActionOptions opts(0);
-        if (Preferences::defaultExecPreActionOnDeferral())
-            opts |= KAEvent::ExecPreActOnDeferral;
-        if (Preferences::defaultCancelOnPreActionError())
-            opts |= KAEvent::CancelOnPreActError;
-        if (Preferences::defaultDontShowPreActionError())
-            opts |= KAEvent::DontShowPreActError;
-        mSpecialActionsButton->setActions(Preferences::defaultPreAction(), Preferences::defaultPostAction(), opts);
-    }
+        mSpecialActionsButton->setActions(Preferences::defaultPreAction(), Preferences::defaultPostAction(),
+                                          Preferences::defaultCancelOnPreActionError(), Preferences::defaultDontShowPreActionError());
 
     KActionCollection* actions = new KActionCollection(this);
     KStandardAction::selectAll(mListView, SLOT(selectAll()), actions);
@@ -295,8 +286,9 @@ QVector<KAEvent> BirthdayDlg::events() const
             event.setReminder(reminder, false);
         if (mSpecialActionsButton)
             event.setActions(mSpecialActionsButton->preAction(),
-                             mSpecialActionsButton->postAction(),
-                             mSpecialActionsButton->options());
+                     mSpecialActionsButton->postAction(),
+                             mSpecialActionsButton->cancelOnError(),
+                             mSpecialActionsButton->dontShowError());
         event.endChanges();
         list.append(event);
     }
@@ -370,5 +362,5 @@ void BirthdayDlg::slotTextLostFocus()
         mBirthdaySortModel->setPrefixSuffix(mPrefixText, mSuffixText);
     }
 }
-#include "moc_birthdaydlg.cpp"
+
 // vim: et sw=4:
