@@ -54,9 +54,10 @@
 #include <Akonadi/ItemDeleteJob>
 #include <akonadi/itemfetchjob.h>
 #include <akonadi/itemfetchscope.h>
+#include <akonadi/session.h>
 
 #include "akonadi/entityorderproxymodel.h"
-#include <Akonadi/Notes/NoteUtils>
+#include "akonadi_next/note.h"
 #include "akonadi_next/notecreatorandselector.h"
 
 // Grantlee
@@ -71,15 +72,16 @@
 #include <KFileDialog>
 #include <KFind>
 #include <KFindDialog>
-#include <KLocalizedString>
+#include <KLocale>
 #include <KMessageBox>
 #include <KReplaceDialog>
 #include <kselectionproxymodel.h>
 #include <KStandardDirs>
+#include <KTextEdit>
+#include <KTextBrowser>
 #include <KGlobalSettings>
 #include <KXMLGUIClient>
 #include <KProcess>
-#include <KPrintPreview>
 
 // KMime
 #include <KMime/KMimeMessage>
@@ -98,15 +100,14 @@
 #include <kdebug.h>
 
 #include <memory>
-#include "noteshared/attributes/notelockattribute.h"
+#include "kjotslockattribute.h"
 #include "localresourcecreator.h"
 #include <krandom.h>
 #include "kjotsbrowser.h"
 
-#ifndef KDE_USE_FINAL
 Q_DECLARE_METATYPE(QTextDocument*)
 Q_DECLARE_METATYPE(QTextCursor)
-#endif
+
 using namespace Akonadi;
 using namespace Grantlee;
 
@@ -147,13 +148,13 @@ KJotsWidget::KJotsWidget( QWidget * parent, KXMLGUIClient *xmlGuiClient, Qt::Win
   ItemFetchScope scope;
   scope.fetchFullPayload( true ); // Need to have full item when adding it to the internal data structure
   scope.fetchAttribute< EntityDisplayAttribute >();
-  scope.fetchAttribute< NoteShared::NoteLockAttribute >();
+  scope.fetchAttribute< KJotsLockAttribute >();
 
   ChangeRecorder *monitor = new ChangeRecorder( this );
   monitor->fetchCollection( true );
   monitor->setItemFetchScope( scope );
   monitor->setCollectionMonitored( Collection::root() );
-  monitor->setMimeTypeMonitored( Akonadi::NoteUtils::noteMimeType() );
+  monitor->setMimeTypeMonitored( Akonotes::Note::mimeType() );
 
   m_kjotsModel = new KJotsModel( monitor, this );
 
@@ -199,119 +200,119 @@ KJotsWidget::KJotsWidget( QWidget * parent, KXMLGUIClient *xmlGuiClient, Qt::Win
 
   KAction *action;
 
-  action = actionCollection->addAction( QLatin1String("go_next_book") );
+  action = actionCollection->addAction( "go_next_book" );
   action->setText( i18n( "Next Book" ) );
-  action->setIcon( KIcon( QLatin1String("go-down") ) );
+  action->setIcon( KIcon( "go-down" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_D ) );
   connect( action, SIGNAL(triggered()), SLOT(nextBook()) );
   connect( this, SIGNAL(canGoNextBookChanged(bool)), action, SLOT(setEnabled(bool)) );
 
-  action = actionCollection->addAction( QLatin1String("go_prev_book") );
+  action = actionCollection->addAction( "go_prev_book" );
   action->setText( i18n( "Previous Book" ) );
-  action->setIcon( KIcon( QLatin1String("go-up") ) );
+  action->setIcon( KIcon( "go-up" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::SHIFT + Qt::Key_D ) );
   connect( action, SIGNAL(triggered()), SLOT(prevBook()) );
   connect( this, SIGNAL(canGoPreviousBookChanged(bool)), action, SLOT(setEnabled(bool)) );
 
-  action = actionCollection->addAction( QLatin1String("go_next_page") );
+  action = actionCollection->addAction( "go_next_page" );
   action->setText( i18n( "Next Page" ) );
-  action->setIcon( KIcon( QLatin1String("go-next") ) );
+  action->setIcon( KIcon( "go-next" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_PageDown ) );
   connect( action, SIGNAL(triggered()), SLOT(nextPage()));
   connect( this, SIGNAL(canGoNextPageChanged(bool)), action, SLOT(setEnabled(bool)) );
 
-  action = actionCollection->addAction( QLatin1String("go_prev_page") );
+  action = actionCollection->addAction( "go_prev_page" );
   action->setText( i18n( "Previous Page" ) );
-  action->setIcon( KIcon( QLatin1String("go-previous") ) );
+  action->setIcon( KIcon( "go-previous" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_PageUp ) );
   connect( action, SIGNAL(triggered()), SLOT(prevPage()) );
   connect( this, SIGNAL(canGoPreviousPageChanged(bool)), action, SLOT(setEnabled(bool)) );
 
-  action = actionCollection->addAction( QLatin1String("new_page") );
+  action = actionCollection->addAction( "new_page" );
   action->setText( i18n( "&New Page" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_N ) );
-  action->setIcon( KIcon( QLatin1String("document-new") ) );
+  action->setIcon( KIcon( "document-new" ) );
   connect( action, SIGNAL(triggered()), SLOT(newPage()) );
 
-  action = actionCollection->addAction(QLatin1String("new_book"));
+  action = actionCollection->addAction("new_book");
   action->setText( i18n( "New &Book..." ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::SHIFT + Qt::Key_N ) );
-  action->setIcon( KIcon( QLatin1String("address-book-new") ) );
+  action->setIcon( KIcon( "address-book-new" ) );
   connect( action, SIGNAL(triggered()), SLOT(newBook()) );
 
-  action = actionCollection->addAction( QLatin1String("del_page") );
+  action = actionCollection->addAction( "del_page" );
   action->setText( i18n( "&Delete Page" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_Delete ) );
-  action->setIcon( KIcon( QLatin1String("edit-delete-page") ) );
+  action->setIcon( KIcon( "edit-delete-page" ) );
   connect( action, SIGNAL(triggered()), SLOT(deletePage()) );
 
-  action = actionCollection->addAction( QLatin1String("del_folder") );
+  action = actionCollection->addAction( "del_folder" );
   action->setText( i18n( "Delete Boo&k" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::SHIFT + Qt::Key_Delete ) );
-  action->setIcon( KIcon( QLatin1String("edit-delete") ) );
+  action->setIcon( KIcon( "edit-delete" ) );
   connect( action, SIGNAL(triggered()), SLOT(deleteBook()) );
 
-  action = actionCollection->addAction( QLatin1String("del_mult") );
+  action = actionCollection->addAction( "del_mult" );
   action->setText( i18n( "Delete Selected" ) );
-  action->setIcon( KIcon( QLatin1String("edit-delete") ) );
+  action->setIcon( KIcon( "edit-delete" ) );
   connect( action, SIGNAL(triggered()), SLOT(deleteMultiple()) );
 
-  action = actionCollection->addAction( QLatin1String("manual_save") );
+  action = actionCollection->addAction( "manual_save" );
   action->setText( i18n( "Manual Save" ) );
-  action->setIcon( KIcon( QLatin1String("document-save") ) );
+  action->setIcon( KIcon( "document-save" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_S ) );
 
-  action = actionCollection->addAction( QLatin1String("auto_bullet") );
+  action = actionCollection->addAction( "auto_bullet" );
   action->setText( i18n( "Auto Bullets" ) );
-  action->setIcon( KIcon( QLatin1String("format-list-unordered") ) );
+  action->setIcon( KIcon( "format-list-unordered" ) );
   action->setCheckable( true );
 
-  action = actionCollection->addAction( QLatin1String("auto_decimal") );
+  action = actionCollection->addAction( "auto_decimal" );
   action->setText( i18n( "Auto Decimal List" ) );
-  action->setIcon( KIcon( QLatin1String("format-list-ordered") ) );
+  action->setIcon( KIcon( "format-list-ordered" ) );
   action->setCheckable( true );
 
-  action = actionCollection->addAction( QLatin1String("manage_link") );
+  action = actionCollection->addAction( "manage_link" );
   action->setText( i18n( "Link" ) );
-  action->setIcon( KIcon( QLatin1String("insert-link") ) );
+  action->setIcon( KIcon( "insert-link" ) );
 
-  action = actionCollection->addAction( QLatin1String("insert_checkmark") );
+  action = actionCollection->addAction( "insert_checkmark" );
   action->setText( i18n( "Insert Checkmark" ) );
-  action->setIcon( KIcon( QLatin1String("checkmark") ) );
+  action->setIcon( KIcon( "checkmark" ) );
   action->setEnabled( false );
 
-  action = actionCollection->addAction( QLatin1String("rename_entry") );
+  action = actionCollection->addAction( "rename_entry" );
   action->setText( i18n( "Rename..." ) );
-  action->setIcon( KIcon( QLatin1String("edit-rename") ) );
+  action->setIcon( KIcon( "edit-rename" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_M ) );
 
-  action = actionCollection->addAction( QLatin1String("insert_date") );
+  action = actionCollection->addAction( "insert_date" );
   action->setText( i18n( "Insert Date" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::SHIFT + Qt::Key_I ) );
-  action->setIcon( KIcon( QLatin1String("view-calendar-time-spent") ) );
+  action->setIcon( KIcon( "view-calendar-time-spent" ) );
 
-  action = actionCollection->addAction( QLatin1String("change_color") );
-  action->setIcon( KIcon( QLatin1String("format-fill-color") ) );
+  action = actionCollection->addAction( "change_color" );
+  action->setIcon( KIcon( "format-fill-color" ) );
   action->setText( i18n( "Change Color..." ) );
 
-  action = actionCollection->addAction( QLatin1String("copy_link_address") );
+  action = actionCollection->addAction( "copy_link_address" );
   action->setText( i18n( "Copy Link Address" ) );
 
-  action = actionCollection->addAction( QLatin1String("lock") );
+  action = actionCollection->addAction( "lock" );
   action->setText(i18n( "Lock Selected" ) );
-  action->setIcon( KIcon( QLatin1String("emblem-locked") ) );
+  action->setIcon( KIcon( "emblem-locked" ) );
   connect( action, SIGNAL(triggered()), SLOT(actionLock()) );
 
-  action = actionCollection->addAction( QLatin1String("unlock") );
+  action = actionCollection->addAction( "unlock" );
   action->setText( i18n( "Unlock Selected" ) );
-  action->setIcon( KIcon( QLatin1String("emblem-unlocked") ) );
+  action->setIcon( KIcon( "emblem-unlocked" ) );
   connect( action, SIGNAL(triggered()), SLOT(actionUnlock()) );
 
-  action = actionCollection->addAction( QLatin1String("sort_children_alpha") );
+  action = actionCollection->addAction( "sort_children_alpha" );
   action->setText( i18n( "Sort children alphabetically" ) );
   connect( action, SIGNAL(triggered()), SLOT(actionSortChildrenAlpha()) );
 
-  action = actionCollection->addAction( QLatin1String("sort_children_by_date") );
+  action = actionCollection->addAction( "sort_children_by_date" );
   action->setText( i18n( "Sort children by creation date" ) );
   connect( action, SIGNAL(triggered()), SLOT(actionSortChildrenByDate()) );
 
@@ -326,34 +327,30 @@ KJotsWidget::KJotsWidget( QWidget * parent, KXMLGUIClient *xmlGuiClient, Qt::Win
 
   KStandardAction::pasteText( editor, SLOT(paste()), actionCollection );
 
-  KStandardAction::undo( editor, SLOT(undo()), actionCollection );
-  KStandardAction::redo( editor, SLOT(redo()), actionCollection );
-  KStandardAction::selectAll( editor, SLOT(selectAll()), actionCollection );
-
-  action = actionCollection->addAction( QLatin1String("copyIntoTitle") );
+  action = actionCollection->addAction( "copyIntoTitle" );
   action->setText( i18n( "Copy &into Page Title" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_T ) );
-  action->setIcon( KIcon( QLatin1String("edit-copy") ) );
+  action->setIcon( KIcon( "edit-copy" ) );
   connect( action, SIGNAL(triggered()), SLOT(copySelectionToTitle()) );
   connect( editor, SIGNAL(copyAvailable(bool)), action, SLOT(setEnabled(bool)) );
   action->setEnabled( false );
 
-  action = actionCollection->addAction( QLatin1String("paste_plain_text") );
+  action = actionCollection->addAction( "paste_plain_text" );
   action->setText( i18nc( "@action Paste the text in the clipboard without rich text formatting.", "Paste Plain Text" ) );
   connect( action, SIGNAL(triggered()), editor, SLOT(pastePlainText()) );
 
   KStandardAction::preferences( this, SLOT(configure()), actionCollection );
 
-  bookmarkMenu = actionCollection->add<KActionMenu>( QLatin1String("bookmarks") );
+  bookmarkMenu = actionCollection->add<KActionMenu>( "bookmarks" );
   bookmarkMenu->setText( i18n( "&Bookmarks" ) );
   KJotsBookmarks* bookmarks = new KJotsBookmarks( treeview );
   /*KBookmarkMenu *bmm =*/ new KBookmarkMenu(
-      KBookmarkManager::managerForFile( KStandardDirs::locateLocal( "data",QLatin1String("kjots/bookmarks.xml") ), QLatin1String("kjots") ),
+      KBookmarkManager::managerForFile( KStandardDirs::locateLocal( "data","kjots/bookmarks.xml" ), "kjots" ),
       bookmarks, bookmarkMenu->menu(), actionCollection );
 
   // "Add bookmark" and "make text bold" actions have conflicting shortcuts (ctrl + b)
   // Make add_bookmark use ctrl+shift+b to resolve that.
-  KAction *bm_action = qobject_cast<KAction *>(actionCollection->action(QLatin1String("add_bookmark")));
+  KAction *bm_action = qobject_cast<KAction *>(actionCollection->action("add_bookmark"));
   Q_ASSERT(bm_action);
   bm_action->setShortcut( Qt::CTRL + Qt::SHIFT + Qt::Key_B );
 
@@ -362,35 +359,34 @@ KJotsWidget::KJotsWidget( QWidget * parent, KXMLGUIClient *xmlGuiClient, Qt::Win
   action->setEnabled(false);
   KStandardAction::replace( this, SLOT(onShowReplace()), actionCollection );
 
-  action = actionCollection->addAction( QLatin1String("save_to") );
+  action = actionCollection->addAction( "save_to" );
   action->setText( i18n( "Rename..." ) );
-  action->setIcon( KIcon( QLatin1String("edit-rename") ) );
+  action->setIcon( KIcon( "edit-rename" ) );
   action->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_M ) );
 
-  KActionMenu *exportMenu = actionCollection->add<KActionMenu>( QLatin1String("save_to") );
+  KActionMenu *exportMenu = actionCollection->add<KActionMenu>( "save_to" );
   exportMenu->setText( i18n( "Export" ) );
-  exportMenu->setIcon( KIcon( QLatin1String("document-export") ) );
+  exportMenu->setIcon( KIcon( "document-export" ) );
 
-  action = actionCollection->addAction( QLatin1String("save_to_ascii") );
+  action = actionCollection->addAction( "save_to_ascii" );
   action->setText( i18n( "To Text File..." ) );
-  action->setIcon( KIcon( QLatin1String("text-plain") ) );
+  action->setIcon( KIcon( "text-plain" ) );
   connect( action, SIGNAL(triggered()), SLOT(exportSelectionToPlainText()) );
   exportMenu->menu()->addAction( action );
 
-  action = actionCollection->addAction( QLatin1String("save_to_html") );
+  action = actionCollection->addAction( "save_to_html" );
   action->setText( i18n( "To HTML File..." ) );
-  action->setIcon( KIcon( QLatin1String("text-html") ) );
+  action->setIcon( KIcon( "text-html" ) );
   connect( action, SIGNAL(triggered()), SLOT(exportSelectionToHtml()) );
   exportMenu->menu()->addAction( action );
 
-  action = actionCollection->addAction( QLatin1String("save_to_book") );
+  action = actionCollection->addAction( "save_to_book" );
   action->setText( i18n( "To Book File..." ) );
-  action->setIcon( KIcon( QLatin1String("x-office-address-book") ) );
+  action->setIcon( KIcon( "x-office-address-book" ) );
   connect( action, SIGNAL(triggered()), SLOT(exportSelectionToXml()) );
   exportMenu->menu()->addAction( action );
 
   KStandardAction::print(this, SLOT(printSelection()), actionCollection);
-  KStandardAction::printPreview(this, SLOT(printPreviewSelection()), actionCollection);
 
   if ( !KJotsSettings::splitterSizes().isEmpty() )
   {
@@ -407,7 +403,7 @@ KJotsWidget::KJotsWidget( QWidget * parent, KXMLGUIClient *xmlGuiClient, Qt::Win
 
   restoreState();
 
-  QDBusConnection::sessionBus().registerObject( QLatin1String("/KJotsWidget"), this, QDBusConnection::ExportScriptableContents );
+  QDBusConnection::sessionBus().registerObject( "/KJotsWidget", this, QDBusConnection::ExportScriptableContents );
 }
 
 KJotsWidget::~KJotsWidget()
@@ -434,7 +430,7 @@ void KJotsWidget::saveState()
 
 void KJotsWidget::delayedInitialization()
 {
-  migrateNoteData( QLatin1String("kjotsmigrator") );
+  migrateNoteData( "kjotsmigrator" );
   // Disable nigration of data from KNotes as that app still exists in 4.5.
 //   migrateNoteData( "kres-migrator", "notes" );
 
@@ -476,36 +472,36 @@ void KJotsWidget::delayedInitialization()
   KActionCollection *actionCollection = m_xmlGuiClient->actionCollection();
 
   // Actions for a single item selection.
-  entryActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Find))) );
-  entryActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Print))) );
-  entryActions.insert( actionCollection->action(QLatin1String("rename_entry")) );
-  entryActions.insert( actionCollection->action(QLatin1String("change_color")) );
-  entryActions.insert( actionCollection->action(QLatin1String("save_to")) );
-  entryActions.insert( actionCollection->action(QLatin1String("copy_link_address")) );
+  entryActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Find)) );
+  entryActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Print)) );
+  entryActions.insert( actionCollection->action("rename_entry") );
+  entryActions.insert( actionCollection->action("change_color") );
+  entryActions.insert( actionCollection->action("save_to") );
+  entryActions.insert( actionCollection->action("copy_link_address") );
 
   // Actions that are used only when a page is selected.
-  pageActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Cut))) );
-  pageActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Paste))) );
-  pageActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Replace))) );
-  pageActions.insert( actionCollection->action(QLatin1String("del_page")) );
-  pageActions.insert( actionCollection->action(QLatin1String("insert_date")) );
-  pageActions.insert( actionCollection->action(QLatin1String("auto_bullet")) );
-  pageActions.insert( actionCollection->action(QLatin1String("auto_decimal")) );
-  pageActions.insert( actionCollection->action(QLatin1String("manage_link")) );
-  pageActions.insert( actionCollection->action(QLatin1String("insert_checkmark")) );
+  pageActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Cut)) );
+  pageActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Paste)) );
+  pageActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Replace)) );
+  pageActions.insert( actionCollection->action("del_page") );
+  pageActions.insert( actionCollection->action("insert_date") );
+  pageActions.insert( actionCollection->action("auto_bullet") );
+  pageActions.insert( actionCollection->action("auto_decimal") );
+  pageActions.insert( actionCollection->action("manage_link") );
+  pageActions.insert( actionCollection->action("insert_checkmark") );
 
   // Actions that are used only when a book is selected.
-  bookActions.insert( actionCollection->action(QLatin1String("save_to_book")) );
-  bookActions.insert( actionCollection->action(QLatin1String("del_folder")) );
-  bookActions.insert( actionCollection->action(QLatin1String("sort_children_alpha")) );
-  bookActions.insert( actionCollection->action(QLatin1String("sort_children_by_date")) );
+  bookActions.insert( actionCollection->action("save_to_book") );
+  bookActions.insert( actionCollection->action("del_folder") );
+  bookActions.insert( actionCollection->action("sort_children_alpha") );
+  bookActions.insert( actionCollection->action("sort_children_by_date") );
 
   // Actions that are used when multiple items are selected.
-  multiselectionActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Find))) );
-  multiselectionActions.insert( actionCollection->action(QLatin1String(KStandardAction::name(KStandardAction::Print))));
-  multiselectionActions.insert( actionCollection->action(QLatin1String("del_mult")) );
-  multiselectionActions.insert( actionCollection->action(QLatin1String("save_to")) );
-  multiselectionActions.insert( actionCollection->action(QLatin1String("change_color")) );
+  multiselectionActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Find)) );
+  multiselectionActions.insert( actionCollection->action(KStandardAction::name(KStandardAction::Print)));
+  multiselectionActions.insert( actionCollection->action("del_mult") );
+  multiselectionActions.insert( actionCollection->action("save_to") );
+  multiselectionActions.insert( actionCollection->action("change_color") );
 
   m_autosaveTimer = new QTimer(this);
   updateConfiguration();
@@ -556,7 +552,7 @@ void KJotsWidget::currentCharFormatChanged(const QTextCharFormat & fmt)
 void KJotsWidget::migrateNoteData( const QString &migrator, const QString &type )
 {
   // Akonadi migration
-  KConfig config( migrator + QLatin1String("rc") );
+  KConfig config( migrator + "rc" );
   KConfigGroup migrationCfg( &config, "Migration" );
   const bool enabled = migrationCfg.readEntry( "Enabled", true );
   const bool completed = migrationCfg.readEntry( "Completed", false );
@@ -565,9 +561,9 @@ void KJotsWidget::migrateNoteData( const QString &migrator, const QString &type
   if ( enabled && !completed && currentVersion < targetVersion ) {
     kDebug() << "Performing Akonadi migration. Good luck!";
     KProcess proc;
-    QStringList args = QStringList() << QLatin1String("--interactive-on-change");
+    QStringList args = QStringList() << "--interactive-on-change";
     if ( !type.isEmpty() )
-      args << QLatin1String("--type") << type;
+      args << "--type" << type;
 
     const QString path = KStandardDirs::findExe( migrator );
     proc.setProgram( path, args );
@@ -642,7 +638,7 @@ void KJotsWidget::updateMenu()
         action->setEnabled(false);
       const bool colIsRootCollection = ( col.parentCollection() == Collection::root() );
       foreach ( QAction* action, bookActions ) {
-        if (action->objectName() == QLatin1String("del_folder") && colIsRootCollection ) {
+        if (action->objectName() == "del_folder" && colIsRootCollection ) {
           action->setEnabled( false );
         } else {
           action->setEnabled( true );
@@ -653,7 +649,7 @@ void KJotsWidget::updateMenu()
       editor->setActionsEnabled( false );
     } else {
       foreach ( QAction* action, pageActions ) {
-        if (action->objectName() == QLatin1String(name( KStandardAction::Cut )) ) {
+        if (action->objectName() == name( KStandardAction::Cut ) ) {
           action->setEnabled( activeEditor()->textCursor().hasSelection() );
         } else {
           action->setEnabled( true );
@@ -745,7 +741,7 @@ void KJotsWidget::deletePage()
   if ( !item.isValid() )
     return;
 
-  if( item.hasAttribute<NoteShared::NoteLockAttribute>() ) {
+  if( item.hasAttribute<KJotsLockAttribute>() ) {
 
         KMessageBox::information(topLevelWidget(),
             i18n("This page is locked. You can only delete it when you first unlock it."),
@@ -755,7 +751,7 @@ void KJotsWidget::deletePage()
 
   if ( KMessageBox::warningContinueCancel(topLevelWidget(),
           i18nc("remove the page, by title", "<qt>Are you sure you want to delete the page <strong>%1</strong>?</qt>", idx.data().toString()),
-          i18n("Delete"), KStandardGuiItem::del(), KStandardGuiItem::cancel(), QLatin1String("DeletePageWarning")) == KMessageBox::Cancel) {
+          i18n("Delete"), KStandardGuiItem::del(), KStandardGuiItem::cancel(), "DeletePageWarning") == KMessageBox::Cancel) {
       return;
   }
 
@@ -778,7 +774,7 @@ void KJotsWidget::deleteBook()
   if ( col.parentCollection() == Collection::root() )
     return;
 
-  if( col.hasAttribute<NoteShared::NoteLockAttribute>() ) {
+  if( col.hasAttribute<KJotsLockAttribute>() ) {
 
       KMessageBox::information(topLevelWidget(),
           i18n("This book is locked. You can only delete it when you first unlock it."),
@@ -787,7 +783,7 @@ void KJotsWidget::deleteBook()
   }
   if ( KMessageBox::warningContinueCancel(topLevelWidget(),
       i18nc("remove the book, by title", "<qt>Are you sure you want to delete the book <strong>%1</strong>?</qt>", idx.data().toString()),
-      i18n("Delete"), KStandardGuiItem::del(), KStandardGuiItem::cancel(), QLatin1String("DeleteBookWarning")) == KMessageBox::Cancel) {
+      i18n("Delete"), KStandardGuiItem::del(), KStandardGuiItem::cancel(), "DeleteBookWarning") == KMessageBox::Cancel) {
         return;
   }
 
@@ -811,10 +807,10 @@ void KJotsWidget::newBook()
 
   QString title = i18nc( "The default name for new books.", "New Book" );
   newCollection.setName( KRandom::randomString( 10 ) );
-  newCollection.setContentMimeTypes( QStringList() << Akonadi::Collection::mimeType() << Akonadi::NoteUtils::noteMimeType() );
+  newCollection.setContentMimeTypes( QStringList() << Akonadi::Collection::mimeType() << Akonotes::Note::mimeType() );
 
   Akonadi::EntityDisplayAttribute *eda = new Akonadi::EntityDisplayAttribute();
-  eda->setIconName( QLatin1String("x-office-address-book") );
+  eda->setIconName( "x-office-address-book" );
   eda->setDisplayName( title );
   newCollection.addAttribute( eda );
 
@@ -957,7 +953,7 @@ QString KJotsWidget::renderSelectionToXml()
   Context c(hash);
 
   QString currentTheme = m_loader->themeName();
-  m_loader->setTheme( QLatin1String("xml_output") );
+  m_loader->setTheme( "xml_output" );
   Template t = m_templateEngine->loadByName( QLatin1String( "template.xml" ) );
 
   QString result = t->render(&c);
@@ -1054,7 +1050,7 @@ void KJotsWidget::exportSelectionToPlainText()
 {
   QString currentTheme = m_loader->themeName();
 
-  m_loader->setTheme( QLatin1String("plain_text") );
+  m_loader->setTheme( "plain_text" );
 
   QString filename = KFileDialog::getSaveFileName();
   if (!filename.isEmpty())
@@ -1076,7 +1072,7 @@ void KJotsWidget::exportSelectionToXml()
 {
   QString currentTheme = m_loader->themeName();
 
-  m_loader->setTheme( QLatin1String("xml_output") );
+  m_loader->setTheme( "xml_output" );
 
   QString filename = KFileDialog::getSaveFileName();
   if (!filename.isEmpty())
@@ -1094,24 +1090,13 @@ void KJotsWidget::exportSelectionToXml()
   m_loader->setTheme(currentTheme);
 }
 
-void KJotsWidget::printPreviewSelection()
-{
-    QPrinter printer(QPrinter::HighResolution);
-    printer.setDocName(QLatin1String("KJots_Print"));
-    printer.setFullPage(false);
-    printer.setCreator(QLatin1String("KJots"));
-    KPrintPreview previewdlg( &printer, 0 );
-    print(printer);
-    previewdlg.exec();
-}
-
 void KJotsWidget::printSelection()
 {
 
-  QPrinter printer(QPrinter::HighResolution);
-  printer.setDocName(QLatin1String("KJots_Print"));
-  printer.setFullPage(false);
-  printer.setCreator(QLatin1String("KJots"));
+  QPrinter *printer = new QPrinter();
+  printer->setDocName("KJots_Print");
+  printer->setFullPage(false);
+  printer->setCreator("KJots");
   //Not supported in Qt?
   //printer->setPageSelection(QPrinter::ApplicationSide);
 
@@ -1120,7 +1105,7 @@ void KJotsWidget::printSelection()
   //are before I setup the printer?
 
 
-  QPointer<QPrintDialog> printDialog = new QPrintDialog(&printer, this);
+  QPointer<QPrintDialog> printDialog = new QPrintDialog(printer, this);
 
   QAbstractPrintDialog::PrintDialogOptions options = printDialog->enabledOptions();
   options &= ~QAbstractPrintDialog::PrintPageRange;
@@ -1130,26 +1115,19 @@ void KJotsWidget::printSelection()
 
   printDialog->setWindowTitle(i18n("Send To Printer"));
   if (printDialog->exec() == QDialog::Accepted) {
-      print(printer);
-  }
-  delete printDialog;
-}
-
-void KJotsWidget::print(QPrinter &printer)
-{
     QTextDocument printDocument;
-    if ( printer.printRange() == QPrinter::Selection )
+    if ( printer->printRange() == QPrinter::Selection )
     {
       printDocument.setHtml( activeEditor()->textCursor().selection().toHtml() );
     } else {
-      //QTextCursor printCursor ( &printDocument );
+      QTextCursor printCursor ( &printDocument );
       QString currentTheme = m_loader->themeName();
-      m_loader->setTheme( QLatin1String("default") );
+      m_loader->setTheme( "default" );
       printDocument.setHtml( renderSelectionToHtml() );
       m_loader->setTheme( currentTheme );
     }
 
-    QPainter p(&printer);
+    QPainter p(printer);
 
     // Check that there is a valid device to print to.
     if (p.isActive()) {
@@ -1176,11 +1154,11 @@ void KJotsWidget::print(QPrinter &printer)
 
       doc->setPageSize(body.size());
 
-      int docCopies = printer.numCopies();
+      int docCopies = printer->numCopies();
       for (int copy = 0; copy < docCopies; ++copy) {
 
         int lastPage = layout->pageCount();
-        for ( int page = 1; page <= lastPage ; ++page ) {
+        for ( int page = 1; page <= lastPage ; page++ ) {
           p.save();
           p.translate(body.left(), body.top() - (page - 1) * body.height());
           QRectF view(0, (page - 1) * body.height(), body.width(), body.height());
@@ -1211,11 +1189,15 @@ void KJotsWidget::print(QPrinter &printer)
           p.restore();
 
           if ( (page+1) <= lastPage ) {
-            printer.newPage();
+            printer->newPage();
           }
         }
       }
     }
+  }
+  delete printDialog;
+
+  delete printer;
 
 }
 
@@ -1423,7 +1405,7 @@ void KJotsWidget::onStartSearch()
     }
   }
 
-  m_xmlGuiClient->actionCollection()->action( QLatin1String(KStandardAction::name( KStandardAction::FindNext )) )->setEnabled( true );
+  m_xmlGuiClient->actionCollection()->action( KStandardAction::name( KStandardAction::FindNext ) )->setEnabled( true );
 
   onRepeatSearch();
 }
@@ -1435,7 +1417,7 @@ void KJotsWidget::onRepeatSearch()
 {
   if ( search( false ) == 0 ) {
     KMessageBox::sorry( 0, i18n( "<qt>No matches found.</qt>" ) );
-    m_xmlGuiClient->actionCollection()->action( QLatin1String(KStandardAction::name( KStandardAction::FindNext )) )->setEnabled( false );
+    m_xmlGuiClient->actionCollection()->action( KStandardAction::name( KStandardAction::FindNext ) )->setEnabled( false );
   }
 }
 
@@ -1444,7 +1426,7 @@ void KJotsWidget::onRepeatSearch()
 */
 void KJotsWidget::onEndSearch()
 {
-  m_xmlGuiClient->actionCollection()->action( QLatin1String(KStandardAction::name( KStandardAction::FindNext )) )->setEnabled( false );
+  m_xmlGuiClient->actionCollection()->action( KStandardAction::name( KStandardAction::FindNext ) )->setEnabled( false );
 }
 
 /*!
@@ -1576,8 +1558,8 @@ void KJotsWidget::onRepeatReplace()
                                         Qt::CaseSensitive : Qt::CaseInsensitive, QRegExp::RegExp2 );
       regExp.indexIn(cursor.selectedText());
       int capCount = regExp.numCaptures();
-      for ( int i=0; i <= capCount; ++i ) {
-        QString c = QString::fromLatin1( "\\%1" ).arg( i );
+      for ( int i=0; i <= capCount; i++ ) {
+        QString c = QString( "\\%1" ).arg( i );
         replacementText.replace( c, regExp.cap( i ) );
       }
     }
@@ -1744,7 +1726,7 @@ int KJotsWidget::search( bool replacing )
 
 void KJotsWidget::updateCaption()
 {
-  emit captionChanged( treeview->captionForSelection( QLatin1String(" / ") ) );
+  emit captionChanged( treeview->captionForSelection( " / " ) );
 }
 
 void KJotsWidget::dataChanged( const QModelIndex &topLeft, const QModelIndex &bottomRight )
@@ -1757,7 +1739,7 @@ void KJotsWidget::dataChanged( const QModelIndex &topLeft, const QModelIndex &bo
   QItemSelection changed( topLeft, bottomRight );
   if ( changed.contains( rows.first() ) )
   {
-    emit captionChanged( treeview->captionForSelection( QLatin1String(" / ") ) );
+    emit captionChanged( treeview->captionForSelection( " / " ) );
   }
 }
 
@@ -1849,3 +1831,4 @@ void KJotsWidget::actionSortChildrenByDate()
   }
 }
 
+#include "kjotswidget.moc"
