@@ -174,14 +174,13 @@ void CertifyCertificateCommand::doStart() {
     }
 
     std::vector<Key> secKeys = KeyCache::instance()->secretKeys();
-    std::vector<Key>::iterator it = std::remove_if( secKeys.begin(), secKeys.end(), !bind( &Key::canCertify, _1 ) );
-    it = std::remove_if( it, secKeys.end(), bind( &Key::protocol, _1 ) != OpenPGP );
+    std::vector<Key>::iterator it = std::remove_if( secKeys.begin(), secKeys.end(), !boost::bind( &Key::canCertify, _1 ) );
+    it = std::remove_if( it, secKeys.end(), boost::bind( &Key::protocol, _1 ) != OpenPGP );
     secKeys.erase( it, secKeys.end() );
 
     if ( secKeys.empty() ) {
-        KMessageBox::error( d->parentWidgetOrView(),
-                            i18n( "To certify other certificates, you first need to create an OpenPGP certificate for yourself. Choose <interface>File->New Certificate...</interface> to create one." ),
-                            i18n( "Certification Not Possible" ) );
+        d->error( i18nc( "@info", "To certify other certificates, you first need to create an OpenPGP certificate for yourself. Choose <interface>File->New Certificate...</interface> to create one." ),
+                  i18n( "Certification Not Possible" ) );
         d->finished();
         return;
     }
@@ -197,6 +196,7 @@ void CertifyCertificateCommand::doStart() {
     d->ensureDialogCreated();
     assert( d->dialog );
     d->dialog->setCertificateToCertify( d->key() );
+    d->dialog->setSelectedUserIDs( d->uids );
     d->dialog->setCertificatesWithSecretKeys( secKeys );
     d->dialog->show();
 }
@@ -244,7 +244,8 @@ void CertifyCertificateCommand::Private::ensureDialogCreated() {
     if ( dialog )
         return;
 
-    dialog = new CertifyCertificateDialog( parentWidgetOrView() );
+    dialog = new CertifyCertificateDialog;
+    applyWindowID( dialog );
     dialog->setAttribute( Qt::WA_DeleteOnClose );
 
     connect( dialog, SIGNAL(rejected()), q, SLOT(slotDialogRejected()) );
