@@ -41,8 +41,7 @@
 #include <models/keycache.h>
 #include <models/predicates.h>
 
-#include <utils/stl_util.h>
-
+#include <kleo/stl_util.h>
 #include <kleo/cryptobackend.h>
 #include <kleo/cryptobackendfactory.h>
 #include <kleo/multideletejob.h>
@@ -93,11 +92,12 @@ public:
     void ensureDialogCreated() {
         if ( dialog )
             return;
-        dialog = new DeleteCertificatesDialog( parentWidgetOrView() );
+        dialog = new DeleteCertificatesDialog;
+        applyWindowID( dialog );
         dialog->setAttribute( Qt::WA_DeleteOnClose );
         dialog->setWindowTitle( i18nc("@title:window", "Delete Certificates") );
-        connect( dialog, SIGNAL(accepted()), q, SLOT(slotDialogAccepted()) );
-        connect( dialog, SIGNAL(rejected()), q, SLOT(slotDialogRejected()) );
+        connect( dialog, SIGNAL(accepted()), q_func(), SLOT(slotDialogAccepted()) );
+        connect( dialog, SIGNAL(rejected()), q_func(), SLOT(slotDialogRejected()) );
     }
     void ensureDialogShown() {
         if ( dialog )
@@ -263,7 +263,7 @@ void DeleteCertificatesCommand::Private::slotDialogAccepted() {
     std::vector<Key>::iterator
         pgpBegin = keys.begin(),
         pgpEnd = std::stable_partition( pgpBegin, keys.end(),
-                                        bind( &GpgME::Key::protocol, _1 ) != CMS ),
+                                        boost::bind( &GpgME::Key::protocol, _1 ) != CMS ),
         cmsBegin = pgpEnd,
         cmsEnd = keys.end() ;
 
@@ -275,11 +275,10 @@ void DeleteCertificatesCommand::Private::slotDialogAccepted() {
             cms.empty() << 1U |     canDelete( CMS ) << 0U ;
 
     if ( const unsigned int actions = deletionErrorCases[errorCase].actions ) {
-        KMessageBox::information( parentWidgetOrView(),
-                                  i18n( deletionErrorCases[errorCase].text ),
-                                  (actions & Failure)
-                                  ? i18n( "Certificate Deletion Failed" )
-                                  : i18n( "Certificate Deletion Problem" ) );
+        information( i18n( deletionErrorCases[errorCase].text ),
+                     (actions & Failure)
+                     ? i18n( "Certificate Deletion Failed" )
+                     : i18n( "Certificate Deletion Problem" ) );
         if ( actions & ClearCMS )
             cms.clear();
         if ( actions & ClearPGP )
@@ -315,8 +314,12 @@ void DeleteCertificatesCommand::Private::startDeleteJob( GpgME::Protocol protoco
 
     std::auto_ptr<MultiDeleteJob> job( new MultiDeleteJob( backend ) );
 
-    connect( job.get(), SIGNAL(result(GpgME::Error,GpgME::Key)),
-             q, protocol == CMS ? SLOT(cmsDeleteResult(GpgME::Error)) : SLOT(pgpDeleteResult(GpgME::Error)) );
+    if ( protocol == CMS )
+        connect( job.get(), SIGNAL(result(GpgME::Error,GpgME::Key)),
+                 q_func(), SLOT(cmsDeleteResult(GpgME::Error)) );
+    else
+        connect( job.get(), SIGNAL(result(GpgME::Error,GpgME::Key)),
+                 q_func(), SLOT(pgpDeleteResult(GpgME::Error)) );
 
     connect( job.get(), SIGNAL(progress(QString,int,int)),
              q, SIGNAL(progress(QString,int,int)) );
@@ -343,7 +346,7 @@ void DeleteCertificatesCommand::Private::showErrorsAndFinish() {
                                  "the certificate:</p>"
                                  "<p><b>%1</b></p></qt>",
                                  pgpError ? cmsError ? pgpErrorString + "</br>" + cmsErrorString : pgpErrorString : cmsErrorString );
-        KMessageBox::error( parentWidgetOrView(), msg, i18n("Certificate Deletion Failed") );
+        error( msg, i18n("Certificate Deletion Failed") );
     } else {
         std::vector<Key> keys = pgpKeys;
         keys.insert( keys.end(), cmsKeys.begin(), cmsKeys.end() );
