@@ -38,6 +38,7 @@
 
 #include <dialogs/exportcertificatesdialog.h>
 
+#include <utils/classify.h>
 #include <utils/filedialog.h>
 
 #include <kleo/cryptobackend.h>
@@ -151,7 +152,7 @@ void ExportCertificateCommand::doStart()
     if ( keys.empty() )
         return;
 
-    const std::vector<Key>::iterator firstCms = std::partition( keys.begin(), keys.end(), bind( &GpgME::Key::protocol, _1 ) != CMS );
+    const std::vector<Key>::iterator firstCms = std::partition( keys.begin(), keys.end(), boost::bind( &GpgME::Key::protocol, _1 ) != CMS );
 
     std::vector<Key> openpgp, cms; 
     std::copy( keys.begin(), firstCms, std::back_inserter( openpgp ) ); 
@@ -176,7 +177,8 @@ bool ExportCertificateCommand::Private::requestFileNames( GpgME::Protocol protoc
     {
         if ( !fileNames[OpenPGP].isEmpty() && !fileNames[CMS].isEmpty() )
             return true;
-        const QPointer<ExportCertificatesDialog> dlg( new ExportCertificatesDialog( parentWidgetOrView() ) );
+        const QPointer<ExportCertificatesDialog> dlg( new ExportCertificatesDialog );
+        applyWindowID( dlg );
         dlg->setOpenPgpExportFileName( fileNames[OpenPGP] );
         dlg->setCmsExportFileName( fileNames[CMS] );
         const bool accepted = dlg->exec() == QDialog::Accepted && dlg ;
@@ -196,12 +198,23 @@ bool ExportCertificateCommand::Private::requestFileNames( GpgME::Protocol protoc
     if ( !fileNames[protocol].isEmpty() )
         return true;
 
-    const QString fname =  FileDialog::getSaveFileName( parentWidgetOrView(),
-                                                        i18n( "Export Certificates" ), 
-                                                        "imp",
-                                                        protocol == GpgME::OpenPGP
-                                                        ? i18n( "OpenPGP Certificates" ) + " (*.asc *.gpg *.pgp)"
-                                                        : i18n( "S/MIME Certificates" )  + " (*.pem *.der)" );
+    QString proposedFileName;
+    if ( keys().size() == 1 )
+        proposedFileName
+            = QString::fromLatin1( keys().front().primaryFingerprint() )
+            + QLatin1Char( '.' )
+            + QString::fromLatin1( outputFileExtension( protocol == OpenPGP
+                                                        ? Class::OpenPGP|Class::Ascii|Class::Certificate
+                                                        : Class::CMS|Class::Ascii|Class::Certificate ) )
+            ;
+
+    const QString fname = FileDialog::getSaveFileNameEx( parentWidgetOrView(),
+                                                         i18n( "Export Certificates" ), 
+                                                         "imp",
+                                                         proposedFileName,
+                                                         protocol == GpgME::OpenPGP
+                                                         ? QString(i18n( "OpenPGP Certificates" ) + " (*.asc *.gpg *.pgp)")
+                                                         : QString(i18n( "S/MIME Certificates" )  + " (*.pem *.der)" ));
     fileNames[protocol] = fname;
     return !fname.isEmpty();
 }
@@ -239,7 +252,7 @@ void ExportCertificateCommand::Private::startExportJob( GpgME::Protocol protocol
     ++jobsPending;
     const QPointer<ExportJob> exportJob( job.release() );
 
-    outFileForSender[exportJob] = fileName;
+    outFileForSender[exportJob.data()] = fileName;
     ( protocol == CMS ? cmsJob : pgpJob ) = exportJob;
 }
 
@@ -250,7 +263,7 @@ void ExportCertificateCommand::Private::showError( const GpgME::Error& err )
                              "the certificate:</p>"
                              "<p><b>%1</b></p></qt>",
                              QString::fromLocal8Bit( err.asString() ) );
-    KMessageBox::error( parentWidgetOrView(), msg, i18n("Certificate Export Failed") );
+    error( msg, i18n("Certificate Export Failed") );
 }
 
 void ExportCertificateCommand::doCancel()
@@ -296,14 +309,14 @@ void ExportCertificateCommand::Private::exportResult( const GpgME::Error& err, c
     const QString errorCaption = i18n( "Certificate Export Failed" );
     if ( !savefile.open() )
     {
-        KMessageBox::error( parentWidgetOrView(), writeErrorMsg, errorCaption );
+        error( writeErrorMsg, errorCaption );
         finishedIfLastJob();
         return;
     }
 
     if ( !write_complete( savefile, data ) ||
          !savefile.finalize() )
-        KMessageBox::error( parentWidgetOrView(), writeErrorMsg, errorCaption );
+        error( writeErrorMsg, errorCaption );
     finishedIfLastJob();
 }
 
