@@ -57,6 +57,7 @@
 #include <QColor>
 #include <QFont>
 #include <QString>
+#include <QPainter>
 #include <QRegExp>
 #include <QApplication>
 #include <QColorDialog>
@@ -432,7 +433,7 @@ void AppearanceConfigWidget::load() {
     KConfig * const config = CryptoBackendFactory::instance()->configObject();
     if ( !config )
         return;
-    const QStringList groups = config->groupList().filter( QRegExp( QLatin1String("^Key Filter #\\d+$") ) );
+    const QStringList groups = config->groupList().filter( QRegExp( "^Key Filter #\\d+$" ) );
     Q_FOREACH( const QString & group, groups ) {
         //QListWidgetItem * item = new QListWidgetItem( d->categoriesLV );
         apply_config( KConfigGroup( config, group ), new QListWidgetItem( d->categoriesLV ) );
@@ -459,7 +460,7 @@ void AppearanceConfigWidget::save() {
         return;
     // We know (assume) that the groups in the config object haven't changed,
     // so we just iterate over them and over the listviewitems, and map one-to-one.
-    const QStringList groups = config->groupList().filter( QRegExp( QLatin1String("^Key Filter #\\d+$") ) );
+    const QStringList groups = config->groupList().filter( QRegExp( "^Key Filter #\\d+$" ) );
 #if 0
     if ( groups.isEmpty() ) {
         // If we created the default categories ourselves just now, then we need to make up their list
@@ -484,16 +485,20 @@ void AppearanceConfigWidget::Private::slotIconClicked() {
     if ( !item )
         return;
 
+#ifndef _WIN32_WCE
     const QString iconName = KIconDialog::getIcon( /* repeating default arguments begin */
                                                   KIconLoader::Desktop, KIconLoader::Application, false, 0, false,
                                                   /* repeating default arguments end */
                                                   q );
     if ( iconName.isEmpty() )
+#endif
         return;
 
+#ifndef _WIN32_WCE
     item->setIcon( KIcon( iconName ) );
     item->setData( IconNameRole, iconName );
     emit q->changed();
+#endif
 }
 
 #ifndef QT_NO_COLORDIALOG
@@ -590,4 +595,4 @@ void AppearanceConfigWidget::Private::slotTooltipDetailsChanged( bool )
 }
 
 
-#include "moc_appearanceconfigwidget.cpp"
+#include "appearanceconfigwidget.moc"
