@@ -45,6 +45,27 @@
 #include <QApplication>
 #include <QIcon>
 
+#ifdef KLEO_STATIC_KCMODULES
+# include <KDesktopFile>
+# define KCM_IMPORT_PLUGIN( x ) extern "C" KCModule * create_##x( QWidget * parent=0, const QVariantList & args=QVariantList() );
+# define addMyModule( x ) addModule( KCModuleInfo( KDesktopFile( "services", #x ".desktop" ) ), create_##x() )
+#else // KLEO_STATIC_KCMODULES
+# define KCM_IMPORT_PLUGIN( x )
+# define addMyModule( x ) addModule( #x )
+#endif // KLEO_STATIC_KCMODULES
+
+KCM_IMPORT_PLUGIN( kleopatra_config_dirserv )
+#ifndef KDEPIM_MOBILE_UI
+KCM_IMPORT_PLUGIN( kleopatra_config_appear )
+#endif
+#ifdef HAVE_KLEOPATRACLIENT_LIBRARY
+# ifndef KDEPIM_MOBILE_UI
+KCM_IMPORT_PLUGIN( kleopatra_config_cryptooperations )
+# endif
+KCM_IMPORT_PLUGIN( kleopatra_config_smimevalidation )
+#endif
+KCM_IMPORT_PLUGIN( kleopatra_config_gnupgsystem )
+
 ConfigureDialog::ConfigureDialog( QWidget * parent )
   : KCMultiDialog( parent )
 {
@@ -55,14 +76,21 @@ ConfigureDialog::ConfigureDialog( QWidget * parent )
                   qApp->windowIcon().pixmap( IconSize( KIconLoader::Small ), IconSize( KIconLoader::Small ) ) );
 #endif
   showButton( User1, true );
-
-  addModule( "kleopatra_config_dirserv" );
-  addModule( "kleopatra_config_appear" );
-  addModule( "kleopatra_config_dnorder" );
-#ifdef HAVE_KLEOPATRACLIENT_LIBRARY
-  addModule( "kleopatra_config_smimevalidation" );
+#ifdef _WIN32_WCE
+  showButton( Help , false );
 #endif
-  addModule( "kleopatra_config_gnupgsystem" );
+
+  addMyModule( kleopatra_config_dirserv );
+#ifndef KDEPIM_MOBILE_UI
+  addMyModule( kleopatra_config_appear );
+#endif
+#ifdef HAVE_KLEOPATRACLIENT_LIBRARY
+# ifndef KDEPIM_MOBILE_UI
+  addMyModule( kleopatra_config_cryptooperations );
+# endif
+  addMyModule( kleopatra_config_smimevalidation );
+#endif
+  addMyModule( kleopatra_config_gnupgsystem );
 
   // We store the minimum size of the dialog on hide, because otherwise
   // the KCMultiDialog starts with the size of the first kcm, not
@@ -74,7 +102,9 @@ ConfigureDialog::ConfigureDialog( QWidget * parent )
   if ( width != 0 && height != 0 ) {
      setMinimumSize( width, height );
   }
-
+#ifdef _WIN32_WCE
+  setWindowState( Qt::WindowFullScreen );
+#endif
 }
 
 void ConfigureDialog::hideEvent( QHideEvent * e ) {
@@ -88,4 +118,7 @@ void ConfigureDialog::hideEvent( QHideEvent * e ) {
 ConfigureDialog::~ConfigureDialog() {
 }
 
+#undef addMyModule
+#undef KCM_IMPORT_PLUGIN
+
 #include "configuredialog.moc"
