@@ -212,7 +212,6 @@ void DecryptVerifyFilesController::doTaskDone( const Task* task, const shared_pt
 {
     assert( task );
     assert( task == d->m_runningTask.get() );
-    Q_UNUSED( task );
 
     // We could just delete the tasks here, but we can't use
     // Qt::QueuedConnection here (we need sender()) and other slots
@@ -265,13 +264,13 @@ namespace {
         const Protocol proto;
         FindExtension( const QString & ext, Protocol proto ) : ext( ext ), proto( proto ) {}
         bool operator()( const shared_ptr<ArchiveDefinition> & ad ) const {
-            kDebug() << "   considering" << ( ad ? ad->label() : QLatin1String( "<null>" ) ) << "for" << ext;
+            qDebug() << "   considering" << ( ad ? ad->label() : QLatin1String( "<null>" ) ) << "for" << ext;
             bool result;
             if ( proto == UnknownProtocol )
                 result = ad && ( ad->extensions( OpenPGP ).contains( ext, Qt::CaseInsensitive ) || ad->extensions( CMS ).contains( ext, Qt::CaseInsensitive ) );
             else
                 result = ad && ad->extensions( proto ).contains( ext, Qt::CaseInsensitive );
-            kDebug() << ( result ? "   -> matches" : "   -> doesn't match" );
+            qDebug() << ( result ? "   -> matches" : "   -> doesn't match" );
             return result;
         }
     };
@@ -284,7 +283,7 @@ shared_ptr<ArchiveDefinition> pick_archive_definition( GpgME::Protocol proto, co
     if ( extension == QLatin1String("out") ) // added by outputFileName() -> useless
         return shared_ptr<ArchiveDefinition>();
 
-    if ( extension.endsWith( QLatin1String( ".out" ) ) ) // added by outputFileName() -> remove
+    if ( extension.endsWith( ".out" ) )      // added by outputFileName() -> remove
         extension.chop(4);
 
     for ( ;; ) {
@@ -298,7 +297,7 @@ shared_ptr<ArchiveDefinition> pick_archive_definition( GpgME::Protocol proto, co
         extension = extension.mid( idx + 1 );
     }
 }
-
+    
 
 QStringList DecryptVerifyFilesController::Private::prepareWizardFromPassedFiles()
 {
@@ -465,8 +464,8 @@ void DecryptVerifyFilesController::cancel()
             d->m_wizard->close();
         d->cancelAllTasks();
     } catch ( const std::exception & e ) {
-        kDebug() << "Caught exception: " << e.what();
+        qDebug( "Caught exception: %s", e.what() );
     }
 }
 
-#include "moc_decryptverifyfilescontroller.cpp"
+#include "decryptverifyfilescontroller.moc"
