@@ -51,7 +51,7 @@
 
 #include <kmime/kmime_header_parsing.h>
 
-#include <KLocalizedString>
+#include <KLocale>
 #include <kdebug.h>
 
 #include <QPointer>
@@ -138,7 +138,7 @@ QString SignEncryptFilesController::Private::titleForOperation( unsigned int op
     const bool archiveForced = (op & ArchiveMask) == ArchiveForced;
 
     kleo_assert( !signDisallowed || !encryptDisallowed );
-
+ 
     if ( !signDisallowed && encryptDisallowed ) {
         if ( archiveForced )
             return i18n( "Archive and Sign Files" );
@@ -316,7 +316,7 @@ createSignEncryptTaskForFileInfo( const QFileInfo & fi, bool pgp, bool sign, boo
     const char * const ext = extension( pgp, sign, encrypt, ascii, true );
     kleo_assert( ext );
 
-    const QString output = input + QLatin1Char('.') + QLatin1String(ext);
+    const QString output = input + '.' + ext;
     task->setOutputFileName( output );
 
     return task;
@@ -347,7 +347,7 @@ createArchiveSignEncryptTaskForFiles( const QStringList & files, const QString &
     kleo_assert( ext );
     kleo_assert( !ad->extensions( proto ).empty() );
 
-    task->setOutputFileName( outputFileBaseName + QLatin1Char('.') + QLatin1String(ext) );
+    task->setOutputFileName( outputFileBaseName + '.' + ext );
 
     return task;
 }
@@ -446,7 +446,7 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared() {
                                                            pgpRecipients, pgpSigners, cmsRecipients, cmsSigners );
         else
             Q_FOREACH( const QString & file, files ) {
-                const std::vector< shared_ptr<SignEncryptFilesTask> > created =
+                const std::vector< shared_ptr<SignEncryptFilesTask> > created = 
                     createSignEncryptTasksForFileInfo( QFileInfo( file ), sign, encrypt, ascii, removeUnencrypted, pgpRecipients, pgpSigners, cmsRecipients, cmsSigners );
                 tasks.insert( tasks.end(), created.begin(), created.end() );
             }
@@ -458,7 +458,7 @@ void SignEncryptFilesController::Private::slotWizardOperationPrepared() {
         kleo_assert( runnable.empty() );
 
         runnable.swap( tasks );
-
+        
         Q_FOREACH( const shared_ptr<Task> task, runnable )
             q->connectTask( task );
 
@@ -514,9 +514,7 @@ shared_ptr<SignEncryptFilesTask> SignEncryptFilesController::Private::takeRunnab
     return result;
 }
 
-void SignEncryptFilesController::doTaskDone( const Task * task, const shared_ptr<const Task::Result> & result )
-{
-    Q_UNUSED( result )
+void SignEncryptFilesController::doTaskDone( const Task * task, const shared_ptr<const Task::Result> & result ) {
     assert( task );
 
     // We could just delete the tasks here, but we can't use
@@ -531,7 +529,7 @@ void SignEncryptFilesController::doTaskDone( const Task * task, const shared_ptr
         d->completed.push_back( d->openpgp );
         d->openpgp.reset();
     }
-
+    
     QTimer::singleShot( 0, this, SLOT(schedule()) );
 }
 
@@ -542,7 +540,7 @@ void SignEncryptFilesController::cancel() {
             d->wizard->close();
         d->cancelAllTasks();
     } catch ( const std::exception & e ) {
-        kDebug() << "Caught exception: " << e.what();
+        qDebug( "Caught exception: %s", e.what() );
     }
 }
 
@@ -552,7 +550,7 @@ void SignEncryptFilesController::Private::cancelAllTasks() {
     // signal emissions.
     runnable.clear();
 
-    // a cancel() will result in a call to
+    // a cancel() will result in a call to 
     if ( cms )
         cms->cancel();
     if ( openpgp )
