@@ -42,7 +42,6 @@
 #include <smartcard/readerstatus.h>
 
 #include <utils/kdsignalblocker.h>
-#include <utils/clipboardmenu.h>
 
 #include <commands/importcertificatefromclipboardcommand.h>
 #include <commands/encryptclipboardcommand.h>
@@ -52,17 +51,19 @@
 #include <commands/learncardkeyscommand.h>
 
 #include <KIcon>
-#include <KLocalizedString>
+#include <KLocale>
 #include <KAboutApplicationDialog>
 #include <KAboutData>
-#include <KActionMenu>
-#include <KMenu>
+#include <KComponentData>
+#include <KWindowSystem>
 
 #include <QMenu>
 #include <QAction>
+#include <QTimer>
 #include <QApplication>
 #include <QClipboard>
 #include <QPointer>
+#include <QDebug>
 
 #include <boost/shared_ptr.hpp>
 #include <boost/bind.hpp>
@@ -99,12 +100,43 @@ private:
         //triggering slotEnableDisableActions again
         const KDSignalBlocker blocker( QApplication::clipboard() );
         openCertificateManagerAction.setEnabled( !q->mainWindow() || !q->mainWindow()->isVisible() );
+        importClipboardAction.setEnabled( ImportCertificateFromClipboardCommand::canImportCurrentClipboard() );
+        encryptClipboardAction.setEnabled( EncryptClipboardCommand::canEncryptCurrentClipboard() );
+        openPGPSignClipboardAction.setEnabled( SignClipboardCommand::canSignCurrentClipboard() );
+        smimeSignClipboardAction.setEnabled( SignClipboardCommand::canSignCurrentClipboard() );
+        decryptVerifyClipboardAction.setEnabled( DecryptVerifyClipboardCommand::canDecryptVerifyCurrentClipboard() );
         setInitialPinAction.setEnabled( anyCardHasNullPin );
         learnCertificatesAction.setEnabled( anyCardCanLearnKeys );
 
         q->setAttentionWanted( ( anyCardHasNullPin || anyCardCanLearnKeys ) && !q->attentionWindow() );
     }
 
+    void startCommand( Command * cmd ) {
+        assert( cmd );
+        cmd->setParent( q->mainWindow() );
+        cmd->start();
+    }
+
+    void slotImportClipboard() {
+        startCommand( new ImportCertificateFromClipboardCommand( 0 ) );
+    }
+
+    void slotEncryptClipboard() {
+        startCommand( new EncryptClipboardCommand( 0 ) );
+    }
+
+    void slotOpenPGPSignClipboard() {
+        startCommand( new SignClipboardCommand( GpgME::OpenPGP, 0 ) );
+    }
+
+    void slotSMIMESignClipboard() {
+        startCommand( new SignClipboardCommand( GpgME::CMS, 0 ) );
+    }
+
+    void slotDecryptVerifyClipboard() {
+        startCommand( new DecryptVerifyClipboardCommand( 0 ) );
+    }
+
     void slotSetInitialPin() {
         SetInitialPinCommand * cmd = new SetInitialPinCommand;
         q->setAttentionWindow( cmd->dialog() );
@@ -116,11 +148,6 @@ private:
         q->setAttentionWindow( cmd->dialog() );
         startCommand( cmd );
     }
-    void startCommand( Command * cmd ) {
-        assert( cmd );
-        cmd->setParent( q->mainWindow() );
-        cmd->start();
-    }
 
 private:
     bool anyCardHasNullPin;
@@ -131,15 +158,20 @@ private:
     QAction configureAction;
     QAction aboutAction;
     QAction quitAction;
-
-    ClipboardMenu clipboardMenu;
-
+    QMenu clipboardMenu;
+    QAction importClipboardAction;
+    QAction encryptClipboardAction;
+    QAction smimeSignClipboardAction;
+    QAction openPGPSignClipboardAction;
+    QAction decryptVerifyClipboardAction;
     QMenu cardMenu;
     QAction updateCardStatusAction;
     QAction setInitialPinAction;
     QAction learnCertificatesAction;
 
     QPointer<KAboutApplicationDialog> aboutDialog;
+
+    QRect mainWindowPreviousGeometry;
 };
 
 SysTrayIcon::Private::Private( SysTrayIcon * qq )
@@ -151,15 +183,21 @@ SysTrayIcon::Private::Private( SysTrayIcon * qq )
       configureAction( i18n("&Configure %1...", KGlobal::mainComponent().aboutData()->programName() ), q ),
       aboutAction( i18n("&About %1...", KGlobal::mainComponent().aboutData()->programName() ), q ),
       quitAction( i18n("&Shutdown Kleopatra"), q ),
-      clipboardMenu( q ),
+      clipboardMenu( i18n("Clipboard" ) ),
+      importClipboardAction( i18n("Certificate Import"), q ),
+      encryptClipboardAction( i18n("Encrypt..."), q ),
+      smimeSignClipboardAction( i18n("S/MIME-Sign..."), q ),
+      openPGPSignClipboardAction( i18n("OpenPGP-Sign..."), q ),
+      decryptVerifyClipboardAction( i18n("Decrypt/Verify..."), q ),
       cardMenu( i18n("SmartCard") ),
       updateCardStatusAction( i18n("Update Card Status"), q ),
       setInitialPinAction( i18n("Set NetKey v3 Initial PIN..."), q ),
       learnCertificatesAction( i18n("Learn NetKey v3 Card Certificates"), q ),
-      aboutDialog()
+      aboutDialog(),
+      mainWindowPreviousGeometry()
 {
-    q->setNormalIcon( KIcon( QLatin1String("kleopatra") ) );
-    q->setAttentionIcon( KIcon( QLatin1String("secure-card") ) );
+    q->setNormalIcon( KIcon( "kleopatra" ) );
+    q->setAttentionIcon( KIcon( "secure-card" ) );
 
     KDAB_SET_OBJECT_NAME( menu );
     KDAB_SET_OBJECT_NAME( openCertificateManagerAction );
@@ -167,6 +205,11 @@ SysTrayIcon::Private::Private( SysTrayIcon * qq )
     KDAB_SET_OBJECT_NAME( aboutAction );
     KDAB_SET_OBJECT_NAME( quitAction );
     KDAB_SET_OBJECT_NAME( clipboardMenu );
+    KDAB_SET_OBJECT_NAME( importClipboardAction );
+    KDAB_SET_OBJECT_NAME( encryptClipboardAction );
+    KDAB_SET_OBJECT_NAME( smimeSignClipboardAction );
+    KDAB_SET_OBJECT_NAME( openPGPSignClipboardAction );
+    KDAB_SET_OBJECT_NAME( decryptVerifyClipboardAction );
     KDAB_SET_OBJECT_NAME( cardMenu );
     KDAB_SET_OBJECT_NAME( setInitialPinAction );
     KDAB_SET_OBJECT_NAME( learnCertificatesAction );
@@ -175,6 +218,11 @@ SysTrayIcon::Private::Private( SysTrayIcon * qq )
     connect( &configureAction, SIGNAL(triggered()), qApp, SLOT(openOrRaiseConfigDialog()) );
     connect( &aboutAction, SIGNAL(triggered()), q, SLOT(slotAbout()) );
     connect( &quitAction, SIGNAL(triggered()), QCoreApplication::instance(), SLOT(quit()) );
+    connect( &importClipboardAction, SIGNAL(triggered()), q, SLOT(slotImportClipboard()) );
+    connect( &encryptClipboardAction, SIGNAL(triggered()), q, SLOT(slotEncryptClipboard()) );
+    connect( &smimeSignClipboardAction, SIGNAL(triggered()), q, SLOT(slotSMIMESignClipboard()) );
+    connect( &openPGPSignClipboardAction, SIGNAL(triggered()), q, SLOT(slotOpenPGPSignClipboard()) );
+    connect( &decryptVerifyClipboardAction, SIGNAL(triggered()), q, SLOT(slotDecryptVerifyClipboard()) );
     connect( &updateCardStatusAction, SIGNAL(triggered()), ReaderStatus::instance(), SLOT(updateStatus()) );
     connect( &setInitialPinAction, SIGNAL(triggered()), q, SLOT(slotSetInitialPin()) );
     connect( &learnCertificatesAction, SIGNAL(triggered()), q, SLOT(slotLearnCertificates()) );
@@ -186,7 +234,12 @@ SysTrayIcon::Private::Private( SysTrayIcon * qq )
     menu.addAction( &configureAction );
     menu.addAction( &aboutAction );
     menu.addSeparator();
-    menu.addMenu( clipboardMenu.clipboardMenu()->menu() );
+    menu.addMenu( &clipboardMenu );
+    clipboardMenu.addAction( &importClipboardAction );
+    clipboardMenu.addAction( &encryptClipboardAction );
+    clipboardMenu.addAction( &smimeSignClipboardAction );
+    clipboardMenu.addAction( &openPGPSignClipboardAction );
+    clipboardMenu.addAction( &decryptVerifyClipboardAction );
     menu.addSeparator();
     menu.addMenu( &cardMenu );
     cardMenu.addAction( &updateCardStatusAction );
@@ -196,7 +249,6 @@ SysTrayIcon::Private::Private( SysTrayIcon * qq )
     menu.addAction( &quitAction );
 
     q->setContextMenu( &menu );
-    clipboardMenu.setMainWindow(q->mainWindow());
 }
 
 SysTrayIcon::Private::~Private() {}
@@ -212,6 +264,15 @@ SysTrayIcon::~SysTrayIcon() {
     KGlobal::deref();
 }
 
+void SysTrayIcon::doMainWindowSet( QWidget * mw ) {
+    if ( mw && !mw->isVisible() && d->mainWindowPreviousGeometry.isValid() )
+        mw->setGeometry( d->mainWindowPreviousGeometry );
+}
+
+void SysTrayIcon::doMainWindowClosed( QWidget * mw ) {
+    d->mainWindowPreviousGeometry = mw->geometry();
+}
+
 MainWindow * SysTrayIcon::mainWindow() const {
     return static_cast<MainWindow*>( SystemTrayIcon::mainWindow() );
 }
@@ -228,10 +289,8 @@ void SysTrayIcon::doActivated() {
         d->slotSetInitialPin();
     else if ( d->anyCardCanLearnKeys )
         d->slotLearnCertificates();
-    else {
-        // Toggle visibility of MainWindow
-        KleopatraApplication::instance()->toggleMainWindowVisibility();
-    }
+    else
+        KleopatraApplication::instance()->openOrRaiseMainWindow();
 }
 
 void SysTrayIcon::setAnyCardHasNullPin( bool on ) {
