@@ -56,6 +56,8 @@ public Q_SLOTS:
     void setAnyCardCanLearnKeys( bool );
 
 private:
+    /* reimp */ void doMainWindowSet( QWidget * );
+    /* reimp */ void doMainWindowClosed( QWidget * );
     /* reimp */ void doActivated();
     /* reimp */ void slotEnableDisableActions();
 
@@ -63,6 +65,11 @@ private:
     class Private;
     kdtools::pimpl_ptr<Private> d;
     Q_PRIVATE_SLOT( d, void slotAbout() )
+    Q_PRIVATE_SLOT( d, void slotImportClipboard() )
+    Q_PRIVATE_SLOT( d, void slotEncryptClipboard() )
+    Q_PRIVATE_SLOT( d, void slotOpenPGPSignClipboard() )
+    Q_PRIVATE_SLOT( d, void slotSMIMESignClipboard() )
+    Q_PRIVATE_SLOT( d, void slotDecryptVerifyClipboard() )
     Q_PRIVATE_SLOT( d, void slotSetInitialPin() )
     Q_PRIVATE_SLOT( d, void slotLearnCertificates() )
 };
