@@ -134,8 +134,8 @@ class VerifyTest : public QObject
     {
       qRegisterMetaType<GpgME::VerificationResult>();
 
-      const QString sigFileName = QLatin1String(KLEO_TEST_DATADIR) + QLatin1String("/test.data.sig");
-      const QString dataFileName = QLatin1String(KLEO_TEST_DATADIR) + QLatin1String("/test.data");
+      const QString sigFileName = KLEO_TEST_DATADIR "/test.data.sig";
+      const QString dataFileName = KLEO_TEST_DATADIR "/test.data";
 
       QFile sigFile( sigFileName );
       QVERIFY( sigFile.open(QFile::ReadOnly ) );
@@ -170,7 +170,7 @@ class VerifyTest : public QObject
     void testParallelVerifyAndKeyListJobs()
     {
       // ### Increasing 10 to 500 makes the verify jobs fail!
-      for ( int i = 0; i < 10; ++i ) {
+      for ( int i = 0; i < 10; i++ ) {
         Kleo::VerifyDetachedJob *job = mBackend->verifyDetachedJob();
         mParallelVerifyJobs.append( job );
         QVERIFY( !job->start( mSignature, mSignedData ) );
