@@ -51,10 +51,11 @@
 #include <utils/detail_p.h>
 #include <utils/hex.h>
 #include <utils/log.h>
-#include <utils/exception.h>
 #include <utils/kleo_assert.h>
 #include <utils/getpid.h>
-#include <utils/stl_util.h>
+
+#include <kleo/stl_util.h>
+#include <kleo/exception.h>
 
 #include <gpgme++/data.h>
 #include <gpgme++/key.h>
@@ -78,7 +79,9 @@
 #include <kleo-assuan.h>
 
 #include <boost/type_traits/remove_pointer.hpp>
+#ifndef _WIN32_WCE
 #include <boost/lexical_cast.hpp>
+#endif
 #include <boost/bind.hpp>
 #include <boost/mem_fn.hpp>
 #include <boost/mpl/if.hpp>
@@ -116,13 +119,28 @@ static const unsigned int INIT_SOCKET_FLAGS = 3; // says info assuan...
 static const int FOR_READING = 0;
 static const unsigned int MAX_ACTIVE_FDS = 32;
 
+#ifdef HAVE_ASSUAN2
+static void my_assuan_release( assuan_context_t ctx ) {
+    if ( ctx )
+        assuan_release( ctx );
+}
+
+#endif
 // shared_ptr for assuan_context_t w/ deleter enforced to assuan_deinit_server:
 typedef shared_ptr< remove_pointer<assuan_context_t>::type > AssuanContextBase;
 struct AssuanContext : AssuanContextBase {
     AssuanContext() : AssuanContextBase() {}
+#ifndef HAVE_ASSUAN2
     explicit AssuanContext( assuan_context_t ctx ) : AssuanContextBase( ctx, &assuan_deinit_server ) {}
+#else
+    explicit AssuanContext( assuan_context_t ctx ) : AssuanContextBase( ctx, &my_assuan_release ) {}
+#endif
 
+#ifndef HAVE_ASSUAN2
     void reset( assuan_context_t ctx=0 ) { AssuanContextBase::reset( ctx, &assuan_deinit_server ); }
+#else
+    void reset( assuan_context_t ctx=0 ) { AssuanContextBase::reset( ctx, &my_assuan_release ); }
+#endif
 };
 
 static inline gpg_error_t assuan_process_done_msg( assuan_context_t ctx, gpg_error_t err, const char * err_msg ) {
@@ -194,7 +212,7 @@ static std::map<std::string,std::string> parse_commandline( const char * line )
 
 static WId wid_from_string( const QString & winIdStr, bool * ok=0 ) {
     return
-#ifdef Q_OS_WIN32
+#if defined(Q_OS_WIN32) || defined(_WIN32_WCE)
         reinterpret_cast<WId>
 #else
         static_cast<WId>
@@ -240,7 +258,12 @@ Q_SIGNALS:
 public Q_SLOTS:
     void slotReadActivity( int ) {
         assert( ctx );
+#ifndef HAVE_ASSUAN2
         if ( const int err = assuan_process_next( ctx.get() ) ) {
+#else
+        int done = false;
+        if ( const int err = assuan_process_next( ctx.get(), &done ) || done ) {
+#endif
             //if ( err == -1 || gpg_err_code(err) == GPG_ERR_EOF ) {
                 topHalfDeletion();
                 if ( nohupedCommands.empty() )
@@ -258,7 +281,7 @@ private:
     void nohupDone( AssuanCommand * cmd ) {
         const std::vector< shared_ptr<AssuanCommand> >::iterator it
             = std::find_if( nohupedCommands.begin(), nohupedCommands.end(),
-                            bind( &shared_ptr<AssuanCommand>::get, _1 ) == cmd );
+                            boost::bind( &shared_ptr<AssuanCommand>::get, _1 ) == cmd );
         assert( it != nohupedCommands.end() );
         nohupedCommands.erase( it );
         if ( nohupedCommands.empty() && closed )
@@ -275,7 +298,9 @@ private:
         if ( currentCommand )
             currentCommand->canceled();
 	if ( fd != ASSUAN_INVALID_FD ) {
-#ifdef Q_OS_WIN32
+#ifdef _WIN32_WCE
+            CloseHandle( (HANDLE)fd );
+#elif defined(Q_OS_WIN32)
             CloseHandle( fd );
 #else
             ::close( fd );
@@ -296,15 +321,27 @@ private:
     }
 
 private:
+#ifndef HAVE_ASSUAN2
     static void reset_handler( assuan_context_t ctx_ ) {
+#else
+    static gpg_error_t reset_handler( assuan_context_t ctx_, char * ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
 
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
         conn.reset();
+#ifdef HAVE_ASSUAN2
+
+        return 0;
+#endif
     }
 
+#ifndef HAVE_ASSUAN2
     static int option_handler( assuan_context_t ctx_, const char * key, const char * value ) {
+#else
+    static gpg_error_t option_handler( assuan_context_t ctx_, const char * key, const char * value ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
 
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
@@ -317,7 +354,11 @@ private:
         //return gpg_error( GPG_ERR_UNKNOWN_OPTION );
     }
 
+#ifndef HAVE_ASSUAN2
     static int session_handler( assuan_context_t ctx_, char * line ) {
+#else
+    static gpg_error_t session_handler( assuan_context_t ctx_, char * line ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
@@ -344,7 +385,11 @@ private:
         return assuan_process_done( ctx_, 0 );
     }
 
+#ifndef HAVE_ASSUAN2
     static int capabilities_handler( assuan_context_t ctx_, char * line ) {
+#else
+    static gpg_error_t capabilities_handler( assuan_context_t ctx_, char * line ) {
+#endif
         if ( !QByteArray( line ).trimmed().isEmpty() ) {
             static const QString errorString = i18n("CAPABILITIES does not take arguments");
             return assuan_process_done_msg( ctx_, gpg_error( GPG_ERR_ASS_PARAMETER ), errorString );
@@ -357,7 +402,11 @@ private:
         return assuan_process_done( ctx_, assuan_send_data( ctx_, capabilities, sizeof capabilities - 1 ) );
     }
 
+#ifndef HAVE_ASSUAN2
     static int getinfo_handler( assuan_context_t ctx_, char * line ) {
+#else
+    static gpg_error_t getinfo_handler( assuan_context_t ctx_, char * line ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
@@ -386,7 +435,11 @@ private:
         return assuan_process_done( ctx_, assuan_send_data( ctx_, ba.constData(), ba.size() ) );
     }
 
+#ifndef HAVE_ASSUAN2
     static int start_keymanager_handler( assuan_context_t ctx_, char * line ) {
+#else
+    static gpg_error_t start_keymanager_handler( assuan_context_t ctx_, char * line ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
@@ -400,7 +453,11 @@ private:
         return assuan_process_done( ctx_, 0 );
     }
 
+#ifndef HAVE_ASSUAN2
     static int start_confdialog_handler( assuan_context_t ctx_, char * line ) {
+#else
+    static gpg_error_t start_confdialog_handler( assuan_context_t ctx_, char * line ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
@@ -418,7 +475,11 @@ private:
 
     // format: TAG (FD|FD=\d+|FILE=...)
     template <bool in, typename T_memptr>
+#ifndef HAVE_ASSUAN2
     static int IO_handler( assuan_context_t ctx_, char * line_, T_memptr which ) {
+#else
+    static gpg_error_t IO_handler( assuan_context_t ctx_, char * line_, T_memptr which ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
@@ -443,7 +504,9 @@ private:
                     if ( const gpg_error_t err = assuan_receivefd( conn.ctx.get(), &fd ) )
                         throw err;
                 } else {
-#ifdef Q_OS_WIN32
+#ifdef _WIN32_WCE
+                    fd = (assuan_fd_t)atoi( fdstr.c_str() );
+#elif defined(Q_OS_WIN32)
                     fd = (assuan_fd_t)lexical_cast<intptr_t>( fdstr );
 #else
                     fd = lexical_cast<assuan_fd_t>( fdstr );
@@ -498,19 +561,35 @@ private:
 
     }
 
+#ifndef HAVE_ASSUAN2
     static int input_handler( assuan_context_t ctx, char * line ) {
+#else
+    static gpg_error_t input_handler( assuan_context_t ctx, char * line ) {
+#endif
         return IO_handler<true>( ctx, line, &Private::inputs );
     }
 
+#ifndef HAVE_ASSUAN2
     static int output_handler( assuan_context_t ctx, char * line ) {
+#else
+    static gpg_error_t output_handler( assuan_context_t ctx, char * line ) {
+#endif
         return IO_handler<false>( ctx, line, &Private::outputs );
     }
 
+#ifndef HAVE_ASSUAN2
     static int message_handler( assuan_context_t ctx, char * line ) {
+#else
+    static gpg_error_t message_handler( assuan_context_t ctx, char * line ) {
+#endif
         return IO_handler<true>( ctx, line, &Private::messages );
     }
 
+#ifndef HAVE_ASSUAN2
     static int file_handler( assuan_context_t ctx_, char * line ) {
+#else
+    static gpg_error_t file_handler( assuan_context_t ctx_, char * line ) {
+#endif
         assert( assuan_get_pointer( ctx_ ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx_ ) );
 
@@ -572,7 +651,11 @@ private:
     }
 
     template <typename T_memptr, typename T_memptr2>
+#ifndef HAVE_ASSUAN2
     static int recipient_sender_handler( T_memptr mp, T_memptr2 info, assuan_context_t ctx, char * line, bool sender=false ) {
+#else
+    static gpg_error_t recipient_sender_handler( T_memptr mp, T_memptr2 info, assuan_context_t ctx, char * line, bool sender=false ) {
+#endif
         assert( assuan_get_pointer( ctx ) );
         AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx ) );
 
@@ -594,73 +677,28 @@ private:
                                             i18n("Garbage after valid RFC-2822 mailbox detected").toUtf8().constData() );
         (conn.*info) = informative;
         (conn.*mp).push_back( mb );
-        // ### we should wait for the KeyCache to become ready here,
-        // ### but we don't have time anymore to turn SENDER into a
-        // ### command, so we just ignore this for now:
+
         const QString email = mb.addrSpec().asString();
         (void)assuan_write_line( conn.ctx.get(), qPrintable( QString().sprintf( "# ok, parsed as \"%s\"", qPrintable( email ) ) ) );
-        if ( sender && !informative ) {
-            const std::vector<GpgME::Key> seckeys =
-                kdtools::copy_if<std::vector<GpgME::Key> >( KeyCache::instance()->findByEMailAddress( email.toStdString() ),
-                                                            mem_fn( &GpgME::Key::hasSecret ) );
-            if ( seckeys.empty() )
-                (void)assuan_write_line( conn.ctx.get(), "# no matching keys found" );
-            else
-                Q_FOREACH( const GpgME::Key & key, seckeys )
-                    (void)assuan_write_line( conn.ctx.get(), qPrintable( QString().sprintf( "# matching %s key %s", key.protocolAsString(), key.primaryFingerprint() ) ) );
-            const bool pgp = proto != GpgME::CMS     && kdtools::any( seckeys, bind( &GpgME::Key::protocol, _1 ) == GpgME::OpenPGP );
-            const bool cms = proto != GpgME::OpenPGP && kdtools::any( seckeys, bind( &GpgME::Key::protocol, _1 ) == GpgME::CMS );
-            if ( cms != pgp )
-                proto = pgp ? GpgME::OpenPGP : GpgME::CMS ;
-            if ( cms && pgp ) {
-                if ( conn.bias != GpgME::UnknownProtocol ) {
-                    proto = conn.bias;
-                } else {
-                    if ( conn.options.count("window-id") )
-                        proto =
-                            KMessageBox::questionYesNoWId( wid_from_string( conn.options["window-id"].toString() ),
-                                                           i18nc("@info",
-                                                                 "<para>The sender address <email>%1</email> matches more than one cryptographic format.</para>"
-                                                                 "<para>Which format do you want to use?</para>", email ),
-                                                           i18nc("@title","Format Choice"),
-                                                           KGuiItem( i18nc("@action:button","Send OpenPGP-Signed") ),
-                                                           KGuiItem( i18nc("@action:button","Send S/MIME-Signed") ),
-                                                           QLatin1String("uiserver-sender-ask-protocol") ) == KMessageBox::Yes
-                            ? GpgME::OpenPGP
-                            : GpgME::CMS ;
-                    else
-                        proto =
-                            KMessageBox::questionYesNo( 0, i18nc("@info",
-                                                                 "<para>The sender address <email>%1</email> matches more than one cryptographic format.</para>"
-                                                                 "<para>Which format do you want to use?</para>", email ),
-                                                        i18nc("@title","Format Choice"),
-                                                        KGuiItem( i18nc("@action:button","Send OpenPGP-Signed") ),
-                                                        KGuiItem( i18nc("@action:button","Send S/MIME-Signed") ),
-                                                        QLatin1String("uiserver-sender-ask-protocol") ) == KMessageBox::Yes
-                            ? GpgME::OpenPGP
-                            : GpgME::CMS ;
-                }
-            }
-            conn.bias = proto;
-            switch ( proto ) {
-            case GpgME::OpenPGP:
-                (void)assuan_write_status( conn.ctx.get(), "PROTOCOL", "OpenPGP" );
-                break;
-            case GpgME::CMS:
-                (void)assuan_write_status( conn.ctx.get(), "PROTOCOL", "CMS" );
-                break;
-            case GpgME::UnknownProtocol:
-                ; // keep compiler happy
-            };
-        }
-        return assuan_process_done( ctx, 0 );
+        if ( sender && !informative )
+            return AssuanCommandFactory::_handle( conn.ctx.get(), line, "PREP_SIGN" );
+        else
+            return assuan_process_done( ctx, 0 );
     }
 
+#ifndef HAVE_ASSUAN2
     static int recipient_handler( assuan_context_t ctx, char * line ) {
+#else
+    static gpg_error_t recipient_handler( assuan_context_t ctx, char * line ) {
+#endif
         return recipient_sender_handler( &Private::recipients, &Private::informativeRecipients, ctx, line );
     }
 
+#ifndef HAVE_ASSUAN2
     static int sender_handler( assuan_context_t ctx, char * line ) {
+#else
+    static gpg_error_t sender_handler( assuan_context_t ctx, char * line ) {
+#endif
         return recipient_sender_handler( &Private::senders, &Private::informativeSenders, ctx, line, true );
     }
 
@@ -687,7 +725,7 @@ private:
         QStringList sl;
         std::transform( c.begin(), c.end(),
                         std::back_inserter( sl ),
-                        bind( &KMime::Types::Mailbox::prettyAddress, _1 ) );
+                        boost::bind( &KMime::Types::Mailbox::prettyAddress, _1 ) );
         return dumpStringList( sl );
     }
 
@@ -726,13 +764,13 @@ private:
         mementos.clear();
         files.clear();
         std::for_each( inputs.begin(), inputs.end(),
-                       bind( &Input::finalize, _1 ) );
+                       boost::bind( &Input::finalize, _1 ) );
         inputs.clear();
         std::for_each( outputs.begin(), outputs.end(),
-                       bind( &Output::finalize, _1 ) );
+                       boost::bind( &Output::finalize, _1 ) );
         outputs.clear();
         std::for_each( messages.begin(), messages.end(),
-                       bind( &Input::finalize, _1 ) );
+                       boost::bind( &Input::finalize, _1 ) );
         messages.clear();
         bias = GpgME::UnknownProtocol;
     }
@@ -792,11 +830,23 @@ AssuanServerConnection::Private::Private( assuan_fd_t fd_, const std::vector< sh
     if ( fd == ASSUAN_INVALID_FD )
         throw Exception( gpg_error( GPG_ERR_INV_ARG ), "pre-assuan_init_socket_server_ext" );
 
+#ifndef HAVE_ASSUAN2
     assuan_context_t naked_ctx = 0;
     if ( const gpg_error_t err = assuan_init_socket_server_ext( &naked_ctx, fd, INIT_SOCKET_FLAGS ) )
+#else
+    {
+        assuan_context_t naked_ctx = 0;
+        if ( const gpg_error_t err = assuan_new( &naked_ctx ) )
+            throw Exception( err, "assuan_new" );
+        ctx.reset( naked_ctx );
+    }
+    if ( const gpg_error_t err = assuan_init_socket_server( ctx.get(), fd, INIT_SOCKET_FLAGS ) )
+#endif
         throw Exception( err, "assuan_init_socket_server_ext" );
 
+#ifndef HAVE_ASSUAN2
     ctx.reset( naked_ctx ); naked_ctx = 0;
+#endif
 
     // for callbacks, associate the context with this connection:
     assuan_set_pointer( ctx.get(), this );
@@ -810,48 +860,96 @@ AssuanServerConnection::Private::Private( assuan_fd_t fd_, const std::vector< sh
     assert( numFDs != -1 ); // == 1
 
     if ( !numFDs || fds[0] != fd ) {
-        const shared_ptr<QSocketNotifier> sn( new QSocketNotifier( (int)fd, QSocketNotifier::Read ), mem_fn( &QObject::deleteLater ) );
+        const shared_ptr<QSocketNotifier> sn( new QSocketNotifier( (intptr_t)fd, QSocketNotifier::Read ), mem_fn( &QObject::deleteLater ) );
         connect( sn.get(), SIGNAL(activated(int)), this, SLOT(slotReadActivity(int)) );
         notifiers.push_back( sn );
     }
 
     notifiers.reserve( notifiers.size() + numFDs );
     for ( int i = 0 ; i < numFDs ; ++i ) {
-        const shared_ptr<QSocketNotifier> sn( new QSocketNotifier( (int)fds[i], QSocketNotifier::Read ), mem_fn( &QObject::deleteLater ) );
+        const shared_ptr<QSocketNotifier> sn( new QSocketNotifier( (intptr_t)fds[i], QSocketNotifier::Read ), mem_fn( &QObject::deleteLater ) );
         connect( sn.get(), SIGNAL(activated(int)), this, SLOT(slotReadActivity(int)) );
         notifiers.push_back( sn );
     }
 
 
     // register our INPUT/OUTPUT/MESSGAE/FILE handlers:
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "INPUT",  input_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "INPUT",  input_handler, "" ) )
+#endif
         throw Exception( err, "register \"INPUT\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "MESSAGE",  message_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "MESSAGE",  message_handler, "" ) )
+#endif
         throw Exception( err, "register \"MESSAGE\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "OUTPUT", output_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "OUTPUT", output_handler, "" ) )
+#endif
         throw Exception( err, "register \"OUTPUT\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "FILE", file_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "FILE", file_handler, "" ) )
+#endif
         throw Exception( err, "register \"FILE\" handler" );
 
 
     // register user-defined commands:
     Q_FOREACH( shared_ptr<AssuanCommandFactory> fac, factories )
+#ifndef HAVE_ASSUAN2
         if ( const gpg_error_t err = assuan_register_command( ctx.get(), fac->name(), fac->_handler() ) )
+#else
+        if ( const gpg_error_t err = assuan_register_command( ctx.get(), fac->name(), fac->_handler(), "" ) )
+#endif
             throw Exception( err, std::string( "register \"" ) + fac->name() + "\" handler" );
 
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "GETINFO", getinfo_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "GETINFO", getinfo_handler, "" ) )
+#endif
         throw Exception( err, "register \"GETINFO\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "START_KEYMANAGER", start_keymanager_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "START_KEYMANAGER", start_keymanager_handler, "" ) )
+#endif
         throw Exception( err, "register \"START_KEYMANAGER\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "START_CONFDIALOG", start_confdialog_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "START_CONFDIALOG", start_confdialog_handler, "" ) )
+#endif
         throw Exception( err, "register \"START_CONFDIALOG\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "RECIPIENT", recipient_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "RECIPIENT", recipient_handler, "" ) )
+#endif
         throw Exception( err, "register \"RECIPIENT\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "SENDER", sender_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "SENDER", sender_handler, "" ) )
+#endif
         throw Exception( err, "register \"SENDER\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "SESSION", session_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "SESSION", session_handler, "" ) )
+#endif
         throw Exception( err, "register \"SESSION\" handler" );
+#ifndef HAVE_ASSUAN2
     if ( const gpg_error_t err = assuan_register_command( ctx.get(), "CAPABILITIES", capabilities_handler ) )
+#else
+    if ( const gpg_error_t err = assuan_register_command( ctx.get(), "CAPABILITIES", capabilities_handler, "" ) )
+#endif
         throw Exception( err, "register \"CAPABILITIES\" handler" );
 
     assuan_set_hello_line( ctx.get(), "GPG UI server (Kleopatra/" KLEOPATRA_VERSION_STRING ") ready to serve" );
@@ -904,10 +1002,10 @@ class InquiryHandler : public QObject {
     Q_OBJECT
 public:
 
-#ifdef HAVE_ASSUAN_INQUIRE_EXT
+#if defined(HAVE_ASSUAN2) || defined(HAVE_ASSUAN_INQUIRE_EXT)
     explicit InquiryHandler( const char * keyword_, QObject * p=0 )
         : QObject( p ),
-# ifndef HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT
+# if !defined(HAVE_ASSUAN2) && !defined(HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT)
           buffer( 0 ),
           buflen( 0 ),
 # endif
@@ -916,8 +1014,12 @@ public:
 
     }
 
-# ifdef HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT
+# if defined(HAVE_ASSUAN2) || defined(HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT)
+#  ifndef HAVE_ASSUAN2
     static int handler( void * cb_data, int rc, unsigned char * buffer, size_t buflen )
+#  else
+    static gpg_error_t handler( void * cb_data, gpg_error_t rc, unsigned char * buffer, size_t buflen )
+#  endif
     {
         assert( cb_data );
         InquiryHandler * this_ = static_cast<InquiryHandler*>(cb_data);
@@ -939,13 +1041,13 @@ public:
 # endif
 
 private:
-# ifndef HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT
+#if !defined(HAVE_ASSUAN2) && !defined(HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT)
     friend class ::Kleo::AssuanCommand;
     unsigned char * buffer;
     size_t buflen;
-# endif
+#endif
     const char * keyword;
-#endif // HAVE_ASSUAN_INQUIRE_EXT
+#endif // defined(HAVE_ASSUAN2) || defined(HAVE_ASSUAN_INQUIRE_EXT)
 
 Q_SIGNALS:
     void signal( int rc, const QByteArray & data, const QByteArray & keyword );
@@ -1157,11 +1259,11 @@ int AssuanCommand::inquire( const char * keyword, QObject * receiver, const char
     if ( d->nohup )
         return makeError( GPG_ERR_INV_OP );
 
-#ifdef HAVE_ASSUAN_INQUIRE_EXT
+#if defined(HAVE_ASSUAN2) || defined(HAVE_ASSUAN_INQUIRE_EXT)
     std::auto_ptr<InquiryHandler> ih( new InquiryHandler( keyword, receiver ) );
     receiver->connect( ih.get(), SIGNAL(signal(int,QByteArray,QByteArray)), slot );
     if ( const gpg_error_t err = assuan_inquire_ext( d->ctx.get(), keyword,
-# ifndef HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT
+# if !defined(HAVE_ASSUAN2) && !defined(HAVE_NEW_STYLE_ASSUAN_INQUIRE_EXT)
                                                      &ih->buffer, &ih->buflen,
 # endif
                                                      maxSize, InquiryHandler::handler, ih.get() ) )
@@ -1170,7 +1272,7 @@ int AssuanCommand::inquire( const char * keyword, QObject * receiver, const char
     return 0;
 #else
     return makeError( GPG_ERR_NOT_SUPPORTED ); // libassuan too old
-#endif // HAVE_ASSUAN_INQUIRE_EXT
+#endif // defined(HAVE_ASSUAN2) || defined(HAVE_ASSUAN_INQUIRE_EXT)
 }
 
 void AssuanCommand::done( const GpgME::Error& err, const QString & details ) {
@@ -1196,11 +1298,11 @@ void AssuanCommand::done( const GpgME::Error& err ) {
     d->done = true;
 
     std::for_each( d->messages.begin(), d->messages.end(),
-                   bind( &Input::finalize, _1 ) );
+                   boost::bind( &Input::finalize, _1 ) );
     std::for_each( d->inputs.begin(), d->inputs.end(),
-                   bind( &Input::finalize, _1 ) );
+                   boost::bind( &Input::finalize, _1 ) );
     std::for_each( d->outputs.begin(), d->outputs.end(),
-                   bind( &Output::finalize, _1 ) );
+                   boost::bind( &Output::finalize, _1 ) );
     d->messages.clear();
     d->inputs.clear();
     d->outputs.clear();
@@ -1262,7 +1364,11 @@ const std::vector<KMime::Types::Mailbox> & AssuanCommand::senders() const {
     return d->senders;
 }
 
+#ifndef HAVE_ASSUAN2
 int AssuanCommandFactory::_handle( assuan_context_t ctx, char * line, const char * commandName ) {
+#else
+gpg_error_t AssuanCommandFactory::_handle( assuan_context_t ctx, char * line, const char * commandName ) {
+#endif
     assert( assuan_get_pointer( ctx ) );
     AssuanServerConnection::Private & conn = *static_cast<AssuanServerConnection::Private*>( assuan_get_pointer( ctx ) );
 
