@@ -45,8 +45,9 @@
 #include <utils/input.h>
 #include <utils/output.h>
 #include <utils/kleo_assert.h>
-#include <utils/exception.h>
-#include <utils/stl_util.h>
+
+#include <kleo/stl_util.h>
+#include <kleo/exception.h>
 
 #include <gpgme++/error.h>
 #include <gpgme++/key.h>
@@ -120,8 +121,8 @@ int DecryptVerifyCommandFilesBase::doStart() {
                       d.get(), SLOT(slotDone()), Qt::QueuedConnection );
     QObject::connect( d->controller.get(), SIGNAL(error(int,QString)),
                       d.get(), SLOT(slotError(int,QString)), Qt::QueuedConnection );
-    QObject::connect( d->controller.get(), SIGNAL(verificationResult( GpgME::VerificationResult ) ), 
-                      d.get(), SLOT(verificationResult( GpgME::VerificationResult ) ), Qt::QueuedConnection );
+    QObject::connect( d->controller.get(), SIGNAL(verificationResult(GpgME::VerificationResult)), 
+                      d.get(), SLOT(verificationResult(GpgME::VerificationResult)), Qt::QueuedConnection );
 
     d->controller->start();
 
