@@ -36,9 +36,11 @@
 
 #include "detail_p.h"
 #include "kleo_assert.h"
-#include "exception.h"
 #include "kdpipeiodevice.h"
 #include "log.h"
+#include "cached.h"
+
+#include <kleo/exception.h>
 
 #include <KLocale>
 #include <KMessageBox>
@@ -52,6 +54,11 @@
 #include <QBuffer>
 #include <QPointer>
 #include <QWidget>
+#include <QDir>
+#include <QFileInfo>
+#include <QProcess>
+#include <QDebug>
+#include <QTimer>
 
 #ifdef Q_OS_WIN
 # include <windows.h>
@@ -63,6 +70,9 @@ using namespace Kleo;
 using namespace Kleo::_detail;
 using namespace boost;
 
+static const int PROCESS_MAX_RUNTIME_TIMEOUT = -1;     // no timeout
+static const int PROCESS_TERMINATE_TIMEOUT   = 5*1000; // 5s
+
 class OverwritePolicy::Private {
 public:
     Private( QWidget* p, OverwritePolicy::Policy pol ) : policy( pol ), widget( p ) {}
@@ -105,10 +115,11 @@ namespace {
         bool openNonInheritable() {
             if ( !QTemporaryFile::open() )
                 return false;
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) && !defined(_WIN32_WCE)
             //QTemporaryFile (tested with 4.3.3) creates the file handle as inheritable.
             //The handle is then inherited by gpgsm, which prevents deletion of the temp file
             //in FileOutput::doFinalize()
+            //There are no inheritable handles under wince
             return SetHandleInformation( (HANDLE)_get_osfhandle( handle() ), HANDLE_FLAG_INHERIT, 0 );
 #endif
             return true;
@@ -131,7 +142,18 @@ namespace {
         void reallyClose() { T_IODevice::close(); }
     };
 
+    template <typename T_IODevice>
+    struct redirect_close : T_IODevice {
+        explicit redirect_close() : T_IODevice(), m_closed( false ) {}
+        template <typename T1>
+        explicit redirect_close( T1 & t1 ) : T_IODevice( t1 ), m_closed( false ) {}
 
+        /* reimp */ void close() { this->closeWriteChannel(); m_closed = true; }
+
+        bool isClosed() const { return m_closed; }
+    private:
+        bool m_closed;
+    };
 
 
     class OutputImplBase : public Output {
@@ -140,6 +162,7 @@ namespace {
             : Output(),
               m_defaultLabel(),
               m_customLabel(),
+              m_errorString(),
               m_isFinalized( false ),
               m_isFinalizing( false ),
               m_cancelPending( false ),
@@ -152,6 +175,12 @@ namespace {
         /* reimp */ void setLabel( const QString & label ) { m_customLabel = label; }
         void setDefaultLabel( const QString & l ) { m_defaultLabel = l; }
 
+        /* reimp */ QString errorString() const {
+            if ( m_errorString.dirty() )
+                m_errorString = doErrorString();
+            return m_errorString;
+        }
+
         /* reimp */ bool isFinalized() const { return m_isFinalized; }
         /* reimp */ void finalize() {
             kDebug() << this;
@@ -178,11 +207,18 @@ namespace {
             }
         }
     private:
+        virtual QString doErrorString() const {
+            if ( shared_ptr<QIODevice> io = ioDevice() )
+                return io->errorString();
+            else
+                return i18n("No output device");
+        }
         virtual void doFinalize() = 0;
         virtual void doCancel() = 0;
     private:
         QString m_defaultLabel;
         QString m_customLabel;
+        mutable cached<QString> m_errorString;
         bool m_isFinalized   : 1;
         bool m_isFinalizing  : 1;
         bool m_cancelPending : 1;
@@ -202,6 +238,32 @@ namespace {
     };
 
 
+    class ProcessStdInOutput : public OutputImplBase {
+    public:
+        explicit ProcessStdInOutput( const QString & cmd, const QStringList & args, const QDir & wd );
+
+        /* reimp */ shared_ptr<QIODevice> ioDevice() const { return m_proc; }
+        /* reimp */ void doFinalize() {
+            if ( !m_proc->isClosed() )
+                m_proc->close();
+            m_proc->waitForFinished( PROCESS_MAX_RUNTIME_TIMEOUT );
+        }
+        /* reimp */ void doCancel() {
+            m_proc->terminate();
+            QTimer::singleShot( PROCESS_TERMINATE_TIMEOUT, m_proc.get(), SLOT(kill()) );
+        }
+        /* reimp */ QString label() const;
+
+    private:
+        /* reimp */ QString doErrorString() const;
+
+    private:
+        const QString m_command;
+        const QStringList m_arguments;
+        const shared_ptr< redirect_close<QProcess> > m_proc;
+    };
+
+
     class FileOutput : public OutputImplBase {
     public:
         explicit FileOutput( const QString & fileName, const shared_ptr<OverwritePolicy> & policy );
@@ -220,6 +282,7 @@ namespace {
         const shared_ptr<OverwritePolicy> m_policy;
     };
 
+#ifndef QT_NO_CLIPBOARD
     class ClipboardOutput : public OutputImplBase {
     public:
         explicit ClipboardOutput( QClipboard::Mode mode );
@@ -228,10 +291,14 @@ namespace {
         /* reimp */ shared_ptr<QIODevice> ioDevice() const { return m_buffer; }
         /* reimp */ void doFinalize();
         /* reimp */ void doCancel() {}
+
+    private:
+        /* reimp */ QString doErrorString() const { return QString(); }
     private:
         const QClipboard::Mode m_mode;
         shared_ptr<QBuffer> m_buffer;
     };
+#endif // QT_NO_CLIPBOARD
 
 }
 
@@ -344,6 +411,62 @@ void FileOutput::doFinalize() {
                            tmpFileName, m_fileName ) );
 }
 
+
+shared_ptr<Output> Output::createFromProcessStdIn( const QString & command ) {
+    return shared_ptr<Output>( new ProcessStdInOutput( command, QStringList(), QDir::current() ) );
+}
+
+shared_ptr<Output> Output::createFromProcessStdIn( const QString & command, const QStringList & args ) {
+    return shared_ptr<Output>( new ProcessStdInOutput( command, args, QDir::current() ) );
+}
+
+shared_ptr<Output> Output::createFromProcessStdIn( const QString & command, const QStringList & args, const QDir & wd ) {
+    return shared_ptr<Output>( new ProcessStdInOutput( command, args, wd ) );
+}
+
+ProcessStdInOutput::ProcessStdInOutput( const QString & cmd, const QStringList & args, const QDir & wd )
+    : OutputImplBase(),
+      m_command( cmd ),
+      m_arguments( args ),
+      m_proc( new redirect_close<QProcess> )
+{
+    qDebug() << "ProcessStdInOutput:" << "\n"
+        "cd" << wd.absolutePath() << "\n" <<
+        cmd << args;
+    if ( cmd.isEmpty() )
+        throw Exception( gpg_error( GPG_ERR_INV_ARG ),
+                         i18n("Command not specified") );
+    m_proc->setWorkingDirectory( wd.absolutePath() );
+    m_proc->start( cmd, args );
+    m_proc->setReadChannel( QProcess::StandardError );
+    if ( !m_proc->waitForStarted() )
+        throw Exception( gpg_error( GPG_ERR_EIO ),
+                         i18n( "Could not start %1 process: %2", cmd, m_proc->errorString() ) );
+}
+
+QString ProcessStdInOutput::label() const {
+    if ( !m_proc )
+        return OutputImplBase::label();
+    // output max. 3 arguments
+    const QString cmdline = ( QStringList( m_command ) + m_arguments.mid(0,3) ).join( " " );
+    if ( m_arguments.size() > 3 )
+        return i18nc( "e.g. \"Input to tar xf - file1 ...\"", "Input to %1 ...", cmdline );
+    else
+        return i18nc( "e.g. \"Input to tar xf - file\"",      "Input to %1",     cmdline );
+}
+
+QString ProcessStdInOutput::doErrorString() const {
+    kleo_assert( m_proc );
+    if ( m_proc->exitStatus() == QProcess::NormalExit && m_proc->exitCode() == 0 )
+        return QString();
+    if ( m_proc->error() == QProcess::UnknownError )
+        return i18n( "Error while running %1: %2", m_command,
+                     QString::fromLocal8Bit( m_proc->readAllStandardError().trimmed().constData() ) );
+    else
+        return i18n( "Failed to execute %1: %2", m_command, m_proc->errorString() );
+}
+
+#ifndef QT_NO_CLIPBOARD
 shared_ptr<Output> Output::createFromClipboard() {
     return shared_ptr<Output>( new ClipboardOutput( QClipboard::Clipboard ) );
 }
@@ -380,6 +503,7 @@ void ClipboardOutput::doFinalize() {
         throw Exception( gpg_error( GPG_ERR_EIO ),
                          i18n( "Could not find clipboard" ) );
 }
+#endif // QT_NO_CLIPBOARD
 
 
 
