@@ -32,21 +32,21 @@
 #include <KAssistantDialog>
 #include <KSharedConfig>
 
-#include <QCheckBox>
-#include <QLayout>
-#include <QPixmap>
 #include <QList>
-#include <QListWidget>
-#include <QBoxLayout>
+#include <akonadi/collection.h>
 
-class KMFolder;
 class QLabel;
+class QTextEdit;
+class QCheckBox;
+class QBoxLayout;
+class QListWidget;
 
-namespace KMail {
-
-  class FolderSelectionTreeWidget;
-  class MainFolderView;
+namespace MailCommon {
+  class FolderTreeWidget;
   class FolderRequester;
+}
+
+  namespace KMail {
 
   class ASWizInfoPage;
   class ASWizSpamRulesPage;
@@ -121,7 +121,7 @@ namespace KMail {
           within one of the wizard pages.
       */
       AntiSpamWizard( WizardMode mode,
-                      QWidget * parent, MainFolderView * mainFolderTree );
+                      QWidget * parent);
 
     protected:
       /**
@@ -255,13 +255,11 @@ namespace KMail {
       /** Create the summary text based on the current settings */
       void slotBuildSummary();
 
-      void allowToSelectFolder( bool );
-
     private:
       /* Check for the availability of an executible along the PATH */
-      int checkForProgram( const QString &executable );
+      int checkForProgram( const QString &executable ) const;
       /* generic checks if any option in a page is checked */
-      bool anyVirusOptionChecked();
+      bool anyVirusOptionChecked() const;
       /* convenience method calling the appropriate filter manager method */
       const QString uniqueNameFor( const QString & name );
       /* convenience method to sort out new and existing filters */
@@ -275,6 +273,11 @@ namespace KMail {
       ASWizVirusRulesPage * mVirusRulesPage;
       ASWizSummaryPage * mSummaryPage;
 
+      KPageWidgetItem * mInfoPageItem;
+      KPageWidgetItem * mSpamRulesPageItem;
+      KPageWidgetItem * mVirusRulesPageItem;
+      KPageWidgetItem * mSummaryPageItem;
+
       /* The configured tools and it's settings to be used in the wizard. */
       QList<SpamToolConfig> mToolList;
 
@@ -296,7 +299,6 @@ namespace KMail {
 
     protected:
       QBoxLayout *mLayout;
-
     private:
       QLabel *mBannerLabel;
   };
@@ -313,7 +315,7 @@ namespace KMail {
 
       void setScanProgressText( const QString &toolName );
       void addAvailableTool( const QString &visibleName );
-      bool isProgramSelected( const QString &visibleName );
+      bool isProgramSelected( const QString &visibleName ) const;
 
     private slots:
       void processSelectionChange();
@@ -322,7 +324,7 @@ namespace KMail {
       void selectionChanged();
 
     private:
-      QLabel *mIntroText;
+      QTextEdit *mIntroText;
       QLabel *mScanProgressText;
       QLabel *mSelectionHint;
       QListWidget *mToolsList;
@@ -334,20 +336,28 @@ namespace KMail {
     Q_OBJECT
 
     public:
-      ASWizSpamRulesPage( QWidget * parent, const char * name, MainFolderView * mainFolderTree );
+      ASWizSpamRulesPage( QWidget * parent, const char * name);
 
       bool markAsReadSelected() const;
       bool moveSpamSelected() const;
       bool moveUnsureSelected() const;
 
-      QString selectedSpamFolderName() const;
-      QString selectedUnsureFolderName() const;
+      QString selectedUnsureCollectionName() const;
+      QString selectedUnsureCollectionId() const;
 
       void allowUnsureFolderSelection( bool enabled );
+      void allowMoveSpam( bool enabled );
+
+      QString selectedSpamCollectionId() const;
+      QString selectedSpamCollectionName() const;
+
+    protected:
+      Akonadi::Collection selectedSpamCollection() const;
+      Akonadi::Collection selectedUnsureCollection() const;
 
     private slots:
       void processSelectionChange();
-      void processSelectionChange( KMFolder* );
+    void processSelectionChange( const Akonadi::Collection & );
 
     signals:
       void selectionChanged();
@@ -356,8 +366,8 @@ namespace KMail {
       QCheckBox * mMarkRules;
       QCheckBox * mMoveSpamRules;
       QCheckBox * mMoveUnsureRules;
-      FolderRequester *mFolderReqForSpamFolder;
-      FolderRequester *mFolderReqForUnsureFolder;
+      MailCommon::FolderRequester *mFolderReqForSpamFolder;
+      MailCommon::FolderRequester *mFolderReqForUnsureFolder;
   };
 
   //-------------------------------------------------------------------------
@@ -366,7 +376,7 @@ namespace KMail {
     Q_OBJECT
 
     public:
-      ASWizVirusRulesPage( QWidget * parent, const char * name, MainFolderView * mainFolderTree );
+      ASWizVirusRulesPage( QWidget * parent, const char * name );
 
       bool pipeRulesSelected() const;
       bool moveRulesSelected() const;
@@ -376,15 +386,13 @@ namespace KMail {
 
     private slots:
       void processSelectionChange();
-      void verifyAllowToSelectFolder( bool allowOk, bool /*allowCreate*/ );
     signals:
       void selectionChanged();
-      void allowToSelectFolder( bool );
 
     private:
       QCheckBox * mPipeRules;
       QCheckBox * mMoveRules;
-      FolderSelectionTreeWidget *mFolderTree;
+      MailCommon::FolderTreeWidget *mFolderTree;
       QCheckBox * mMarkRules;
   };
 
