@@ -24,70 +24,77 @@
 #include <Akonadi/Entity>
 #include <Akonadi/Collection>
 
-#include <QHash>
+#include <QMap>
 #include <QModelIndex>
 #include <QObject>
 
+namespace MailCommon {
+  class Kernel;
+}
+
 class QAction;
 
 class KActionCollection;
 
 namespace KMail {
 
-class FolderShortcutCommand : public QObject
-{
+  class FolderShortcutCommand : public QObject
+  {
     Q_OBJECT
 
-public:
+  public:
     FolderShortcutCommand( QWidget* mainwidget, const Akonadi::Collection & col );
     ~FolderShortcutCommand();
 
-public slots:
+  public slots:
     void start();
     /** Assign a KAction to the command which is used to trigger it. This
     * action will be deleted along with the command, so you don't need to
     * keep track of it separately. */
     void setAction( QAction* );
 
-signals:
+  signals:
     void selectCollectionFolder( const Akonadi::Collection & col );
 
-private:
-    Akonadi::Collection mCollectionFolder;
+  private:
     QWidget *mMainWidget;
+    Akonadi::Collection mCollectionFolder;
     QAction *mAction;
-};
+  };
 
-class KMAIL_EXPORT FolderShortcutActionManager : public QObject
-{
+  class KMAIL_EXPORT FolderShortcutActionManager : public QObject
+  {
     Q_OBJECT
 
-public:
-    explicit FolderShortcutActionManager( QWidget *parent, KActionCollection *actionCollection );
-    void createActions();
+    public:
 
-public slots:
+      FolderShortcutActionManager( QWidget *parent, KActionCollection *actionCollection );
+      void createActions();
 
-    /**
+    public slots:
+
+      /**
        * Updates the shortcut action for this collection. Call this when a shortcut was
        * added, removed or changed.
        */
-    void shortcutChanged( const Akonadi::Collection &collection );
+      void shortcutChanged( const Akonadi::Collection &collection );
 
-private slots:
-    /**
+    private slots:
+
+      /**
        * Removes the shortcut actions associated with a folder.
        */
-    void slotCollectionRemoved( const Akonadi::Collection &collection );
+      void slotCollectionRemoved( const Akonadi::Collection &collection );
 
-    void slotRowsInserted( const QModelIndex &parent, int start, int end );
+      void slotRowsInserted( const QModelIndex &parent, int start, int end );
 
-private:
-    void updateShortcutsForIndex( const QModelIndex &parent, int start, int end );
-    QHash< Akonadi::Entity::Id, FolderShortcutCommand* > mFolderShortcutCommands;
-    KActionCollection *mActionCollection;
-    QWidget *mParent;
-};
+    private:
+
+      void updateShortcutsForIndex( const QModelIndex &parent, int start, int end );
+      QMap< Akonadi::Entity::Id, FolderShortcutCommand* > mFolderShortcutCommands;
+      KActionCollection *mActionCollection;
+      QWidget *mParent;
+  };
 
 }
 
