@@ -105,8 +105,6 @@ void IdentityPage::load()
 
 void IdentityPage::save()
 {
-  Q_ASSERT( !mIdentityDialog );
-
   mIdentityManager->sort();
   mIdentityManager->commit();
 
@@ -180,6 +178,7 @@ void IdentityPage::slotNewIdentity()
     }
 
     slotModifyIdentity();
+    updateButtons();
   }
 }
 
@@ -237,6 +236,7 @@ void IdentityPage::slotRemoveIdentity()
         mIPage.mIdentityList->currentItem()->setSelected( true );
       }
       refreshList();
+      updateButtons();
     }
   }
 }
@@ -316,12 +316,16 @@ void IdentityPage::refreshList()
 }
 
 void IdentityPage::slotIdentitySelectionChanged()
+{
+  updateButtons();
+}
+
+void IdentityPage::updateButtons()
 {
   IdentityListViewItem *item = 0;
   if ( !mIPage.mIdentityList->selectedItems().isEmpty() ) {
     item = dynamic_cast<IdentityListViewItem*>( mIPage.mIdentityList->selectedItems()[0] );
   }
-
   mIPage.mRemoveButton->setEnabled( item && mIPage.mIdentityList->topLevelItemCount() > 1 );
   mIPage.mModifyButton->setEnabled( item );
   mIPage.mRenameButton->setEnabled( item );
