@@ -1,43 +1,51 @@
-/* -*- mode: C++; c-file-style: "gnu" -*-
-  This file is part of KMail, the KDE mail client.
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
+/*
+ * This file is part of KMail.
+ * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+ *
+ * Based on KMail code by:
+ * Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 
 #ifndef __KMComposeWin
 #define __KMComposeWin
 
 // KMail includes
 #include "composer.h"
-#include "messagesender.h"
+#include "recipientseditor.h"
 
 // Qt includes
 #include <QFont>
 #include <QList>
-#include <QPalette>
-#include <QPointer>
 
 // KDE includes
 #include <kglobalsettings.h>
 
 // LIBKDEPIM includes
-#include <libkdepim/kmeditor.h>
+#include <messagecomposer/kmeditor.h>
+
+#include "messagecomposer/messagesender.h"
+
+// KDEPIMLIBS includes
+#include <kmime/kmime_message.h>
+#include <kmime/kmime_headers.h>
 
 // Other includes
 #include "kleo/enum.h"
+#include <composerviewbase.h>
 
 class QByteArray;
 class QCheckBox;
@@ -46,33 +54,21 @@ class QGridLayout;
 class QLabel;
 class QPushButton;
 class QSplitter;
-class QTreeWidgetItem;
 
+class CodecAction;
 class KLineEdit;
 class KMComposeWin;
 class KMComposerEditor;
-class KMFolderComboBox;
-class KMFolder;
-class KMMessage;
-class KMMessagePart;
-class KSelectAction;
 class KSelectAction;
 class KAction;
 class KJob;
 class KToggleAction;
-class KTemporaryFile;
-class KTempDir;
-class KToggleAction;
 class KUrl;
 class KRecentFilesAction;
-class MessageComposer;
-class RecipientsEditor;
-class KMLineEdit;
-class KMAtmListViewItem;
 class SnippetWidget;
-class partNode;
 
-namespace KPIM {
+namespace boost {
+  template <typename T> class shared_ptr;
 }
 
 namespace Sonnet {
@@ -80,27 +76,32 @@ namespace Sonnet {
 }
 
 namespace KPIMIdentities {
-  class IdentityCombo;
   class Identity;
 }
 
-namespace MailTransport {
-  class TransportComboBox;
-}
 
 namespace KMail {
-  class AttachmentListView;
-  class EditorWatcher;
+  class AttachmentController;
 }
 
 namespace KIO {
   class Job;
 }
 
-namespace GpgME {
-  class Error;
+namespace Message {
+  class Composer;
+  class KMSubjectLineEdit;
 }
 
+namespace MessageComposer
+{
+  class ComposerLineEdit;
+}
+namespace MailCommon
+{
+  class FolderRequester;
+}
+ 
 //-----------------------------------------------------------------------------
 class KMComposeWin : public KMail::Composer
 {
@@ -109,16 +110,14 @@ class KMComposeWin : public KMail::Composer
 
   friend class ::KMComposerEditor;
 
-  friend class ::MessageComposer;
-
   private: // mailserviceimpl, kmkernel, kmcommands, callback, kmmainwidget
-    explicit KMComposeWin( KMMessage *msg = 0, TemplateContext context = NoTemplate,
+    explicit KMComposeWin( const KMime::Message::Ptr &msg = KMime::Message::Ptr(), TemplateContext context = NoTemplate,
                            uint identity = 0, const QString & textSelection = QString(),
                            const QString & customTemplate = QString() );
     ~KMComposeWin();
 
   public:
-    static Composer *create( KMMessage *msg = 0, TemplateContext context = NoTemplate,
+    static Composer *create( const KMime::Message::Ptr &msg = KMime::Message::Ptr(), TemplateContext context = NoTemplate,
                              uint identity = 0, const QString & textSelection = QString(),
                              const QString & customTemplate = QString() );
 
@@ -129,6 +128,7 @@ class KMComposeWin : public KMail::Composer
    * Start of D-Bus callable stuff. The D-Bus methods need to be public slots,
    * otherwise they can't be accessed.
    */
+  // TODO clean-up dbus stuff; make the adaptor a friend; etc.
   public slots:
 
     Q_SCRIPTABLE void send( int how );
@@ -141,33 +141,36 @@ class KMComposeWin : public KMail::Composer
                                      const QString & comment );
 
     Q_SCRIPTABLE void addAttachment( const QString & name,
-                                     const QByteArray & cte,
+                                     KMime::Headers::contentEncoding cte,
+                                     const QString& charset,
                                      const QByteArray & data,
-                                     const QByteArray & type,
-                                     const QByteArray & subType,
-                                     const QByteArray & paramAttr,
-                                     const QString & paramValue,
-                                     const QByteArray & contDisp );
+                                     const QByteArray & mimeType );
 
   /**
    * End of D-Bus callable stuff
    */
 
-  private:
+  signals:
+    void identityChanged( const KPIMIdentities::Identity &identity );
 
-    /**
-     * Write settings to app's config file.
-     */
-    void writeConfig( void );
 
   public: // kmkernel, kmcommands, callback
     /**
      * Set the message the composer shall work with. This discards
      * previous messages without calling applyChanges() on them before.
      */
-     void setMsg( KMMessage *newMsg, bool mayAutoSign=true,
+    void setMsg( const KMime::Message::Ptr &newMsg, bool mayAutoSign=true,
                  bool allowDecryption=false, bool isModified=false );
 
+    void setCurrentTransport( int transportId );
+
+    /**
+     * Use the given folder as sent-mail folder if the given folder exists.
+     * Else show an error message and use the default sent-mail folder as
+     * sent-mail folder.
+     */
+    void setFcc( const QString &idString );
+
      /**
       * Disables word wrap completely. No wrapping at all will occur, not even
       * at the right end of the editor.
@@ -184,27 +187,10 @@ class KMComposeWin : public KMail::Composer
       */
      void forceDisableHtml();
 
-     /** Don't check if there are too many recipients for a mail, eg. when sending out invitations. */
-     void disableRecipientNumberCheck();
-
-    /** Don't check for forgotten attachments for a mail, eg. when sending out invitations. */
-    void disableForgottenAttachmentsCheck();
-
-    /**
-    * Ignore the "sticky" setting of the transport combo box and prefer the X-KMail-Transport
-    * header field of the message instead.
-    * Do the same for the identity combo box, don't obey the "sticky" setting but use the
-    * X-KMail-Identity header field instead.
-    *
-    * This is useful when sending out invitations, since you don't see the GUI and want the
-    * identity and transport to be set to the values stored in the messages.
-    */
-    void ignoreStickyFields();
-
      /**
       * Returns @c true while the message composing is in progress.
       */
-     bool isComposing() const { return mComposer != 0; }
+     bool isComposing() const { return mComposerBase && mComposerBase->isComposing(); }
 
      /**
       * Set the text selection the message is a response to.
@@ -216,52 +202,16 @@ class KMComposeWin : public KMail::Composer
       */
      void setCustomTemplate( const QString& customTemplate );
 
-  private: // kmedit
-    /**
-     * Returns message of the composer. To apply the user changes to the
-     * message, call applyChanges() first.
-     */
-     KMMessage *msg() const { return mMsg; }
-
-  public: // kmkernel
-    /**
-     * Set the filename which is used for autosaving.
-     */
-    void setAutoSaveFilename( const QString & filename );
-
-  private:
-    /**
-     * Returns true if the message was modified by the user.
-     */
-    bool isModified() const;
-
-    /**
-     * Set whether the message should be treated as modified or not.
-     */
-    void setModified( bool modified );
-
-  public: // kmkernel, callback
-    /**
-     * If this flag is set the message of the composer is deleted when
-     * the composer is closed and the message was not sent. Default: false
-     */
-     inline void setAutoDelete( bool f ) { mAutoDeleteMsg = f; }
-
-  public: // kmcommand
+    /** Disabled signing and encryption completely for this composer window. */
+    void setSigningAndEncryptionDisabled( bool v )
+    {
+      mSigningAndEncryptionExplicitlyDisabled = v;
+    }
     /**
      * If this folder is set, the original message is inserted back after
      * canceling
      */
-     void setFolder( KMFolder *aFolder ) { mFolder = aFolder; }
-
-  public: // kmkernel, kmcommand, mailserviceimpl
-
-    /**
-     * Reimplemented
-     */
-     virtual void setCharset( const QByteArray &aCharset, bool forceDefault = false );
-
-  public: // kmcommand
+    void setFolder(const Akonadi::Collection &aFolder ) { mFolder = aFolder; }
     /**
      * Sets the focus to the edit-widget.
      */
@@ -273,24 +223,34 @@ class KMComposeWin : public KMail::Composer
      */
      void setFocusToSubject();
 
+  bool insertFromMimeData( const QMimeData *source, bool forceAttachment = false );
+
   private:
+  /**
+   * Write settings to app's config file.
+   */
+  void writeConfig( void );
+
+
+    /**
+     * Returns message of the composer. To apply the user changes to the
+     * message, call applyChanges() first.
+     */
+    KMime::Message::Ptr msg() const { return mMsg; }
+    /**
+     * Returns true if the message was modified by the user.
+     */
+    bool isModified() const;
+    bool isComposerModified() const;
+    void changeModifiedState( bool modified );
+
+
+  
     /**
      * determines whether inline signing/encryption is selected
      */
      bool inlineSigningEncryptionSelected();
 
-     /**
-      * Enables HTML mode, by showing the HTML toolbar and checking the
-      * "Formatting" action
-      */
-     void enableHtml();
-
-     /**
-      * Disables the HTML mode, by hiding the HTML toolbar and unchecking the
-      * "Formatting" action. Also, removes all rich-text formatting.
-      */
-     enum Confirmation { LetUserConfirm, NoConfirmationNeeded };
-     void disableHtml( Confirmation confirmation );
 
      /**
       * Tries to find the given mimetype @p type in the KDE Mimetype registry.
@@ -299,28 +259,43 @@ class KMComposeWin : public KMail::Composer
       */
      static QString prettyMimeType( const QString &type );
 
-  public: // callback
-    /** Disabled signing and encryption completely for this composer window. */
-    void setSigningAndEncryptionDisabled( bool v )
-    {
-      mSigningAndEncryptionExplicitlyDisabled = v;
-    }
+  public slots: // kmkernel, callback
+    void slotSendNow();
+    /**
+     * Switch wordWrap on/off
+     */
+    void slotWordWrapToggled( bool );
+
+    void slotToggleMarkup();
+    void slotTextModeChanged( KRichTextEdit::Mode );
+    void htmlToolBarVisibilityChanged( bool visible );
+    void slotSpellcheckDoneClearStatus();
+    void autoSaveMessage(bool force = false);
+    /**
+     * Set whether the message should be treated as modified or not.
+     */
+    void setModified( bool modified );
+  void slotFetchJob(KJob*);
 
   private slots:
+     /**
+      * Disables the HTML mode, by hiding the HTML toolbar and unchecking the
+      * "Formatting" action. Also, removes all rich-text formatting.
+      */
+     void disableHtml( Message::ComposerViewBase::Confirmation confirmation );
+    /**
+     * Enables HTML mode, by showing the HTML toolbar and checking the
+     * "Formatting" action
+     */
+    void enableHtml();
 
     /**
      * Actions:
      */
     void slotPrint();
-    void slotAttachFile();
     void slotInsertRecentFile( const KUrl & );
-    void slotAttachedFile( const KUrl & );
     void slotRecentListFileClear();
 
-  public slots: // kmkernel, callback
-    void slotSendNow();
-
-  private slots:
     void slotSendNowVia( QAction * );
     void slotSendLater();
     void slotSendLaterVia( QAction * );
@@ -344,21 +319,11 @@ class KMComposeWin : public KMail::Composer
     void slotFormatReset();
     void slotMarkAll();
 
-    void slotFolderRemoved( KMFolder * );
-    void slotEditDone( KMail::EditorWatcher* watcher );
+  void slotFolderRemoved( const Akonadi::Collection& );
     void slotLanguageChanged( const QString &language );
-
+  void slotFccFolderChanged(const Akonadi::Collection&);
     void slotEditorTextChanged();
-  public slots: // kmkernel
-    /**
-       Tell the composer to always send the message, even if the user
-       hasn't changed the next. This is useful if a message is
-       autogenerated (e.g., via a D-Bus call), and the user should
-       simply be able to confirm the message and send it.
-    */
-    void slotSetAlwaysSend( bool bAlwaysSend );
-
-  private slots:
+    void slotOverwriteModeChanged();
     /**
      * toggle fixed width font.
      */
@@ -374,7 +339,6 @@ class KMComposeWin : public KMail::Composer
      */
     void slotInsertFile();
 
-    void slotSetCharset();
     /**
      * Check spelling of text.
      */
@@ -401,7 +365,7 @@ class KMComposeWin : public KMail::Composer
     /**
      * Change window title to given string.
      */
-    void slotUpdWinTitle( const QString & );
+    void slotUpdWinTitle();
 
     /**
      * Switch the icon to lock or unlock respectivly.
@@ -414,71 +378,6 @@ class KMComposeWin : public KMail::Composer
      */
     void slotSignToggled( bool );
 
-  public slots: // kmkernel, callback
-    /**
-     * Switch wordWrap on/off
-     */
-    void slotWordWrapToggled( bool );
-
-  private slots:
-    /**
-     * Append signature to the end of the text in the editor.
-     */
-    void slotAppendSignature();
-
-    /**
-    * Prepend signature at the beginning of the text in the editor.
-    */
-    void slotPrependSignature();
-
-    /**
-    * Insert signature at the cursor position of the text in the editor.
-    */
-    void slotInsertSignatureAtCursor();
-
-    /**
-     * Attach sender's public key.
-     */
-    void slotInsertMyPublicKey();
-
-    /**
-     * Insert arbitrary public key from public keyring in the editor.
-     */
-    void slotInsertPublicKey();
-
-    /**
-     * Enable/disable some actions in the Attach menu
-     */
-    void slotUpdateAttachActions();
-    void slotAttachEdit();
-    void slotAttachEditWith();
-
-    /**
-     * Open a popup-menu in the attachments-listbox.
-     */
-    void slotAttachPopupMenu( QTreeWidgetItem* );
-
-    /**
-     * Attachment operations.
-     */
-    void slotAttachOpen();
-    void slotAttachView();
-    void slotAttachRemove();
-    void slotAttachSave();
-    void slotAttachProperties();
-    void slotAttachmentDragStarted();
-
-    void slotCleanSpace();
-    void slotToggleMarkup();
-    void slotTextModeChanged( KRichTextEdit::Mode );
-    void htmlToolBarVisibilityChanged( bool visible );
-    void slotSpellcheckDoneClearStatus();
-
-  public slots: // kmkernel
-    void autoSaveMessage();
-
-  private slots:
-
     void slotView();
 
     /**
@@ -489,44 +388,64 @@ class KMComposeWin : public KMail::Composer
      */
     void slotIdentityChanged( uint uoid, bool initalChange = false );
 
-    /**
-     * KIO slots for attachment insertion
-     */
-    void slotAttachFileData( KIO::Job *, const QByteArray & );
-    void slotAttachFileResult( KJob * );
-
     void slotCursorPositionChanged();
 
     void slotSpellCheckingStatus( const QString & status );
 
-  public: // kmkernel, attachmentlistview
-    bool addAttach( const KUrl &url );
+    void slotDelayedApplyTemplate( KJob* );
+  
+    void recipientEditorSizeHintChanged();
+    void setMaximumHeaderSize();
+    void slotDoDelayedSend( KJob* );
+
+    void slotCompletionModeChanged( KGlobalSettings::Completion );
+    void slotConfigChanged();
+
+    void slotPrintComposeResult( KJob *job );
+
+    void slotEncryptChiasmusToggled( bool );
+
+    void slotSendFailed( const QString& msg );
+    void slotSendSuccessful();
+
+    /**
+     *  toggle automatic spellchecking
+     */
+    void slotAutoSpellCheckingToggled( bool );
+
+    /**
+     * Updates the visibility and text of the signature and encryption state indicators.
+     */
+    void slotUpdateSignatureAndEncrypionStateIndicators();
+
+    virtual void setAutoSaveFileName( const QString& fileName );
+    void slotSpellCheckingLanguage(const QString& language);
+    void forceAutoSaveMessage();
+  
 
   public: // kmcommand
+    // FIXME we need to remove these, but they're pure virtual in Composer.
+    void addAttach( KMime::Content *msgPart );
+  
+    const KPIMIdentities::Identity &identity() const;
+
+    /** Don't check for forgotten attachments for a mail, eg. when sending out invitations. */
+    void disableForgottenAttachmentsCheck();
+
     /**
-     * Add an attachment to the list.
-     */
-    void addAttach( KMMessagePart *msgPart );
+    * Ignore the "sticky" setting of the transport combo box and prefer the X-KMail-Transport
+    * header field of the message instead.
+    * Do the same for the identity combo box, don't obey the "sticky" setting but use the
+    * X-KMail-Identity header field instead.
+    *
+    * This is useful when sending out invitations, since you don't see the GUI and want the
+    * identity and transport to be set to the values stored in the messages.
+    */
+    void ignoreStickyFields();
 
   private:
-    const KPIMIdentities::Identity & identity() const;
-    uint identityUid() const;
     Kleo::CryptoMessageFormat cryptoMessageFormat() const;
-    bool encryptToSelf() const;
-
-  signals:
-    void applyChangesDone( bool );
-    void attachmentAdded( const KUrl &, bool success );
-
-  private:
-    /**
-     * Applies the user changes to the message object of the composer
-     * and signs/encrypts the message if activated. Returns false in
-     * case of an error (e.g. if PGP encryption fails).
-     * Disables the controls of the composer window unless @p dontDisable
-     * is true.
-     */
-    void applyChanges( bool dontSignNorEncrypt, bool dontDisable=false );
+    QString overwriteModeStr() const;
 
     /**
      * Install grid management and header fields. If fields exist that
@@ -543,13 +462,13 @@ class KMComposeWin : public KMail::Composer
     /**
      * Show or hide header lines
      */
-
     void rethinkHeaderLine( int aValue, int aMask, int &aRow,
-                            QLabel *aLbl, KLineEdit *aEdt,
+                            QLabel *aLbl, QWidget *aEdt,
                             QPushButton *aBtn = 0 );
 
     void rethinkHeaderLine( int value, int mask, int &row,
-                            QLabel *lbl, QComboBox *cbx, QCheckBox *chk ); // krazy:exclude=qclasses
+                            QLabel *lbl, QWidget *cbx, QCheckBox *chk ); // krazy:exclude=qclasses
+
 
     /**
      * Apply template to new or unmodified message.
@@ -579,18 +498,11 @@ class KMComposeWin : public KMail::Composer
      * Header fields.
      */
     QString subject() const;
-    QString to() const;
-    QString cc() const;
-    QString bcc() const;
     QString from() const;
     QString replyTo() const;
 
-    /**
-     * Use the given folder as sent-mail folder if the given folder exists.
-     * Else show an error message and use the default sent-mail folder as
-     * sent-mail folder.
-     */
-    void setFcc( const QString &idString );
+    void setCharset( const QByteArray &charset );
+    void setAutoCharset();
 
     /**
      * Ask for confirmation if the message was changed before close.
@@ -601,70 +513,19 @@ class KMComposeWin : public KMail::Composer
      * prevent kmail from exiting when last window is deleted (kernel rules)
      */
     virtual bool queryExit();
-
-    /**
-     * Open the attachment with the given index.
-     */
-    void openAttach( int index );
-
-    /**
-     * View the attachment with the given index.
-     */
-    void viewAttach( int index );
-
-    /**
-     * Remove an attachment from the list.
-     */
-    void removeAttach( const QString &url );
-    void removeAttach( int idx );
-
-    /**
-     * Updates an item in the QListView to represnet a given message part
-     */
-    void msgPartToItem( const KMMessagePart *msgPart, KMAtmListViewItem *lvi,
-                        bool loadDefaults = true );
-
-
-    /**
-     * Searches the mime tree, where root is the root node, for embedded images,
-     * extracts them froom the body and adds them to the editor.
-     */
-    void collectImages( partNode *root );
-
-  private:
     /**
      * Turn encryption on/off. If setByUser is true then a message box is shown
      * in case encryption isn't possible.
      */
     void setEncryption( bool encrypt, bool setByUser = false );
 
-    /**
-      Edit the attachment with the given index.
-    */
-    void editAttach( int index, bool openWith );
-
     /**
      * Turn signing on/off. If setByUser is true then a message box is shown
      * in case signing isn't possible.
      */
     void setSigning( bool sign, bool setByUser = false );
 
-    /**
-      Returns true if the user forgot to attach something.
-    */
-    bool userForgotAttachment();
-
-    /**
-     * Retrieve encrypt flag of an attachment
-     * ( == state of it's check box in the attachments list view )
-     */
-    bool encryptFlagOfAttachment( int idx );
-
-    /**
-     * Retrieve sign flag of an attachment
-     * ( == state of it's check box in the attachments list view )
-     */
-    bool signFlagOfAttachment( int idx );
+    Message::ComposerViewBase::MissingAttachment userForgotAttachment();
 
     /**
      * Decrypt an OpenPGP block or strip off the OpenPGP envelope of a text
@@ -676,107 +537,82 @@ class KMComposeWin : public KMail::Composer
     static void decryptOrStripOffCleartextSignature( QByteArray & );
 
     /**
-     * Save the message into the Drafts or Templates folder.
+     * Send the message.
      */
-    bool saveDraftOrTemplate( const QString &folderName, KMMessage *msg );
+    void doSend( MessageSender::SendMethod method=MessageSender::SendDefault,
+                 MessageSender::SaveIn saveIn = MessageSender::SaveInNone );
 
-    enum SaveIn {
-      None,
-      Drafts,
-      Templates
-    };
+    void doDelayedSend( MessageSender::SendMethod method, MessageSender::SaveIn saveIn );
+
+    void changeCryptoAction();
+    void applyComposerSetting( Message::ComposerViewBase* mComposerBase );
+    /**
+     * Creates a simple composer that creates a KMime::Message out of the composer content.
+     * Crypto handling is not done, therefore the name "simple".
+     * This is used when autosaving or printing a message.
+     *
+     * The caller takes ownership of the composer.
+     */
+    Message::Composer* createSimpleComposer();
+
+    bool canSignEncryptAttachments() const {
+      return cryptoMessageFormat() != Kleo::InlineOpenPGPFormat;
+    }
+
+    QString addQuotesToText( const QString &inputText ) const;
+    // helper method for rethinkFields
+    int calcColumnWidth( int which, long allShowing, int width ) const;
+
+
+    /** Initialize header fields. Should be called on new messages
+      if they are not set manually. E.g. before composing. Calling
+      of setAutomaticFields(), see below, is still required. */
+    void initHeader( KMime::Message *message, uint identity=0 );
 
     /**
-     * Send the message. Returns true if the message was sent successfully.
+     * Helper methods to read from config various encryption settings
      */
-    void doSend( KMail::MessageSender::SendMethod method=KMail::MessageSender::SendDefault,
-                 KMComposeWin::SaveIn saveIn = KMComposeWin::None );
+    inline bool encryptToSelf();
+    inline bool showKeyApprovalDialog();
+    inline int encryptKeyNearExpiryWarningThresholdInDays();
+    inline int signingKeyNearExpiryWarningThresholdInDays();
+    inline int encryptRootCertNearExpiryWarningThresholdInDays();
+    inline int signingRootCertNearExpiryWarningThresholdInDays();
+    inline int encryptChainCertNearExpiryWarningThresholdInDays();
+    inline int signingChainCertNearExpiryWarningThresholdInDays();
 
-    /**
-     * Returns the autosave interval in milliseconds (as needed for QTimer).
-     */
-    int autoSaveInterval() const;
-
-    /**
-     * Initialize autosaving (timer and filename).
-     */
-    void initAutoSave();
-
-    /**
-     * Enables/disables autosaving depending on the value of the autosave
-     * interval.
-     */
-    void updateAutoSave();
-
-    /**
-     * Stop autosaving and delete the autosaved message.
-     */
-    void cleanupAutoSave();
-
-    /**
-     * Helper to insert the signature of the current identity arbitrarily
-     * in the editor, connecting slot functions to KMeditor::insertSignature().
-     * @param placement the position of the signature
-     */
-    void insertSignatureHelper( KPIMIdentities::Signature::Placement = KPIMIdentities::Signature::End );
-
-
-  private slots:
-    /**
-     * Compress an attachemnt with the given index
-     */
-    void compressAttach( KMAtmListViewItem *attachmentItem );
-    void uncompressAttach( KMAtmListViewItem *attachmentItem );
-    void recipientEditorSizeHintChanged();
-    void setMaximumHeaderSize();
 
   private:
     QWidget   *mMainWidget;
-    MailTransport::TransportComboBox *mTransport;
     Sonnet::DictionaryComboBox *mDictionaryCombo;
-    KPIMIdentities::IdentityCombo    *mIdentity;
-    KMFolderComboBox *mFcc;
-    KMLineEdit *mEdtFrom, *mEdtReplyTo;
-    KMLineEdit *mEdtSubject;
+    MessageComposer::ComposerLineEdit *mEdtFrom, *mEdtReplyTo;
+    Message::KMSubjectLineEdit *mEdtSubject;
     QLabel    *mLblIdentity, *mLblTransport, *mLblFcc;
     QLabel    *mLblFrom, *mLblReplyTo;
     QLabel    *mLblSubject;
     QLabel    *mDictionaryLabel;
-    QCheckBox *mBtnIdentity, *mBtnTransport, *mBtnFcc;
+    QCheckBox *mBtnIdentity, *mBtnDictionary, *mBtnTransport, *mBtnFcc;
     bool mDone;
-    bool mAtmModified;
 
-    KMComposerEditor *mEditor;
+    KMime::Message::Ptr mMsg;
     QGridLayout *mGrid;
-    KMMessage *mMsg;
     QString mTextSelection;
     QString mCustomTemplate;
-    QVector<KMMessage*> mComposedMessages;
-    KMail::AttachmentListView *mAtmListView;
-    QList<KMAtmListViewItem*> mAtmItemList;
-    QList<KMMessagePart*> mAtmList;
-    QMenu *mAttachMenu;
     QAction *mOpenId, *mViewId, *mRemoveId, *mSaveAsId, *mPropertiesId,
             *mEditAction, *mEditWithAction;
-    bool mAutoDeleteMsg;
-    bool mSigningAndEncryptionExplicitlyDisabled;
-    bool mLastSignActionState, mLastEncryptActionState;
+    bool mLastSignActionState, mLastEncryptActionState, mSigningAndEncryptionExplicitlyDisabled;
     bool mLastIdentityHasSigningKey, mLastIdentityHasEncryptionKey;
-    KMFolder *mFolder;
+    Akonadi::Collection mFolder;
     long mShowHeaders;
     bool mConfirmSend;
-    bool mDisableBreaking;
     bool mForceDisableHtml;     // Completely disable any HTML. Useful when sending invitations in the
                                 // mail body.
     int mNumHeaders;
     QFont mBodyFont, mFixedFont;
-    QList<KTemporaryFile*> mAtmTempList;
-    QPalette mPalette;
     uint mId;
     TemplateContext mContext;
 
-    KAction *mAttachPK, *mAttachMPK, *mAttachRemoveAction, *mAttachSaveAction,
-            *mAttachPropertiesAction, *mCleanSpace;
+    KAction *mCleanSpace;
     KRecentFilesAction *mRecentAction;
 
     KToggleAction *mSignAction, *mEncryptAction, *mRequestMDNAction;
@@ -790,124 +626,46 @@ class KMComposeWin : public KMail::Composer
     KToggleAction *markupAction;
     KAction *actionFormatReset;
 
-    KSelectAction *mEncodingAction;
+    CodecAction *mCodecAction;
     KSelectAction *mCryptoModuleAction;
 
-    KAction * mFindText, *mFindNextText, *mReplaceText, *mSelectAll;
+    KAction *mFindText, *mFindNextText, *mReplaceText, *mSelectAll;
 
-    QByteArray mCharset;
-    QByteArray mDefCharset;
-    QStringList mCharsets;
-    bool mAutoCharset;
-
-    bool mAlwaysSend;
-
-    QStringList mFolderNames;
-    QList<QPointer<KMFolder> > mFolderList;
-    QMap<KJob*, KUrl> mAttachJobs;
-    KUrl::List mAttachFilesPending;
-    int mAttachFilesSend;
-
-  private:
-  // helper method for slotInsert(My)PublicKey()
-    void startPublicKeyExport();
-    bool canSignEncryptAttachments() const {
-      return cryptoMessageFormat() != Kleo::InlineOpenPGPFormat;
-    }
-
-    // helper method for rethinkFields
-    int calcColumnWidth( int which, long allShowing, int width ) const;
-
-    // Sends a key event with the control modifier and the specified key to
-    // the given widget. This function is protected against recursion.
-    void sendControlKeyEvent( QWidget *receiver, Qt::Key key );
-
-  private slots:
-    void slotCompletionModeChanged( KGlobalSettings::Completion );
-    void slotConfigChanged();
-
-    void slotComposerDone( bool );
-
-    void slotContinueDoSend( bool );
-    void slotContinuePrint( bool );
-    void slotContinueAutoSave();
-
-    void slotEncryptChiasmusToggled( bool );
-
-    /**
-     * Helper method (you could call is a bottom-half :) for
-     * startPublicKeyExport()
-     */
-    void slotPublicKeyExportResult( const GpgME::Error &err,
-                                    const QByteArray &keydata );
-
-    /**
-     *  toggle automatic spellchecking
-     */
-    void slotAutoSpellCheckingToggled( bool );
-
-    /**
-     * Updates the visibility and text of the signature and encryption state indicators.
-     */
-    void slotUpdateSignatureAndEncrypionStateIndicators();
-
-  private:
+  //bool mAlwaysSend;
+  
     QFont mSaveFont;
     QSplitter *mHeadersToEditorSplitter;
     QWidget* mHeadersArea;
     QSplitter *mSplitter;
     QSplitter *mSnippetSplitter;
-    struct atmLoadData
-    {
-      KUrl url;
-      QByteArray data;
-      bool insert;
-      QByteArray encoding;
-    };
-    QMap<KIO::Job *, atmLoadData> mMapAtmLoadData;
-
-    // These are for passing on methods over the applyChanges calls
-    KMail::MessageSender::SendMethod mSendMethod;
-    KMComposeWin::SaveIn mSaveIn;
+    QByteArray mOriginalPreferredCharset;
 
     KToggleAction *mEncryptChiasmusAction;
-    bool mEncryptWithChiasmus;
 
-    // The temporary object that constructs the message out of the window
-    MessageComposer *mComposer;
+    Message::Composer *mDummyComposer;
+    // used for auto saving, printing, etc. Not for sending, which happens in ComposerViewBase
+    QList< Message::Composer* > mMiscComposers;
 
-    // Temp var for slotPrint:
-    bool mMessageWasModified;
-
-    // Temp var for slotInsert(My)PublicKey():
-    QString mFingerprint;
-
-    RecipientsEditor *mRecipientsEditor;
     int mLabelWidth;
 
-    QTimer *mAutoSaveTimer;
-    QString mAutoSaveFilename;
-    int mLastAutoSaveErrno; // holds the errno of the last try to autosave
-
     QMenu *mActNowMenu;
     QMenu *mActLaterMenu;
 
     QString mdbusObjectPath;
     static int s_composerNumber;
 
-    QMap<KMail::EditorWatcher*, KMMessagePart*> mEditorMap;
-    QMap<KMail::EditorWatcher*, KTemporaryFile*> mEditorTempFiles;
+    Message::ComposerViewBase* mComposerBase;
+
 
     SnippetWidget *mSnippetWidget;
-    QList<KTempDir*> mTempDirs;
 
     QLabel *mSignatureStateIndicator;
-    QLabel *mEncryptionStateIndicator;
-
+  QLabel *mEncryptionStateIndicator;
+  MailCommon::FolderRequester *mFccFolder;
     bool mPreventFccOverwrite;
-    bool mCheckForRecipients;
     bool mCheckForForgottenAttachments;
     bool mIgnoreStickyFields;
+  bool mWasModified;
 };
 
 #endif
