@@ -612,7 +612,7 @@ int KMKernel::openComposer( const QString &to, const QString &cc,
   }
   else if ( !body.isEmpty() ) {
     context = KMail::Composer::NoTemplate;
-    msg->setBody( body.toUtf8() );
+    msg->setBody( body.toLatin1() );
   }
   else {
     TemplateParser::TemplateParser parser( msg, TemplateParser::TemplateParser::NewMessage );
@@ -782,7 +782,7 @@ QDBusObjectPath KMKernel::openComposer( const QString &to, const QString &cc,
   if ( !subject.isEmpty() ) msg->subject()->fromUnicodeString( subject, "utf-8" );
   if ( !to.isEmpty() )      msg->to()->fromUnicodeString( to, "utf-8" );
   if ( !body.isEmpty() ) {
-    msg->setBody(body.toUtf8());
+    msg->setBody(body.toLatin1());
   } else {
     TemplateParser::TemplateParser parser( msg, TemplateParser::TemplateParser::NewMessage );
     parser.setIdentityManager( KMKernel::self()->identityManager() );
