@@ -18,31 +18,31 @@
 #ifndef KMSYSTEMTRAY_H
 #define KMSYSTEMTRAY_H
 
-#include <ksystemtrayicon.h>
+#include <akonadi/collection.h>
+#include <kicon.h>
+#include <kstatusnotifieritem.h>
 
+#include <QAction>
 #include <QMap>
 #include <QPointer>
 #include <QVector>
-
-#include <QPixmap>
-#include <QImage>
+#include <QAbstractItemModel>
 
 #include <time.h>
 
-class KMFolder;
 class QPoint;
 class QMenu;
 
 /**
- * KMSystemTray extends KSystemTray and handles system
+ * KMSystemTray extends KStatusNotifierItem and handles system
  * tray notification for KMail
  */
-class KMSystemTray : public KSystemTrayIcon
+class KMSystemTray : public KStatusNotifierItem
 {
   Q_OBJECT
 public:
   /** construtor */
-  KMSystemTray(QWidget* parent=0);
+  explicit KMSystemTray(QObject* parent=0);
   /** destructor */
   ~KMSystemTray();
 
@@ -52,42 +52,33 @@ public:
   void hideKMail();
   bool hasUnreadMail() const;
 
-public slots:
-  void foldersChanged();
+  void updateSystemTray();
 
 private slots:
-  void updateNewMessageNotification(KMFolder * folder);
-  void selectedAccount(int);
-  void updateNewMessages();
-  void slotActivated( QSystemTrayIcon::ActivationReason reason );
+  void slotActivated();
   void slotContextMenuAboutToShow();
-
+  void slotSelectCollection(QAction*act);
+  void initListOfCollection();
+  void slotCollectionStatisticsChanged( Akonadi::Collection::Id,const Akonadi::CollectionStatistics& );
+  
 protected:
   bool mainWindowIsOnCurrentDesktop();
-  void showKMail();
   void buildPopupMenu();
   void updateCount();
-
-  QString prettyName(KMFolder *);
+  void fillFoldersMenu( QMenu *menu, const QAbstractItemModel *model, const QString& parentName = QString(), const QModelIndex& parentIndex = QModelIndex() );
+  void unreadMail( const QAbstractItemModel *model, const QModelIndex& parentIndex = QModelIndex() );
+  
+  bool excludeFolder( const Akonadi::Collection& collection ) const;
 
 private:
-
-  bool mParentVisible;
-  QPoint mPosOfMainWin;
   int mDesktopOfMainWin;
 
   int mMode;
   int mCount;
+  KIcon mIcon;
 
   QMenu *mNewMessagesPopup;
   QAction *mSendQueued;
-  QPixmap mDefaultIcon;
-
-  QVector<KMFolder*> mPopupFolders;
-  QMap<QPointer<KMFolder>, int> mFoldersWithUnread;
-  QMap<QPointer<KMFolder>, bool> mPendingUpdates;
-  QTimer *mUpdateTimer;
-  time_t mLastUpdate;
 };
 
 #endif
