@@ -48,8 +48,11 @@
 #include <KLocale>
 
 #include <KStandardDirs>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/EntityMimeTypeFilterModel>
 
 #include <QProcess>
+#include <QModelIndex>
 
 #include "foldercollection.h"
 
