@@ -19,17 +19,38 @@
 #define KIMPORTPAGE_H
 
 #include "ui_kimportpagedlg.h"
+#include <QStyledItemDelegate>
+class QTextDocument;
 
-class KImportPage : public QWidget
+class LogItemDelegate : public QStyledItemDelegate
 {
-    Q_OBJECT
-public:
-    explicit KImportPage(QWidget *parent=0);
-    ~KImportPage();
+  public:
+  explicit LogItemDelegate( QObject *parent );
+  ~LogItemDelegate();
+  
+  virtual QSize sizeHint ( const QStyleOptionViewItem &option, const QModelIndex &index ) const;
+  virtual void paint ( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const;
+  virtual QWidget  *createEditor ( QWidget *, const QStyleOptionViewItem  &, const QModelIndex & ) const;
 
-    Ui::KImportPageDlg *widget() const;
-private:
-    Ui::KImportPageDlg *mWidget;
+
+  private:
+  QTextDocument* document ( const QStyleOptionViewItem &option, const QModelIndex &index ) const;
+};
+
+class KImportPageDlg : public QWidget, public Ui::KImportPageDlg
+{
+public:
+  KImportPageDlg( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+
+class KImportPage : public KImportPageDlg  {
+	Q_OBJECT
+public:
+	KImportPage(QWidget *parent=0);
+	~KImportPage();
 };
 
 #endif
