@@ -44,9 +44,9 @@
 #include <kxmlguifactory.h>
 #include <ksqueezedtextlabel.h>
 
-#include "libkdepim/misc/uistatesaver.h"
-#include "libkdepim/misc/broadcaststatus.h"
-#include "libkdepim/addressline/recentaddress/recentaddresses.h"
+#include "libkdepim/uistatesaver.h"
+#include "libkdepim/broadcaststatus.h"
+#include "libkdepim/recentaddresses.h"
 using KPIM::BroadcastStatus;
 using KPIM::RecentAddresses;
 
@@ -2113,3 +2113,4 @@ bool KNMainWidget::handleCommandLine()
 //////////////////////// end D-Bus implementation
 ////////////////////////////////////////////////////////////////////////
 
+#include "knmainwidget.moc"
