@@ -27,12 +27,25 @@
 
 #include <KontactInterface/Summary>
 
+#include <kviewstatemaintainer.h> //krazy:exclude=camelcase TODO wait for kdelibs4.8
+
+namespace Akonadi {
+  class ChangeRecorder;
+  class Collection;
+  class EntityTreeModel;
+  class ETMViewStateSaver;
+}
+
 namespace KontactInterface {
   class Plugin;
 }
 
+class KCheckableProxyModel;
+
 class QGridLayout;
+class QItemSelectionModel;
 class QLabel;
+class QModelIndex;
 
 class SummaryWidget : public KontactInterface::Summary
 {
@@ -52,14 +65,21 @@ class SummaryWidget : public KontactInterface::Summary
 
   private slots:
     void selectFolder( const QString & );
-    void slotUnreadCountChanged();
+    void slotCollectionChanged( const Akonadi::Collection & );
+    void slotRowInserted( const QModelIndex & parent, int start, int end );
 
   private:
-    void updateFolderList( const QStringList &folders );
+    void updateFolderList();
+    void displayModel( const QModelIndex &, int &, const bool, QStringList );
 
     QList<QLabel*> mLabels;
     QGridLayout *mLayout;
     KontactInterface::Plugin *mPlugin;
+    Akonadi::ChangeRecorder *mChangeRecorder;
+    Akonadi::EntityTreeModel *mModel;
+    KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mModelState;
+    KCheckableProxyModel *mModelProxy;
+    QItemSelectionModel *mSelectionModel;
     int mTimeOfLastMessageCountUpdate;
 };
 
