@@ -24,36 +24,89 @@
 */
 
 #include "sdsummarywidget.h"
-#include "korganizer/stdcalendar.h"
-
-#include <akonadi/contact/contactsearchjob.h>
-#include <akonadi/contact/contactviewerdialog.h>
-#include <akonadi/itemfetchjob.h>
-#include <akonadi/itemfetchscope.h>
-
-#include <KCal/CalendarResources>
-#include <KCal/CalHelper>
-
-#include <KHolidays/Holidays>
 
 #include <KontactInterface/Core>
 #include <KontactInterface/Plugin>
 
-#include <KConfigGroup>
-#include <KIconLoader>
+#include <calendarsupport/utils.h>
+#include <calendarsupport/calendar.h>
+#include <calendarsupport/calendarmodel.h>
+#include <calendarsupport/calendaradaptor.h>
+#include <calendarsupport/incidencechanger.h>
+
+#include <Akonadi/Session>
+#include <Akonadi/Collection>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/Contact/ContactSearchJob>
+#include <Akonadi/Contact/ContactViewerDialog>
+
+#include <KCalCore/Calendar>
+
 #include <KMenu>
-#include <KToolInvocation>
+#include <KLocale>
 #include <KUrlLabel>
+#include <KIconLoader>
+#include <KConfigGroup>
+#include <KToolInvocation>
+#include <KSystemTimeZones>
+#include <KHolidays/Holidays>
 
 #include <QDate>
 #include <QEvent>
-#include <QGridLayout>
 #include <QLabel>
+#include <QGridLayout>
+
+using namespace KHolidays;
+
+class BirthdaySearchJob : public Akonadi::ItemSearchJob
+{
+  public:
+    BirthdaySearchJob( QObject *parent, int daysInAdvance );
+};
+
+BirthdaySearchJob::BirthdaySearchJob( QObject *parent, int daysInAdvance )
+  : ItemSearchJob( QString(), parent )
+{
+  fetchScope().fetchFullPayload();
+  const QString query = QString::fromLatin1(
+    "prefix nco:<http://www.semanticdesktop.org/ontologies/2007/03/22/nco#> "
+    "prefix xsd:<http://www.w3.org/2001/XMLSchema#> "
+    ""
+    "SELECT DISTINCT ?r "
+    "WHERE { "
+    "  graph ?g "
+    "  { "
+    "    { "
+    "      ?r a nco:PersonContact . "
+    "      ?r <%1> ?akonadiItemId . "
+    "      ?r nco:birthDate ?birthDate . "
+    "      FILTER( bif:dayofyear(?birthDate) >= bif:dayofyear(xsd:date(\"%2\")) ) "
+    "      FILTER( bif:dayofyear(?birthDate) <= bif:dayofyear(xsd:date(\"%2\")) + %3 ) "
+    "    } "
+    "    UNION "
+    "    { "
+    "      ?r a nco:PersonContact . "
+    "      ?r <%1> ?akonadiItemId . "
+    "      ?r nco:birthDate ?birthDate . "
+    "      FILTER( bif:dayofyear(?birthDate) + 365 >= bif:dayofyear(xsd:date(\"%2\")) ) "
+    "      FILTER( bif:dayofyear(?birthDate) + 365 <= bif:dayofyear(xsd:date(\"%2\")) + %3 ) "
+    "    } "
+    "  } "
+    "}" ).
+    arg( QString::fromLatin1( Akonadi::ItemSearchJob::akonadiItemIdUri().toEncoded() ) ).
+    arg( QDate::currentDate().toString( Qt::ISODate ) ).
+    arg( daysInAdvance );
+  Akonadi::ItemSearchJob::setQuery( query );
+}
 
 enum SDIncidenceType {
   IncidenceTypeContact,
   IncidenceTypeEvent
 };
+
 enum SDCategory {
   CategoryBirthday,
   CategoryAnniversary,
@@ -82,7 +135,7 @@ class SDEntry
 };
 
 SDSummaryWidget::SDSummaryWidget( KontactInterface::Plugin *plugin, QWidget *parent )
-  : KontactInterface::Summary( parent ), mPlugin( plugin ), mCalendar( 0 ), mHolidays( 0 )
+  : KontactInterface::Summary( parent ), mCalendar( 0 ), mPlugin( plugin ), mHolidays( 0 )
 {
   // Create the Summary Layout
   QVBoxLayout *mainLayout = new QVBoxLayout( this );
@@ -106,18 +159,18 @@ SDSummaryWidget::SDSummaryWidget( KontactInterface::Plugin *plugin, QWidget *par
   mShowAnniversariesFromKAB = true;
   mShowAnniversariesFromCal = true;
   mShowHolidays = true;
+  mJobRunning = false;
   mShowSpecialsFromCal = true;
 
   // Setup the Addressbook
-  connect( mPlugin->core(), SIGNAL(dayChanged(const QDate&)),
+  connect( mPlugin->core(), SIGNAL(dayChanged(QDate)),
            this, SLOT(updateView()) );
 
-  // Setup the Calendar
-  mCalendar = KOrg::StdCalendar::self();
+  createCalendar();
 
   connect( mCalendar, SIGNAL(calendarChanged()),
            this, SLOT(updateView()) );
-  connect( mPlugin->core(), SIGNAL(dayChanged(const QDate&)),
+  connect( mPlugin->core(), SIGNAL(dayChanged(QDate)),
            this, SLOT(updateView()) );
 
   // Update Configuration
@@ -154,9 +207,7 @@ bool SDSummaryWidget::initHolidays()
   KConfigGroup hconfig( &_hconfig, "Time & Date" );
   QString location = hconfig.readEntry( "Holidays" );
   if ( !location.isEmpty() ) {
-    if ( mHolidays ) {
-      delete mHolidays;
-    }
+    delete mHolidays;
     mHolidays = new HolidayRegion( location );
     return true;
   }
@@ -164,9 +215,9 @@ bool SDSummaryWidget::initHolidays()
 }
 
 // number of days remaining in an Event
-int SDSummaryWidget::span( Event *event )
+int SDSummaryWidget::span( const KCalCore::Event::Ptr &event ) const
 {
-  int span=1;
+  int span = 1;
   if ( event->isMultiDay() && event->allDay() ) {
     QDate d = event->dtStart().date();
     if ( d < QDate::currentDate() ) {
@@ -181,7 +232,7 @@ int SDSummaryWidget::span( Event *event )
 }
 
 // day of a multiday Event
-int SDSummaryWidget::dayof( Event *event, const QDate &date )
+int SDSummaryWidget::dayof( const KCalCore::Event::Ptr &event, const QDate &date ) const
 {
   int dayof = 1;
   QDate d = event->dtStart().date();
@@ -197,11 +248,40 @@ int SDSummaryWidget::dayof( Event *event, const QDate &date )
   return dayof;
 }
 
-void SDSummaryWidget::updateView()
+void SDSummaryWidget::slotBirthdayJobFinished( KJob *job )
+{
+  // ;)
+  BirthdaySearchJob* bJob = dynamic_cast< BirthdaySearchJob *>( job );
+  if ( bJob ) {
+    foreach ( const Akonadi::Item &item, bJob->items() ) {
+      if ( item.hasPayload<KABC::Addressee>() ) {
+        const KABC::Addressee addressee = item.payload<KABC::Addressee>();
+        const QDate birthday = addressee.birthday().date();
+        if ( birthday.isValid() ) {
+          SDEntry entry;
+          entry.type = IncidenceTypeContact;
+          entry.category = CategoryBirthday;
+          dateDiff( birthday, entry.daysTo, entry.yearsOld );
+
+          entry.date = birthday;
+          entry.addressee = addressee;
+          entry.item = item;
+          entry.span = 1;
+          mDates.append( entry );
+        }
+      }
+    }
+    // Carry on.
+    createLabels();
+  }
+
+  mJobRunning = false;
+}
+
+void SDSummaryWidget::createLabels()
 {
   KIconLoader loader( "kdepim" );
 
-  QList<SDEntry> dates;
   QLabel *label = 0;
 
   // Remove all special date labels from the layout and delete them, as we
@@ -210,82 +290,32 @@ void SDSummaryWidget::updateView()
   foreach ( label, mLabels ) {
     mLayout->removeWidget( label );
     delete( label );
+    update();
   }
   mLabels.clear();
 
-  // Search for Birthdays and Anniversaries in the Addressbook
-  //TODO: change into a search folder with date range
-  Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob( this );
-  job->exec();
-
-  const Akonadi::Item::List items = job->items();
-  foreach ( const Akonadi::Item &item, items ) {
-    if ( !item.hasPayload<KABC::Addressee>() ) // skip contact groups
-      continue;
-
-    const KABC::Addressee contact = item.payload<KABC::Addressee>();
-
-    const QDate birthday = contact.birthday().date();
-    if ( birthday.isValid() && mShowBirthdaysFromKAB ) {
-      SDEntry entry;
-      entry.type = IncidenceTypeContact;
-      entry.category = CategoryBirthday;
-      dateDiff( birthday, entry.daysTo, entry.yearsOld );
-
-      entry.date = birthday;
-      entry.addressee = contact;
-      entry.item = item;
-      entry.span = 1;
-      if ( entry.daysTo <= mDaysAhead ) {
-        dates.append( entry );
-      }
-    }
-
-    const QString anniversaryAsString = contact.custom( "KADDRESSBOOK", "X-Anniversary" );
-    if ( !anniversaryAsString.isEmpty() ) {
-      const QDate anniversary = QDate::fromString( anniversaryAsString, Qt::ISODate );
-      if ( anniversary.isValid() && mShowAnniversariesFromKAB ) {
-        SDEntry entry;
-        entry.type = IncidenceTypeContact;
-        entry.category = CategoryAnniversary;
-        dateDiff( anniversary, entry.daysTo, entry.yearsOld );
-
-        entry.date = anniversary;
-        entry.addressee = contact;
-        entry.item = item;
-        entry.span = 1;
-        if ( entry.daysTo <= mDaysAhead ) {
-          dates.append( entry );
-        }
-      }
-    }
-  }
-
-  // Search for Birthdays, Anniversaries, Holidays, and Special Occasions
-  // in the Calendar
-  ResourceCalendar *bdayRes = usingBirthdayResource();
-  ResourceCalendar *annvRes = bdayRes;
-  if ( !mShowBirthdaysFromKAB ) {
-    bdayRes = 0;
-  }
-  if ( !mShowAnniversariesFromKAB ) {
-    annvRes = 0;
-  }
-
   QDate dt;
-  for ( dt=QDate::currentDate();
-        dt<=QDate::currentDate().addDays( mDaysAhead - 1 );
-        dt=dt.addDays(1) ) {
-    Event::List events = mCalendar->events( dt, mCalendar->timeSpec(),
-                                            EventSortStartDate,
-                                            SortDirectionAscending );
-    Event *ev;
-    Event::List::ConstIterator it;
-    for ( it = events.constBegin(); it != events.constEnd(); ++it ) {
-      ev = *it;
+  for ( dt = QDate::currentDate();
+        dt <= QDate::currentDate().addDays( mDaysAhead - 1 );
+        dt = dt.addDays( 1 ) ) {
+    Akonadi::Item::List items  = mCalendar->events( dt, mCalendar->timeSpec(),
+                                                    CalendarSupport::EventSortStartDate,
+                                                    CalendarSupport::SortDirectionAscending );
+    foreach ( const Akonadi::Item &item, items ) {
+      KCalCore::Event::Ptr ev = CalendarSupport::event( item );
 
       // Optionally, show only my Events
-      if ( mShowMineOnly && !CalHelper::isMyCalendarIncidence( mCalendar, ev ) ) {
+      /* if ( mShowMineOnly &&
+              !KCalCore::CalHelper::isMyCalendarIncidence( mCalendarAdaptor, ev. ) ) {
+        // FIXME; does isMyCalendarIncidence work !? It's deprecated too.
+        continue;
+        }
+        // TODO: CalHelper is deprecated, remove this?
+        */
+
+      if ( ev->customProperty( "KABC","BIRTHDAY" ) == "YES" ) {
+        // Skipping, because these are got by the BirthdaySearchJob
+        // See comments in updateView()
         continue;
       }
 
@@ -295,7 +325,7 @@ void SDSummaryWidget::updateView()
         for ( it2 = c.constBegin(); it2 != c.constEnd(); ++it2 ) {
 
           // Append Birthday Event?
-          if ( mShowBirthdaysFromCal && ( ( *it2 ).toUpper() == i18n( "BIRTHDAY" ) ) ) {
+          if ( mShowBirthdaysFromCal && ( (*it2).toUpper() == "BIRTHDAY" ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryBirthday;
@@ -304,14 +334,20 @@ void SDSummaryWidget::updateView()
             entry.desc = ev->description();
             dateDiff( ev->dtStart().date(), entry.daysTo, entry.yearsOld );
             entry.span = 1;
-            if ( !check( bdayRes, dt, ev->summary() ) ) {
-              dates.append( entry );
+
+            /* The following check is to prevent duplicate entries,
+             * so in case of having a KCal incidence with category birthday
+             * with summary and date equal to some KABC Atendee we don't show it
+             * FIXME: port to akonadi, it's kresource based
+             * */
+            if ( /*!check( bdayRes, dt, ev->summary() )*/true ) {
+              mDates.append( entry );
             }
             break;
           }
 
           // Append Anniversary Event?
-          if ( mShowAnniversariesFromCal && ( ( *it2 ).toUpper() == i18n( "ANNIVERSARY" ) ) ) {
+          if ( mShowAnniversariesFromCal && ( (*it2).toUpper() == "ANNIVERSARY" ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryAnniversary;
@@ -320,14 +356,14 @@ void SDSummaryWidget::updateView()
             entry.desc = ev->description();
             dateDiff( ev->dtStart().date(), entry.daysTo, entry.yearsOld );
             entry.span = 1;
-            if ( !check( annvRes, dt, ev->summary() ) ) {
-              dates.append( entry );
+            if ( /*!check( annvRes, dt, ev->summary() )*/true ) {
+              mDates.append( entry );
             }
             break;
           }
 
           // Append Holiday Event?
-          if ( mShowHolidays && ( ( *it2 ).toUpper() == i18n( "HOLIDAY" ) ) ) {
+          if ( mShowHolidays && ( (*it2).toUpper() == "HOLIDAY" ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryHoliday;
@@ -340,12 +376,12 @@ void SDSummaryWidget::updateView()
             if ( entry.span > 1 && dayof( ev, dt ) > 1 ) { // skip days 2,3,...
               break;
             }
-            dates.append( entry );
+            mDates.append( entry );
             break;
           }
 
           // Append Special Occasion Event?
-          if ( mShowSpecialsFromCal && ( ( *it2 ).toUpper() == i18n( "SPECIAL OCCASION" ) ) ) {
+          if ( mShowSpecialsFromCal && ( (*it2).toUpper() == "SPECIAL OCCASION" ) ) {
             SDEntry entry;
             entry.type = IncidenceTypeEvent;
             entry.category = CategoryOther;
@@ -358,7 +394,7 @@ void SDSummaryWidget::updateView()
             if ( entry.span > 1 && dayof( ev, dt ) > 1 ) { // skip days 2,3,...
               break;
             }
-            dates.append( entry );
+            mDates.append( entry );
             break;
           }
         }
@@ -384,21 +420,22 @@ void SDSummaryWidget::updateView()
           dateDiff( dt, entry.daysTo, entry.yearsOld );
           entry.yearsOld = -1; //ignore age of holidays
           entry.span = 1;
-          dates.append( entry );
+
+          mDates.append( entry );
         }
       }
     }
   }
 
   // Sort, then Print the Special Dates
-  qSort( dates );
+  qSort( mDates );
 
-  if ( !dates.isEmpty() ) {
+  if ( !mDates.isEmpty() ) {
     int counter = 0;
     QList<SDEntry>::Iterator addrIt;
     QString lines;
-    for ( addrIt = dates.begin(); addrIt != dates.end(); ++addrIt ) {
-      bool makeBold = (*addrIt).daysTo == 0; // i.e., today
+    for ( addrIt = mDates.begin(); addrIt != mDates.end(); ++addrIt ) {
+      const bool makeBold = (*addrIt).daysTo == 0; // i.e., today
 
       // Pixmap
       QImage icon_img;
@@ -524,10 +561,10 @@ void SDSummaryWidget::updateView()
         mLayout->addWidget( urlLabel, counter, 4 );
         mLabels.append( urlLabel );
 
-        connect( urlLabel, SIGNAL(leftClickedUrl(const QString&)),
-                 this, SLOT(mailContact(const QString&)) );
-        connect( urlLabel, SIGNAL(rightClickedUrl(const QString&)),
-                 this, SLOT(popupMenu(const QString&)) );
+        connect( urlLabel, SIGNAL(leftClickedUrl(QString)),
+                 this, SLOT(mailContact(QString)) );
+        connect( urlLabel, SIGNAL(rightClickedUrl(QString)),
+                 this, SLOT(popupMenu(QString)) );
       } else {
         label = new QLabel( this );
         label->setText( (*addrIt).summary );
@@ -566,28 +603,64 @@ void SDSummaryWidget::updateView()
   }
 
   QList<QLabel*>::ConstIterator lit;
+
   for ( lit = mLabels.constBegin(); lit != mLabels.constEnd(); ++lit ) {
     (*lit)->show();
   }
-
   setUpdatesEnabled( true );
 }
 
+void SDSummaryWidget::updateView()
+{
+  mDates.clear();
+
+  /* KABC Birthdays are got through a ItemSearchJob/SPARQL Query
+   * I then added an ETM/CalendarModel because we need to search
+   * for calendar entries that have birthday/anniversary categories too.
+   *
+   * Also, we can't get KABC Anniversaries through nepomuk because the
+   * current S.D.O doesn't support it, so i also them through the ETM.
+   *
+   * So basically we have:
+   * Calendar anniversaries - ETM
+   * Calendar birthdays - ETM
+   * KABC birthdays - BirthdaySearchJob
+   * KABC anniversaries - ETM ( needs Birthday Agent running )
+   *
+   * We could remove thomas' BirthdaySearchJob and use the ETM for that
+   * but it has the advantage that we don't need a Birthday agent running.
+   *
+   **/
+
+  // Search for Birthdays
+  if ( mShowBirthdaysFromKAB && !mJobRunning ) {
+    BirthdaySearchJob *job = new BirthdaySearchJob( this, mDaysAhead );
+
+    connect( job, SIGNAL(result(KJob*)), this, SLOT(slotBirthdayJobFinished(KJob*)) );
+    job->start();
+    mJobRunning = true;
+
+    // The result slot will trigger the rest of the update
+  }
+}
+
 void SDSummaryWidget::mailContact( const QString &url )
 {
   const Akonadi::Item item = Akonadi::Item::fromUrl( url );
   if ( !item.isValid() ) {
-    qDebug( "Invalid item found" );
+    kDebug() << "Invalid item found";
     return;
   }
 
   Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( item, this );
   job->fetchScope().fetchFullPayload();
-  if ( !job->exec() )
+  if ( !job->exec() ) {
     return;
+  }
 
-  if ( job->items().isEmpty() )
+  if ( job->items().isEmpty() ) {
     return;
+  }
 
   const KABC::Addressee contact = job->items().first().payload<KABC::Addressee>();
 
@@ -598,7 +671,7 @@ void SDSummaryWidget::viewContact( const QString &url )
 {
   const Akonadi::Item item = Akonadi::Item::fromUrl( url );
   if ( !item.isValid() ) {
-    qDebug( "Invalid item found" );
+    kDebug() << "Invalid item found";
     return;
   }
 
@@ -633,14 +706,14 @@ bool SDSummaryWidget::eventFilter( QObject *obj, QEvent *e )
       emit message( i18n( "Mail to:\"%1\"", label->text() ) );
     }
     if ( e->type() == QEvent::Leave ) {
-      emit message( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
+      emit message( QString::null ); //krazy:exclude=nullstrassign for old broken gcc
     }
   }
 
   return KontactInterface::Summary::eventFilter( obj, e );
 }
 
-void SDSummaryWidget::dateDiff( const QDate &date, int &days, int &years )
+void SDSummaryWidget::dateDiff( const QDate &date, int &days, int &years ) const
 {
   QDate currentDate;
   QDate eventDate;
@@ -669,43 +742,33 @@ void SDSummaryWidget::dateDiff( const QDate &date, int &days, int &years )
   }
 }
 
-ResourceCalendar *SDSummaryWidget::usingBirthdayResource()
-{
-  ResourceCalendar *resource = 0;
-
-  CalendarResourceManager *manager = mCalendar->resourceManager();
-  if ( !manager->isEmpty() ) {
-    CalendarResourceManager::Iterator it;
-    for ( it = manager->begin(); it != manager->end(); ++it ) {
-      if ( (*it)->type() == QLatin1String( "birthdays" ) ) {
-        resource = (*it);
-        break;
-      }
-    }
-  }
-  return resource;
-}
-
-bool SDSummaryWidget::check( ResourceCalendar *cal, const QDate &date,
-                             const QString &summary )
-{
-  if ( !cal ) {
-    return false;
-  }
-
-  Event::List events = cal->rawEventsForDate( date );
-  Event::List::ConstIterator it;
-  for ( it = events.constBegin(); it != events.constEnd(); ++it ) {
-    if ( (*it)->summary() == summary ) {
-      return true;
-    }
-  }
-  return false;
-}
-
 QStringList SDSummaryWidget::configModules() const
 {
   return QStringList( "kcmsdsummary.desktop" );
 }
 
+void SDSummaryWidget::createCalendar()
+{
+  Akonadi::Session *session = new Akonadi::Session( "SDSummaryWidget", this );
+  Akonadi::ChangeRecorder *monitor = new Akonadi::ChangeRecorder( this );
+
+  Akonadi::ItemFetchScope scope;
+  scope.fetchFullPayload( true );
+  scope.fetchAttribute<Akonadi::EntityDisplayAttribute>();
+
+  monitor->setSession( session );
+  monitor->setCollectionMonitored( Akonadi::Collection::root() );
+  monitor->fetchCollection( true );
+  monitor->setItemFetchScope( scope );
+  monitor->setMimeTypeMonitored( KCalCore::Event::eventMimeType(), true );
+
+  CalendarSupport::CalendarModel *calendarModel =
+    new CalendarSupport::CalendarModel( monitor, this );
+
+  mCalendar =
+    new CalendarSupport::Calendar( calendarModel, calendarModel, KSystemTimeZones::local() );
+
+  mCalendarAdaptor = new CalendarSupport::CalendarAdaptor( mCalendar, this );
+}
+
 #include "sdsummarywidget.moc"
