@@ -26,9 +26,7 @@
 #include "prefs.h"
 using namespace Kontact;
 
-#include <libkdepim/reminderclient.h>
-
-#include <Akonadi/Control>
+#include <libkdepimdbusinterfaces/reminderclient.h>
 
 #include <KontactInterface/Plugin>
 #include <KontactInterface/UniqueAppHandler>
@@ -151,8 +149,7 @@ int KontactApp::newInstance()
     }
   }
 
-  KPIM::ReminderClient reminderclient;
-  reminderclient.startDaemon();
+  KPIM::ReminderClient::startDaemon();
 
   // Handle startup notification and window activation
   // (The first time it will do nothing except note that it was called)
@@ -163,7 +160,7 @@ int main( int argc, char **argv )
 {
   KAboutData about( "kontact", 0, ki18n( "Kontact" ), version, ki18n(description),
                     KAboutData::License_GPL,
-                    ki18n( "(C) 2001-2009 The Kontact developers" ),
+                    ki18n( "Copyright © 2001–2010 Kontact authors" ),
                     KLocalizedString(), "http://kontact.org" );
 
   about.addAuthor( ki18n( "Allen Winter" ), KLocalizedString(), "winter@kde.org" );
@@ -178,6 +175,7 @@ int main( int argc, char **argv )
   about.addAuthor( ki18n( "Zack Rusin" ), KLocalizedString(), "zack@kde.org" );
   about.addAuthor( ki18n( "Matthias Hoelzer-Kluepfel" ),
                    ki18n( "Original Author" ), "mhk@kde.org" );
+  about.addCredit( ki18n( "Torgny Nyblom" ), ki18n("Git Migration"), "nyblom@kde.org" );
   about.setOrganizationDomain( "kde.org" );
 
   KCmdLineArgs::init( argc, argv, &about );
@@ -199,10 +197,6 @@ int main( int argc, char **argv )
 
   KontactApp app;
 
-  // KDE 4.4: do akonadi startup before creating any window, since creating
-  // the window loads kmail. In 4.5 we'll do this startup async instead.
-  Akonadi::Control::start( 0 );
-
   // Qt doesn't treat the system tray as a window, and therefore Qt would quit
   // the event loop when an error message is clicked away while Kontact is in the
   // tray.
