@@ -23,11 +23,11 @@
 */
 
 #include "aboutdata.h"
-#include "kdepim-version.h"
+#include "version.h"
 using namespace KOrg;
 
 AboutData::AboutData()
-  : KAboutData( "korganizer", 0, ki18n( "KOrganizer" ), KDEPIM_VERSION,
+  : KAboutData( "korganizer", 0, ki18n( "KOrganizer" ), korgVersion,
                 ki18n( "A Personal Organizer" ),
                 KAboutData::License_GPL,
                 ki18n( "Copyright © 1997–1999 Preston Brown\n"
@@ -35,13 +35,13 @@ AboutData::AboutData()
                        "Copyright © 2004–2005 Reinhold Kainhofer\n"
                        "Copyright © 2006–2012 Allen Winter" ),
                 KLocalizedString(),
-                "https://userbase.kde.org/KOrganizer" )
+                "http://korganizer.kde.org" )
 {
 #if defined( KDEPIM_GIT_REVISION_STRING ) && defined( KDEPIM_GIT_LAST_CHANGE )
   const QByteArray rev( KDEPIM_GIT_REVISION_STRING );
   const QByteArray last( KDEPIM_GIT_LAST_CHANGE );
   if ( !rev.isEmpty() && !last.isEmpty() ) {
-    QByteArray versionInfo( KDEPIM_VERSION );
+    QByteArray versionInfo( korgVersion );
     versionInfo += '-' + rev + ' ' + '(' + last + ')';
     setVersion( versionInfo );
   }
@@ -56,9 +56,8 @@ AboutData::AboutData()
   addAuthor( ki18n( "Preston Brown"),ki18n( "Original Author" ),
              "pbrown@kde.org" );
   addCredit( ki18n( "Richard Apodaca" ) );
-  addCredit( ki18n( "Björn Balazs" ) );
+  addCredit( ki18n( "Mike McQuaid" ) );
   addCredit( ki18n( "Jan-Pascal van Best" ) );
-  addCredit( ki18n( "Bertjan Broeksema" ) );
   addCredit( ki18n( "Laszlo Boloni" ) );
   addCredit( ki18n( "Barry Benowitz" ) );
   addCredit( ki18n( "Christopher Beard" ) );
@@ -74,7 +73,6 @@ AboutData::AboutData()
   addCredit( ki18n( "Martin Koller" ) );
   addCredit( ki18n( "Uwe Koloska" ) );
   addCredit( ki18n( "Sergio Luis Martins" ) );
-  addCredit( ki18n( "Mike McQuaid" ) );
   addCredit( ki18n( "Glen Parker" ) );
   addCredit( ki18n( "Dan Pilone" ) );
   addCredit( ki18n( "Roman Rohr" ) );
