@@ -23,25 +23,31 @@
   with any edition of Qt, and distribute the resulting executable,
   without including the source code for Qt in the source distribution.
 */
-
 #ifndef KORG_AKONADICOLLECTIONVIEW_H
 #define KORG_AKONADICOLLECTIONVIEW_H
 
 #include "calendarview.h"
+
 #include <Akonadi/Collection>
 
-class AkonadiCollectionView;
+#include <QTreeWidget>
+#include <QList>
+
+class QAbstractProxyModel;
 
 namespace Akonadi {
+  class Collection;
   class EntityTreeView;
-  class EntityTreeModel;
   class StandardCalendarActionManager;
 }
 
+namespace CalendarSupport {
+  class CalendarModel;
+}
+
 class KAction;
 class KJob;
-class QAbstractProxyModel;
-class QModelIndex;
+class AkonadiCollectionView;
 
 /**
  * The factory for AkonadiCollectionView instances.
@@ -57,6 +63,7 @@ class AkonadiCollectionViewFactory : public CalendarViewExtension::Factory
     CalendarViewExtension *create( QWidget * );
 
   private:
+    CalendarSupport::CalendarModel *mModel;
     CalendarView *mView;
     AkonadiCollectionView *mAkonadiCollectionView;
 };
@@ -76,12 +83,9 @@ class AkonadiCollectionView : public CalendarViewExtension
 
     KCheckableProxyModel *collectionSelectionProxyModel() const;
     void setCollectionSelectionProxyModel( KCheckableProxyModel * );
+    static bool isStructuralCollection( const Akonadi::Collection & );
 
-    Akonadi::Collection selectedCollection() const;
-    Akonadi::Collection::List checkedCollections() const;
-    bool isChecked(const Akonadi::Collection &) const;
-
-  Q_SIGNALS:
+  signals:
     void resourcesChanged( bool enabled );
     void resourcesAddedRemoved();
     void defaultResourceChanged( const Akonadi::Collection & );
@@ -90,8 +94,6 @@ class AkonadiCollectionView : public CalendarViewExtension
   private Q_SLOTS:
     void updateView();
     void updateMenu();
-    void restoreTreeState();
-    void checkNewCalendar( const QModelIndex &parent, int begin, int end );
 
     void newCalendar();
     void newCalendarDone( KJob * );
@@ -104,17 +106,20 @@ class AkonadiCollectionView : public CalendarViewExtension
     void setDefaultCalendar();
 
   private:
-    Akonadi::EntityTreeModel *entityTreeModel() const;
-
     Akonadi::StandardCalendarActionManager *mActionManager;
-    Akonadi::EntityTreeView *mCollectionView;
+    Akonadi::EntityTreeView *mCollectionview;
     QAbstractProxyModel *mBaseModel;
     KCheckableProxyModel *mSelectionProxyModel;
+    KAction *mCreateAction;
+    KAction *mDeleteAction;
     KAction *mAssignColor;
     KAction *mDisableColor;
+    KAction *mEditAction;
     KAction *mDefaultCalendar;
+    CalendarSupport::CollectionSelection *mCollectionSelection;
     bool mNotSendAddRemoveSignal;
     bool mWasDefaultCalendar;
+    bool mInitDefaultCalendar;
     bool mHasContextMenu;
   };
 
