@@ -26,12 +26,11 @@
 #include "exportwebdialog.h"
 #include "koprefs.h"
 #include "kocore.h"
+#include "htmlexportsettings.h"
 
-#include <libkdepim/kdateedit.h>
-
-#include <kcal/calendar.h>
-#include <kcal/htmlexportsettings.h>
+#include <calendarsupport/calendar.h>
 
+#include <KDateComboBox>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
@@ -64,7 +63,7 @@
 //        because we want custom buttons, a Tabbed dialog, and a different
 //        headline... Maybe we should try to achieve the same without code
 //        duplication.
-ExportWebDialog::ExportWebDialog( HTMLExportSettings *settings, QWidget *parent )
+ExportWebDialog::ExportWebDialog( KOrg::HTMLExportSettings *settings, QWidget *parent )
   : KPageDialog( parent ),
     KPrefsWidManager( settings ), mSettings( settings )
 {
@@ -187,8 +186,9 @@ void ExportWebDialog::setupGeneralPage()
 
   KPrefsWidPath *pathWid = addWidPath( mSettings->outputFileItem(),
                                        destGroup, "text/html", KFile::File );
-  connect( pathWid->urlRequester(), SIGNAL(textChanged(const QString&)),
-           SLOT(slotTextChanged(const QString&)) );
+  pathWid->urlRequester()->fileDialog()->setOperationMode( KFileDialog::Saving );
+  connect( pathWid->urlRequester(), SIGNAL(textChanged(QString)),
+           SLOT(slotTextChanged(QString)) );
   destLayout->addWidget( pathWid->label() );
   destLayout->addWidget( pathWid->urlRequester() );
 
