@@ -55,17 +55,17 @@ KDateNavigator::KDateNavigator( QWidget *parent )
   mNavigatorBar = new NavigatorBar( this );
   topLayout->addWidget( mNavigatorBar, 0, 0, 1, 8 );
 
-  connect( mNavigatorBar, SIGNAL(goPrevYear()), SIGNAL(goPrevYear()) );
-  connect( mNavigatorBar, SIGNAL(goPrevMonth()), SIGNAL(goPrevMonth()) );
-  connect( mNavigatorBar, SIGNAL(goNextMonth()), SIGNAL(goNextMonth()) );
-  connect( mNavigatorBar, SIGNAL(goNextYear()), SIGNAL(goNextYear()) );
-  connect( mNavigatorBar, SIGNAL(goMonth(int)), SIGNAL(goMonth(int)) );
-  connect( mNavigatorBar, SIGNAL(goYear(int)), SIGNAL(goYear(int)) );
+  connect( mNavigatorBar, SIGNAL(prevYearClicked()), SIGNAL(prevYearClicked()) );
+  connect( mNavigatorBar, SIGNAL(prevMonthClicked()), SIGNAL(prevMonthClicked()) );
+  connect( mNavigatorBar, SIGNAL(nextMonthClicked()), SIGNAL(nextMonthClicked()) );
+  connect( mNavigatorBar, SIGNAL(nextYearClicked()), SIGNAL(nextYearClicked()) );
+  connect( mNavigatorBar, SIGNAL(monthSelected(int)), SIGNAL(monthSelected(int)) );
+  connect( mNavigatorBar, SIGNAL(yearSelected(int)), SIGNAL(yearSelected(int)));
 
   QString generalFont = KGlobalSettings::generalFont().family();
 
   // Set up the heading fields.
-  for ( int i=0; i < 7; i++ ) {
+  for ( int i = 0; i < 7; i++ ) {
     mHeadings[i] = new QLabel( this );
     mHeadings[i]->setFont( QFont( generalFont, 10, QFont::Bold ) );
     mHeadings[i]->setAlignment( Qt::AlignCenter );
@@ -74,7 +74,7 @@ KDateNavigator::KDateNavigator( QWidget *parent )
   }
 
   // Create the weeknumber labels
-  for ( int i=0; i < 6; i++ ) {
+  for ( int i = 0; i < 6; i++ ) {
     mWeeknos[i] = new QLabel( this );
     mWeeknos[i]->setAlignment( Qt::AlignCenter );
     mWeeknos[i]->setFont( QFont( generalFont, 10 ) );
@@ -86,20 +86,20 @@ KDateNavigator::KDateNavigator( QWidget *parent )
   mDayMatrix = new KODayMatrix( this );
   mDayMatrix->setObjectName( "KDateNavigator::dayMatrix" );
 
-  connect( mDayMatrix, SIGNAL(selected(const KCal::DateList &)),
-           SIGNAL(datesSelected(const KCal::DateList &)) );
+  connect( mDayMatrix, SIGNAL(selected(KCalCore::DateList)),
+           SIGNAL(datesSelected(KCalCore::DateList)) );
 
-  connect( mDayMatrix, SIGNAL(incidenceDropped(Incidence *,const QDate &)),
-           SIGNAL(incidenceDropped(Incidence *,const QDate &)) );
-  connect( mDayMatrix, SIGNAL(incidenceDroppedMove(Incidence *,const QDate &)),
-           SIGNAL(incidenceDroppedMove(Incidence *,const QDate &)) );
+  connect( mDayMatrix, SIGNAL(incidenceDropped(Akonadi::Item,QDate)),
+           SIGNAL(incidenceDropped(Akonadi::Item,QDate)) );
+  connect( mDayMatrix, SIGNAL(incidenceDroppedMove(Akonadi::Item,QDate)),
+           SIGNAL(incidenceDroppedMove(Akonadi::Item,QDate)) );
 
-  connect( mDayMatrix, SIGNAL(newEventSignal(const QDate &)),
-           SIGNAL(newEventSignal(const QDate &)) );
-  connect( mDayMatrix, SIGNAL(newTodoSignal(const QDate &)),
-           SIGNAL(newTodoSignal(const QDate &)) );
-  connect( mDayMatrix, SIGNAL(newJournalSignal(const QDate &)),
-           SIGNAL(newJournalSignal(const QDate &)) );
+  connect( mDayMatrix, SIGNAL(newEventSignal(QDate)),
+           SIGNAL(newEventSignal(QDate)) );
+  connect( mDayMatrix, SIGNAL(newTodoSignal(QDate)),
+           SIGNAL(newTodoSignal(QDate)) );
+  connect( mDayMatrix, SIGNAL(newJournalSignal(QDate)),
+           SIGNAL(newJournalSignal(QDate)) );
 
   topLayout->addWidget( mDayMatrix, 2, 1, 6, 7 );
 
@@ -111,7 +111,7 @@ KDateNavigator::~KDateNavigator()
 {
 }
 
-void KDateNavigator::setCalendar( Calendar *cal )
+void KDateNavigator::setCalendar( CalendarSupport::Calendar *cal )
 {
   mDayMatrix->setCalendar( cal );
 }
@@ -125,12 +125,12 @@ void KDateNavigator::setBaseDate( const QDate &date )
     updateView();
 
     // Use the base date to show the monthname and year in the header
-    KCal::DateList dates;
+    KCalCore::DateList dates;
     dates.append( date );
     mNavigatorBar->selectDates( dates );
 
-    repaint();
-    mDayMatrix->repaint();
+    update();
+    mDayMatrix->update();
   }
 }
 
@@ -143,7 +143,7 @@ QSizePolicy KDateNavigator::sizePolicy () const
 void KDateNavigator::updateToday()
 {
   mDayMatrix->recalculateToday();
-  mDayMatrix->repaint();
+  mDayMatrix->update();
 }
 
 QDate KDateNavigator::startDate() const
@@ -194,8 +194,8 @@ void KDateNavigator::updateDates()
     // Use QDate's weekNumber method to determine the week number!
     QDate dtStart = mDayMatrix->getDate( i * 7 );
     QDate dtEnd = mDayMatrix->getDate( ( i + 1 ) * 7 - 1 );
-    int weeknumstart = calsys->weekNumber( dtStart );
-    int weeknumend = calsys->weekNumber( dtEnd );
+    const int weeknumstart = calsys->week( dtStart );
+    const int weeknumend = calsys->week( dtEnd );
     QString weeknum;
 
     if ( weeknumstart != weeknumend ) {
@@ -218,7 +218,7 @@ void KDateNavigator::updateDates()
 void KDateNavigator::updateDayMatrix()
 {
   mDayMatrix->updateView();
-  mDayMatrix->repaint();
+  mDayMatrix->update();
 }
 
 void KDateNavigator::setUpdateNeeded()
@@ -226,10 +226,24 @@ void KDateNavigator::setUpdateNeeded()
   mDayMatrix->setUpdateNeeded();
 }
 
+QDate KDateNavigator::month() const
+{
+  QDate firstCell = startDate();
+  const KCalendarSystem *calSys = KOGlobals::self()->calendarSystem();
+
+  if ( calSys->day( firstCell ) == 1 ) {
+    return firstCell;
+  } else {
+    calSys->setDate( firstCell, calSys->year( firstCell ),
+                    calSys->month( firstCell ), 1 );
+    return calSys->addMonths( firstCell, 1 );
+  }
+}
+
 void KDateNavigator::updateView()
 {
   updateDayMatrix();
-  repaint();
+  update();
 }
 
 void KDateNavigator::updateConfig()
@@ -240,9 +254,6 @@ void KDateNavigator::updateConfig()
     day = weekstart + i <= 7 ? weekstart + i : ( weekstart + i ) % 7;
     QString dayName =
       KOGlobals::self()->calendarSystem()->weekDayName( day, KCalendarSystem::ShortDayName );
-    if ( KOPrefs::instance()->mCompactDialogs ) {
-      dayName = dayName.left( 1 );
-    }
     QString longDayName =
       KOGlobals::self()->calendarSystem()->weekDayName( day, KCalendarSystem::LongDayName );
     mHeadings[i]->setText( dayName );
@@ -250,7 +261,9 @@ void KDateNavigator::updateConfig()
     mHeadings[i]->setWhatsThis(
       i18n( "A column header of the %1 dates in the month.", longDayName ) );
   }
-
+  mDayMatrix->setUpdateNeeded();
+  updateDayMatrix();
+  update();
   // FIXME: Use actual config setting here
 //  setShowWeekNums( true );
 }
@@ -323,9 +336,9 @@ bool KDateNavigator::eventFilter ( QObject *o, QEvent *e )
   if ( e->type() == QEvent::MouseButtonPress ) {
     int i;
     for ( i=0; i < 6; ++i ) {
-      if ( o == mWeeknos[ i ] ) {
-        QDate weekstart = mDayMatrix->getDate( i * 7 );
-        emit weekClicked( weekstart );
+      if ( o == mWeeknos[i] ) {
+        const QDate weekstart = mDayMatrix->getDate( i * 7 );
+        emit weekClicked( weekstart, month() );
         break;
       }
     }
