@@ -24,13 +24,15 @@
   without including the source code for Qt in the source distribution.
 */
 
-#ifndef KORG_KOCOREHELPER_H
-#define KORG_KOCOREHELPER_H
+#ifndef KOCOREHELPER_H
+#define KOCOREHELPER_H
 
-#include "kocore.h"
-#include "koglobals.h"
-#include "prefs/koprefs.h"
 #include "korganizer/corehelper.h"
+#include "koprefs.h"
+#include "koglobals.h"
+#include "kocore.h"
+
+class KCalendarSystem;
 
 class KOCoreHelper : public KOrg::CoreHelper
 {
@@ -51,6 +53,11 @@ class KOCoreHelper : public KOrg::CoreHelper
     {
       return KOGlobals::self()->calendarSystem();
     }
+
+    virtual KOrg::PrintPlugin::List loadPrintPlugins()
+    {
+      return KOCore::self()->loadPrintPlugins();
+    }
 };
 
 #endif
