@@ -23,15 +23,34 @@
   with any edition of Qt, and distribute the resulting executable,
   without including the source code for Qt in the source distribution.
 */
+#ifndef KODAYMATRIX_H
+#define KODAYMATRIX_H
 
-#ifndef KORG_KODAYMATRIX_H
-#define KORG_KODAYMATRIX_H
-
-#include <Akonadi/Calendar/ETMCalendar>
-
-#include <KCalCore/IncidenceBase> //for KCalCore::DateList typedef
+#include <calendarsupport/calendar.h>
 
+#include <QColor>
 #include <QFrame>
+#include <QMap>
+
+namespace KCal {
+  class Incidence;
+}
+namespace Akonadi {
+  class Item;
+}
+using namespace KCalCore;
+
+class QEvent;
+class QMouseEvent;
+class QResizeEvent;
+class QPaintEvent;
+
+#ifndef KORG_NODND
+class QDragEnterEvent;
+class QDragMoveEvent;
+class QDragLeaveEvent;
+class QDropEvent;
+#endif
 
 /**
  *  Replacement for kdpdatebuton.cpp that used 42 widgets for the day
@@ -66,7 +85,7 @@
  *
  *  @author Eitzenberger Thomas
  */
-class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
+class KODayMatrix: public QFrame, public CalendarSupport::Calendar::CalendarObserver
 {
   Q_OBJECT
   public:
@@ -90,7 +109,7 @@ class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
       Associate a calendar with this day matrix. If there is a calendar, the
       day matrix will accept drops and days with events will be highlighted.
     */
-    void setCalendar( const Akonadi::ETMCalendar::Ptr &  );
+    void setCalendar( CalendarSupport::Calendar * );
 
     /** updates the day matrix to start with the given date. Does all the
      *  necessary checks for holidays or events on a day and stores them
@@ -124,7 +143,7 @@ class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
      * Adds all actual selected days from mSelStart to mSelEnd to the supplied
      * DateList.
      */
-    void addSelectedDaysTo( KCalCore::DateList & );
+    void addSelectedDaysTo( DateList & );
 
     /**
      * Sets the actual to be displayed selection in the day matrix starting
@@ -156,12 +175,12 @@ class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
     bool isEndOfMonth() const { return mToday >= 27; }
 
     /**
-     *  Reimplemented from Akonadi::ETMCalendar
+     *  Reimplemented from CalendarSupport::Calendar
      *  They set mPendingChanges to true
      */
-    void calendarIncidenceAdded( const KCalCore::Incidence::Ptr &incidence );
-    void calendarIncidenceChanged( const KCalCore::Incidence::Ptr &incidence );
-    void calendarIncidenceDeleted( const KCalCore::Incidence::Ptr &incidence );
+    void calendarIncidenceAdded( const Akonadi::Item &incidence );
+    void calendarIncidenceChanged( const Akonadi::Item &incidence );
+    void calendarIncidenceDeleted( const Akonadi::Item &incidence );
 
     /** Sets which incidences should be highlighted */
     void setHighlightMode( bool highlightEvents,
@@ -230,6 +249,7 @@ class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
 
     void resizeEvent( QResizeEvent * );
 
+#ifndef KORG_NODND
     void dragEnterEvent( QDragEnterEvent *e );
 
     void dragMoveEvent( QDragMoveEvent *e );
@@ -237,6 +257,7 @@ class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
     void dragLeaveEvent( QDragLeaveEvent *e );
 
     void dropEvent( QDropEvent *e );
+#endif
 
   private:
     /**
@@ -272,7 +293,7 @@ class KODayMatrix: public QFrame, public Akonadi::ETMCalendar::CalendarObserver
     static const int NUMDAYS;
 
     /** calendar instance to be queried for holidays, events, ... */
-    Akonadi::ETMCalendar::Ptr mCalendar;
+    CalendarSupport::Calendar *mCalendar;
 
     /** starting date of the matrix */
     QDate mStartDate;
