@@ -30,31 +30,27 @@
 #include <QList>
 #include <QPointer>
 
-class ArchiveDialog;
 class CalendarView;
 class FilterEditDialog;
 class KCMultiDialog;
-class KOEventEditor;
-class KOIncidenceEditor;
-class KOJournalEditor;
-class KOTodoEditor;
 class SearchDialog;
 
-namespace KOrg {
-  class AgendaView;
+namespace Akonadi {
+  class Item;
 }
-using namespace KOrg;
 
-namespace KPIM {
+namespace IncidenceEditorNG {
   class CategoryEditDialog;
+  class IncidenceDialog;
 }
-using namespace KPIM;
 
 namespace KCal {
   class CalFilter;
-  class Incidence;
 }
-using namespace KCal;
+
+namespace CalendarSupport {
+  class ArchiveDialog;
+}
 
 /**
   This class manages the dialogs used by the calendar view. It owns the objects
@@ -67,32 +63,21 @@ class KODialogManager : public QObject
     explicit KODialogManager( CalendarView * );
     virtual ~KODialogManager();
 
-    /** Get the appropriate editor for the given incidence */
-    KOIncidenceEditor *getEditor( KCal::Incidence * );
+    IncidenceEditorNG::IncidenceDialog *createDialog( const Akonadi::Item &item );
 
-    /** Get an editor dialog for an Event. */
-    KOEventEditor *getEventEditor();
-
-    /** Get an editor dialog for a Todo. */
-    KOTodoEditor *getTodoEditor();
-
-    /** Get an editor dialog for a Journal. */
-    KOJournalEditor *getJournalEditor();
-
-    void connectEditor( KOIncidenceEditor *editor );
+    // TODO_NG: see if editors-NG have the needed slots.
+    void connectEditor( IncidenceEditorNG::IncidenceDialog *editor );
 
     void updateSearchDialog();
 
-    void connectTypeAhead( KOEventEditor *editor, KOEventView *view );
-
-    static void errorSaveIncidence( QWidget *parent, KCal::Incidence *incidence );
+    void connectTypeAhead( IncidenceEditorNG::IncidenceDialog *editor, KOEventView *view );
 
   public slots:
     void showOptionsDialog();
     void showCategoryEditDialog();
     void showSearchDialog();
     void showArchiveDialog();
-    void showFilterEditDialog( QList<KCal::CalFilter*> *filters );
+    void showFilterEditDialog( QList<KCalCore::CalFilter*> *filters );
 
   private:
     void createCategoryEditor();
@@ -100,11 +85,10 @@ class KODialogManager : public QObject
     class EditorDialogVisitor;
 
     CalendarView *mMainView;
-
     KCMultiDialog *mOptionsDialog;
-    QPointer<KPIM::CategoryEditDialog> mCategoryEditDialog;
+    QPointer<IncidenceEditorNG::CategoryEditDialog> mCategoryEditDialog;
     SearchDialog *mSearchDialog;
-    ArchiveDialog *mArchiveDialog;
+    CalendarSupport::ArchiveDialog *mArchiveDialog;
     FilterEditDialog *mFilterEditDialog;
 };
 
