@@ -25,58 +25,60 @@
 
 #include "koeventpopupmenu.h"
 #include "actionmanager.h"
+#include "calprinter.h"
 #include "kocorehelper.h"
 #include "koglobals.h"
 
+#include <calendarsupport/calendar.h>
 #include <calendarsupport/kcalprefs.h>
 #include <calendarsupport/utils.h>
-#include <calendarsupport/printing/calprinter.h>
-#include <calendarsupport/printing/calprintdefaultplugins.h>
-
-#include <KCalCore/Incidence>
 
+#include <kcalcore/incidence.h>
+#include <kmimetypetrader.h>
 #include <KActionCollection>
-#include <KMimeTypeTrader>
-#include <KPrintPreview>
-KOEventPopupMenu::KOEventPopupMenu( Akonadi::ETMCalendar * calendar, QWidget *parent )
+#include <KLocale>
+
+using namespace KCalCore;
+
+KOEventPopupMenu::KOEventPopupMenu( CalendarSupport::Calendar *calendar, QWidget *parent )
   : QMenu( parent ), mCalendar( calendar )
 {
   mHasAdditionalItems = false;
 
-  addAction( KOGlobals::self()->smallIcon( QLatin1String("document-preview") ), i18n( "&Show" ),
+  addAction( KOGlobals::self()->smallIcon( "document-preview" ), i18n( "&Show" ),
              this, SLOT(popupShow()) );
   mEditOnlyItems.append(
-    addAction( KOGlobals::self()->smallIcon( QLatin1String("document-edit") ), i18n( "&Edit..." ),
+    addAction( KOGlobals::self()->smallIcon( "document-edit" ), i18n( "&Edit..." ),
                this, SLOT(popupEdit()) ) );
   mEditOnlyItems.append( addSeparator() );
-  addAction( KOGlobals::self()->smallIcon( QLatin1String("document-print") ), i18n( "&Print..." ),
+  addAction( KOGlobals::self()->smallIcon( "document-print" ), i18n( "&Print..." ),
              this, SLOT(print()) );
-  if (KPrintPreview::isAvailable()) {
-      addAction( KOGlobals::self()->smallIcon( QLatin1String("document-print-preview") ),
-                 i18n( "Print Previe&w..." ),
-                 this, SLOT(printPreview()) );
-  }
+  QAction *preview = addAction( KOGlobals::self()->smallIcon( "document-print-preview" ),
+                                i18n( "Print Previe&w..." ),
+                                this, SLOT(printPreview()) );
+  preview->setEnabled( !KMimeTypeTrader::self()->query( "application/pdf",
+                                                        "KParts/ReadOnlyPart" ).isEmpty() );
   //------------------------------------------------------------------------
   mEditOnlyItems.append( addSeparator() );
-  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( QLatin1String("edit-cut") ),
+  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( "edit-cut" ),
                                     i18nc( "cut this event", "C&ut" ),
                                     this, SLOT(popupCut()) ) );
-  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( QLatin1String("edit-copy") ),
+  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( "edit-copy" ),
                                     i18nc( "copy this event", "&Copy" ),
                                     this, SLOT(popupCopy()) ) );
   // paste is always possible
-  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( QLatin1String("edit-paste") ),
+  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( "edit-paste" ),
                                     i18n( "&Paste" ),
                                     this, SLOT(popupPaste()) ) );
-  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( QLatin1String("edit-delete") ),
+  mEditOnlyItems.append( addAction( KOGlobals::self()->smallIcon( "edit-delete" ),
                                     i18nc( "delete this incidence", "&Delete" ),
                                     this, SLOT(popupDelete()) ) );
   //------------------------------------------------------------------------
   mEditOnlyItems.append( addSeparator() );
-  mTodoOnlyItems.append( addAction( KOGlobals::self()->smallIcon( QLatin1String("task-complete") ),
+  mTodoOnlyItems.append( addAction( KOGlobals::self()->smallIcon( "task-complete" ),
                                     i18n( "Togg&le To-do Completed" ),
                                     this, SLOT(toggleTodoCompleted()) ) );
-  mToggleReminder =  addAction( QIcon( KOGlobals::self()->smallIcon( QLatin1String("appointment-reminder") ) ),
+  mToggleReminder =  addAction( QIcon( KOGlobals::self()->smallIcon( "appointment-reminder" ) ),
                                     i18n( "&Toggle Reminder" ), this, SLOT(toggleAlarm()));
   mEditOnlyItems.append( mToggleReminder );
   //------------------------------------------------------------------------
@@ -86,7 +88,7 @@ KOEventPopupMenu::KOEventPopupMenu( Akonadi::ETMCalendar * calendar, QWidget *pa
   mRecurrenceItems.append( mDissociateOccurrences );
 
   addSeparator();
-  addAction( KOGlobals::self()->smallIcon( QLatin1String("mail-forward") ),
+  addAction( KOGlobals::self()->smallIcon( "mail-forward" ),
              i18n( "Send as iCalendar..." ),
              this, SLOT(forward()) );
 }
@@ -107,9 +109,9 @@ void KOEventPopupMenu::showIncidencePopup( const Akonadi::Item &item, const QDat
     return;
   }
 
-  const bool hasChangeRights = mCalendar->hasRight( mCurrentIncidence, Akonadi::Collection::CanChangeItem );
+  const bool hasChangeRights = mCalendar->hasChangeRights( mCurrentIncidence );
 
-  KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence( mCurrentIncidence );
+  Incidence::Ptr incidence = CalendarSupport::incidence( mCurrentIncidence );
   Q_ASSERT( incidence );
   if ( incidence->recurs() ) {
     const KDateTime thisDateTime( qd, CalendarSupport::KCalPrefs::instance()->timeSpec() );
@@ -123,18 +125,15 @@ void KOEventPopupMenu::showIncidencePopup( const Akonadi::Item &item, const QDat
 
   // Enable/Disabled menu items only valid for editable events.
   QList<QAction *>::Iterator it;
-  QList<QAction *>::Iterator end(mEditOnlyItems.end());
-  for ( it = mEditOnlyItems.begin(); it != end; ++it ) {
+  for ( it = mEditOnlyItems.begin(); it != mEditOnlyItems.end(); ++it ) {
     (*it)->setEnabled( hasChangeRights );
   }
-  mToggleReminder->setVisible( ( incidence->type() != KCalCore::Incidence::TypeJournal ) );
-  end = mRecurrenceItems.end();
-  for ( it = mRecurrenceItems.begin(); it != end; ++it ) {
+  mToggleReminder->setVisible( ( incidence->type() != Incidence::TypeJournal ) );
+  for ( it = mRecurrenceItems.begin(); it != mRecurrenceItems.end(); ++it ) {
     (*it)->setVisible( incidence->recurs() );
   }
-  end = mTodoOnlyItems.end();
-  for ( it = mTodoOnlyItems.begin(); it != end; ++it ) {
-    (*it)->setVisible( incidence->type() == KCalCore::Incidence::TypeTodo );
+  for ( it = mTodoOnlyItems.begin(); it != mTodoOnlyItems.end(); ++it ) {
+    (*it)->setVisible( incidence->type() == Incidence::TypeTodo );
     (*it)->setEnabled( hasChangeRights );
   }
   popup( QCursor::pos() );
@@ -162,15 +161,15 @@ void KOEventPopupMenu::print()
 void KOEventPopupMenu::print( bool preview )
 {
   KOCoreHelper helper;
-  CalendarSupport::CalPrinter printer( this, mCalendar, true );
+  CalPrinter printer( this, mCalendar, &helper, true );
   connect( this, SIGNAL(configChanged()), &printer, SLOT(updateConfig()) );
 
   //Item::List selectedIncidences;
-  KCalCore::Incidence::List selectedIncidences;
+  Incidence::List selectedIncidences;
   Q_ASSERT( mCurrentIncidence.hasPayload<KCalCore::Incidence::Ptr>() );
   selectedIncidences.append( mCurrentIncidence.payload<KCalCore::Incidence::Ptr>() );
 
-  printer.print( CalendarSupport::CalPrinterBase::Incidence,
+  printer.print( KOrg::CalPrinterBase::Incidence,
                  mCurrentDate, mCurrentDate, selectedIncidences, preview );
 }
 
@@ -227,7 +226,7 @@ void KOEventPopupMenu::forward()
   }
 
   KActionCollection *ac = w->getActionCollection();
-  QAction *action = ac->action( QLatin1String("schedule_forward") );
+  QAction *action = ac->action( "schedule_forward" );
   if ( action ) {
     action->trigger();
   } else {
@@ -242,8 +241,9 @@ void KOEventPopupMenu::toggleTodoCompleted()
   }
 }
 
-void KOEventPopupMenu::setCalendar( const Akonadi::ETMCalendar::Ptr &calendar )
+void KOEventPopupMenu::setCalendar( CalendarSupport::Calendar *calendar )
 {
   mCalendar = calendar;
 }
 
+#include "koeventpopupmenu.moc"
