@@ -26,13 +26,19 @@
 
 #include "korganizer_export.h"
 
-#include <QColor>
+#include <kcalcore/incidence.h>
 
-namespace KCal {
-  class Calendar;
-  class Incidence;
+#include <Akonadi/Entity>
+
+namespace KOrg {
 }
 
+namespace Akonadi {
+  class Collection;
+  class Item;
+}
+
+class QColor;
 class QDate;
 
 // Provides static methods that are useful to all views.
@@ -42,7 +48,7 @@ namespace KOHelper
   /**
     Returns a nice QColor for text, give the input color &c.
   */
-  KORGANIZER_CORE_EXPORT QColor getTextColor( const QColor &c );
+  KORGANIZERPRIVATE_EXPORT QColor getTextColor( const QColor &c );
 
   /**
     This method returns the proper resource / subresource color for the view.
@@ -52,12 +58,23 @@ namespace KOHelper
     @param incidence the incidence for which the color is needed (to
                      determine which  subresource needs to be used)
   */
-  KORGANIZER_CORE_EXPORT QColor resourceColor( KCal::Calendar *calendar,
-                                               KCal::Incidence *incidence );
+  KORGANIZERPRIVATE_EXPORT QColor resourceColor( const Akonadi::Item &incidence );
+
+  KORGANIZERPRIVATE_EXPORT QColor resourceColor( const Akonadi::Collection &collection );
+
   /**
     Returns the number of years between the @p start QDate and the @p end QDate
+    (i.e. the difference in the year number of both dates)
   */
-  KORGANIZER_CORE_EXPORT qint64 yearDiff( const QDate &start, const QDate &end );
+  KORGANIZERPRIVATE_EXPORT int yearDiff( const QDate &start, const QDate &end );
+
+  /**
+    Return true if it's the standard calendar
+  */
+  KORGANIZERPRIVATE_EXPORT bool isStandardCalendar( const Akonadi::Entity::Id &id );
+
+  KORGANIZERPRIVATE_EXPORT void showSaveIncidenceErrorMsg(
+    QWidget *parent, const KCalCore::Incidence::Ptr &incidence );
 }
 
 #endif
