@@ -29,23 +29,54 @@
 */
 
 #include "korganizer.h"
-#include "actionmanager.h"
 #include "calendarview.h"
+#include "koviewmanager.h"
+#include "kodialogmanager.h"
+#include "kowindowlist.h"
+#include "koprefs.h"
 #include "kocore.h"
+#include "actionmanager.h"
 #include "koglobals.h"
-#include "impl/korganizerifaceimpl.h"
+#include "korganizerifaceimpl.h"
 
-#include "libkdepim/progresswidget/progressstatusbarwidget.h"
-#include "libkdepim/progresswidget/statusbarprogresswidget.h"
+#include <korganizer/part.h>
 
+#include <libkdepim/statusbarprogresswidget.h>
+#include <libkdepim/progressdialog.h>
 
+#include <kio/netaccess.h>
 
-#include <KAction>
-#include <KActionCollection>
-#include <KDebug>
-#include <KShortcutsDialog>
-#include <KStandardAction>
-#include <KStatusBar>
+#include <kglobal.h>
+#include <kdebug.h>
+#include <kiconloader.h>
+#include <kstandarddirs.h>
+#include <kstandardshortcut.h>
+#include <kfiledialog.h>
+#include <kaction.h>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
+#include <kedittoolbar.h>
+#include <ktemporaryfile.h>
+#include <kmenubar.h>
+#include <kmessagebox.h>
+#include <kwindowsystem.h>
+#include <ktip.h>
+#include <KStandardGuiItem>
+#include <kstatusbar.h>
+#include <kshortcutsdialog.h>
+#include <krecentfilesaction.h>
+
+#include <QCursor>
+#include <QTimer>
+#include <QFile>
+#include <QLabel>
+#include <QLayout>
+
+#include <stdlib.h>
+
+using namespace KParts;
+#include "korganizer.moc"
+using namespace KOrg;
 
 KOrganizer::KOrganizer() : KParts::MainWindow(), KOrg::MainWindow()
 {
@@ -58,7 +89,7 @@ KOrganizer::KOrganizer() : KParts::MainWindow(), KOrg::MainWindow()
 //  setMinimumSize(600,400);  // make sure we don't get resized too small...
 
   mCalendarView = new CalendarView( this );
-  mCalendarView->setObjectName( QLatin1String("KOrganizer::CalendarView") );
+  mCalendarView->setObjectName( "KOrganizer::CalendarView" );
   setCentralWidget( mCalendarView );
 
   mActionManager = new ActionManager( this, mCalendarView, this, this, false, menuBar() );
@@ -93,12 +124,17 @@ void KOrganizer::init( bool document )
 
   KStatusBar *bar = statusBar();
 
-  bar->insertItem( QString(), ID_GENERAL, 10 );
+  bar->insertItem( "", ID_GENERAL, 10 );
   connect( bar, SIGNAL(pressed(int)), SLOT(statusBarPressed(int)) );
 
-  KPIM::ProgressStatusBarWidget *progressBar = new KPIM::ProgressStatusBarWidget( statusBar(), this);
+  KPIM::ProgressDialog *progressDialog = new KPIM::ProgressDialog( bar, this );
+  progressDialog->hide();
 
-  bar->addPermanentWidget( progressBar->littleProgress() );
+  KPIM::StatusbarProgressWidget *progressWidget;
+  progressWidget = new KPIM::StatusbarProgressWidget( progressDialog, bar );
+  progressWidget->show();
+
+  bar->addPermanentWidget( progressWidget );
 
   connect( mActionManager->view(), SIGNAL(statusMessage(QString)),
            SLOT(showStatusMessage(QString)) );
@@ -112,7 +148,7 @@ void KOrganizer::newMainWindow( const KUrl &url )
   KOrganizer *korg = new KOrganizer();
   if ( url.isValid() || url.isEmpty() ) {
     korg->init( true );
-    if ( mActionManager->importURL( url, false ) || url.isEmpty() ) {
+    if ( korg->openURL( url ) || url.isEmpty() ) {
       korg->show();
     } else {
       delete korg;
@@ -154,7 +190,7 @@ void KOrganizer::initActions()
   KStandardAction::configureToolbars( this, SLOT(configureToolbars()), actionCollection() );
   KStandardAction::quit( this, SLOT(close()), actionCollection() );
 
-  setXMLFile( QLatin1String("korganizerui.rc"), true );
+  setXMLFile( "korganizerui.rc", true );
   createGUI( 0 );
 
   setAutoSaveSettings();
@@ -181,6 +217,14 @@ bool KOrganizer::queryClose()
   return close;
 }
 
+bool KOrganizer::queryExit()
+{
+  // Don't call writeSettings here, because filename isn't valid anymore. It is
+  // now called in queryClose.
+//  writeSettings();
+  return true;
+}
+
 void KOrganizer::statusBarPressed( int id )
 {
   Q_UNUSED( id );
@@ -193,7 +237,7 @@ void KOrganizer::showStatusMessage( const QString &message )
 
 bool KOrganizer::openURL( const KUrl &url, bool merge )
 {
-  return mActionManager->importURL( url, merge );
+  return mActionManager->openURL( url, merge );
 }
 
 bool KOrganizer::saveURL()
@@ -245,13 +289,12 @@ void KOrganizer::setTitle()
     }
 
     if ( mCalendarView->isReadOnly() ) {
-      title += QLatin1String(" [") + i18nc( "the calendar is read-only", "read-only" ) + QLatin1Char(']');
+      title += " [" + i18nc( "the calendar is read-only", "read-only" ) + ']';
     }
   }
   if ( mCalendarView->isFiltered() ) {
-    title += QLatin1String(" - <") + mCalendarView->currentFilterName() + QLatin1String("> ");
+    title += " - <" + mCalendarView->currentFilterName() + "> ";
   }
 
   setCaption( title, false );
 }
-
