@@ -42,10 +42,6 @@ NavigatorBar::NavigatorBar( QWidget *parent ) : QWidget( parent )
 
   bool isRTL = KOGlobals::self()->reverseLayout();
 
-  // Create a horizontal spacers
-  QSpacerItem *frontSpacer = new QSpacerItem( 50, 1, QSizePolicy::Expanding );
-  QSpacerItem *endSpacer = new QSpacerItem( 50, 1, QSizePolicy::Expanding );
-
   mPrevYear = createNavigationButton(
     isRTL ? "arrow-right-double" : "arrow-left-double",
     i18n( "Scroll backward to the previous year" ),
@@ -86,19 +82,20 @@ NavigatorBar::NavigatorBar( QWidget *parent ) : QWidget( parent )
 
   // set up control frame layout
   QHBoxLayout *ctrlLayout = new QHBoxLayout( this );
+  ctrlLayout->setMargin( 0 );
   ctrlLayout->addWidget( mPrevYear );
   ctrlLayout->addWidget( mPrevMonth );
-  ctrlLayout->addSpacerItem( frontSpacer );
+  ctrlLayout->addStretch();
   ctrlLayout->addWidget( mMonth );
   ctrlLayout->addWidget( mYear );
-  ctrlLayout->addSpacerItem( endSpacer );
+  ctrlLayout->addStretch();
   ctrlLayout->addWidget( mNextMonth );
   ctrlLayout->addWidget( mNextYear );
 
-  connect( mPrevYear, SIGNAL(clicked()), SIGNAL(goPrevYear()) );
-  connect( mPrevMonth, SIGNAL(clicked()), SIGNAL(goPrevMonth()) );
-  connect( mNextMonth, SIGNAL(clicked()), SIGNAL(goNextMonth()) );
-  connect( mNextYear, SIGNAL(clicked()), SIGNAL(goNextYear()) );
+  connect( mPrevYear, SIGNAL(clicked()), SIGNAL(prevYearClicked()) );
+  connect( mPrevMonth, SIGNAL(clicked()), SIGNAL(prevMonthClicked()) );
+  connect( mNextMonth, SIGNAL(clicked()), SIGNAL(nextMonthClicked()) );
+  connect( mNextYear, SIGNAL(clicked()), SIGNAL(nextYearClicked()) );
   connect( mMonth, SIGNAL(clicked()), SLOT(selectMonthFromMenu()) );
   connect( mYear, SIGNAL(clicked()), SLOT(selectYearFromMenu()) );
 }
@@ -126,7 +123,7 @@ void NavigatorBar::showButtons( bool left, bool right )
   }
 }
 
-void NavigatorBar::selectDates( const KCal::DateList &dateList )
+void NavigatorBar::selectDates( const KCalCore::DateList &dateList )
 {
   if ( dateList.count() > 0 ) {
     mDate = dateList.first();
@@ -135,7 +132,8 @@ void NavigatorBar::selectDates( const KCal::DateList &dateList )
 
     // set the label text at the top of the navigator
     mMonth->setText( i18nc( "monthname", "%1", calSys->monthName( mDate ) ) );
-    mYear->setText( i18nc( "4 digit year", "%1", calSys->yearString( mDate ) ) );
+    mYear->setText( i18nc( "4 digit year", "%1",
+                           calSys->formatDate( mDate, KLocale::Year, KLocale::LongNumber ) ) );
   }
 }
 
@@ -176,7 +174,7 @@ void NavigatorBar::selectMonthFromMenu()
   delete menu;
 
   if ( month > 0 ) {
-    emit goMonth( month );
+    emit monthSelected( month );
   }
 }
 
@@ -221,7 +219,7 @@ void NavigatorBar::selectYearFromMenu()
   delete menu;
 
   if ( year > 0 ) {
-    emit goYear( year );
+    emit yearSelected( year );
   }
 }
 
