@@ -26,24 +26,36 @@
   without including the source code for Qt in the source distribution.
 */
 
-#ifndef KORG_NOPRINTER
-
 #include "calprintdefaultplugins.h"
-#include "koprefs.h"
+#include "koglobals.h"
 
-#include <KCal/Calendar>
-#include <KCal/Todo>
-#include <KCal/IncidenceFormatter>
+#include <calendarsupport/calendar.h>
+#include <calendarsupport/kcalprefs.h>
+#include <calendarsupport/utils.h>
+
+#include <kcalcore/visitor.h>
+#include <kcalcore/todo.h>
+
+#include <kcalutils/incidenceformatter.h>
+#include <kcalutils/stringify.h>
 
 #include <KCalendarSystem>
 #include <KDateTime>
 #include <KConfigGroup>
-#include <ksystemtimezone.h>
+#include <KSystemTimeZones>
 
 #include <QDateTime>
 #include <QPainter>
 #include <QPrinter>
 
+using namespace KCalUtils;
+
+static QString cleanStr( const QString &instr )
+{
+  QString ret = instr;
+  return ret.replace( '\n', ' ' );
+}
+
 /**************************************************************
  *           Print Incidence
  **************************************************************/
@@ -115,21 +127,21 @@ void CalPrintIncidence::saveConfig()
   }
 }
 
-class TimePrintStringsVisitor : public IncidenceBase::Visitor
+class TimePrintStringsVisitor : public Visitor
 {
   public:
     TimePrintStringsVisitor() {}
 
-    bool act( IncidenceBase *incidence )
+    bool act( IncidenceBase::Ptr incidence )
     {
-      return incidence->accept( *this );
+      return incidence->accept( *this, incidence );
     }
     QString mStartCaption, mStartString;
     QString mEndCaption, mEndString;
     QString mDurationCaption, mDurationString;
 
   protected:
-    bool visit( Event *event ) {
+    bool visit( Event::Ptr event ) {
       if ( event->dtStart().isValid() ) {
         mStartCaption =  i18n( "Start date: " );
         mStartString = IncidenceFormatter::dateTimeToString(
@@ -158,7 +170,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       }
       return true;
     }
-    bool visit( Todo *todo ) {
+  bool visit( Todo::Ptr todo ) {
       if ( todo->hasStartDate() ) {
         mStartCaption =  i18n( "Start date: " );
         mStartString = IncidenceFormatter::dateTimeToString(
@@ -178,7 +190,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       }
       return true;
     }
-    bool visit( Journal *journal ) {
+    bool visit( Journal::Ptr journal ) {
       mStartCaption = i18n( "Start date: " );
       mStartString = IncidenceFormatter::dateTimeToString(
         journal->dtStart(), journal->allDay(), false );
@@ -186,7 +198,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
       mEndString.clear();
       return true;
     }
-    bool visit( FreeBusy *fb ) {
+    bool visit( FreeBusy::Ptr fb ) {
       Q_UNUSED( fb );
       return true;
     }
@@ -203,12 +215,12 @@ int CalPrintIncidence::printCaptionAndText( QPainter &p, const QRect &box,
 
   QFont oldFont( p.font() );
   p.setFont( captionFont );
-  p.drawText( box, Qt::AlignLeft|Qt::AlignTop|Qt::SingleLine, caption );
+  p.drawText( box, Qt::AlignLeft|Qt::AlignTop|Qt::TextSingleLine, caption );
 
   if ( !text.isEmpty() ) {
     textRect.setLeft( textRect.left() + textWd );
     p.setFont( textFont );
-    p.drawText( textRect, Qt::AlignLeft|Qt::AlignTop|Qt::SingleLine, text );
+    p.drawText( textRect, Qt::AlignLeft|Qt::AlignTop|Qt::TextSingleLine, text );
   }
   p.setFont( oldFont );
   return textRect.bottom();
@@ -233,7 +245,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
       mPrinter->newPage();
     }
 
-    const bool isJournal = ( (*it)->type() == "Journal" );
+    const bool isJournal = ( (*it)->type() == Incidence::TypeJournal );
 
     //  PAGE Layout (same for landscape and portrait! astonishingly, it looks good with both!):
     //  +-----------------------------------+
@@ -280,7 +292,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
 
     TimePrintStringsVisitor stringVis;
     int h = timesBox.top();
-    if ( stringVis.act(*it) ) {
+    if ( stringVis.act( *it ) ) {
       QRect textRect( timesBox.left() + padding(),
                       timesBox.top() + padding(), 0, lineHeight );
       textRect.setRight( timesBox.center().x() );
@@ -297,7 +309,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     if ( (*it)->recurs() ) {
       QRect recurBox( timesBox.left() + padding(), h + padding(),
                       timesBox.right() - padding(), lineHeight );
-      KCal::Recurrence *recurs = (*it)->recurrence();
+      KCalCore::Recurrence *recurs = (*it)->recurrence();
       QString displayString = IncidenceFormatter::recurrenceString((*it));
       // exception dates
       QString exceptString;
@@ -326,9 +338,9 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
       cap = i18np( "Reminder: ", "%1 reminders: ", alarms.count() );
 
       QStringList alarmStrings;
-      KCal::Alarm::List::ConstIterator it;
+      KCalCore::Alarm::List::ConstIterator it;
       for ( it = alarms.constBegin(); it != alarms.constEnd(); ++it ) {
-        Alarm *alarm = *it;
+        Alarm::Ptr alarm = *it;
 
         // Alarm offset, copied from koeditoralarms.cpp:
         KLocalizedString offsetstr;
@@ -378,7 +390,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     QRect organizerBox( timesBox.left() + padding(), h + padding(),
                         timesBox.right() - padding(), lineHeight );
     h = qMax( printCaptionAndText( p, organizerBox, i18n( "Organizer: " ),
-                                   (*it)->organizer().fullName(), captionFont, textFont ), h );
+                                   (*it)->organizer()->fullName(), captionFont, textFont ), h );
 
     // Finally, draw the frame around the time information...
     timesBox.setBottom( qMax( timesBox.bottom(), h + padding() ) );
@@ -396,17 +408,24 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     locationBox.setBottom( locationBottom );
 
     // Now start constructing the boxes from the bottom:
-    QRect categoriesBox( locationBox );
-    categoriesBox.setBottom( box.bottom() );
+    QRect footerBox( locationBox );
+    footerBox.setBottom( box.bottom() );
+    footerBox.setTop( footerBox.bottom() - lineHeight - 2 * padding() );
+
+    QRect categoriesBox( footerBox );
+    categoriesBox.setBottom( footerBox.top() );
     categoriesBox.setTop( categoriesBox.bottom() - lineHeight - 2 * padding() );
     QRect attendeesBox( box.left(), categoriesBox.top() - padding() - box.height() / 9,
                         box.width(), box.height() / 9 );
     QRect attachmentsBox( box.left(), attendeesBox.top() - padding() - box.height() / 9,
                           box.width() * 3 / 4 - padding(), box.height() / 9 );
-    QRect optionsBox( isJournal ? box.left() :  attachmentsBox.right() + padding(), attachmentsBox.top(), 0, 0 );
+    QRect optionsBox( isJournal ? box.left() :  attachmentsBox.right() + padding(),
+                      attachmentsBox.top(), 0, 0 );
     optionsBox.setRight( box.right() );
     optionsBox.setBottom( attachmentsBox.bottom() );
-    QRect notesBox( optionsBox.left(), isJournal ? ( timesBox.bottom() + padding() ) : ( locationBox.bottom() + padding() ),
+    QRect notesBox( optionsBox.left(),
+                    isJournal ? ( timesBox.bottom() + padding() ) :
+                                ( locationBox.bottom() + padding() ),
                     optionsBox.width(), 0 );
     notesBox.setBottom( optionsBox.top() - padding() );
     QRect descriptionBox( notesBox );
@@ -452,14 +471,18 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     if ( mShowNoteLines ) {
       drawNoteLines( p, descriptionBox, newBottom );
     }
+
+    Akonadi::Item item = mCalendar->itemForIncidenceUid( (*it)->uid() );
+    Akonadi::Item::List relations = mCalendar->findChildren( item );
+
     if ( mShowSubitemsNotes && !isJournal ) {
-      if ( (*it)->relations().isEmpty() || (*it)->type() != "Todo" ) {
+      if ( relations.isEmpty() || (*it)->type() != Incidence::TypeTodo ) {
         int notesPosition = drawBoxWithCaption( p, notesBox, i18n( "Notes:" ),
                                                 QString(), /*sameLine=*/false,
                                                 /*expand=*/false, captionFont, textFont );
         drawNoteLines( p, notesBox, notesPosition );
       } else {
-        Incidence::List relations = (*it)->relations();
+
         QString subitemCaption;
         if ( relations.count() == 0 ) {
           subitemCaption = i18n( "No Subitems" );
@@ -469,20 +492,21 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
                                   "%1 Subitems:",
                                   relations.count() );
         }
-        Incidence::List::ConstIterator rit;
+
         QString subitemString;
         QString statusString;
         QString datesString;
         int count = 0;
-        for ( rit = relations.constBegin(); rit != relations.constEnd(); ++rit ) {
+        foreach ( const Akonadi::Item &item, relations ) {
+          Todo::Ptr todo = CalendarSupport::todo( item );
           ++count;
-          if ( !(*rit) ) { // defensive, skip any zero pointers
+          if ( !todo ) { // defensive, skip any zero pointers
             continue;
           }
           // format the status
-          statusString = (*rit)->statusStr();
+          statusString = Stringify::incidenceStatus( todo->status() );
           if ( statusString.isEmpty() ) {
-            if ( (*rit)->status() == Incidence::StatusNone ) {
+            if ( todo->status() == Incidence::StatusNone ) {
               statusString = i18nc( "no status", "none" );
             } else {
               statusString = i18nc( "unknown status", "unknown" );
@@ -490,33 +514,36 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
           }
           // format the dates if provided
           datesString.clear();
-          KDateTime::Spec spec = KOPrefs::instance()->timeSpec();
-          if ( (*rit)->dtStart().isValid() ) {
+          KDateTime::Spec spec = CalendarSupport::KCalPrefs::instance()->timeSpec();
+          if ( todo->dtStart().isValid() ) {
             datesString += i18nc(
               "subitem start date", "Start Date: %1\n",
-              KGlobal::locale()->formatDate( (*rit)->dtStart().toTimeSpec( spec ).date(),
+              KGlobal::locale()->formatDate( todo->dtStart().toTimeSpec( spec ).date(),
                                              KLocale::ShortDate ) );
-            if ( !(*rit)->allDay() ) {
+            if ( !todo->allDay() ) {
               datesString += i18nc(
                 "subitem start time", "Start Time: %1\n",
-                KGlobal::locale()->formatTime( (*rit)->dtStart().toTimeSpec( spec ).time(),
+                KGlobal::locale()->formatTime( todo->dtStart().toTimeSpec( spec ).time(),
                                                false, false ) );
             }
           }
-          if ( (*rit)->dtEnd().isValid() ) {
-            subitemString += i18nc(
-              "subitem due date", "Due Date: %1\n",
-              KGlobal::locale()->formatDate( (*rit)->dtEnd().toTimeSpec( spec ).date(),
-                                             KLocale::ShortDate ) );
-            if ( !(*rit)->allDay() ) {
+          if ( todo->dateTime( Incidence::RoleEnd ).isValid() ) {
+            subitemString +=
+              i18nc( "subitem due date", "Due Date: %1\n",
+                     KGlobal::locale()->formatDate(
+                       todo->dateTime( Incidence::RoleEnd ).toTimeSpec( spec ).date(),
+                       KLocale::ShortDate ) );
+
+            if ( !todo->allDay() ) {
               subitemString += i18nc(
                 "subitem due time", "Due Time: %1\n",
-                KGlobal::locale()->formatTime( (*rit)->dtEnd().toTimeSpec( spec ).time(),
-                                               false, false ) );
+                KGlobal::locale()->formatTime(
+                  todo->dateTime( Incidence::RoleEnd ).toTimeSpec( spec ).time(),
+                  false, false ) );
             }
           }
           subitemString += i18nc( "subitem counter", "%1: ", count );
-          subitemString += (*rit)->summary();
+          subitemString += todo->summary();
           subitemString += '\n';
           if ( !datesString.isEmpty() ) {
             subitemString += datesString;
@@ -525,13 +552,13 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
           subitemString += i18nc( "subitem Status: statusString",
                                   "Status: %1\n",
                                    statusString );
-          subitemString += IncidenceFormatter::recurrenceString((*rit)) + '\n';
+          subitemString += IncidenceFormatter::recurrenceString( todo ) + '\n';
           subitemString += i18nc( "subitem Priority: N",
                                   "Priority: <numid>%1</numid>\n",
-                                  (*rit)->priority() );
+                                  todo->priority() );
           subitemString += i18nc( "subitem Secrecy: secrecyString",
                                   "Secrecy: %1\n",
-                                  (*rit)->secrecyStr() );
+                                  Stringify::incidenceSecrecy( todo->secrecy() ) );
           subitemString += '\n';
         }
         drawBoxWithCaption( p, notesBox, subitemCaption,
@@ -585,7 +612,9 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
                 "'Name (Role): Status', e.g. 'Reinhold Kainhofer "
                 "<reinhold@kainhofer.com> (Participant): Awaiting Response'",
                 "%1 (%2): %3",
-                (*ait)->fullName(), (*ait)->roleStr(), (*ait)->statusStr() );
+                (*ait)->fullName(),
+                Stringify::attendeeRole( (*ait)->role() ),
+                Stringify::attendeeStatus( ( *ait )->status() ) );
       }
       drawBoxWithCaption( p, attendeesBox, attendeeCaption, attendeeString,
                           /*sameLine=*/false, /*expand=*/false,
@@ -594,29 +623,29 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
 
     if ( mShowOptions ) {
       QString optionsString;
-      if ( !(*it)->statusStr().isEmpty() ) {
-        optionsString += i18n( "Status: %1", (*it)->statusStr() );
+      if ( !Stringify::incidenceStatus( (*it)->status() ).isEmpty() ) {
+        optionsString += i18n( "Status: %1", Stringify::incidenceStatus( (*it)->status() ) );
         optionsString += '\n';
       }
-      if ( !(*it)->secrecyStr().isEmpty() ) {
-        optionsString += i18n( "Secrecy: %1", (*it)->secrecyStr() );
+      if ( !Stringify::incidenceSecrecy( (*it)->secrecy() ).isEmpty() ) {
+        optionsString += i18n( "Secrecy: %1", Stringify::incidenceSecrecy( (*it)->secrecy() ) );
         optionsString += '\n';
       }
-      if ( (*it)->type() == "Event" ) {
-        Event *e = static_cast<Event*>(*it);
+      if ( (*it)->type() == Incidence::TypeEvent ) {
+        Event::Ptr e = (*it).staticCast<Event>();
         if ( e->transparency() == Event::Opaque ) {
           optionsString += i18n( "Show as: Busy" );
         } else {
           optionsString += i18n( "Show as: Free" );
         }
         optionsString += '\n';
-      } else if ( (*it)->type() == "Todo" ) {
-        Todo *t = static_cast<Todo*>(*it);
+      } else if ( (*it)->type() == Incidence::TypeTodo ) {
+        Todo::Ptr t = (*it).staticCast<Todo>();
         if ( t->isOverdue() ) {
           optionsString += i18n( "This task is overdue!" );
           optionsString += '\n';
         }
-      } else if ( (*it)->type() == "Journal" ) {
+      } else if ( (*it)->type() == Incidence::TypeJournal ) {
         //TODO: Anything Journal-specific?
       }
       drawBoxWithCaption( p, optionsBox, i18n( "Settings: " ),
@@ -627,7 +656,8 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     drawBoxWithCaption( p, categoriesBox, i18n( "Categories: " ),
            (*it)->categories().join( i18nc( "Spacer for the joined list of categories", ", " ) ),
            /*sameLine=*/true, /*expand=*/false, captionFont, textFont );
-    drawFooter( p, box );
+
+    drawFooter( p, footerBox );
   }
   p.setFont( oldFont );
 }
@@ -662,7 +692,7 @@ void CalPrintDay::readSettingsWidget()
     } else if ( cfg->mPrintTypeTimetable->isChecked() ) {
       mDayPrintType = Timetable;
     } else {
-      mDayPrintType = Timetable;
+      mDayPrintType = SingleTimetable;
     }
 
     mStartTime = cfg->mFromTime->time();
@@ -689,6 +719,7 @@ void CalPrintDay::setSettingsWidget()
 
     cfg->mPrintTypeFilofax->setChecked( mDayPrintType == Filofax );
     cfg->mPrintTypeTimetable->setChecked( mDayPrintType == Timetable );
+    cfg->mPrintTypeSingleTimetable->setChecked( mDayPrintType == SingleTimetable );
 
     cfg->mFromTime->setTime( mStartTime );
     cfg->mToTime->setTime( mEndTime );
@@ -763,27 +794,39 @@ void CalPrintDay::print( QPainter &p, int width, int height )
 
   KDateTime::Spec timeSpec = KSystemTimeZones::local();
 
+  QRect headerBox( 0, 0, width, headerHeight() );
+  QRect footerBox( 0, height - footerHeight(), width, footerHeight() );
+  height -= footerHeight();
+
+  KLocale *local = KGlobal::locale();
+
   switch ( mDayPrintType ) {
   case Filofax:
+  case SingleTimetable:
     {
-      QString line1, line2, title;
-      QRect headerBox( 0, 0, width, headerHeight() );
       QRect daysBox( headerBox );
-      KLocale *local = KGlobal::locale();
       daysBox.setTop( headerBox.bottom() + padding() );
       daysBox.setBottom( height );
-      line1 = local->formatDate( mFromDate );
-      line2 = local->formatDate( mToDate );
+      QString line1 = local->formatDate( mFromDate );
+      QString line2 = local->formatDate( mToDate );
+      QString title;
       if ( orientation() == QPrinter::Landscape ) {
         title = i18nc( "date from-to", "%1 - %2", line1, line2 );
       } else {
         title = i18nc( "date from-\nto", "%1 -\n%2", line1, line2 );
       }
       drawHeader( p, title, mFromDate, QDate(), headerBox );
-      drawDays( p, mFromDate, mToDate, daysBox, mSingleLineLimit,
-                mShowNoteLines, mIncludeDescription,
-                mExcludeConfidential, mExcludePrivate );
-      drawFooter( p, daysBox );
+      if ( mDayPrintType == Filofax ) {
+        drawDays( p, mFromDate, mToDate, mStartTime, mEndTime, daysBox,
+                  mSingleLineLimit,  mShowNoteLines,
+                  mIncludeDescription, mExcludeConfidential, mExcludePrivate );
+      } else if ( mDayPrintType == SingleTimetable ) {
+        drawTimeTable( p, mFromDate, mToDate,
+                       mIncludeAllEvents, mStartTime, mEndTime, daysBox,
+                       mIncludeDescription, mExcludeTime, mExcludeConfidential,
+                       mExcludePrivate );
+      }
+      drawFooter( p, footerBox );
     }
     break;
 
@@ -800,32 +843,91 @@ void CalPrintDay::print( QPainter &p, int width, int height )
       curEndTime = curStartTime.addSecs( 3600 );
     }
 
-    KLocale *local = KGlobal::locale();
-    QRect headerBox( 0, 0, width, headerHeight() );
-
     drawHeader( p, local->formatDate( curDay ), curDay, QDate(), headerBox );
-    Event::List eventList = mCalendar->events( curDay, timeSpec,
-                                               EventSortStartDate,
-                                               SortDirectionAscending );
+    Akonadi::Item::List eventList = mCalendar->events( curDay, timeSpec,
+                                               CalendarSupport::EventSortStartDate,
+                                               CalendarSupport::SortDirectionAscending );
 
-    p.setFont( QFont( "sans-serif", 12 ) );
+    // split out the all day events as they will be printed in a separate box
+    Akonadi::Item::List alldayEvents, timedEvents;
+    Akonadi::Item::List::ConstIterator it;
+    for ( it = eventList.constBegin(); it != eventList.constEnd(); ++it ) {
+      Event::Ptr event = CalendarSupport::event( *it );
+      if ( event->allDay() ) {
+        alldayEvents.append( *it );
+      } else {
+        timedEvents.append( *it );
+      }
+    }
 
-    // TODO: Find a good way to determine the height of the all-day box
+    int fontSize = 11;
+    QFont textFont( "sans-serif", fontSize, QFont::Normal );
+    p.setFont( textFont );
+    int lineSpacing = p.fontMetrics().lineSpacing();
+
+    int maxAllDayEvents = 8; // the max we allow to be printed, sorry.
+    int allDayHeight = qMin( alldayEvents.count(), maxAllDayEvents ) * lineSpacing;
+    allDayHeight = qMax( allDayHeight, ( 5 * lineSpacing ) ) + ( 2 * padding() );
     QRect allDayBox( TIMELINE_WIDTH + padding(), headerBox.bottom() + padding(),
-        0, height - headerBox.bottom() - padding() );
-    allDayBox.setRight( width );
+                     width - TIMELINE_WIDTH - padding(), allDayHeight );
+    if ( alldayEvents.count() > 0 ) {
+      // draw the side bar for all-day events
+      QFont oldFont( p.font() );
+      p.setFont( QFont( "sans-serif", 9, QFont::Normal ) );
+      drawVerticalBox( p,
+                       BOX_BORDER_WIDTH,
+                       QRect( 0, headerBox.bottom() + padding(), TIMELINE_WIDTH, allDayHeight ),
+                       i18n( "Today's Events" ),
+                       Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap );
+      p.setFont( oldFont );
+
+      // now draw at most maxAllDayEvents in the all-day box
+      drawBox( p, BOX_BORDER_WIDTH, allDayBox );
+
+      Akonadi::Item::List::ConstIterator it;
+      QRect eventBox( allDayBox );
+      eventBox.setLeft( TIMELINE_WIDTH + ( 2 * padding() ) );
+      eventBox.setTop( eventBox.top() + padding() );
+      eventBox.setBottom( eventBox.top() + lineSpacing );
+      int count = 0;
+      for ( it = alldayEvents.constBegin(); it != alldayEvents.constEnd(); ++it ) {
+        Event::Ptr event = CalendarSupport::event( *it );
+        if ( count == maxAllDayEvents ) {
+          break;
+        }
+        count++;
+        QString str;
+        if ( event->location().isEmpty() ) {
+          str = cleanStr( event->summary() );
+        } else {
+          str = i18nc( "summary, location", "%1, %2",
+                       cleanStr( event->summary() ), cleanStr( event->location() ) );
+        }
+        printEventString( p, eventBox, str );
+        eventBox.setTop( eventBox.bottom() );
+        eventBox.setBottom( eventBox.top() + lineSpacing );
+      }
+    } else {
+      allDayBox.setBottom( headerBox.bottom() );
+    }
 
     QRect dayBox( allDayBox );
-    drawAgendaDayBox( p, eventList, curDay, mIncludeAllEvents,
-                        curStartTime, curEndTime, dayBox,
-                        mIncludeDescription, mExcludeTime,
-                        mExcludeConfidential, mExcludePrivate );
+    dayBox.setTop( allDayBox.bottom() + padding() );
+    dayBox.setBottom( height );
+    QList<QDate> workDays = KOGlobals::self()->workDays( curDay, curDay );
+    drawAgendaDayBox( p, timedEvents, curDay, mIncludeAllEvents,
+                      curStartTime, curEndTime, dayBox,
+                      mIncludeDescription, mExcludeTime,
+                      mExcludeConfidential, mExcludePrivate,
+                      workDays );
 
     QRect tlBox( dayBox );
     tlBox.setLeft( 0 );
     tlBox.setWidth( TIMELINE_WIDTH );
     drawTimeLine( p, curStartTime, curEndTime, tlBox );
-    drawFooter( p, dayBox );
+
+    drawFooter( p, footerBox );
+
     curDay = curDay.addDays( 1 );
     if ( curDay <= mToDate ) {
       mPrinter->newPage();
@@ -983,6 +1085,9 @@ void CalPrintWeek::print( QPainter &p, int width, int height )
 
   QString line1, line2, title;
   QRect headerBox( 0, 0, width, headerHeight() );
+  QRect footerBox( 0, height - footerHeight(), width, footerHeight() );
+  height -= footerHeight();
+
   QRect weekBox( headerBox );
   weekBox.setTop( headerBox.bottom() + padding() );
   weekBox.setBottom( height );
@@ -998,10 +1103,13 @@ void CalPrintWeek::print( QPainter &p, int width, int height )
         title = i18nc( "date from-\nto", "%1 -\n%2", line1, line2 );
       }
       drawHeader( p, title, curWeek.addDays( -6 ), QDate(), headerBox );
-      drawWeek( p, curWeek, weekBox, mSingleLineLimit,
+
+      drawWeek( p, curWeek, mStartTime, mEndTime, weekBox, mSingleLineLimit,
                 mShowNoteLines, mIncludeDescription,
                 mExcludeConfidential, mExcludePrivate );
-      drawFooter( p, weekBox );
+
+      drawFooter( p, footerBox );
+
       curWeek = curWeek.addDays( 7 );
       if ( curWeek <= toWeek ) {
         mPrinter->newPage();
@@ -1021,15 +1129,15 @@ void CalPrintWeek::print( QPainter &p, int width, int height )
         title = i18nc( "date from -\nto (week number)", "%1 -\n%2 (Week %3)",
                        line1, line2, curWeek.weekNumber() );
       }
-
       drawHeader( p, title, curWeek, QDate(), headerBox );
-      QRect weekBox( headerBox );
-      weekBox.setTop( headerBox.bottom() + padding() );
-      weekBox.setBottom( height );
-      drawTimeTable( p, fromWeek, curWeek, mStartTime, mEndTime, weekBox,
+
+      drawTimeTable( p, fromWeek, curWeek,
+                     false, mStartTime, mEndTime, weekBox,
                      mIncludeDescription, mExcludeTime, mExcludeConfidential,
                      mExcludePrivate );
-      drawFooter( p, weekBox );
+
+      drawFooter( p, footerBox );
+
       fromWeek = fromWeek.addDays( 7 );
       curWeek = fromWeek.addDays( 6 );
       if ( curWeek <= toWeek ) {
@@ -1050,16 +1158,19 @@ void CalPrintWeek::print( QPainter &p, int width, int height )
       int hh = headerHeight();
 
       drawSplitHeaderRight( p, fromWeek, curWeek, QDate(), width, hh );
-      drawTimeTable( p, fromWeek, endLeft, mStartTime, mEndTime, weekBox,
+      drawTimeTable( p, fromWeek, endLeft,
+                     false, mStartTime, mEndTime, weekBox,
                      mIncludeDescription, mExcludeTime,
                      mExcludeConfidential, mExcludePrivate );
       drawFooter( p, weekBox1 );
       mPrinter->newPage();
       drawSplitHeaderRight( p, fromWeek, curWeek, QDate(), width, hh );
-      drawTimeTable( p, endLeft.addDays( 1 ), curWeek, mStartTime, mEndTime,
-                     weekBox1, mIncludeDescription, mExcludeTime,
+      drawTimeTable( p, endLeft.addDays( 1 ), curWeek,
+                     false, mStartTime, mEndTime, weekBox1,
+                     mIncludeDescription, mExcludeTime,
                      mExcludeConfidential, mExcludePrivate );
-      drawFooter( p, weekBox1 );
+      drawFooter( p, footerBox );
+
       fromWeek = fromWeek.addDays( 7 );
       curWeek = fromWeek.addDays( 6 );
       if ( curWeek <= toWeek ) {
@@ -1197,6 +1308,9 @@ void CalPrintMonth::print( QPainter &p, int width, int height )
   }
 
   QRect headerBox( 0, 0, width, headerHeight() );
+  QRect footerBox( 0, height - footerHeight(), width, footerHeight() );
+  height -= footerHeight();
+
   QRect monthBox( 0, 0, width, height );
   monthBox.setTop( headerBox.bottom() + padding() );
 
@@ -1210,10 +1324,15 @@ void CalPrintMonth::print( QPainter &p, int width, int height )
 
     drawHeader( p, title, curMonth.addMonths( -1 ), curMonth.addMonths( 1 ),
                 headerBox );
-    drawMonthTable( p, curMonth, mWeekNumbers, mRecurDaily, mRecurWeekly,
+    drawMonthTable( p,
+                    curMonth, QTime(), QTime(),
+                    mWeekNumbers,
+                    mRecurDaily, mRecurWeekly,
                     mSingleLineLimit, mShowNoteLines, mIncludeDescription,
                     mExcludeConfidential, mExcludePrivate, monthBox );
-    drawFooter( p, monthBox );
+
+    drawFooter( p, footerBox );
+
     curMonth = curMonth.addDays( curMonth.daysInMonth() );
     if ( curMonth <= toMonth ) {
       mPrinter->newPage();
@@ -1300,11 +1419,11 @@ void CalPrintTodos::setSettingsWidget()
 
     if ( mTodoSortField != TodoFieldUnset ) {
       // do not insert if already done so.
-      cfg->mSortField->addItem( i18n( "Summary" ) );
-      cfg->mSortField->addItem( i18n( "Start Date" ) );
-      cfg->mSortField->addItem( i18n( "Due Date" ) );
-      cfg->mSortField->addItem( i18n( "Priority" ) );
-      cfg->mSortField->addItem( i18n( "Percent Complete" ) );
+      cfg->mSortField->addItem( i18nc( "@option sort by title", "Title" ) );
+      cfg->mSortField->addItem( i18nc( "@option sort by start date/time", "Start Date" ) );
+      cfg->mSortField->addItem( i18nc( "@option sort by due date/time", "Due Date" ) );
+      cfg->mSortField->addItem( i18nc( "@option sort by priority", "Priority" ) );
+      cfg->mSortField->addItem( i18nc( "@option sort by percent completed", "Percent Complete" ) );
       cfg->mSortField->setCurrentIndex( mTodoSortField );
     }
 
@@ -1359,15 +1478,18 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
 {
   // TODO: Find a good way to guarantee a nicely designed output
   int pospriority = 0;
-  int possummary = 60;
+  int possummary = 100;
   int posdue = width - 65;
   int poscomplete = posdue - 70; //Complete column is to right of the Due column
   int lineSpacing = 15;
-  int fontHeight = 10;
+  //int fontHeight = 10;
+
+  QRect headerBox( 0, 0, width, headerHeight() );
+  QRect footerBox( 0, height - footerHeight(), width, footerHeight() );
+  height -= footerHeight();
 
   // Draw the First Page Header
-  drawHeader( p, mPageTitle, mFromDate, QDate(),
-                       QRect( 0, 0, width, headerHeight() ) );
+  drawHeader( p, mPageTitle, mFromDate, QDate(), headerBox );
 
   // Draw the Column Headers
   int mCurrentLinePos = headerHeight() + 5;
@@ -1381,12 +1503,11 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
     outStr += i18n( "Priority" );
     p.drawText( pospriority, mCurrentLinePos - 2, outStr );
   } else {
-    possummary = 10;
     pospriority = -1;
   }
 
   outStr.truncate( 0 );
-  outStr += i18n( "Summary" );
+  outStr += i18nc( "@label to-do summary", "Title" );
   p.drawText( possummary, mCurrentLinePos - 2, outStr );
 
   if ( mIncludePercentComplete ) {
@@ -1409,41 +1530,41 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
   }
 
   p.setFont( QFont( "sans-serif", 10 ) );
-  fontHeight = p.fontMetrics().height();
+  //fontHeight = p.fontMetrics().height();
 
-  Todo::List todoList;
-  Todo::List tempList;
-  Todo::List::ConstIterator it;
+  Akonadi::Item::List todoList;
+  Akonadi::Item::List tempList;
+  Akonadi::Item::List::ConstIterator it;
 
   // Convert sort options to the corresponding enums
-  TodoSortField sortField = TodoSortSummary;
+  CalendarSupport::TodoSortField sortField = CalendarSupport::TodoSortSummary;
   switch( mTodoSortField ) {
   case TodoFieldSummary:
-    sortField = TodoSortSummary;
+    sortField = CalendarSupport::TodoSortSummary;
     break;
   case TodoFieldStartDate:
-    sortField = TodoSortStartDate;
+    sortField = CalendarSupport::TodoSortStartDate;
     break;
   case TodoFieldDueDate:
-    sortField = TodoSortDueDate;
+    sortField = CalendarSupport::TodoSortDueDate;
     break;
   case TodoFieldPriority:
-    sortField = TodoSortPriority;
+    sortField = CalendarSupport::TodoSortPriority;
     break;
   case TodoFieldPercentComplete:
-    sortField = TodoSortPercentComplete;
+    sortField = CalendarSupport::TodoSortPercentComplete;
     break;
   case TodoFieldUnset:
     break;
   }
 
-  SortDirection sortDirection = SortDirectionAscending;
+  CalendarSupport::SortDirection sortDirection = CalendarSupport::SortDirectionAscending;
   switch( mTodoSortDirection ) {
   case TodoDirectionAscending:
-    sortDirection = SortDirectionAscending;
+    sortDirection = CalendarSupport::SortDirectionAscending;
     break;
   case TodoDirectionDescending:
-    sortDirection = SortDirectionDescending;
+    sortDirection = CalendarSupport::SortDirectionDescending;
     break;
   case TodoDirectionUnset:
     break;
@@ -1456,7 +1577,9 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
     break;
   case TodosUnfinished:
     for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
-      if ( !(*it)->isCompleted() ) {
+      const Todo::Ptr todo = CalendarSupport::todo( *it );
+      Q_ASSERT( todo );
+      if ( !todo->isCompleted() ) {
         tempList.append( *it );
       }
     }
@@ -1464,8 +1587,10 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
     break;
   case TodosDueRange:
     for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
-      if ( (*it)->hasDueDate() ) {
-        if ( (*it)->dtDue().date() >= mFromDate && (*it)->dtDue().date() <= mToDate ) {
+      const Todo::Ptr todo = CalendarSupport::todo( *it );
+      Q_ASSERT( todo );
+      if ( todo->hasDueDate() ) {
+        if ( todo->dtDue().date() >= mFromDate && todo->dtDue().date() <= mToDate ) {
           tempList.append( *it );
         }
       } else {
@@ -1479,15 +1604,15 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
   // Print to-dos
   int count = 0;
   for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
-    Todo *currEvent = *it;
-    if ( ( mExcludeConfidential && currEvent->secrecy() == Incidence::SecrecyConfidential ) ||
-         ( mExcludePrivate      && currEvent->secrecy() == Incidence::SecrecyPrivate ) ) {
+    const Todo::Ptr todo = CalendarSupport::todo( *it );
+    if ( ( mExcludeConfidential && todo->secrecy() == Incidence::SecrecyConfidential ) ||
+         ( mExcludePrivate      && todo->secrecy() == Incidence::SecrecyPrivate ) ) {
       continue;
     }
     // Skip sub-to-dos. They will be printed recursively in drawTodo()
-    if ( !currEvent->relatedTo() ) {
+    if ( todo->relatedTo().isEmpty() ) { //review(AKONADI_PORT)
       count++;
-      drawTodo( count, currEvent, p,
+      drawTodo( count, *it, p,
                 sortField, sortDirection,
                 mConnectSubTodos,
                 mStrikeOutCompleted, mIncludeDescription,
@@ -1496,7 +1621,7 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
                 mExcludeConfidential, mExcludePrivate );
     }
   }
+
+  drawFooter( p, footerBox );
   p.setFont( oldFont );
 }
-
-#endif
