@@ -23,11 +23,10 @@
   without including the source code for Qt in the source distribution.
 */
 
+#include "koprefs.h"
 #include "monthview.h"
 #include "koeventpopupmenu.h"
-#include "prefs/koprefs.h"
-
-#include <calendarviews/month/monthview.h>
+#include <calendarviews/eventviews/month/monthview.h>
 
 #include <QVBoxLayout>
 
@@ -48,7 +47,6 @@ class MonthView::Private
 
     EventViews::MonthView *mMonthView;
     KOEventPopupMenu *mPopup;
-
   private:
     MonthView *q;
 };
@@ -95,15 +93,21 @@ MonthView::MonthView( QWidget *parent )
   connect( d->mMonthView, SIGNAL(toggleTodoCompletedSignal(Akonadi::Item)),
            SIGNAL(toggleTodoCompletedSignal(Akonadi::Item)) );
 
-  connect( d->mMonthView, SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)),
-           SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)) );
+  connect( d->mMonthView, SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,QString)),
+           SIGNAL(copyIncidenceToResourceSignal(Akonadi::Item,QString)) );
 
-  connect( d->mMonthView, SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)),
-           SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,Akonadi::Collection)) );
+  connect( d->mMonthView, SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,QString)),
+           SIGNAL(moveIncidenceToResourceSignal(Akonadi::Item,QString)) );
 
   connect( d->mMonthView, SIGNAL(dissociateOccurrencesSignal(Akonadi::Item,QDate)),
            SIGNAL(dissociateOccurrencesSignal(Akonadi::Item,QDate)) );
 
+  connect( d->mMonthView, SIGNAL(startMultiModify(QString)),
+           SIGNAL(startMultiModify(QString)) );
+
+  connect( d->mMonthView, SIGNAL(endMultiModify()),
+           SIGNAL(endMultiModify()) );
+
   connect( d->mMonthView, SIGNAL(newEventSignal()),
            SIGNAL(newEventSignal()) );
 
@@ -124,9 +128,6 @@ MonthView::MonthView( QWidget *parent )
 
   connect( d->mMonthView, SIGNAL(newJournalSignal(QDate)),
            SIGNAL(newJournalSignal(QDate)) );
-
-  connect( d->mMonthView, SIGNAL(fullViewChanged(bool)),
-           SIGNAL(fullViewChanged(bool)) );
 }
 
 MonthView::~MonthView()
@@ -134,9 +135,9 @@ MonthView::~MonthView()
   delete d;
 }
 
-CalendarSupport::CalPrinterBase::PrintType MonthView::printType() const
+CalPrinterBase::PrintType MonthView::printType() const
 {
-  return CalendarSupport::CalPrinterBase::Month;
+  return CalPrinterBase::Month;
 }
 
 int MonthView::currentDateCount() const
@@ -194,10 +195,9 @@ void MonthView::showIncidences( const Akonadi::Item::List &incidenceList, const
   d->mMonthView->showIncidences( incidenceList, date );
 }
 
-void MonthView::changeIncidenceDisplay( const Akonadi::Item &item,
-                                        Akonadi::IncidenceChanger::ChangeType changeType )
+void MonthView::changeIncidenceDisplay( const Akonadi::Item &item, int mode )
 {
-  d->mMonthView->changeIncidenceDisplay( item, changeType );
+  d->mMonthView->changeIncidenceDisplay( item, mode );
 }
 
 void MonthView::updateConfig()
@@ -226,14 +226,14 @@ void MonthView::setDateRange( const KDateTime &start, const KDateTime &end,
   d->mMonthView->setDateRange( start, end, preferredMonth );
 }
 
-void MonthView::setCalendar( const Akonadi::ETMCalendar::Ptr &cal )
+void MonthView::setCalendar( CalendarSupport::Calendar *cal )
 {
   KOEventView::setCalendar( cal );
   d->mPopup->setCalendar( cal );
   d->mMonthView->setCalendar( cal );
 }
 
-void MonthView::setIncidenceChanger( Akonadi::IncidenceChanger *changer )
+void MonthView::setIncidenceChanger( CalendarSupport::IncidenceChanger *changer )
 {
   d->mMonthView->setIncidenceChanger( changer );
 }
@@ -244,4 +244,3 @@ void MonthView::showDates( const QDate &start, const QDate &end, const QDate &pr
   Q_UNUSED( end );
   Q_UNUSED( preferredMonth );
 }
-
