@@ -22,15 +22,17 @@
   without including the source code for Qt in the source distribution.
 */
 
-#ifndef KORG_VIEWS_KOTIMESPENTVIEW_H
-#define KORG_VIEWS_KOTIMESPENTVIEW_H
+#ifndef TIMESPENTVIEW_H
+#define TIMESPENTVIEW_H
 
-#include "korganizer/baseview.h"
-#include <Akonadi/Calendar/ETMCalendar>
+#include <QTextBrowser>
 
-namespace EventViews {
-  class TimeSpentView;
-}
+#include <korganizer/baseview.h>
+
+#include <Akonadi/Item>
+
+class QDate;
+class TimeSpentWidget;
 
 /**
   This view show the time spent on each category.
@@ -43,30 +45,31 @@ class KOTimeSpentView : public KOrg::BaseView
     ~KOTimeSpentView();
 
     virtual int currentDateCount() const;
-
     virtual Akonadi::Item::List selectedIncidences()
     {
       return Akonadi::Item::List();
     }
-
     KCalCore::DateList selectedIncidenceDates()
     {
       return KCalCore::DateList();
     }
 
-    void setCalendar( const Akonadi::ETMCalendar::Ptr &cal );
-
-  public Q_SLOTS:
+  public slots:
     virtual void updateView();
     virtual void showDates( const QDate &start, const QDate &end,
                             const QDate &preferredMonth = QDate() );
     virtual void showIncidences( const Akonadi::Item::List &incidenceList, const QDate &date );
 
-    void changeIncidenceDisplay( const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType );
-    virtual CalendarSupport::CalPrinterBase::PrintType printType() const;
+    void changeIncidenceDisplay( const Akonadi::Item &, int );
+    virtual KOrg::CalPrinterBase::PrintType printType() const;
 
   private:
-    EventViews::TimeSpentView *mView;
+    TimeSpentWidget *mView;
+
+    QDate mStartDate;
+    QDate mEndDate;
+
+    friend class TimeSpentWidget;
 };
 
 #endif
