@@ -23,68 +23,71 @@
 */
 
 #include "kotodomodel.h"
-#include "koprefs.h"
 #include "koglobals.h"
-#include "kodialogmanager.h"
-#include "korganizer/incidencechangerbase.h"
+#include "koprefs.h"
+#include "kohelper.h"
 
-#include <kcal/calendar.h>
-#include <kcal/calformat.h>
-#include <kcal/incidence.h>
-#include <kcal/incidenceformatter.h>
-#include <kcal/todo.h>
+#include <calendarsupport/calendar.h>
+#include <calendarsupport/calendaradaptor.h>
+#include <calendarsupport/dndfactory.h>
+#include <calendarsupport/incidencechanger.h>
+#include <calendarsupport/kcalprefs.h>
+#include <calendarsupport/utils.h>
+
+#include <KCalCore/CalFormat>
+#include <KCalCore/Todo>
+#include <KCalUtils/IncidenceFormatter>
 
 #ifndef KORG_NODND
-  #include <kcal/icaldrag.h>
-  #include <kcal/vcaldrag.h>
-  #include <kcal/dndfactory.h>
+  #include <KCalUtils/DndFactory>
+  #include <KCalUtils/ICalDrag>
+  #include <KCalUtils/VCalDrag>
 #endif
 
-#include <kpimutils/email.h>
+#include <KPIMUtils/Email>
 
-#include <KMessageBox>
 #include <KDebug>
+#include <KLocale>
+#include <KMessageBox>
 
-#include <QString>
+#include <QBrush>
 #include <QIcon>
-#include <QHash>
-#include <QList>
-#include <QtAlgorithms>
 
 #ifndef KORG_NODND
-  #include <QDrag>
   #include <QMimeData>
 #endif
 
+using namespace KCalUtils;
+
 /** This class represents a node in the todo-tree. */
 struct KOTodoModel::TodoTreeNode : QObject
 {
-  TodoTreeNode( Todo *todo, TodoTreeNode *parent, KOTodoModel *model )
-    : mTodo( todo ), mParent( parent ), mParentListPos( 0 ),
+  TodoTreeNode( const Akonadi::Item &todo_, TodoTreeNode *parent, KOTodoModel *model )
+    : mTodo( todo_ ), mParent( parent ), mParentListPos( 0 ),
       mToDelete( false ), mModel( model )
   {
-    if ( mTodo ) {
-      mUid = mTodo->uid();
-      mModel->mTodoHash[ mUid ] = this;
+    if ( CalendarSupport::hasTodo( mTodo ) ) {
+      mItemId = mTodo.id();
+      mModel->mTodoUidHash.insert( CalendarSupport::todo( mTodo )->uid(), this );
     }
   }
 
   /** Recursively delete all TodoTreeNodes which are children of this one. */
   ~TodoTreeNode()
   {
-    if ( mTodo ) {
-      mModel->mTodoHash.remove( mUid );
+    if ( CalendarSupport::hasTodo( mTodo ) ) {
+      mModel->mTodoUidHash.remove( CalendarSupport::todo( mTodo )->uid() );
     } else {
       // root node gets deleted, clear the whole hash
-      mModel->mTodoHash.clear();
+      mModel->mTodoUidHash.clear();
     }
     qDeleteAll( mChildren );
   }
 
   /** Checks if it's save to access the todo-pointer of this node. */
-  bool isValid()
+  bool isValid() const
   {
-    return mTodo && !mToDelete;
+    return CalendarSupport::hasTodo( mTodo ) && !mToDelete;
   }
 
   /** Recursively set mToDelete to true for all todos.
@@ -103,17 +106,23 @@ struct KOTodoModel::TodoTreeNode : QObject
   void deleteMarked()
   {
     if ( mToDelete ) {
+      /*
+        I commented the following check because the item get be deleted outside of korg.
+
 #ifndef NDEBUG
+
       // all sub-todos should be marked for delete too, otherwise there is
       // something wrong
       QList<TodoTreeNode*> toCheck;
       toCheck << mChildren;
       while ( !toCheck.isEmpty() ) {
         TodoTreeNode *node = toCheck.takeFirst();
-        Q_ASSERT ( node->mToDelete || !node->mTodo->relatedTo() );
+        Q_ASSERT ( node->mToDelete || CalendarSupport::todo( node->mTodo )->relatedTo().isEmpty() );
         toCheck << node->mChildren;
       }
+
 #endif
+      */
 
       QModelIndex tmp = mModel->getModelIndex( this );
       mModel->beginRemoveRows( mModel->getModelIndex( mParent ),
@@ -133,7 +142,7 @@ struct KOTodoModel::TodoTreeNode : QObject
    *  Note: public field for performance reason, and because this
    *  class is only used internally from KOTodoModel
    */
-  Todo *mTodo;
+  Akonadi::Item mTodo;
   /** Pointer to the parent TodoTreeNode. Only the root element has no parent. */
   TodoTreeNode *mParent;
   /** Position of this TodoTreeNode in it's parents children list */
@@ -174,42 +183,41 @@ struct KOTodoModel::TodoTreeNode : QObject
     /** Pointer to the KOTodoModel owning this object */
     KOTodoModel *mModel;
     /** The uid of the Todo object, needed in the dtor where mTodo might be invalid already. */
-    QString mUid;
+    Akonadi::Item::Id mItemId;
 };
 
-KOTodoModel::KOTodoModel( Calendar *cal, QObject *parent )
-  : QAbstractItemModel( parent ), mColumnCount( DescriptionColumn + 1 )
+KOTodoModel::KOTodoModel( QObject *parent )
+  : QAbstractItemModel( parent ), mColumnCount( ColumnCount ), mCalendar( 0 ),
+    mChanger( 0 )
 {
-  mRootNode = new TodoTreeNode( 0, 0, this );
+  mRootNode = new TodoTreeNode( Akonadi::Item(), 0, this );
   mFlatView = false;
-  setCalendar( cal );
+}
 
-#ifndef KORG_NODND
-  mDndFactory = new DndFactory( cal );
-#endif
+static bool isDueToday( const Todo::Ptr &todo )
+{
+  return !todo->isCompleted() && todo->dtDue().date() == QDate::currentDate();
 }
 
 KOTodoModel::~KOTodoModel()
 {
   delete mRootNode;
-
-#ifndef KORG_NODND
-  delete mDndFactory;
-#endif
 }
 
-void KOTodoModel::setCalendar( Calendar *cal )
+void KOTodoModel::setCalendar( CalendarSupport::Calendar *cal )
 {
-  mCalendar = cal;
-  // old todos might no longer be valid, so clear them
-  clearTodos();
-  reloadTodos();
+  if ( cal != mCalendar ) {
+    mCalendar = cal;
+    // old todos might no longer be valid, so clear them
+    clearTodos();
+    reloadTodos();
+  }
 }
 
 void KOTodoModel::clearTodos()
 {
   delete mRootNode;
-  mRootNode = new TodoTreeNode( 0, 0, this );
+  mRootNode = new TodoTreeNode( Akonadi::Item(), 0, this );
   // inform all views that we cleared our internal list
   reset();
 }
@@ -225,18 +233,19 @@ void KOTodoModel::reloadTodos()
   // never delete the root node
   mRootNode->mToDelete = false;
 
-  Todo::List todoList = mCalendar->todos();
-  Todo::List::ConstIterator it;
+  Akonadi::Item::List todoList = mCalendar->todos();
+  Akonadi::Item::List::ConstIterator it;
   QList<TodoTreeNode*> changedNodes;
   for ( it = todoList.constBegin(); it != todoList.constEnd(); ++it ) {
-    TodoTreeNode *tmp = findTodo( *it );
+    TodoTreeNode *tmp = findTodo( CalendarSupport::incidence( *it )->uid() );
     if ( !tmp ) {
+      // kDebug() << "Inserting " << CalendarSupport::todo(*it)->summary()
+      //          << CalendarSupport::todo(*it)->relatedTo();
       insertTodo( *it );
     } else {
       // update pointer to the todo
       // apparently this is necessary because undo's and redo's don't modify
       // the modified todos but replace pointers to them with others
-      // TODO check if that's true, and if this is OK
       tmp->mTodo = *it;
 
       // the todo is still in the calendar, we don't delete it
@@ -256,42 +265,50 @@ void KOTodoModel::reloadTodos()
   }
 }
 
-void KOTodoModel::processChange( Incidence *incidence, int action )
+void KOTodoModel::processChange( const Akonadi::Item & aitem, int action )
 {
-  if ( incidence->type() != "Todo" ) {
+  if ( !CalendarSupport::hasTodo( aitem ) ) {
     return;
   }
 
-  Todo *todo = static_cast<Todo *>( incidence );
+  if ( action == CalendarSupport::IncidenceChanger::INCIDENCEEDITED ) {
+    TodoTreeNode *ttTodo = findTodo( CalendarSupport::incidence ( aitem )->uid() );
+    if ( !ttTodo || !ttTodo->isValid() ) {
+      return;
+    }
 
-  if ( action == KOGlobals::INCIDENCEEDITED ) {
-    TodoTreeNode *ttTodo = findTodo( todo );
-    Q_ASSERT( ttTodo );
-
-    QModelIndex miChanged = moveIfParentChanged( ttTodo, todo, false );
+    QModelIndex miChanged = moveIfParentChanged( ttTodo, aitem, false );
 
     // force the view to redraw the element even if the parent relationship
     // changed, because we can't be sure that only the relationship changed
     emit dataChanged( miChanged,
                       miChanged.sibling( miChanged.row(), mColumnCount - 1 ) );
-  } else if ( action == KOGlobals::INCIDENCEADDED ) {
-    // the todo should not be in our tree...
-    Q_ASSERT( !findTodo( todo ) );
+  } else if ( action == CalendarSupport::IncidenceChanger::INCIDENCEADDED ) {
+    const bool found = findTodo( CalendarSupport::incidence ( aitem )->uid() );
 
-    insertTodo( todo );
-  } else if ( action == KOGlobals::INCIDENCEDELETED ) {
-    TodoTreeNode *ttTodo = findTodo( todo );
-    // we can only delete todo's which are in the tree
-    Q_ASSERT( ttTodo );
-    // somebody should assure that all todo's which relate to this one
-    // are un-linked before deleting this one
-    Q_ASSERT( !ttTodo->hasChildren() );
+    // "found" can be true, with akonadi calendarview listens to ETM model signals
+    // and calls updateview, which calls reloadTodos().  I think we have lots of room
+    // for optimization and refactoring in this area. Calling reloadTodos() for one incidence
+    // doesn't justify it.
+    if ( !found ) {
+      insertTodo( aitem );
+    }
+  } else if ( action == CalendarSupport::IncidenceChanger::INCIDENCEDELETED ) {
+    TodoTreeNode *ttTodo = findTodo( CalendarSupport::incidence ( aitem )->uid() );
+    if ( !ttTodo || !ttTodo->isValid() ) {
+      return;
+    }
 
     // find the model index of the deleted incidence
     QModelIndex miDeleted = getModelIndex( ttTodo );
 
     beginRemoveRows( miDeleted.parent(), miDeleted.row(), miDeleted.row() );
     ttTodo->mParent->removeChild( miDeleted.row() );
+
+    if ( ttTodo->hasChildren() ) {
+      moveIfParentChanged( ttTodo, aitem, true );
+    }
+
     delete ttTodo;
     endRemoveRows();
   } else {
@@ -300,54 +317,15 @@ void KOTodoModel::processChange( Incidence *incidence, int action )
   }
 }
 
-QModelIndex KOTodoModel::addTodo( const QString &summary,
-                                  const QModelIndex &parent )
+Akonadi::Item KOTodoModel::todoForIndex( const QModelIndex &idx ) const
 {
-  if ( !mChanger ) {
-    return QModelIndex();
+  if ( !idx.isValid() ) {
+    return Akonadi::Item();
   }
 
-  if ( !summary.trimmed().isEmpty() ) {
-    Todo *todo = new Todo();
-    todo->setSummary( summary.trimmed() );
-    todo->setOrganizer( Person( KOPrefs::instance()->fullName(),
-                                KOPrefs::instance()->email() ) );
-    if ( parent.isValid() ) {
-      todo->setRelatedTo(
-              static_cast<TodoTreeNode *>( parent.internalPointer() )->mTodo );
-    }
-
-    if ( !mChanger->addIncidence( todo ) ) {
-      KODialogManager::errorSaveIncidence( 0, todo );
-      delete todo;
-      return QModelIndex();
-    }
-
-    return getModelIndex( findTodo( todo ) );
-  }
-
-  return QModelIndex();
-}
-
-void KOTodoModel::copyTodo( const QModelIndex &index, const QDate &date )
-{
-  if ( !mChanger || !index.isValid() ) {
-    return;
-  }
-
-  TodoTreeNode *node = static_cast<TodoTreeNode *>( index.internalPointer() );
-  Todo *todo = node->mTodo->clone();
-
-  todo->setUid( CalFormat::createUniqueId() );
-
-  KDateTime due = todo->dtDue();
-  due.setDate( date );
-  todo->setDtDue( due );
-
-  if ( !mChanger->addIncidence( todo ) ) {
-    KODialogManager::errorSaveIncidence( 0, todo );
-    delete todo;
-  }
+  TodoTreeNode *node = static_cast<TodoTreeNode *>( idx.internalPointer() );
+  Q_ASSERT( node );
+  return node->isValid() ? node->mTodo : Akonadi::Item();
 }
 
 QModelIndex KOTodoModel::getModelIndex( TodoTreeNode *node ) const
@@ -360,9 +338,10 @@ QModelIndex KOTodoModel::getModelIndex( TodoTreeNode *node ) const
   return createIndex( node->mParentListPos, 0, node );
 }
 
-QModelIndex KOTodoModel::moveIfParentChanged( TodoTreeNode *curNode, Todo *todo,
+QModelIndex KOTodoModel::moveIfParentChanged( TodoTreeNode *curNode, const Akonadi::Item &aitem,
                                               bool addParentIfMissing )
 {
+  const Todo::Ptr todo = CalendarSupport::todo( aitem );
   // find the model index of the changed incidence
   QModelIndex miChanged = getModelIndex( curNode );
 
@@ -370,30 +349,39 @@ QModelIndex KOTodoModel::moveIfParentChanged( TodoTreeNode *curNode, Todo *todo,
   TodoTreeNode *ttOldParent = curNode->mParent;
 
   // get the new parent
-  Todo *newParent = 0;
+  Todo::Ptr newParent;
 
   if ( !mFlatView ) {
     // in flat view, no todo has a parent
 
     if ( !isInHierarchyLoop( todo ) ) {
-      Incidence *inc = todo->relatedTo();
-      if ( inc && inc->type() == "Todo" ) {
-        newParent = static_cast<Todo *>( inc );
+      const QString parentUid = todo->relatedTo();
+      if ( !parentUid.isEmpty() ) {
+        Akonadi::Item parentItem = mCalendar->itemForIncidenceUid( parentUid );
+        Incidence::Ptr inc = CalendarSupport::incidence( parentItem );
+        if ( inc && inc->type() == Incidence::TypeTodo ) {
+          newParent = Todo::Ptr( static_cast<Todo *>( inc ->clone() ) );
+        }
       }
     }
   }
 
   // check if the relation to the parent has changed
-  if ( ( newParent == 0 && ttOldParent->mTodo != 0 ) ||
-       ( newParent != 0 && ttOldParent->mTodo == 0 ) ||
-       ( newParent != 0 && ttOldParent->mTodo != 0 &&
-         newParent->uid() != ttOldParent->mTodo->uid() ) ) {
+  if ( ( newParent == 0 && CalendarSupport::hasTodo( ttOldParent->mTodo ) ) ||  // became parentless
+       ( newParent != 0 && !CalendarSupport::hasTodo( ttOldParent->mTodo ) ) ||  // gained a parent
+       ( newParent != 0 && CalendarSupport::hasTodo( ttOldParent->mTodo ) &&     // changed parent
+         newParent->uid() != CalendarSupport::todo( ttOldParent->mTodo )->uid() ) ) {
+
+    kDebug() << "parent changed";
+
     // find the node and model index of the new parent
     TodoTreeNode *ttNewParent = 0;
     if ( newParent ) {
-      ttNewParent = findTodo( newParent );
+      Akonadi::Item newParentItem;
+      newParentItem.setPayload<Todo::Ptr>(newParent);
+      ttNewParent = findTodo( CalendarSupport::incidence ( newParentItem )->uid() );
       if ( !ttNewParent && addParentIfMissing ) {
-        ttNewParent = insertTodo( newParent );
+        ttNewParent = insertTodo( newParentItem );
       }
     } else {
       ttNewParent = mRootNode;
@@ -438,39 +426,56 @@ QModelIndex KOTodoModel::moveIfParentChanged( TodoTreeNode *curNode, Todo *todo,
   return miChanged;
 }
 
-KOTodoModel::TodoTreeNode *KOTodoModel::findTodo( const Todo *todo )
+KOTodoModel::TodoTreeNode *KOTodoModel::findTodo( const QString &uid ) const
 {
-  Q_ASSERT( todo );
-  return mTodoHash.value( todo->uid() );
+  return mTodoUidHash.value( uid );
 }
 
-bool KOTodoModel::isInHierarchyLoop( const Todo *todo ) const {
+void KOTodoModel::expandTodoIfNeeded( const Akonadi::Item &todoItem )
+{
+  Todo::Ptr todo = CalendarSupport::todo( todoItem );
+  if ( !todo ) {
+    return;
+  }
 
+  if ( todo->isOverdue() || isDueToday( todo ) ) {
+    QModelIndex index = getModelIndex( findTodo( CalendarSupport::incidence( todoItem )->uid() ) );
+    emit expandIndex( index );
+  }
+}
+
+bool KOTodoModel::isInHierarchyLoop( const Todo::Ptr &todo ) const
+{
   if ( !todo ) {
     return false;
   }
 
-  Incidence *i = todo->relatedTo();
-  QList<Incidence *> processedParents;
+  QString parentUid = todo->relatedTo();
 
-  // Lets iterate through all parents, if we find one with the same
-  // uid then there's a loop.
-  while ( i ) {
-    if ( i->uid() == todo->uid() ) {
-      // loop detected!
-      return true;
-    } else {
-      if ( !processedParents.contains( i ) ) {
-        processedParents.append( i );
-        // Next parent
-        i = i->relatedTo();
+  if ( !parentUid.isEmpty() ) {
+    Incidence::Ptr i = CalendarSupport::incidence( mCalendar->itemForIncidenceUid( parentUid ) );
+    QList<Incidence::Ptr > processedParents;
+
+    // Lets iterate through all parents, if we find one with the same
+    // uid then there's a loop.
+    while ( i ) {
+      if ( i->uid() == todo->uid() ) {
+        // loop detected!
+        return true;
       } else {
-        // There's a loop but this to-do isn't in it
-        // the loop is at a higher level, e.g:
-        // t1->t2->t3->t4->t3->t4->t3->t4->t3..
-        // t1 and t2 can be added as sons of t3 without
-        // danger of inifinit looping
-        return false;
+        if ( !processedParents.contains( i ) ) {
+          processedParents.append( i );
+          // Next parent
+          parentUid = todo->relatedTo();
+          i = CalendarSupport::incidence( mCalendar->itemForIncidenceUid( parentUid ) );
+        } else {
+          // There's a loop but this to-do isn't in it
+          // the loop is at a higher level, e.g:
+          // t1->t2->t3->t4->t3->t4->t3->t4->t3..
+          // t1 and t2 can be added as sons of t3 without
+          // danger of infinit looping
+          return false;
+        }
       }
     }
   }
@@ -478,60 +483,66 @@ bool KOTodoModel::isInHierarchyLoop( const Todo *todo ) const {
   return false;
 }
 
-KOTodoModel::TodoTreeNode *KOTodoModel::insertTodo( Todo *todo,
+KOTodoModel::TodoTreeNode *KOTodoModel::insertTodo( const Akonadi::Item &todoItem,
                                                     bool checkRelated )
 {
-  Incidence *incidence = todo->relatedTo();
-  if ( !mFlatView && checkRelated &&
-       incidence && incidence->type() == "Todo" ) {
-    // Use static_cast, checked for type already
-    Todo *relatedTodo = static_cast<Todo *>(incidence);
+  const Todo::Ptr todo = CalendarSupport::todo( todoItem );
+  if ( !mFlatView && checkRelated && todo && !todo->relatedTo().isEmpty() ) {
+    const QString parentUid = todo->relatedTo();
+    Akonadi::Item parentItem = mCalendar->itemForIncidenceUid( parentUid );
+    Incidence::Ptr incidence = CalendarSupport::incidence( parentItem );
+    Todo::Ptr relatedTodo = incidence.dynamicCast<Todo>();
 
-    // check if there are recursively linked todos
-
-    if ( isInHierarchyLoop( todo ) ) {
+    // check if there are recursively linked todos, or if we got broken input data
+    if ( isInHierarchyLoop( todo ) || !relatedTodo ) {
       // recursion detected, break recursion
-      return insertTodo( todo, false );
+      return insertTodo( todoItem, false );
     }
 
+    // FIXME(AKONADI_PORT) how to handle the related incidences where we don't know the item?
+    Akonadi::Item relatedTodoItem;
+    relatedTodoItem.setPayload( Todo::Ptr( relatedTodo->clone() ) );
+
     // if the parent is not already in the tree, we have to insert it first.
     // necessary because we can't rely on todos coming in a defined order.
-    TodoTreeNode *parent = findTodo( relatedTodo );
+    TodoTreeNode *parent = findTodo( relatedTodo->uid() );
+
     if ( !parent ) {
-      parent = insertTodo( relatedTodo, checkRelated );
+      parent = insertTodo( relatedTodoItem, checkRelated );
     }
 
     beginInsertRows( getModelIndex( parent ), parent->childrenCount(),
                                               parent->childrenCount() );
 
     // add the todo under it's parent
-    TodoTreeNode *ret = new TodoTreeNode( todo, parent, this );
+    TodoTreeNode *ret = new TodoTreeNode( todoItem, parent, this );
     parent->addChild( ret );
 
     endInsertRows();
-
+    expandTodoIfNeeded( todoItem );
     return ret;
   } else {
     beginInsertRows( getModelIndex( mRootNode ), mRootNode->childrenCount(),
                                                  mRootNode->childrenCount() );
 
     // add the todo as root item
-    TodoTreeNode *ret = new TodoTreeNode( todo, mRootNode, this );
+    TodoTreeNode *ret = new TodoTreeNode( todoItem, mRootNode, this );
     mRootNode->addChild( ret );
 
     endInsertRows();
+    expandTodoIfNeeded( todoItem );
     return ret;
   }
 }
 
 void KOTodoModel::setFlatView( bool flatView )
 {
-  if ( mFlatView == flatView ) {
-    return;
+  if ( mFlatView != flatView ) {
+    mFlatView = flatView;
+    reloadTodos();
+    // Tell both views, so they can disable drag n drop if needed
+    emit flatViewChanged( flatView );
   }
-
-  mFlatView = flatView;
-  reloadTodos();
 }
 
 Qt::ItemFlags KOTodoModel::flags( const QModelIndex &index ) const
@@ -549,9 +560,9 @@ Qt::ItemFlags KOTodoModel::flags( const QModelIndex &index ) const
 
   ret |= Qt::ItemIsDragEnabled;
 
-  Todo *todo = node->mTodo;
+  const Todo::Ptr todo = CalendarSupport::todo( node->mTodo );
 
-  if ( !todo->isReadOnly() ) {
+  if ( mCalendar->hasChangeRights( node->mTodo ) ) {
     // the following columns are editable:
     switch ( index.column() ) {
     case SummaryColumn:
@@ -595,22 +606,26 @@ QModelIndex KOTodoModel::index( int row, int column,
     return createIndex( row, column, mRootNode->childAt( row ) );
   } else {
     TodoTreeNode *node = static_cast<TodoTreeNode *>( parent.internalPointer() );
-    return createIndex( row, column, node->childAt( row ) );
+    if ( node->isValid() ) {
+      return createIndex( row, column, node->childAt( row ) );
+    } else {
+      return QModelIndex();
+    }
   }
 }
 
 QModelIndex KOTodoModel::parent( const QModelIndex &child ) const
 {
-  if ( !child.isValid() ) {
+  if ( !child.isValid() || !child.internalPointer() ) {
     return QModelIndex();
   }
 
   TodoTreeNode *node = static_cast<TodoTreeNode *>( child.internalPointer() );
-  // every model index given out by us has a valid internal pointer, so
-  // that's save:
-  TodoTreeNode *parent = node->mParent;
-
-  return getModelIndex( parent );
+  if ( node->isValid() ) {
+    return getModelIndex( node->mParent );
+  } else {
+    return QModelIndex();
+  }
 }
 
 int KOTodoModel::columnCount( const QModelIndex &/*parent*/ ) const
@@ -627,10 +642,11 @@ int KOTodoModel::rowCount( const QModelIndex &parent ) const
   if ( parent.column() == 0 ) {
     // only items in the first column have children
     TodoTreeNode *node = static_cast<TodoTreeNode *>( parent.internalPointer() );
-    return node->childrenCount();
-  } else {
-    return 0;
+    if ( node->isValid() ) {
+      return node->childrenCount();
+    }
   }
+  return 0;
 }
 
 QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
@@ -644,7 +660,7 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
     return QVariant();
   }
 
-  Todo *todo = node->mTodo;
+  const Todo::Ptr todo = CalendarSupport::todo( node->mTodo );
 
   if ( role == Qt::DisplayRole ) {
     switch ( index.column() ) {
@@ -663,7 +679,7 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
       return QVariant( todo->percentComplete() );
     case DueDateColumn:
       if ( todo->hasDueDate() && todo->dtDue().date().isValid() ) {
-        return QVariant( todo->dtDueStr() );
+        return QVariant( IncidenceFormatter::dateToString( todo->dtDue() ) );
       } else {
         return QVariant( QString() );
       }
@@ -675,6 +691,8 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
     }
     case DescriptionColumn:
       return QVariant( todo->description() );
+    case CalendarColumn:
+      return QVariant( CalendarSupport::displayName( node->mTodo.parentCollection() ) );
     }
     return QVariant();
   }
@@ -695,6 +713,8 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
       return QVariant( todo->categories() );
     case DescriptionColumn:
       return QVariant( todo->description() );
+    case CalendarColumn:
+      return QVariant( CalendarSupport::displayName( node->mTodo.parentCollection() ) );
     }
     return QVariant();
   }
@@ -703,7 +723,9 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
   if ( role == Qt::ToolTipRole ) {
     if ( KOPrefs::instance()->enableToolTips() ) {
       return QVariant( IncidenceFormatter::toolTipStr(
-                         todo, true, KOPrefs::instance()->timeSpec() ) );
+                         CalendarSupport::displayName( node->mTodo.parentCollection() ),
+                         todo, QDate(), true,
+                         CalendarSupport::KCalPrefs::instance()->timeSpec() ) );
     } else {
       return QVariant();
     }
@@ -713,10 +735,10 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
   if ( role == Qt::BackgroundRole ) {
     if ( todo->isOverdue() ) {
       return QVariant(
-        QBrush( KOPrefs::instance()->agendaCalendarItemsToDosOverdueBackgroundColor() ) );
-    } else if ( !todo->isCompleted() && todo->dtDue().date() == QDate::currentDate() ) {
+        QBrush( KOPrefs::instance()->todoOverdueColor() ) );
+    } else if ( isDueToday( todo ) ) {
       return QVariant(
-        QBrush( KOPrefs::instance()->agendaCalendarItemsToDosDueTodayBackgroundColor() ) );
+        QBrush( KOPrefs::instance()->todoDueTodayColor() ) );
     }
   }
 
@@ -729,8 +751,10 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
     }
   }
 
-  // item for recurring todos
-  if ( role == Qt::DecorationRole && index.column() == DueDateColumn ) {
+  // icon for recurring todos
+  // It's in the summary column so you don't accidentally click
+  // the checkbox ( which increments the next occurrence date ).
+  if ( role == Qt::DecorationRole && index.column() == SummaryColumn ) {
     if ( todo->recurs() ) {
       return QVariant( QIcon( KOGlobals::self()->smallIcon( "task-recurring" ) ) );
     }
@@ -740,13 +764,14 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
   if ( role == Qt::DecorationRole && index.column() == SummaryColumn ) {
     QStringList categories = todo->categories();
     if ( !categories.isEmpty() ) {
-      return QVariant( KOPrefs::instance()->categoryColor( categories.first() ) );
+      return
+        QVariant( CalendarSupport::KCalPrefs::instance()->categoryColor( categories.first() ) );
     }
   }
 
   if ( role == TodoRole ) {
     QVariant ret( QMetaType::VoidStar );
-    ret.setValue( static_cast<void *>( todo ) );
+    ret.setValue( node->mTodo );
     return ret;
   }
 
@@ -760,6 +785,18 @@ QVariant KOTodoModel::data( const QModelIndex &index, int role ) const
     }
   }
 
+  if ( role == Qt::TextAlignmentRole ) {
+    switch ( index.column() ) {
+      // If you change this, change headerData() too.
+      case RecurColumn:
+      case PriorityColumn:
+      case PercentColumn:
+      case DueDateColumn:
+        return QVariant( Qt::AlignHCenter | Qt::AlignVCenter );
+    }
+    return QVariant( Qt::AlignLeft | Qt::AlignVCenter );
+  }
+
   return QVariant();
 }
 
@@ -789,14 +826,18 @@ QVariant KOTodoModel::headerData( int column,
       return QVariant( i18n( "Categories" ) );
     case DescriptionColumn:
       return QVariant( i18n( "Description" ) );
+    case CalendarColumn:
+      return QVariant( i18n( "Calendar" ) );
     }
   }
 
   if ( role == Qt::TextAlignmentRole ) {
     switch ( column ) {
+      // If you change this, change data() too.
       case RecurColumn:
       case PriorityColumn:
       case PercentColumn:
+      case DueDateColumn:
         return QVariant( Qt::AlignHCenter );
     }
     return QVariant();
@@ -810,19 +851,32 @@ bool KOTodoModel::setData( const QModelIndex &index, const QVariant &value, int
     return false;
   }
 
-  Todo *todo = static_cast<TodoTreeNode *>( index.internalPointer() )->mTodo;
+  TodoTreeNode *node = static_cast<TodoTreeNode *>( index.internalPointer() );
+  if ( !node->isValid() ) {
+    return false;
+  }
 
-  if ( !todo->isReadOnly() && mChanger->beginChange( todo ) ) {
-    Todo *oldTodo = todo->clone();
-    int modified = KOGlobals::UNKNOWN_MODIFIED;
+  const QVariant oldValue = data( index, role );
+
+  if ( oldValue == value ) {
+    // Nothing changed, the user used one of the QStyledDelegate's editors but seted the old value
+    // Lets just skip this then and avoid a roundtrip to akonadi, and avoid sending invitations
+    return true;
+  }
+
+  const Todo::Ptr todo = CalendarSupport::todo( node->mTodo );
+
+  if ( mCalendar->hasChangeRights( node->mTodo ) ) {
+    Todo::Ptr oldTodo( todo->clone() );
+    CalendarSupport::IncidenceChanger::WhatChanged modified =
+      CalendarSupport::IncidenceChanger::UNKNOWN_MODIFIED;
 
     if ( role == Qt::CheckStateRole && index.column() == 0 ) {
-      todo->setCompleted( static_cast<Qt::CheckState>( value.toInt() ) == Qt::Checked ?
-                          true : false );
+      todo->setCompleted( static_cast<Qt::CheckState>( value.toInt() ) == Qt::Checked );
       if ( todo->recurs() ) {
-        modified = KOGlobals::COMPLETION_MODIFIED_WITH_RECURRENCE;
+        modified = CalendarSupport::IncidenceChanger::COMPLETION_MODIFIED_WITH_RECURRENCE;
       } else {
-        modified = KOGlobals::COMPLETION_MODIFIED;
+        modified = CalendarSupport::IncidenceChanger::COMPLETION_MODIFIED;
       }
     }
 
@@ -831,16 +885,16 @@ bool KOTodoModel::setData( const QModelIndex &index, const QVariant &value, int
         case SummaryColumn:
           if ( !value.toString().isEmpty() ) {
             todo->setSummary( value.toString() );
-            modified = KOGlobals::SUMMARY_MODIFIED;
+            modified = CalendarSupport::IncidenceChanger::SUMMARY_MODIFIED;
           }
           break;
         case PriorityColumn:
           todo->setPriority( value.toInt() );
-          modified = KOGlobals::PRIORITY_MODIFIED;
+          modified = CalendarSupport::IncidenceChanger::PRIORITY_MODIFIED;
           break;
         case PercentColumn:
           todo->setPercentComplete( value.toInt() );
-          modified = KOGlobals::COMPLETION_MODIFIED;
+          modified = CalendarSupport::IncidenceChanger::COMPLETION_MODIFIED;
           break;
         case DueDateColumn:
           {
@@ -848,34 +902,34 @@ bool KOTodoModel::setData( const QModelIndex &index, const QVariant &value, int
             tmp.setDate( value.toDate() );
             todo->setDtDue( tmp );
             todo->setHasDueDate( value.toDate().isValid() );
-            modified = KOGlobals::DATE_MODIFIED;
+            modified = CalendarSupport::IncidenceChanger::DATE_MODIFIED;
           }
           break;
         case CategoriesColumn:
           todo->setCategories( value.toStringList() );
-          modified = KOGlobals::CATEGORY_MODIFIED;
+          modified = CalendarSupport::IncidenceChanger::CATEGORY_MODIFIED;
           break;
         case DescriptionColumn:
           todo->setDescription( value.toString() );
-          modified = KOGlobals::DESCRIPTION_MODIFIED;
+          modified = CalendarSupport::IncidenceChanger::DESCRIPTION_MODIFIED;
           break;
       }
     }
 
-    if ( modified != KOGlobals::UNKNOWN_MODIFIED ) {
-      mChanger->changeIncidence( oldTodo, todo, modified );
+    if ( modified != CalendarSupport::IncidenceChanger::UNKNOWN_MODIFIED ) {
+      mChanger->changeIncidence( oldTodo, node->mTodo, modified, 0 );
       // changeIncidence will eventually call the view's
       // changeIncidenceDisplay method, which in turn
       // will call processChange. processChange will then emit
       // dataChanged to the view, so we don't have to
       // do it here
     }
-    mChanger->endChange( todo );
-    delete oldTodo;
 
     return true;
   } else {
-    KODialogManager::errorSaveIncidence( 0, todo );
+    if ( !( role == Qt::CheckStateRole && index.column() == 0 ) ) {
+      KOHelper::showSaveIncidenceErrorMsg( 0, todo ); //TODO pass parent
+    }
     return false;
   }
 }
@@ -898,15 +952,14 @@ QStringList KOTodoModel::mimeTypes() const
 
 QMimeData *KOTodoModel::mimeData( const QModelIndexList &indexes ) const
 {
+  Akonadi::Item::List items;
   Q_FOREACH ( const QModelIndex &index, indexes ) {
-    Todo *todo = static_cast<TodoTreeNode *>( index.internalPointer() )->mTodo;
-
-    return mDndFactory->createMimeData( todo );
-
-   //TODO implement dragging of more than one element
+    const TodoTreeNode * const node = static_cast<TodoTreeNode *>( index.internalPointer() );
+    if ( node->isValid() && !items.contains( node->mTodo ) ) {
+      items.push_back( node->mTodo );
+    }
   }
-
-  return new QMimeData();
+  return CalendarSupport::createMimeData( items, mCalendar->timeSpec() );
 }
 
 bool KOTodoModel::dropMimeData( const QMimeData *data, Qt::DropAction action,
@@ -923,48 +976,50 @@ bool KOTodoModel::dropMimeData( const QMimeData *data, Qt::DropAction action,
 
   if ( mCalendar && mChanger &&
        ( ICalDrag::canDecode( data ) || VCalDrag::canDecode( data ) ) ) {
-    Todo *todo = mDndFactory->createDropTodo( data );
-    Event *event = mDndFactory->createDropEvent( data );
+    CalendarSupport::DndFactory dndFactory (
+      CalendarSupport::CalendarAdaptor::Ptr(
+        new CalendarSupport::CalendarAdaptor( mCalendar, 0 ) ), true );
+    Todo::Ptr t = dndFactory.createDropTodo( data );
+    Event::Ptr e = dndFactory.createDropEvent( data );
 
-    if ( todo ) {
+    if ( t ) {
       // we don't want to change the created todo, but the one which is already
       // stored in our calendar / tree
-      TodoTreeNode *ttTodo = findTodo( todo );
+      TodoTreeNode *ttTodo = findTodo( t->uid() );
       Q_ASSERT( ttTodo ); //TODO if the todo is not found, just insert a new one
-      delete todo;
-      todo = ttTodo->mTodo;
+      Todo::Ptr todo = CalendarSupport::todo( ttTodo->mTodo );
 
-      Todo *destTodo = 0;
+      Todo::Ptr destTodo;
       if ( parent.isValid() ) {
-        destTodo = static_cast<TodoTreeNode *>( parent.internalPointer() )->mTodo;
+        TodoTreeNode *node = static_cast<TodoTreeNode *>( parent.internalPointer() );
+        if ( node->isValid() ) {
+          destTodo = CalendarSupport::todo( node->mTodo );
+        }
       }
 
-      Incidence *tmp = destTodo;
+      Incidence::Ptr tmp = destTodo;
       while ( tmp ) {
-        if ( *tmp == *todo ) {
+        if ( tmp->uid() == todo->uid() ) {
           KMessageBox::information(
             0,
             i18n( "Cannot move to-do to itself or a child of itself." ),
             i18n( "Drop To-do" ), "NoDropTodoOntoItself" );
           return false;
         }
-        tmp = tmp->relatedTo();
+        const QString parentUid = tmp->relatedTo();
+        tmp = CalendarSupport::incidence( mCalendar->itemForIncidenceUid( parentUid ) );
       }
 
-      if ( mChanger->beginChange( todo ) ) {
-        Todo *oldTodo = todo->clone();
-        todo->setRelatedTo( destTodo );
-        mChanger->changeIncidence( oldTodo, todo, KOGlobals::RELATION_MODIFIED );
-        mChanger->endChange( todo );
-        // again, no need to emit dataChanged, that's done by processChange
+      Todo::Ptr oldTodo = Todo::Ptr( todo->clone() );
+      // destTodo is empty when we drag a to-do out of a relationship
+      todo->setRelatedTo( destTodo ? destTodo->uid() : QString() );
+      mChanger->changeIncidence( oldTodo, ttTodo->mTodo,
+                                 CalendarSupport::IncidenceChanger::RELATION_MODIFIED, 0 );
 
-        delete oldTodo;
-        return true;
-      } else {
-        KODialogManager::errorSaveIncidence( 0, todo );
-        return false;
-      }
-    } else if ( event ) {
+      // again, no need to emit dataChanged, that's done by processChange
+      return true;
+
+    } else if ( e ) {
       // TODO: Implement dropping an event onto a to-do: Generate a relationship to the event!
     } else {
       if ( !parent.isValid() ) {
@@ -973,41 +1028,32 @@ bool KOTodoModel::dropMimeData( const QMimeData *data, Qt::DropAction action,
         return false;
       }
 
-      Todo *destTodo = static_cast<TodoTreeNode *>( parent.internalPointer() )->mTodo;
+      TodoTreeNode *node = static_cast<TodoTreeNode *>( parent.internalPointer() );
+      Todo::Ptr destTodo = CalendarSupport::todo( node->mTodo );
 
       if ( data->hasText() ) {
         QString text = data->text();
 
-        if( mChanger->beginChange( destTodo ) ) {
-          Todo *oldTodo = destTodo->clone();
+        Todo::Ptr oldTodo = Todo::Ptr( destTodo->clone() );
 
-          if( text.startsWith( "file:" ) ) {
-            destTodo->addAttachment( new Attachment( text ) );
-          } else {
-            QStringList emails = KPIMUtils::splitAddressList( text );
-            for ( QStringList::ConstIterator it = emails.constBegin();
-                  it != emails.constEnd(); ++it ) {
-              QString name, email, comment;
-              if ( KPIMUtils::splitAddress( *it, name, email, comment ) ==
-                   KPIMUtils::AddressOk ) {
-                destTodo->addAttendee( new Attendee( name, email ) );
-              }
+        if( text.startsWith( QLatin1String( "file:" ) ) ) {
+          destTodo->addAttachment( Attachment::Ptr( new Attachment( text ) ) );
+        } else {
+          QStringList emails = KPIMUtils::splitAddressList( text );
+          for ( QStringList::ConstIterator it = emails.constBegin();
+                it != emails.constEnd(); ++it ) {
+            QString name, email, comment;
+            if ( KPIMUtils::splitAddress( *it, name, email, comment ) ==
+                 KPIMUtils::AddressOk ) {
+              destTodo->addAttendee( Attendee::Ptr( new Attendee( name, email ) ) );
             }
           }
-          mChanger->changeIncidence( oldTodo, destTodo );
-          mChanger->endChange( destTodo );
-
-          delete oldTodo;
-          return true;
-        } else {
-          KODialogManager::errorSaveIncidence( 0, destTodo );
-          return false;
         }
+        mChanger->changeIncidence( oldTodo, node->mTodo,
+                                   CalendarSupport::IncidenceChanger::RELATION_MODIFIED, 0 );
+        return true;
       }
     }
-  } else {
-    kDebug() << "Drop was not decodable";
-    return false;
   }
 
   return false;
