@@ -24,43 +24,37 @@
 
 #include "kowhatsnextview.h"
 #include "koglobals.h"
-#include "koprefs.h"
-#include "koeventviewerdialog.h"
 
-#include <kcal/calendar.h>
+#include <calendarsupport/calendar.h>
+#include <calendarsupport/kcalprefs.h>
+#include <calendarsupport/utils.h>
 
-#include <kglobal.h>
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kmessagebox.h>
+#include <kcalutils/incidenceformatter.h>
+#include <kcalcore/todo.h>
 
-#include <QLayout>
-#include <QTextCodec>
-#include <QFileInfo>
-#include <QLabel>
-#include <QVBoxLayout>
 #include <QBoxLayout>
 
-using namespace KOrg;
+using namespace KCalCore;
+using namespace KCalUtils;
 
 void WhatsNextTextBrowser::setSource( const QUrl &name )
 {
   QString uri = name.toString();
-  if ( uri.startsWith( "event:" ) ) {
+  if ( uri.startsWith( QLatin1String( "event:" ) ) ) {
     emit showIncidence( uri );
-  } else if ( uri.startsWith( "todo:" ) ) {
+  } else if ( uri.startsWith( QLatin1String( "todo:" ) ) ) {
     emit showIncidence( uri );
   } else {
     KTextBrowser::setSource( uri );
   }
 }
 
-KOWhatsNextView::KOWhatsNextView( Calendar *calendar, QWidget *parent )
-  : KOrg::BaseView( calendar, parent )
+KOWhatsNextView::KOWhatsNextView( QWidget *parent )
+  : KOrg::BaseView( parent )
 {
   mView = new WhatsNextTextBrowser( this );
-  connect( mView, SIGNAL(showIncidence(const QString &)),
-           SLOT(showIncidence(const QString &)) );
+  connect( mView, SIGNAL(showIncidence(QString)),
+           SLOT(showIncidence(QString)) );
 
   QBoxLayout *topLayout = new QVBoxLayout( this );
   topLayout->addWidget(mView);
@@ -70,7 +64,7 @@ KOWhatsNextView::~KOWhatsNextView()
 {
 }
 
-int KOWhatsNextView::currentDateCount()
+int KOWhatsNextView::currentDateCount() const
 {
   return mStartDate.daysTo( mEndDate );
 }
@@ -78,14 +72,14 @@ int KOWhatsNextView::currentDateCount()
 void KOWhatsNextView::updateView()
 {
   KIconLoader kil( "korganizer" );
-  QString *ipath = new QString();
+  QString ipath;
   kil.loadIcon( "office-calendar", KIconLoader::NoGroup, 32,
-                KIconLoader::DefaultState, QStringList(), ipath );
+                KIconLoader::DefaultState, QStringList(), &ipath );
 
   mText = "<table width=\"100%\">\n";
   mText += "<tr bgcolor=\"#3679AD\"><td><h1>";
   mText += "<img src=\"";
-  mText += *ipath;
+  mText += ipath;
   mText += "\">";
   mText += "<font color=\"white\"> ";
   mText += i18n( "What's Next?" ) + "</font></h1>";
@@ -102,26 +96,26 @@ void KOWhatsNextView::updateView()
   }
   mText+="</h2>\n";
 
-  Event::List events;
-  KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
+  Akonadi::Item::List events;
+  KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
 
   events = calendar()->events( mStartDate, mEndDate, timeSpec, false );
-  calendar()->sortEvents( &events, EventSortStartDate, SortDirectionAscending );
+  events = calendar()->sortEvents( events, CalendarSupport::EventSortStartDate,
+                                   CalendarSupport::SortDirectionAscending );
 
   if ( events.count() > 0 ) {
     mText += "<p></p>";
     kil.loadIcon( "view-calendar-day", KIconLoader::NoGroup, 22,
-                  KIconLoader::DefaultState, QStringList(), ipath );
+                  KIconLoader::DefaultState, QStringList(), &ipath );
     mText += "<h2><img src=\"";
-    mText += *ipath;
+    mText += ipath;
     mText += "\">";
     mText += i18n( "Events:" ) + "</h2>\n";
     mText += "<table>\n";
-    Event::List::ConstIterator it;
-    for ( it = events.constBegin(); it != events.constEnd(); ++it ) {
-      Event *ev = *it;
+    Q_FOREACH ( const Akonadi::Item &evItem, events ) {
+      Event::Ptr ev = CalendarSupport::event( evItem );
       if ( !ev->recurs() ) {
-        appendEvent( ev );
+        appendEvent( evItem );
       } else {
         Recurrence *recur = ev->recurrence();
         int duration = ev->dtStart().secsTo( ev->dtEnd() );
@@ -129,7 +123,7 @@ void KOWhatsNextView::updateView()
         KDateTime end = start.addSecs( duration );
         KDateTime endDate( mEndDate, QTime( 23, 59, 59 ), timeSpec );
         if ( end.date() >= mStartDate ) {
-          appendEvent( ev, start.dateTime(), end.dateTime() );
+          appendEvent( evItem, start.dateTime(), end.dateTime() );
         }
         DateTimeList times = recur->timesInInterval( start, endDate );
         int count = times.count();
@@ -142,7 +136,7 @@ void KOWhatsNextView::updateView()
             --count;  // list overflow
           }
           for ( ;  i < count && times[i].date() <= mEndDate;  ++i ) {
-            appendEvent( ev, times[i].dateTime() );
+            appendEvent( evItem, times[i].dateTime() );
           }
         }
       }
@@ -151,29 +145,29 @@ void KOWhatsNextView::updateView()
   }
 
   mTodos.clear();
-  Todo::List todos = calendar()->todos( TodoSortDueDate, SortDirectionAscending );
+  Akonadi::Item::List todos = calendar()->todos( CalendarSupport::TodoSortDueDate,
+                                        CalendarSupport::SortDirectionAscending );
   if ( todos.count() > 0 ) {
     kil.loadIcon( "view-calendar-tasks", KIconLoader::NoGroup, 22,
-                  KIconLoader::DefaultState, QStringList(), ipath );
+                  KIconLoader::DefaultState, QStringList(), &ipath );
     mText += "<h2><img src=\"";
-    mText += *ipath;
+    mText += ipath;
     mText += "\">";
     mText += i18n( "To-do:" ) + "</h2>\n";
     mText += "<ul>\n";
-    Todo::List::ConstIterator it;
-    for ( it = todos.constBegin(); it != todos.constEnd(); ++it ) {
-      Todo *todo = *it;
+    Q_FOREACH( const Akonadi::Item & todoItem, todos ) {
+      Todo::Ptr todo = CalendarSupport::todo( todoItem );
       if ( !todo->isCompleted() && todo->hasDueDate() && todo->dtDue().date() <= mEndDate ) {
-        appendTodo( todo );
+        appendTodo( todoItem );
       }
     }
     bool gotone = false;
     int priority = 1;
     while ( !gotone && priority <= 9 ) {
-      for ( it = todos.constBegin(); it != todos.constEnd(); ++it ) {
-        Todo *todo = *it;
+      Q_FOREACH( const Akonadi::Item & todoItem, todos ) {
+        Todo::Ptr todo = CalendarSupport::todo( todoItem );
         if ( !todo->isCompleted() && ( todo->priority() == priority ) ) {
-          appendTodo( todo );
+          appendTodo( todoItem );
           gotone = true;
         }
       }
@@ -182,49 +176,47 @@ void KOWhatsNextView::updateView()
     mText += "</ul>\n";
   }
 
-  QStringList myEmails( KOPrefs::instance()->allEmails() );
+  QStringList myEmails( CalendarSupport::KCalPrefs::instance()->allEmails() );
   int replies = 0;
   events = calendar()->events( QDate::currentDate(), QDate( 2975, 12, 6 ), timeSpec );
-  Event::List::ConstIterator it2;
-  for ( it2 = events.constBegin(); it2 != events.constEnd(); ++it2 ) {
-    Event *ev = *it2;
-    Attendee *me = ev->attendeeByMails( myEmails );
+  Q_FOREACH ( const Akonadi::Item &evItem, events ) {
+    Event::Ptr ev = CalendarSupport::event( evItem );
+    Attendee::Ptr me = ev->attendeeByMails( myEmails );
     if ( me != 0 ) {
       if ( me->status() == Attendee::NeedsAction && me->RSVP() ) {
         if ( replies == 0 ) {
           mText += "<p></p>";
-          kil.loadIcon( "mail-reply", KIconLoader::NoGroup, 22,
-                        KIconLoader::DefaultState, QStringList(), ipath );
+          kil.loadIcon( "mail-reply-sender", KIconLoader::NoGroup, 22,
+                        KIconLoader::DefaultState, QStringList(), &ipath );
           mText += "<h2><img src=\"";
-          mText += *ipath;
+          mText += ipath;
           mText += "\">";
           mText += i18n( "Events and to-dos that need a reply:" ) + "</h2>\n";
           mText += "<table>\n";
         }
         replies++;
-        appendEvent( ev );
+        appendEvent( evItem );
       }
     }
   }
   todos = calendar()->todos();
-  Todo::List::ConstIterator it3;
-  for ( it3 = todos.constBegin(); it3 != todos.constEnd(); ++it3 ) {
-    Todo *to = *it3;
-    Attendee *me = to->attendeeByMails( myEmails );
+  Q_FOREACH( const Akonadi::Item & todoItem, todos ) {
+    Todo::Ptr to = CalendarSupport::todo( todoItem );
+    Attendee::Ptr me = to->attendeeByMails( myEmails );
     if ( me != 0 ) {
       if ( me->status() == Attendee::NeedsAction && me->RSVP() ) {
         if ( replies == 0 ) {
           mText += "<p></p>";
-          kil.loadIcon( "mail-reply", KIconLoader::NoGroup, 22,
-                        KIconLoader::DefaultState, QStringList(), ipath );
+          kil.loadIcon( "mail-reply-sender", KIconLoader::NoGroup, 22,
+                        KIconLoader::DefaultState, QStringList(), &ipath );
           mText += "<h2><img src=\"";
-          mText += *ipath;
+          mText += ipath;
           mText += "\">";
           mText += i18n( "Events and to-dos that need a reply:" ) + "</h2>\n";
           mText += "<table>\n";
         }
         replies++;
-        appendEvent( to );
+        appendEvent( todoItem );
       }
     }
   }
@@ -234,28 +226,30 @@ void KOWhatsNextView::updateView()
 
   mText += "</td></tr>\n</table>\n";
 
-  delete ipath;
-
   mView->setText(mText);
 }
 
-void KOWhatsNextView::showDates( const QDate &start, const QDate &end )
+void KOWhatsNextView::showDates( const QDate &start, const QDate &end, const QDate & )
 {
   mStartDate = start;
   mEndDate = end;
   updateView();
 }
 
-void KOWhatsNextView::showIncidences( const Incidence::List & )
+void KOWhatsNextView::showIncidences( const Akonadi::Item::List &incidenceList, const QDate &date )
 {
+  Q_UNUSED( incidenceList );
+  Q_UNUSED( date );
 }
 
-void KOWhatsNextView::changeIncidenceDisplay( Incidence *, int action )
+void KOWhatsNextView::changeIncidenceDisplay( const Akonadi::Item &incidence, int action )
 {
+  Q_UNUSED( incidence );
+
   switch( action ) {
-  case KOGlobals::INCIDENCEADDED:
-  case KOGlobals::INCIDENCEEDITED:
-  case KOGlobals::INCIDENCEDELETED:
+  case CalendarSupport::IncidenceChanger::INCIDENCEADDED:
+  case CalendarSupport::IncidenceChanger::INCIDENCEEDITED:
+  case CalendarSupport::IncidenceChanger::INCIDENCEDELETED:
     updateView();
     break;
   default:
@@ -263,14 +257,13 @@ void KOWhatsNextView::changeIncidenceDisplay( Incidence *, int action )
   }
 }
 
-void KOWhatsNextView::appendEvent( Incidence *ev, const QDateTime &start,
+void KOWhatsNextView::appendEvent( const Akonadi::Item &aitem, const QDateTime &start,
                                    const QDateTime &end )
 {
-
+  const Incidence::Ptr incidence = CalendarSupport::incidence( aitem );
   mText += "<tr><td><b>";
-  if ( ev->type() == "Event" ) {
-    Event *event = static_cast<Event *>(ev);
-    KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
+  if ( const Event::Ptr event = CalendarSupport::event( aitem ) ) {
+    KDateTime::Spec timeSpec = CalendarSupport::KCalPrefs::instance()->timeSpec();
     KDateTime starttime( start, timeSpec );
     if ( !starttime.isValid() ) {
       starttime = event->dtStart();
@@ -284,49 +277,50 @@ void KOWhatsNextView::appendEvent( Incidence *ev, const QDateTime &start,
       mText += i18nc(
         "date from - to", "%1 - %2",
         KGlobal::locale()->formatDateTime(
-          starttime.toTimeSpec( KOPrefs::instance()->timeSpec() ) ),
+          starttime.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ) ),
         KGlobal::locale()->formatDateTime(
-          endtime.toTimeSpec( KOPrefs::instance()->timeSpec() ) ) );
+          endtime.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ) ) );
     } else {
       mText += i18nc(
         "date, from - to", "%1, %2 - %3",
         KGlobal::locale()->formatDate(
-          starttime.toTimeSpec( KOPrefs::instance()->timeSpec() ).date(), KLocale::ShortDate ),
+          starttime.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ).date(),
+          KLocale::ShortDate ),
         KGlobal::locale()->formatTime(
-          starttime.toTimeSpec( KOPrefs::instance()->timeSpec() ).time() ),
+          starttime.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ).time() ),
         KGlobal::locale()->formatTime(
-          endtime.toTimeSpec( KOPrefs::instance()->timeSpec() ).time() ) );
+          endtime.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ).time() ) );
     }
   }
   mText += "</b></td><td><a ";
-  if ( ev->type() == "Event" ) {
+  if ( incidence->type() == Incidence::TypeEvent ) {
     mText += "href=\"event:";
   }
-  if ( ev->type() == "Todo" ) {
+  if ( incidence->type() == Incidence::TypeTodo ) {
     mText += "href=\"todo:";
   }
-  mText += ev->uid() + "\">";
-  mText += ev->summary();
+  mText += incidence->uid() + "\">";
+  mText += incidence->summary();
   mText += "</a></td></tr>\n";
 }
 
-void KOWhatsNextView::appendTodo( Incidence *incidence )
+void KOWhatsNextView::appendTodo( const Akonadi::Item &aitem )
 {
-  if ( mTodos.contains( incidence ) ) {
+  if ( mTodos.contains( aitem ) ) {
     return;
   }
 
-  mTodos.append( incidence );
+  mTodos.append( aitem );
 
+  const Incidence::Ptr incidence = CalendarSupport::incidence( aitem );
   mText += "<li><a href=\"todo:" + incidence->uid() + "\">";
   mText += incidence->summary();
   mText += "</a>";
 
-  if ( incidence->type() == "Todo" ) {
-    Todo *todo = static_cast<Todo*>( incidence );
+  if ( const Todo::Ptr todo = CalendarSupport::todo( aitem ) ) {
     if ( todo->hasDueDate() ) {
       mText += i18nc( "to-do due date", "  (Due: %1)",
-                     todo->allDay() ? todo->dtDueDateStr() : todo->dtDueStr() );
+                      IncidenceFormatter::dateTimeToString( todo->dtDue(), todo->allDay() ) );
     }
   }
   mText += "</li>\n";
@@ -334,16 +328,32 @@ void KOWhatsNextView::appendTodo( Incidence *incidence )
 
 void KOWhatsNextView::showIncidence( const QString &uid )
 {
-  Incidence *incidence = 0;
+  Akonadi::Item incidence;
 
-  if ( uid.startsWith( "event:" ) ) {
-    incidence = calendar()->incidence( uid.mid( 6 ) );
-  } else if ( uid.startsWith( "todo:" ) ) {
-    incidence = calendar()->incidence( uid.mid( 5 ) );
+  CalendarSupport::Calendar* cal = dynamic_cast<CalendarSupport::Calendar*>( calendar() );
+  if ( !cal ) {
+    return;
   }
-  if ( incidence ) {
+
+  if ( uid.startsWith( QLatin1String( "event:" ) ) ) {
+    incidence = cal->incidence( cal->itemIdForIncidenceUid( uid.mid( 6 ) ) );
+  } else if ( uid.startsWith( QLatin1String( "todo:" ) ) ) {
+    incidence = cal->incidence( cal->itemIdForIncidenceUid( uid.mid( 5 ) ) );
+  }
+
+  if ( incidence.isValid() ) {
     emit showIncidenceSignal( incidence );
-  } 
+  }
+}
+
+KOrg::CalPrinterBase::PrintType KOWhatsNextView::printType() const
+{
+  // If up to three days are selected, use day style, otherwise week
+  if ( currentDateCount() <= 3 ) {
+    return KOrg::CalPrinterBase::Day;
+  } else {
+    return KOrg::CalPrinterBase::Week;
+  }
 }
 
 #include "kowhatsnextview.moc"
