@@ -33,6 +33,7 @@
 #include <KStandardDirs>
 #include <KXMLGUIFactory>
 #include <KActionCollection>
+#include <KShortcutsDialog>
 
 #include <kdemacros.h>
 #include <kpluginfactory.h>
@@ -87,6 +88,12 @@ void ktimetrackerpart::makeMenus()
                                         "bindings which are specific to ktimetracker") );
 }
 
+void ktimetrackerpart::keyBindings()
+{
+  KShortcutsDialog::configure( actionCollection(),
+                               KShortcutsEditor::LetterShortcutsAllowed );
+}
+
 void ktimetrackerpart::setStatusBar(const QString & qs)
 {
     kDebug(5970) << "Entering function";
