@@ -19,6 +19,7 @@
 */
 
 #include "statisticsproxymodel.h"
+#include <QItemSelection>
 
 #include <akonadi/entitytreemodel.h>
 #include <akonadi/collectionutils_p.h>
@@ -49,11 +50,13 @@ class StatisticsProxyModel::Private
     {
     }
 
-    int sourceColumnCount( const QModelIndex &parent )
+    int sourceColumnCount() const
     {
-      return mParent->sourceModel()->columnCount( mParent->mapToSource( parent ) );
+      return mParent->sourceModel()->columnCount();
     }
 
+    QModelIndex sourceIndexAtFirstColumn(const QModelIndex& proxyIndex) const;
+
     QString toolTipForCollection( const QModelIndex &index, const Collection &collection )
     {
       QString bckColor = QApplication::palette().color( QPalette::ToolTipBase ).name();
@@ -302,8 +305,7 @@ QModelIndex StatisticsProxyModel::index( int row, int column, const QModelIndex
 
 
     int sourceColumn = column;
-
-    if ( column>=d->sourceColumnCount( parent ) ) {
+    if ( column >= d->sourceColumnCount() ) {
       sourceColumn = 0;
     }
 
@@ -311,20 +313,61 @@ QModelIndex StatisticsProxyModel::index( int row, int column, const QModelIndex
     return createIndex( i.row(), column, i.internalPointer() );
 }
 
+struct SourceModelIndex
+{
+    SourceModelIndex(int _r, int _c, void *_p, QAbstractItemModel *_m)
+      : r(_r), c(_c), p(_p), m(_m) {}
+
+    operator QModelIndex() { return reinterpret_cast<QModelIndex&>(*this); }
+
+    int r, c;
+    void *p;
+    const QAbstractItemModel *m;
+};
+
+QModelIndex StatisticsProxyModel::Private::sourceIndexAtFirstColumn(const QModelIndex& proxyIndex) const
+{
+  // We rely on the fact that the internal pointer is the same for column 0 and for the extra columns
+  return SourceModelIndex(proxyIndex.row(), 0, proxyIndex.internalPointer(), mParent->sourceModel());
+}
+
+QModelIndex StatisticsProxyModel::parent(const QModelIndex& child) const
+{
+  if (!sourceModel())
+    return QModelIndex();
+
+  Q_ASSERT(child.isValid() ? child.model() == this : true);
+  if (child.column() >= d->sourceColumnCount()) {
+    // We need to get hold of the source index at column 0. But we can't do that
+    // via the proxy index at column 0, because sibling() or index() needs the
+    // parent index, and that's *exactly* what we're trying to determine here.
+    // So the only way is to create a source index ourselves.
+    const QModelIndex sourceIndex = d->sourceIndexAtFirstColumn(child);
+    const QModelIndex sourceParent = sourceIndex.parent();
+    //kDebug() << "parent of" << child.data() << "is" << sourceParent.data();
+    return mapFromSource(sourceParent);
+  } else {
+    return KIdentityProxyModel::parent(child);
+  }
+}
+
 QVariant StatisticsProxyModel::data( const QModelIndex & index, int role) const
 {
   if (!sourceModel())
     return QVariant();
-  if ( role == Qt::DisplayRole && index.column()>=d->sourceColumnCount( index.parent() ) ) {
-    const QModelIndex sourceIndex = mapToSource( index.sibling( index.row(), 0 ) );
+
+  const int sourceColumnCount = d->sourceColumnCount();
+
+  if ( role == Qt::DisplayRole && index.column() >= sourceColumnCount ) {
+    const QModelIndex sourceIndex = d->sourceIndexAtFirstColumn( index );
     Collection collection = sourceModel()->data( sourceIndex, EntityTreeModel::CollectionRole ).value<Collection>();
 
     if ( collection.isValid() && collection.statistics().count()>=0 ) {
-      if ( index.column() == d->sourceColumnCount( QModelIndex() )+2 ) {
+      if ( index.column() == sourceColumnCount + 2 ) {
         return KIO::convertSize( (KIO::filesize_t)( collection.statistics().size() ) );
-      } else if ( index.column() == d->sourceColumnCount( QModelIndex() )+1 ) {
+      } else if ( index.column() == sourceColumnCount + 1 ) {
         return collection.statistics().count();
-      } else if ( index.column() == d->sourceColumnCount( QModelIndex() ) ) {
+      } else if ( index.column() == sourceColumnCount ) {
         if ( collection.statistics().unreadCount() > 0 ) {
           return collection.statistics().unreadCount();
         } else {
@@ -336,11 +379,11 @@ QVariant StatisticsProxyModel::data( const QModelIndex & index, int role) const
       }
     }
 
-  } else if ( role == Qt::TextAlignmentRole && index.column()>=d->sourceColumnCount( index.parent() ) ) {
+  } else if ( role == Qt::TextAlignmentRole && index.column() >= sourceColumnCount ) {
     return Qt::AlignRight;
 
   } else if ( role == Qt::ToolTipRole && d->mToolTipEnabled ) {
-    const QModelIndex sourceIndex = mapToSource( index.sibling( index.row(), 0 ) );
+    const QModelIndex sourceIndex = d->sourceIndexAtFirstColumn( index );
     Collection collection
       = sourceModel()->data( sourceIndex,
                              EntityTreeModel::CollectionRole ).value<Collection>();
@@ -350,36 +393,42 @@ QVariant StatisticsProxyModel::data( const QModelIndex & index, int role) const
     }
 
   } else if ( role == Qt::DecorationRole && index.column() == 0 ) {
-    const QModelIndex sourceIndex = mapToSource( index.sibling( index.row(), 0 ) );
+    const QModelIndex sourceIndex = mapToSource( index );
     Collection collection = sourceModel()->data( sourceIndex, EntityTreeModel::CollectionRole ).value<Collection>();
-
     if ( collection.isValid() )
-      return KIcon(  CollectionUtils::displayIconName( collection ) );
+      return KIcon( CollectionUtils::displayIconName( collection ) );
     else
       return QVariant();
   }
 
+  if ( index.column() >= sourceColumnCount )
+    return QVariant();
+
   return QAbstractProxyModel::data( index, role );
 }
 
 QVariant StatisticsProxyModel::headerData( int section, Qt::Orientation orientation, int role) const
 {
   if ( orientation == Qt::Horizontal && role == Qt::DisplayRole ) {
-    if ( section == d->sourceColumnCount( QModelIndex() ) + 2 ) {
+    if ( section == d->sourceColumnCount() + 2 ) {
       return i18nc( "collection size", "Size" );
-    } else if ( section == d->sourceColumnCount( QModelIndex() ) + 1 ) {
+    } else if ( section == d->sourceColumnCount() + 1 ) {
       return i18nc( "number of entities in the collection", "Total" );
-    } else if ( section == d->sourceColumnCount( QModelIndex() ) ) {
+    } else if ( section == d->sourceColumnCount() ) {
       return i18nc( "number of unread entities in the collection", "Unread" );
     }
   }
 
+  if ( orientation == Qt::Horizontal && section >= d->sourceColumnCount() ) {
+    return QVariant();
+  }
+
   return KIdentityProxyModel::headerData( section, orientation, role );
 }
 
 Qt::ItemFlags StatisticsProxyModel::flags( const QModelIndex & index ) const
 {
-  if ( index.column()>=d->sourceColumnCount( index.parent() ) ) {
+  if ( index.column() >= d->sourceColumnCount() ) {
     return KIdentityProxyModel::flags( index.sibling( index.row(), 0 ) )
          & ( Qt::ItemIsSelectable | Qt::ItemIsDragEnabled // Allowed flags
            | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled );
@@ -388,12 +437,12 @@ Qt::ItemFlags StatisticsProxyModel::flags( const QModelIndex & index ) const
   return KIdentityProxyModel::flags( index );
 }
 
-int StatisticsProxyModel::columnCount( const QModelIndex & parent ) const
+int StatisticsProxyModel::columnCount( const QModelIndex & /*parent*/ ) const
 {
   if ( sourceModel()==0 ) {
     return 0;
   } else {
-    return d->sourceColumnCount( parent )
+    return d->sourceColumnCount()
          + ( d->mExtraColumnsEnabled ? 3 : 0 );
   }
 }
@@ -415,6 +464,64 @@ QModelIndexList StatisticsProxyModel::match( const QModelIndex& start, int role,
   return list;
 }
 
+QModelIndex StatisticsProxyModel::mapFromSource(const QModelIndex& sourceIndex) const
+{
+  if (!sourceIndex.isValid())
+    return QModelIndex();
+  Q_ASSERT(sourceIndex.model() == sourceModel());
+  Q_ASSERT(sourceIndex.column() < d->sourceColumnCount());
+  return KIdentityProxyModel::mapFromSource(sourceIndex);
+}
+
+QModelIndex StatisticsProxyModel::mapToSource(const QModelIndex& index) const
+{
+  if (!index.isValid())
+    return QModelIndex();
+  Q_ASSERT(index.model() == this);
+  Q_ASSERT(index.column() < d->sourceColumnCount());
+  if (index.column() >= d->sourceColumnCount() ) {
+      return QModelIndex();
+  }
+  return KIdentityProxyModel::mapToSource(index);
+}
+
+QModelIndex StatisticsProxyModel::buddy(const QModelIndex &index) const
+{
+  Q_UNUSED(index);
+  return QModelIndex();
+}
+
+QItemSelection StatisticsProxyModel::mapSelectionToSource(const QItemSelection& selection) const
+{
+    QItemSelection sourceSelection;
+
+    if (!sourceModel())
+      return sourceSelection;
+
+    // mapToSource will give invalid index for our additional columns, so truncate the selection
+    // to the columns known by the source model
+    const int sourceColumnCount = d->sourceColumnCount();
+    QItemSelection::const_iterator it = selection.constBegin();
+    const QItemSelection::const_iterator end = selection.constEnd();
+    for ( ; it != end; ++it) {
+        Q_ASSERT(it->model() == this);
+        QModelIndex topLeft = it->topLeft();
+        Q_ASSERT(topLeft.isValid());
+        Q_ASSERT(topLeft.model() == this);
+        topLeft = topLeft.sibling(topLeft.row(), 0);
+        QModelIndex bottomRight = it->bottomRight();
+        Q_ASSERT(bottomRight.isValid());
+        Q_ASSERT(bottomRight.model() == this);
+        if (bottomRight.column() >= sourceColumnCount)
+          bottomRight = bottomRight.sibling(bottomRight.row(), sourceColumnCount-1);
+        // This can lead to duplicate source indexes, so use merge().
+        const QItemSelectionRange range(mapToSource(topLeft), mapToSource(bottomRight));
+        QItemSelection newSelection; newSelection << range;
+        sourceSelection.merge(newSelection, QItemSelectionModel::Select);
+    }
+
+    return sourceSelection;
+}
 
 #include "statisticsproxymodel.moc"
 
