@@ -437,7 +437,12 @@ bool FolderTreeView::trySelectNextUnreadFolder( const QModelIndex &current, Mail
     if ( !index.isValid() )
       return false;
 
-    const Akonadi::Collection collection = index.data( Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+    const Akonadi::Collection collection =
+      index.data( Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+    if( collection == Kernel::self()->trashCollectionFolder() ||
+        collection == Kernel::self()->outboxCollectionFolder() )
+      continue;
+
     if ( ignoreUnreadFolder( collection, confirm ) )
       continue;
 
@@ -557,7 +562,14 @@ void FolderTreeView::mousePressEvent( QMouseEvent * e )
 
 void FolderTreeView::restoreHeaderState( const QByteArray& data )
 {
-  header()->restoreState( data );
+  if(data.isEmpty()) {
+    const int nbColumn = header()->count();
+    for ( int i = 1; i <nbColumn; ++i ) {
+      setColumnHidden( i, true );
+    }
+  }
+  else
+    header()->restoreState( data );
   mCollectionStatisticsDelegate->setUnreadCountShown( header()->isSectionHidden( 1 ) );
 }
 
