@@ -196,10 +196,12 @@ void Message::ComposerViewBase::send ( MessageSender::SendMethod method, Message
   MessageViewer::KCursorSaver busy( MessageViewer::KBusyPtr::busy() );
 #endif
 
+  const KPIMIdentities::Identity identity = identityManager()->identityForUoid( m_identityCombo->currentIdentity() );
+
   m_msg->setHeader( new KMime::Headers::Generic( "X-KMail-Transport", m_msg.get(), QString::number(m_transport->currentTransportId()), "utf-8" ) );
  
   m_msg->setHeader( new KMime::Headers::Generic( "X-KMail-Fcc", m_msg.get(), QString::number( m_fccCollection.id() ) , "utf-8" ) );
-
+  m_msg->setHeader( new KMime::Headers::Generic( "X-KMail-Identity", m_msg.get(), QString::number( identity.uoid() ), "utf-8" ));
 
   // Save the quote prefix which is used for this message. Each message can have
   // a different quote prefix, for example depending on the original sender.
@@ -256,7 +258,8 @@ void Message::ComposerViewBase::send ( MessageSender::SendMethod method, Message
     m_msg->removeHeader( "X-KMail-CryptoMessageFormat" );
   }
 
-  Message::Util::sendMailDispatcherIsOnline( m_parentWidget );
+  if( mSendMethod == MessageSender::SendImmediate )
+    Message::Util::sendMailDispatcherIsOnline( m_parentWidget );
 
   readyForSending();
 }
@@ -1323,12 +1326,12 @@ bool Message::ComposerViewBase::inlineSigningEncryptionSelected()
   return m_cryptoMessageFormat == Kleo::InlineOpenPGPFormat;
 }
 
-bool Message::ComposerViewBase::checkForMissingAttachments( const QStringList& attachmentKeywords )
+Message::ComposerViewBase::MissingAttachment Message::ComposerViewBase::checkForMissingAttachments( const QStringList& attachmentKeywords )
 {
   if ( attachmentKeywords.isEmpty() )
-    return false;
+    return NoMissingAttachmentFound;
   if ( m_attachmentModel->rowCount() > 0 ) {
-    return false;
+    return NoMissingAttachmentFound;
   }
 
   QStringList attachWordsList = attachmentKeywords;
@@ -1362,7 +1365,7 @@ bool Message::ComposerViewBase::checkForMissingAttachments( const QStringList& a
   }
 
   if ( !gotMatch )
-    return false;
+    return NoMissingAttachmentFound;
 
   int rc = KMessageBox::warningYesNoCancel( m_editor,
                                             i18n("The message you have composed seems to refer to an "
@@ -1372,12 +1375,13 @@ bool Message::ComposerViewBase::checkForMissingAttachments( const QStringList& a
                                             KGuiItem(i18n("&Attach File...")),
                                             KGuiItem(i18n("&Send as Is")) );
   if ( rc == KMessageBox::Cancel )
-    return true;
+    return FoundMissingAttachmentAndCancel;
   if ( rc == KMessageBox::Yes ) {
     m_attachmentController->showAddAttachmentDialog();
+    return FoundMissingAttachmentAndAddedAttachment;
   }
 
-  return false;
+  return FoundMissingAttachmentAndSending;
 }
 
 
