@@ -18,7 +18,6 @@
  *
  *******************************************************************************/
 
-#include "item.h"
 #include "core/item.h"
 #include "core/item_p.h"
 #include "core/model.h"
@@ -32,106 +31,106 @@
 using namespace MessageList::Core;
 
 Item::Item( Type type )
-  : d( new ItemPrivate( this ) )
+  : d_ptr( new ItemPrivate( this ) )
 {
-  d->mType = type;
-  d->mChildItems = 0;
-  d->mParent = 0;
-  d->mThisItemIndexGuess = 0;
-  d->mIsViewable = false;
-  d->mInitialExpandStatus = NoExpandNeeded;
+  d_ptr->mType = type;
+}
+
+Item::Item ( Item::Type type, ItemPrivate* dd )
+  : d_ptr( dd )
+{
+  d_ptr->mType = type;
 }
 
 Item::~Item()
 {
   killAllChildItems();
 
-  if ( d->mParent )
-    d->mParent->d->childItemDead( this );
+  if ( d_ptr->mParent )
+    d_ptr->mParent->d_ptr->childItemDead( this );
 
-  delete d;
+  delete d_ptr;
 }
 
 void Item::childItemStats( ChildItemStats &stats ) const
 {
-  Q_ASSERT( d->mChildItems );
+  Q_ASSERT( d_ptr->mChildItems );
 
-  stats.mTotalChildCount += d->mChildItems->count();
-  for( QList< Item * >::Iterator it = d->mChildItems->begin(); it != d->mChildItems->end(); ++it )
+  stats.mTotalChildCount += d_ptr->mChildItems->count();
+  QList< Item * >::ConstIterator end( d_ptr->mChildItems->constEnd() );
+  for( QList< Item * >::ConstIterator it = d_ptr->mChildItems->constBegin(); it != end; ++it )
   {
-    if ( ( *it )->status().isNew() )
-      stats.mNewChildCount++;
-    else if ( ( *it )->status().isUnread() )
+    if ( !( *it )->status().isRead() )
       stats.mUnreadChildCount++;
-    if ( ( *it )->d->mChildItems )
+    if ( ( *it )->d_ptr->mChildItems )
       ( *it )->childItemStats( stats );
   }
 }
 
 QList< Item * > *Item::childItems() const
 {
-  return d->mChildItems;
+  return d_ptr->mChildItems;
 }
 
 Item *Item::childItem( int idx ) const
 {
   if ( idx < 0 )
     return 0;
-  if ( !d->mChildItems )
+  if ( !d_ptr->mChildItems )
     return 0;
-  if ( d->mChildItems->count() <= idx )
+  if ( d_ptr->mChildItems->count() <= idx )
     return 0;
-  return d->mChildItems->at( idx );
+  return d_ptr->mChildItems->at( idx );
 }
 
 Item * Item::firstChildItem() const
 {
-  return d->mChildItems ? ( d->mChildItems->count() > 0 ? d->mChildItems->at( 0 ) : 0 ) : 0;
+  return d_ptr->mChildItems ? ( d_ptr->mChildItems->count() > 0 ? d_ptr->mChildItems->at( 0 ) : 0 ) : 0;
 }
 
 Item * Item::itemBelowChild( Item * child )
 {
-  Q_ASSERT( d->mChildItems );
+  Q_ASSERT( d_ptr->mChildItems );
 
   int idx = child->indexGuess();
   if ( !childItemHasIndex( child, idx ) )
   {
-    idx = d->mChildItems->indexOf( child );
+    idx = d_ptr->mChildItems->indexOf( child );
     child->setIndexGuess( idx );
   }
   Q_ASSERT( idx >= 0 );
 
   idx++;
 
-  if ( idx < d->mChildItems->count() )
-    return d->mChildItems->at( idx );
+  if ( idx < d_ptr->mChildItems->count() )
+    return d_ptr->mChildItems->at( idx );
 
-  if ( !d->mParent )
+  if ( !d_ptr->mParent )
     return 0;
 
-  return d->mParent->itemBelowChild( this );
+  return d_ptr->mParent->itemBelowChild( this );
 }
 
 Item * Item::itemBelow()
 {
-  if ( d->mChildItems )
+  if ( d_ptr->mChildItems )
   {
-    if ( d->mChildItems->count() > 0 )
-      return d->mChildItems->at( 0 );
+    if ( !d_ptr->mChildItems->isEmpty() )
+      return d_ptr->mChildItems->at( 0 );
   }
 
-  if ( !d->mParent )
+  if ( !d_ptr->mParent )
     return 0;
 
-  return d->mParent->itemBelowChild( this );
+  return d_ptr->mParent->itemBelowChild( this );
 }
 
 Item * Item::deepestItem()
 {
-  if ( d->mChildItems )
+  if ( d_ptr->mChildItems )
   {
-    if ( d->mChildItems->count() > 0 )
-      return d->mChildItems->at( d->mChildItems->count() - 1 )->deepestItem();
+    if ( !d_ptr->mChildItems->isEmpty() )
+      return d_ptr->mChildItems->at( d_ptr->mChildItems->count() - 1 )->deepestItem();
   }
 
   return this;
@@ -139,19 +138,19 @@ Item * Item::deepestItem()
 
 Item * Item::itemAboveChild( Item * child )
 {
-  if ( d->mChildItems )
+  if ( d_ptr->mChildItems )
   {
     int idx = child->indexGuess();
     if ( !childItemHasIndex( child, idx ) )
     {
-      idx = d->mChildItems->indexOf( child );
+      idx = d_ptr->mChildItems->indexOf( child );
       child->setIndexGuess( idx );
     }
     Q_ASSERT( idx >= 0 );
     idx--;
 
     if ( idx >= 0 )
-      return d->mChildItems->at( idx );
+      return d_ptr->mChildItems->at( idx );
   }
 
   return this;
@@ -159,22 +158,22 @@ Item * Item::itemAboveChild( Item * child )
 
 Item * Item::itemAbove()
 {
-  if ( !d->mParent )
+  if ( !d_ptr->mParent )
     return 0;
 
-  Item *siblingAbove = d->mParent->itemAboveChild( this );
-  if ( siblingAbove && siblingAbove != this && siblingAbove != d->mParent &&
+  Item *siblingAbove = d_ptr->mParent->itemAboveChild( this );
+  if ( siblingAbove && siblingAbove != this && siblingAbove != d_ptr->mParent &&
        siblingAbove->childItemCount() > 0 )
   {
     return siblingAbove->deepestItem();
   }
 
-  return d->mParent->itemAboveChild( this );
+  return d_ptr->mParent->itemAboveChild( this );
 }
 
 int Item::childItemCount() const
 {
-  return d->mChildItems ? d->mChildItems->count() : 0;
+  return d_ptr->mChildItems ? d_ptr->mChildItems->count() : 0;
 }
 
 bool Item::hasChildren() const
@@ -184,35 +183,35 @@ bool Item::hasChildren() const
 
 int Item::indexOfChildItem( Item *item ) const
 {
-  return d->mChildItems ? d->mChildItems->indexOf( item ) : -1;
+  return d_ptr->mChildItems ? d_ptr->mChildItems->indexOf( item ) : -1;
 }
 
 int Item::indexGuess() const
 {
-  return d->mThisItemIndexGuess;
+  return d_ptr->mThisItemIndexGuess;
 }
 
 void Item::setIndexGuess( int index )
 {
-  d->mThisItemIndexGuess = index;
+  d_ptr->mThisItemIndexGuess = index;
 }
 
 bool Item::childItemHasIndex( const Item *item, int idx ) const
 {
-  return d->mChildItems ? ( ( d->mChildItems->count() > idx ) ? ( d->mChildItems->at( idx ) == item ) : false ) : false;
+  return d_ptr->mChildItems ? ( ( d_ptr->mChildItems->count() > idx ) ? ( d_ptr->mChildItems->at( idx ) == item ) : false ) : false;
 }
 
 Item * Item::topmostNonRoot()
 {
-  Q_ASSERT( d->mType != InvisibleRoot );
+  Q_ASSERT( d_ptr->mType != InvisibleRoot );
 
-  if ( !d->mParent )
+  if ( !d_ptr->mParent )
     return this;
 
-  if ( d->mParent->type() == InvisibleRoot )
+  if ( d_ptr->mParent->type() == InvisibleRoot )
     return this;
 
-  return d->mParent->topmostNonRoot();
+  return d_ptr->mParent->topmostNonRoot();
 }
 
 
@@ -226,12 +225,10 @@ static inline void append_string( QString &buffer, const QString &append )
 QString Item::statusDescription() const
 {
   QString ret;
-  if( status().isNew() )
-    append_string( ret, i18nc( "Status of an item", "New" ) );
-  else if( status().isUnread() )
-    append_string( ret, i18nc( "Status of an item", "Unread" ) );
-  else
+  if( status().isRead() )
     append_string( ret, i18nc( "Status of an item", "Read" ) );
+  else
+    append_string( ret, i18nc( "Status of an item", "Unread" ) );
 
   if( status().hasAttachment() )
     append_string( ret, i18nc( "Status of an item", "Has Attachment" ) );
@@ -266,51 +263,42 @@ QString Item::statusDescription() const
   return ret;
 }
 
-const QString & Item::formattedSize()
+QString Item::formattedSize() const
 {
-  if ( d->mFormattedSize.isEmpty() )
-    d->mFormattedSize = KIO::convertSize( ( KIO::filesize_t ) size() );
-  return d->mFormattedSize;
+  return KIO::convertSize( ( KIO::filesize_t ) size() );
 }
 
-const QString & Item::formattedDate()
+QString Item::formattedDate() const
 {
-  if ( d->mFormattedDate.isEmpty() )
-  {
-    if ( static_cast< uint >( date() ) == static_cast< uint >( -1 ) )
-      d->mFormattedDate = Manager::instance()->cachedLocalizedUnknownText();
-    else
-      d->mFormattedDate = Manager::instance()->dateFormatter()->dateString( date() );
-  }
-  return d->mFormattedDate;
+  if ( static_cast< uint >( date() ) == static_cast< uint >( -1 ) )
+    return Manager::instance()->cachedLocalizedUnknownText();
+  else
+    return Manager::instance()->dateFormatter()->dateString( date() );
 }
 
-const QString & Item::formattedMaxDate()
+QString Item::formattedMaxDate() const
 {
-  if ( d->mFormattedMaxDate.isEmpty() )
-  {
-    if ( static_cast< uint >( maxDate() ) == static_cast< uint >( -1 ) )
-      d->mFormattedMaxDate = Manager::instance()->cachedLocalizedUnknownText();
-    else
-      d->mFormattedMaxDate = Manager::instance()->dateFormatter()->dateString( maxDate() );
-  }
-  return d->mFormattedMaxDate;
+  if ( static_cast< uint >( maxDate() ) == static_cast< uint >( -1 ) )
+    return Manager::instance()->cachedLocalizedUnknownText();
+  else
+    return Manager::instance()->dateFormatter()->dateString( maxDate() );
 }
 
 bool Item::recomputeMaxDate()
 {
-  time_t newMaxDate = d->mDate;
+  time_t newMaxDate = d_ptr->mDate;
 
-  if ( d->mChildItems )
+  if ( d_ptr->mChildItems )
   {
-    for ( QList< Item * >::ConstIterator it = d->mChildItems->constBegin(); it != d->mChildItems->constEnd(); ++it )
+    QList< Item * >::ConstIterator end = d_ptr->mChildItems->constEnd();
+    for ( QList< Item * >::ConstIterator it = d_ptr->mChildItems->constBegin(); it != end; ++it )
     {
-      if ( ( *it )->d->mMaxDate > newMaxDate )
-        newMaxDate = ( *it )->d->mMaxDate;
+      if ( ( *it )->d_ptr->mMaxDate > newMaxDate )
+        newMaxDate = ( *it )->d_ptr->mMaxDate;
     }
   }
 
-  if ( newMaxDate != d->mMaxDate )
+  if ( newMaxDate != d_ptr->mMaxDate )
   {
     setMaxDate( newMaxDate );
     return true;
@@ -321,43 +309,43 @@ bool Item::recomputeMaxDate()
 
 Item::Type Item::type() const
 {
-  return d->mType;
+  return d_ptr->mType;
 }
 
 Item::InitialExpandStatus Item::initialExpandStatus() const
 {
-  return d->mInitialExpandStatus;
+  return d_ptr->mInitialExpandStatus;
 }
 
 void Item::setInitialExpandStatus( InitialExpandStatus initialExpandStatus )
 {
-  d->mInitialExpandStatus = initialExpandStatus;
+  d_ptr->mInitialExpandStatus = initialExpandStatus;
 }
 
 bool Item::isViewable() const
 {
-  return d->mIsViewable;
+  return d_ptr->mIsViewable;
 }
 
 bool Item::hasAncestor( const Item * it ) const
 {
-  return d->mParent ? ( d->mParent == it ? true : d->mParent->hasAncestor( it ) ) : false;
+  return d_ptr->mParent ? ( d_ptr->mParent == it ? true : d_ptr->mParent->hasAncestor( it ) ) : false;
 }
 
 void Item::setViewable( Model *model,bool bViewable )
 {
-  if ( d->mIsViewable == bViewable )
+  if ( d_ptr->mIsViewable == bViewable )
     return;
 
-  if ( !d->mChildItems )
+  if ( !d_ptr->mChildItems )
   {
-    d->mIsViewable = bViewable;
+    d_ptr->mIsViewable = bViewable;
     return;
   }
 
-  if ( d->mChildItems->count() < 1 )
+  if ( d_ptr->mChildItems->count() < 1 )
   {
-    d->mIsViewable = bViewable;
+    d_ptr->mIsViewable = bViewable;
     return;
   }
 
@@ -366,21 +354,23 @@ void Item::setViewable( Model *model,bool bViewable )
     if ( model )
     {
       // fake having no children, for a second
-      QList< Item * > * tmp = d->mChildItems;
-      d->mChildItems = 0;
+      QList< Item * > * tmp = d_ptr->mChildItems;
+      d_ptr->mChildItems = 0;
       //qDebug("BEGIN INSERT ROWS FOR PARENT %x: from %d to %d, (will) have %d children",this,0,tmp->count()-1,tmp->count());
       model->beginInsertRows( model->index( this, 0 ), 0, tmp->count() - 1 );
-      d->mChildItems = tmp;
-      d->mIsViewable = true;
+      d_ptr->mChildItems = tmp;
+      d_ptr->mIsViewable = true;
       model->endInsertRows();
     } else {
-      d->mIsViewable = true;
+      d_ptr->mIsViewable = true;
     }
 
-    for ( QList< Item * >::Iterator it = d->mChildItems->begin(); it != d->mChildItems->end() ;++it )
+    QList< Item * >::ConstIterator end( d_ptr->mChildItems->constEnd() );
+    for ( QList< Item * >::ConstIterator it = d_ptr->mChildItems->constBegin(); it != end ;++it )
      ( *it )->setViewable( model, bViewable );
   } else {
-    for ( QList< Item * >::Iterator it = d->mChildItems->begin(); it != d->mChildItems->end() ;++it )
+    QList< Item * >::ConstIterator end( d_ptr->mChildItems->constEnd() );
+    for ( QList< Item * >::ConstIterator it = d_ptr->mChildItems->constBegin(); it != end ;++it )
       ( *it )->setViewable( model, bViewable );
 
     // It seems that we can avoid removing child items here since the parent has been removed: this is a hack tough
@@ -389,168 +379,165 @@ void Item::setViewable( Model *model,bool bViewable )
     if ( model )
     {
       // fake having no children, for a second
-      model->beginRemoveRows( model->index( this, 0 ), 0, d->mChildItems->count() - 1 );
-      QList< Item * > * tmp = d->mChildItems;
-      d->mChildItems = 0;
-      d->mIsViewable = false;
+      model->beginRemoveRows( model->index( this, 0 ), 0, d_ptr->mChildItems->count() - 1 );
+      QList< Item * > * tmp = d_ptr->mChildItems;
+      d_ptr->mChildItems = 0;
+      d_ptr->mIsViewable = false;
       model->endRemoveRows();
-      d->mChildItems = tmp;
+      d_ptr->mChildItems = tmp;
     } else {
-      d->mIsViewable = false;
+      d_ptr->mIsViewable = false;
     }
   }
 }
 
 void Item::killAllChildItems()
 {
-  if ( !d->mChildItems )
+  if ( !d_ptr->mChildItems )
     return;
 
-  while( !d->mChildItems->isEmpty() )
-    delete d->mChildItems->first(); // this will call childDead() which will remove the child from the list
+  while( !d_ptr->mChildItems->isEmpty() )
+    delete d_ptr->mChildItems->first(); // this will call childDead() which will remove the child from the list
 
-  delete d->mChildItems;
-  d->mChildItems = 0;
+  delete d_ptr->mChildItems;
+  d_ptr->mChildItems = 0;
 }
 
 Item * Item::parent() const
 {
-  return d->mParent;
+  return d_ptr->mParent;
 }
 
 void Item::setParent( Item *pParent )
 {
-  d->mParent = pParent;
+  d_ptr->mParent = pParent;
 }
 
-const KPIM::MessageStatus &Item::status() const
+const Akonadi::MessageStatus &Item::status() const
 {
-  return d->mStatus;
+  return d_ptr->mStatus;
 }
 
-void Item::setStatus( const KPIM::MessageStatus &status )
+void Item::setStatus( const Akonadi::MessageStatus &status )
 {
-  d->mStatus = status;
+  d_ptr->mStatus = status;
 }
 
 size_t Item::size() const
 {
-  return d->mSize;
+  return d_ptr->mSize;
 }
 
 void Item::setSize( size_t size )
 {
-  d->mSize = size;
-  d->mFormattedSize.clear();
+  d_ptr->mSize = size;
 }
 
 time_t Item::date() const
 {
-  return d->mDate;
+  return d_ptr->mDate;
 }
 
 void Item::setDate( time_t date )
 {
-  d->mDate = date;
-  d->mFormattedDate.clear();
+  d_ptr->mDate = date;
 }
 
 time_t Item::maxDate() const
 {
-  return d->mMaxDate;
+  return d_ptr->mMaxDate;
 }
 
 void Item::setMaxDate( time_t date )
 {
-  d->mMaxDate = date;
-  d->mFormattedMaxDate.clear();
+  d_ptr->mMaxDate = date;
 }
 
 const QString &Item::sender() const
 {
-  return d->mSender;
+  return d_ptr->mSender;
 }
 
 void Item::setSender( const QString &sender )
 {
-  d->mSender = sender;
+  d_ptr->mSender = sender;
 }
 
 const QString &Item::receiver() const
 {
-  return d->mReceiver;
+  return d_ptr->mReceiver;
 }
 
 void Item::setReceiver( const QString &receiver )
 {
-  d->mReceiver = receiver;
+  d_ptr->mReceiver = receiver;
 }
 
 const QString &Item::senderOrReceiver() const
 {
-  return d->mSenderOrReceiver;
+  return d_ptr->mUseReceiver ? d_ptr->mReceiver : d_ptr->mSender;
 }
 
-void Item::setSenderOrReceiver( const QString &senderOrReceiver )
+bool Item::useReceiver() const
 {
-  d->mSenderOrReceiver = senderOrReceiver;
+  return d_ptr->mUseReceiver;
 }
 
 const QString &Item::subject() const
 {
-  return d->mSubject;
+  return d_ptr->mSubject;
 }
 
 void Item::setSubject( const QString &subject )
 {
-  d->mSubject = subject;
+  d_ptr->mSubject = subject;
 }
 
 void MessageList::Core::Item::initialSetup( time_t date, size_t size,
                                             const QString &sender,
                                             const QString &receiver,
-                                            const QString &senderOrReceiver )
+                                            bool useReceiver )
 {
-  d->mDate = date;
-  d->mMaxDate = date;
-  d->mSize = size;
-  d->mSender = sender;
-  d->mReceiver = receiver;
-  d->mSenderOrReceiver = senderOrReceiver;
+  d_ptr->mDate = date;
+  d_ptr->mMaxDate = date;
+  d_ptr->mSize = size;
+  d_ptr->mSender = sender;
+  d_ptr->mReceiver = receiver;
+  d_ptr->mUseReceiver = useReceiver;
 }
 
 void MessageList::Core::Item::setSubjectAndStatus(const QString &subject,
-                                                  const KPIM::MessageStatus &status)
+                                                  const Akonadi::MessageStatus &status)
 {
-  d->mSubject = subject;
-  d->mStatus = status;
+  d_ptr->mSubject = subject;
+  d_ptr->mStatus = status;
 }
 
 // FIXME: Try to "cache item insertions" and call beginInsertRows() and endInsertRows() in a chunked fashion...
 
 void Item::rawAppendChildItem( Item * child )
 {
-  if ( !d->mChildItems )
-    d->mChildItems = new QList< Item * >();
-  d->mChildItems->append( child );
+  if ( !d_ptr->mChildItems )
+    d_ptr->mChildItems = new QList< Item * >();
+  d_ptr->mChildItems->append( child );
 }
 
 int Item::appendChildItem( Model *model, Item *child )
 {
-  if ( !d->mChildItems )
-    d->mChildItems = new QList< Item * >();
-  int idx = d->mChildItems->count();
-  if ( d->mIsViewable )
+  if ( !d_ptr->mChildItems )
+    d_ptr->mChildItems = new QList< Item * >();
+  const int idx = d_ptr->mChildItems->count();
+  if ( d_ptr->mIsViewable )
   {
     if ( model )
       model->beginInsertRows( model->index( this, 0 ), idx, idx ); // THIS IS EXTREMELY UGLY, BUT IT'S THE ONLY POSSIBLE WAY WITH QT4 AT THE TIME OF WRITING
-    d->mChildItems->append( child );
+    d_ptr->mChildItems->append( child );
     child->setIndexGuess( idx );
     if ( model )
       model->endInsertRows(); // THIS IS EXTREMELY UGLY, BUT IT'S THE ONLY POSSIBLE WAY WITH QT4 AT THE TIME OF WRITING
     child->setViewable( model, true );
   } else {
-    d->mChildItems->append( child );
+    d_ptr->mChildItems->append( child );
     child->setIndexGuess( idx );
   }
   return idx;
@@ -559,29 +546,30 @@ int Item::appendChildItem( Model *model, Item *child )
 
 void Item::dump( const QString &prefix )
 {
-  QString out = QString(QLatin1String( "%1 %x VIEWABLE:%2" )).arg(prefix).arg(d->mIsViewable ? QLatin1String( "yes" ) : QLatin1String( "no" ));
+  QString out = QString::fromLatin1( "%1 %x VIEWABLE:%2" ).arg(prefix).arg(d_ptr->mIsViewable ? QLatin1String( "yes" ) : QLatin1String( "no" ));
   qDebug( out.toUtf8().data(),this );
 
-  QString nPrefix = prefix;
+  QString nPrefix( prefix );
   nPrefix += QLatin1String("  ");
 
-  if (!d->mChildItems )
+  if (!d_ptr->mChildItems )
     return;
 
-  for ( QList< Item * >::Iterator it = d->mChildItems->begin(); it != d->mChildItems->end() ;++it )
+  QList< Item * >::ConstIterator end( d_ptr->mChildItems->constEnd() );
+  for ( QList< Item * >::ConstIterator it = d_ptr->mChildItems->constBegin(); it != end ;++it )
     (*it)->dump(nPrefix);
 }
 
 void Item::takeChildItem( Model *model, Item *child )
 {
-  if ( !d->mChildItems )
+  if ( !d_ptr->mChildItems )
     return; // Ugh... not our child ?
 
-  if ( !d->mIsViewable )
+  if ( !d_ptr->mIsViewable )
   {
     //qDebug("TAKING NON VIEWABLE CHILD ITEM %x",child);
     // We can highly optimize this case
-    d->mChildItems->removeOne( child );
+    d_ptr->mChildItems->removeOne( child );
 #if 0
     // This *could* be done, but we optimize and avoid it.
     if ( d->mChildItems->count() < 1 )
@@ -596,12 +584,13 @@ void Item::takeChildItem( Model *model, Item *child )
 
   // Can't optimize: must call the model functions
   int idx = child->indexGuess();
-  if ( d->mChildItems->count() > idx )
+  if ( d_ptr->mChildItems->count() > idx )
   {
-    if ( d->mChildItems->at( idx ) != child ) // bad guess :/
-      idx = d->mChildItems->indexOf( child );
-  } else
-    idx = d->mChildItems->indexOf( child ); // bad guess :/
+    if ( d_ptr->mChildItems->at( idx ) != child ) // bad guess :/
+      idx = d_ptr->mChildItems->indexOf( child );
+  }
+  else
+    idx = d_ptr->mChildItems->indexOf( child ); // bad guess :/
 
   if ( idx < 0 )
     return; // Aaargh... not our child ?
@@ -610,7 +599,7 @@ void Item::takeChildItem( Model *model, Item *child )
   if ( model )
     model->beginRemoveRows( model->index( this, 0 ), idx, idx );
   child->setParent( 0 );
-  d->mChildItems->removeAt( idx );
+  d_ptr->mChildItems->removeAt( idx );
   if ( model )
     model->endRemoveRows();
 
