@@ -21,11 +21,9 @@
 
 #include <messagelist/core/widgetbase.h>
 #include <messagelist/core/view.h>
-#include <messagelist/core/widgets/quicksearchline.h>
 #include <akonadi/item.h>
 
 #include <kmime/kmime_message.h>
-#include <KJob>
 
 #include <messagelist/messagelist_export.h>
 
@@ -45,16 +43,16 @@ namespace MessageList
  */
 class MESSAGELIST_EXPORT Widget : public MessageList::Core::Widget
 {
-    Q_OBJECT
+  Q_OBJECT
 
 public:
-    /**
+  /**
    * Create a new message list widget.
    */
-    explicit Widget( QWidget *parent );
-    ~Widget();
+  explicit Widget( QWidget *parent );
+  ~Widget();
 
-    /**
+  /**
    * Sets the XML GUI client which the view is used in.
    *
    * This is needed if you want to use the built-in context menu.
@@ -62,27 +60,27 @@ public:
    *
    * @param xmlGuiClient The KXMLGUIClient the view is used in.
    */
-    void setXmlGuiClient( KXMLGUIClient *xmlGuiClient );
+  void setXmlGuiClient( KXMLGUIClient *xmlGuiClient );
 
-    /**
+  /**
    * Returns the current message for the list as Akonadi::Item.
    * May return an invalid Item if there is no current message or no current folder.
    */
-    Akonadi::Item currentItem() const;
+  Akonadi::Item currentItem() const;
 
-    /**
+  /**
    * Returns the current message for the list as KMime::Message::Ptr.
    * May return 0 if there is no current message or no current folder.
    */
-    KMime::Message::Ptr currentMessage() const;
+  KMime::Message::Ptr currentMessage() const;
 
 
-    /**
+  /**
    * Returns true if this drag can be accepted by the underlying view
    */
-    bool canAcceptDrag( const QDropEvent *e );
+  bool canAcceptDrag( const QDropEvent *e );
 
-    /**
+  /**
    * Selects the next message item in the view.
    *
    * messageTypeFilter can be used to restrict the selection to only certain message types.
@@ -95,12 +93,12 @@ public:
    * If loop is true then the "next" algorithm will restart from the beginning
    * of the list if the end is reached, otherwise it will just stop returning false.
    */
-    bool selectNextMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                bool centerItem,
-                                bool loop );
+  bool selectNextMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter,
+                              MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
+                              bool centerItem,
+                              bool loop );
 
-    /**
+  /**
    * Selects the previous message item in the view.
    * If centerItem is true then the specified item will be positioned
    * at the center of the view, if possible.
@@ -113,12 +111,12 @@ public:
    * If loop is true then the "previous" algorithm will restart from the end
    * of the list if the beginning is reached, otherwise it will just stop returning false.
    */
-    bool selectPreviousMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                    MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                    bool centerItem,
-                                    bool loop );
+  bool selectPreviousMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter,
+                                  MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
+                                  bool centerItem,
+                                  bool loop );
 
-    /**
+  /**
    * Focuses the next message item in the view without actually selecting it.
    *
    * messageTypeFilter can be used to restrict the selection to only certain message types.
@@ -128,9 +126,9 @@ public:
    * If loop is true then the "next" algorithm will restart from the beginning
    * of the list if the end is reached, otherwise it will just stop returning false.
    */
-    bool focusNextMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
+  bool focusNextMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
 
-    /**
+  /**
    * Focuses the previous message item in the view without actually selecting it.
    *
    * messageTypeFilter can be used to restrict the selection to only certain message types.
@@ -140,17 +138,17 @@ public:
    * If loop is true then the "previous" algorithm will restart from the end
    * of the list if the beginning is reached, otherwise it will just stop returning false.
    */
-    bool focusPreviousMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
+  bool focusPreviousMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
 
-    /**
+  /**
    * Selects the currently focused message item. May do nothing if the
    * focused message item is already selected (which is very likely).
    * If centerItem is true then the specified item will be positioned
    * at the center of the view, if possible.
    */
-    void selectFocusedMessageItem( bool centerItem );
+  void selectFocusedMessageItem( bool centerItem );
 
-    /**
+  /**
    * Selects the first message item in the view that matches the specified Core::MessageTypeFilter.
    * If centerItem is true then the specified item will be positioned
    * at the center of the view, if possible.
@@ -165,47 +163,38 @@ public:
    *
    * The function returns true if a message was selected and false otherwise.
    */
-    bool selectFirstMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem );
+  bool selectFirstMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem );
 
-    /**
-   * Selects the last message item in the view that matches the specified Core::MessageTypeFilter.
-   * If centerItem is true then the specified item will be positioned
-   * at the center of the view, if possible.
-   *
-   * The function returns true if a message was selected and false otherwise.
-   */
-    bool selectLastMessageItem( MessageList::Core::MessageTypeFilter messageTypeFilter, bool centerItem );
-
-    /**
+  /**
    * Selects all the items in the current folder.
    */
-    void selectAll();
-    /**
+  void selectAll();
+  /**
    * If expand is true then it expands the current thread, otherwise
    * collapses it.
    */
-    void setCurrentThreadExpanded( bool expand );
+  void setCurrentThreadExpanded( bool expand );
 
-    /**
+  /**
    * If expand is true then it expands all the threads, otherwise
    * collapses them.
    */
-    void setAllThreadsExpanded( bool expand );
+  void setAllThreadsExpanded( bool expand );
 
-    /**
+  /**
    * If expand is true then it expands all the groups (only the toplevel
    * group item: inner threads are NOT expanded). If expand is false
    * then it collapses all the groups. If no grouping is in effect
    * then this function does nothing.
    */
-    void setAllGroupsExpanded( bool expand );
+  void setAllGroupsExpanded( bool expand );
 
-    /**
+  /**
    * Sets the focus on the quick search line of the currently active tab.
    */
-    void focusQuickSearch(const QString &selectedText);
+  void focusQuickSearch();
 
-    /**
+  /**
    * Returns the currently selected KMime::Message::Ptr (bound to current StorageModel).
    * The list may be empty if there are no selected messages or no StorageModel.
    *
@@ -216,9 +205,9 @@ public:
    * to the main even loop. Don't store it for any longer. If you need to reference
    * this set of messages at a later stage then take a look at createPersistentSet().
    */
-    QList<KMime::Message::Ptr > selectionAsMessageList( bool includeCollapsedChildren = true ) const;
+  QList<KMime::Message::Ptr > selectionAsMessageList( bool includeCollapsedChildren = true ) const;
 
-    /**
+  /**
    * Returns the currently selected Items (bound to current StorageModel).
    * The list may be empty if there are no selected messages or no StorageModel.
    *
@@ -229,9 +218,9 @@ public:
    * to the main even loop. Don't store it for any longer. If you need to reference
    * this set of messages at a later stage then take a look at createPersistentSet().
    */
-    QList<Akonadi::Item> selectionAsMessageItemList( bool includeCollapsedChildren = true ) const;
+  QList<Akonadi::Item> selectionAsMessageItemList( bool includeCollapsedChildren = true ) const;
 
-    /**
+  /**
    * Returns the currently selected Items id (bound to current StorageModel).
    * The list may be empty if there are no selected messages or no StorageModel.
    *
@@ -243,10 +232,9 @@ public:
    * this set of messages at a later stage then take a look at createPersistentSet().
    */
 
-    QVector<qlonglong> selectionAsMessageItemListId( bool includeCollapsedChildren ) const;
-    QList<Akonadi::Item::Id> selectionAsListMessageId( bool includeCollapsedChildren ) const;
+  QVector<qlonglong> selectionAsMessageItemListId( bool includeCollapsedChildren ) const;
 
-    /**
+  /**
    * Returns the Akonadi::Item bound to the current StorageModel that
    * are part of the current thread. The current thread is the thread
    * that contains currentMessageItem().
@@ -256,30 +244,30 @@ public:
    * to the main even loop. Don't store it for any longer. If you need to reference
    * this set of messages at a later stage then take a look at createPersistentSet().
    */
-    QList<Akonadi::Item> currentThreadAsMessageList() const;
+  QList<Akonadi::Item> currentThreadAsMessageList() const;
 
-    /**
+  /**
    * Returns the Akonadi::MessageStatus in the current quicksearch field.
    */
-    QList<Akonadi::MessageStatus> currentFilterStatus() const;
+  Akonadi::MessageStatus currentFilterStatus() const;
 
-    /**
+  /**
    * Returns the search term in the current quicksearch field.
    */
-    QString currentFilterSearchString() const;
+  QString currentFilterSearchString() const;
 
-    /**
+  /**
    * Returns true if the current Aggregation is threaded, false otherwise
    * (or if there is no current Aggregation).
    */
-    bool isThreaded() const;
+  bool isThreaded() const;
 
-    /**
+  /**
    * Fast function that determines if the selection is empty
    */
-    bool selectionEmpty() const;
+  bool selectionEmpty() const;
 
-    /**
+  /**
    * Fills the lists of the selected message serial numbers and of the selected+visible ones.
    * Returns true if the returned stats are valid (there is a current folder after all)
    * and false otherwise. This is called by KMMainWidget in a single place so we optimize by
@@ -289,107 +277,102 @@ public:
    * collapsed items are also included in the stats
    */
 
-    bool getSelectionStats( Akonadi::Item::List &selectedSernums,
-                            Akonadi::Item::List &selectedVisibleSernums,
-                            bool * allSelectedBelongToSameThread,
-                            bool includeCollapsedChildren = true ) const;
-    /**
+  bool getSelectionStats( Akonadi::Item::List &selectedSernums,
+                          Akonadi::Item::List &selectedVisibleSernums,
+                          bool * allSelectedBelongToSameThread,
+                          bool includeCollapsedChildren = true ) const;
+  /**
    * Deletes the persistent set pointed by the specified reference.
    * If the set does not exist anymore, nothing happens.
    */
-    void deletePersistentSet( MessageList::Core::MessageItemSetReference ref );
+  void deletePersistentSet( MessageList::Core::MessageItemSetReference ref );
 
-    /**
+  /**
    * If bMark is true this function marks the messages as "about to be removed"
    * so they appear dimmer and aren't selectable in the view.
    * If bMark is false then this function clears the "about to be removed" state
    * for the specified MessageItems.
    */
-    void markMessageItemsAsAboutToBeRemoved( MessageList::Core::MessageItemSetReference ref, bool bMark );
+  void markMessageItemsAsAboutToBeRemoved( MessageList::Core::MessageItemSetReference ref, bool bMark );
 
-    /**
+  /**
    * Return Akonadi::Item from messageItemReference
    */
-    QList<Akonadi::Item> itemListFromPersistentSet( MessageList::Core::MessageItemSetReference ref );
+  QList<Akonadi::Item> itemListFromPersistentSet( MessageList::Core::MessageItemSetReference ref );
 
-    /**
+  /**
    * Return a persistent set from current selection
    */
-    MessageList::Core::MessageItemSetReference selectionAsPersistentSet( bool includeCollapsedChildren = true ) const;
+  MessageList::Core::MessageItemSetReference selectionAsPersistentSet( bool includeCollapsedChildren = true ) const;
 
-    /**
+  /**
    * Return a persistent set from current thread
    */
-    MessageList::Core::MessageItemSetReference currentThreadAsPersistentSet() const;
-    Akonadi::Collection currentCollection() const;
+  MessageList::Core::MessageItemSetReference currentThreadAsPersistentSet() const;
+  Akonadi::Collection currentCollection() const;
 
-    void setQuickSearchClickMessage(const QString &msg);
-    MessageList::Core::QuickSearchLine::SearchOptions currentOptions() const;
 protected:
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void fillMessageTagCombo();
+  virtual void fillMessageTagCombo( KComboBox * combo );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewMessageSelected( MessageList::Core::MessageItem *msg );
+  virtual void viewMessageSelected( MessageList::Core::MessageItem *msg );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewMessageActivated( MessageList::Core::MessageItem *msg );
+  virtual void viewMessageActivated( MessageList::Core::MessageItem *msg );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewSelectionChanged();
+  virtual void viewSelectionChanged();
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewMessageListContextPopupRequest( const QList< MessageList::Core::MessageItem * > &selectedItems, const QPoint &globalPos );
+  virtual void viewMessageListContextPopupRequest( const QList< MessageList::Core::MessageItem * > &selectedItems, const QPoint &globalPos );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewGroupHeaderContextPopupRequest( MessageList::Core::GroupHeaderItem *group, const QPoint &globalPos );
+  virtual void viewGroupHeaderContextPopupRequest( MessageList::Core::GroupHeaderItem *group, const QPoint &globalPos );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewDragEnterEvent( QDragEnterEvent * e );
+  virtual void viewDragEnterEvent( QDragEnterEvent * e );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewDragMoveEvent( QDragMoveEvent * e );
+  virtual void viewDragMoveEvent( QDragMoveEvent * e );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewDropEvent( QDropEvent * e );
+  virtual void viewDropEvent( QDropEvent * e );
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewStartDragRequest();
+  virtual void viewStartDragRequest();
 
-    /**
+  /**
    * Reimplemented from MessageList::Core::Widget
    */
-    virtual void viewMessageStatusChangeRequest( MessageList::Core::MessageItem *msg, const Akonadi::MessageStatus &set, const Akonadi::MessageStatus &clear );
+  virtual void viewMessageStatusChangeRequest( MessageList::Core::MessageItem *msg, const Akonadi::MessageStatus &set, const Akonadi::MessageStatus &clear );
+
 
-private Q_SLOTS:
-    void slotCollapseItem();
-    void slotExpandItem();
-    void slotTagsFetched(KJob *job);
 
 
 signals:
-    /**
+  /**
    * Emitted when a message is selected (that is, single clicked and thus made current in the view)
    * Note that this message CAN be 0 (when the current item is cleared, for example).
    *
@@ -399,26 +382,26 @@ signals:
    * this signal only for the last clicked message (or at all, if the last shift+clicked
    * thing is a group header...). You should handle selection changed in this case.
    */
-    void messageSelected( const Akonadi::Item &item );
+  void messageSelected( const Akonadi::Item &item );
 
-    /**
+  /**
    * Emitted when a message is doubleclicked or activated by other input means
    */
-    void messageActivated( const Akonadi::Item &item );
+  void messageActivated( const Akonadi::Item &item );
 
-    /**
+  /**
    * Emitted when the selection in the view changes.
    */
-    void selectionChanged();
+  void selectionChanged();
 
-    /**
+  /**
    * Emitted when a message wants its status to be changed
    */
-    void messageStatusChangeRequest( const Akonadi::Item &item, const Akonadi::MessageStatus &set, const Akonadi::MessageStatus &clear );
+  void messageStatusChangeRequest( const Akonadi::Item &item, const Akonadi::MessageStatus &set, const Akonadi::MessageStatus &clear );
 
 private:
-    class Private;
-    Private * const d;
+  class Private;
+  Private * const d;
 };
 
 } // namespace MessageList
