@@ -25,24 +25,39 @@
 #include <QWidget>
 class Ui_Settings;
 
+class KConfigDialogManager;
+
+namespace MessageViewer {
 
 /**
-Configure widget that can be used in a KConfigDialog.
-
-	@author Andras Mantia <andras@kdab.net>
-*/
+ * Configure widget that can be used in a KConfigDialog.
+ *
+ * @author Andras Mantia <andras@kdab.net>
+ */
 class MESSAGEVIEWER_EXPORT ConfigureWidget : public QWidget
 {
 Q_OBJECT
 public:
-    ConfigureWidget(QWidget *parent = 0);
+  ConfigureWidget( QWidget *parent = 0 );
 
-    ~ConfigureWidget();
+  ~ConfigureWidget();
 
-private slots:
-  void slotSettingsChanged();
+  //
+  // Read and write config settings to the GlobalSettings.
+  // Note that this does not deal with all settings, some of those settings need to saved and read
+  // with a KConfigDialogManager, since this widgets correctly sets the objectname to the pattern
+  // required by KConfigDialogManager.
+  //
+
+  void writeConfig();
+  void readConfig();
 
 signals:
+
+  /**
+   * Emitted when the user changes the setting in some widget. Useful to enable the "Apply"
+   * button after this has been emitted.
+   */
   void settingsChanged();
 
 private:
@@ -50,9 +65,8 @@ private:
   void readCurrentOverrideCodec();
 
   Ui_Settings *mSettingsUi;
-
 };
 
-
+}
 
 #endif
