@@ -842,7 +842,7 @@ QString EnterpriseHeaderStyle::format( KMime::Message *message ) const
     //if ( strategy->showHeader( "date" ) )
     headerStr +=
       "     <tr> \n"
-      "      <td style=\"font-size: 10px; padding-left: 5px; padding-right: 24px; text-align: right; "+borderSettings+"\">"+i18n("From: ")+"</td> \n"
+      "      <td style=\"font-size: 10px; padding-left: 5px; padding-right: 24px; text-align: right; vertical-align:top; "+borderSettings+"\">"+i18n("From: ")+"</td> \n"
       "      <td style=\""+borderSettings+"\">"+ fromPart +"</td> "
       "     </tr> ";
   }
@@ -851,7 +851,7 @@ QString EnterpriseHeaderStyle::format( KMime::Message *message ) const
   if ( strategy->showHeader( "to" ) ) {
     headerStr +=
       "     <tr> "
-      "      <td style=\"font-size: 10px; text-align: right; padding-left: 5px; padding-right: 24px; " + borderSettings + "\">" + i18n("To: ") + "</td> "
+      "      <td style=\"font-size: 10px; text-align: right; vertical-align:top; padding-left: 5px; padding-right: 24px; " + borderSettings + "\">" + i18n("To: ") + "</td> "
       "      <td style=\"" + borderSettings + "\">" +
       StringUtil::emailAddrAsAnchor( message->to(), StringUtil::DisplayFullAddress, linkColor ) +
       "      </td> "
@@ -862,7 +862,7 @@ QString EnterpriseHeaderStyle::format( KMime::Message *message ) const
   if ( strategy->showHeader( "cc" ) && message->cc( false ) ) {
     headerStr +=
       "     <tr> "
-      "      <td style=\"font-size: 10px; text-align: right; padding-left: 5px; padding-right: 24px; " + borderSettings + "\">" + i18n("CC: ") + "</td> "
+      "      <td style=\"font-size: 10px; text-align: right; vertical-align:top; padding-left: 5px; padding-right: 24px; " + borderSettings + "\">" + i18n("CC: ") + "</td> "
       "      <td style=\"" + borderSettings + "\">" +
       StringUtil::emailAddrAsAnchor( message->cc(), StringUtil::DisplayFullAddress, linkColor ) +
       "      </td> "
@@ -873,19 +873,34 @@ QString EnterpriseHeaderStyle::format( KMime::Message *message ) const
   if ( strategy->showHeader( "bcc" ) && message->bcc( false ) ) {
     headerStr +=
       "     <tr> "
-      "      <td style=\"font-size: 10px; text-align: right; padding-left: 5px; padding-right: 24px; " + borderSettings + "\">" + i18n("BCC: ") + "</td> "
+      "      <td style=\"font-size: 10px; text-align: right; vertical-align:top; padding-left: 5px; padding-right: 24px; " + borderSettings + "\">" + i18n("BCC: ") + "</td> "
       "      <td style=\"" + borderSettings + "\">" +
       StringUtil::emailAddrAsAnchor( message->bcc(), StringUtil::DisplayFullAddress, linkColor ) +
       "      </td> "
       "     </tr>\n";
   }
 
+  // attachments
+  QString attachment;
+  if( isTopLevel() ) {
+    attachment =
+      "<tr>"
+      "<td style='min-width: 6px; max-width: 6px; background: url("+imgpath+"left.png);'</td>"
+      "<td style='padding-right:20px;'>"
+        "<div class=\"noprint\" >"
+        "<div id=\"attachmentInjectionPoint\"></div>"
+        "</div>"
+      "</td>"
+      "<td style='min-width: 6px; max-width: 6px; background: url("+imgpath+"right.png);'</td>"
+      "</tr>";
+  }
+
   // header-bottom
   headerStr +=
     "    </table> \n"
     "   </td> \n"
     "   <td style=\"min-width: 6px; max-height: 15px; background: url("+imgpath+"right.png); \"></td> \n"
-    "  </tr> \n"
+    "  </tr> \n" + attachment +
     "  <tr> \n"
     "   <td style=\"min-width: 6px; background: url("+imgpath+"s_left.png); \"></td> \n"
     "   <td style=\"height: 35px; width: 80%; background: url("+imgpath+"sbar.png);\"> \n"
@@ -895,16 +910,6 @@ QString EnterpriseHeaderStyle::format( KMime::Message *message ) const
     "  </tr> \n"
     " </table> \n";
 
-  // kmail icon
-  if( isTopLevel() ) {
-
-    // attachments
-    headerStr +=
-      "<div class=\"noprint\" style=\"position: absolute; top: 60px; right: 20px;\">"
-      "<div id=\"attachmentInjectionPoint\"></div>"
-      "</div>\n";
-  }
-
   if ( isPrinting() ) {
     //provide a bit more left padding when printing
     //kolab/issue3254 (printed mail cut at the left side)
