@@ -18,7 +18,7 @@
 */
 #include "htmlquotecolorertest.h"
 
-#include "viewer/htmlquotecolorer.cpp"
+#include "../htmlquotecolorer.cpp"
 
 #include "qtest_kde.h"
 
@@ -32,12 +32,10 @@ void HTMLQuoteColorerTester::test_QuoteColor()
   QFETCH( QString, expectedCode );
 
   HTMLQuoteColorer colorer;
-  colorer.setEnableHtmlQuoteColorer(true);
   colorer.setQuoteColor( 0, QColor( "#FF0000" ) );
   colorer.setQuoteColor( 1, QColor( "#00FF00" ) );
   colorer.setQuoteColor( 2, QColor( "#0000FF" ) );
-  QString header;
-  QCOMPARE( colorer.process( originalCode, header ), expectedCode );
+  QCOMPARE( colorer.process( originalCode ), expectedCode );
 }
 
 void HTMLQuoteColorerTester::test_QuoteColor_data()
@@ -62,19 +60,15 @@ void HTMLQuoteColorerTester::test_QuoteColor_data()
   QTest::newRow( "" ) << "<html><body>&gt;Some <b>quoted</b> text.</body></html>"
                       << "<font color=\"#ff0000\">&gt;Some </font><b><font color=\"#ff0000\">quoted</font></b><font color=\"#ff0000\"> text.</font>";
   QTest::newRow( "" ) << "<html><body>"
-                         "&gt; &gt; &gt; Level 3 Quote<br>"
+                         "&gt;&gt;&gt;Level 3 Quote<br>"
                          "No Quote<br>"
-                         "&gt; &gt; Level 2 Quote<br>"
-                         "&gt; Level 1 Quote<br>"
+                         "&gt;&gt;Level 2 Quote<br>"
+                         "&gt;Level 1 Quote<br>"
                          "No Quote<br>"
                          "</body></html>"
-                      << "<font color=\"#0000ff\">&gt; &gt; &gt; Level 3 Quote</font><br>"
+                      << "<font color=\"#0000ff\">&gt;&gt;&gt;Level 3 Quote</font><br>"
                          "No Quote<br>"
-                         "<font color=\"#00ff00\">&gt; &gt; Level 2 Quote</font><br>"
-                         "<font color=\"#ff0000\">&gt; Level 1 Quote</font><br>"
+                         "<font color=\"#00ff00\">&gt;&gt;Level 2 Quote</font><br>"
+                         "<font color=\"#ff0000\">&gt;Level 1 Quote</font><br>"
                          "No Quote<br>";
-
-  QTest::newRow("") << "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; -qt-user-state:0;\">&gt; &gt; &gt; Sdf sdfqsdf fqs dfq sfsdfsqfqs</p>"
-                    << "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; -qt-user-state:0;\"><font color=\"#0000ff\">&gt; &gt; &gt; Sdf sdfqsdf fqs dfq sfsdfsqfqs</font></p>";
-
 }
