@@ -225,6 +225,7 @@ public:
   KService::Ptr getServiceOffer( KMime::Content *content);
   KMime::Content::List selectedContents();
   void attachmentOpenWith( KMime::Content *node );
+  void attachmentOpen( KMime::Content *node, KService::Ptr offer );
   void attachmentOpen( KMime::Content *node );
 
 
@@ -354,7 +355,6 @@ public:
   void atmViewMsg( KMime::Message::Ptr message );
 
   void adjustLayout();
-  void saveSplitterSizes() const;
   void createWidgets();
   void createActions();
 
@@ -465,6 +465,8 @@ private slots:
 
   void slotMessageRendered();
 
+  void saveSplitterSizes() const;
+
 public slots:
   /** An URL has been activate with a click. */
   void slotUrlOpen( const QUrl &url = QUrl());
@@ -611,7 +613,6 @@ public:
   bool mUseFixedFont;
   bool mPrinting;
   //bool mShowCompleteMessage;
-  QList<int> mSplitterSizes;
   QString mIdOfLastViewedMessage;
   QWidget *mMainWindow;
   KActionCollection *mActionCollection;
