@@ -2,8 +2,7 @@
 
   This file is part of KMail, the KDE mail client.
   Copyright (c) 2004 Till Adam <adam@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  Copyright (C) 2012-2015 Laurent Montel <montel@kde.org>
+  Copyright (c) 2010 Klarlvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
   KMail is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -33,14 +32,10 @@
 #include "messageviewer/interfaces/bodypartformatter.h"
 #include "messageviewer/interfaces/bodyparturlhandler.h"
 #include "messageviewer/interfaces/bodypart.h"
-#include <messageviewer/viewer/nodehelper.h>
-#include "updatecontactjob.h"
-#include "vcardmemento.h"
-
 using MessageViewer::Interface::BodyPart;
-#include "messageviewer/htmlwriter/webkitparthtmlwriter.h"
+#include "messageviewer/webkitparthtmlwriter.h"
 
-#include <libkdepim/job/addcontactjob.h>
+#include <libkdepim/addcontactjob.h>
 
 #include <Akonadi/Contact/ContactViewer>
 #include <Akonadi/Contact/StandardContactFormatter>
@@ -48,17 +43,15 @@ using MessageViewer::Interface::BodyPart;
 #include <KABC/VCardConverter>
 #include <KABC/Addressee>
 
-#include <KLocale>
 #include <kdemacros.h>
 #include <KFileDialog>
 #include <KGlobal>
 #include <KIcon>
-#include <KLocalizedString>
+#include <KLocale>
 #include <KMenu>
 #include <KMessageBox>
 #include <KTemporaryFile>
 #include <KIO/NetAccess>
-#include <QDebug>
 
 namespace {
 
@@ -69,114 +62,44 @@ class Formatter : public MessageViewer::Interface::BodyPartFormatter
     {
     }
 
-    Result format( BodyPart * part, MessageViewer::HtmlWriter * writer ) const
-    {
-      return format ( part, writer, 0 );
-    }
-
-    Result format( BodyPart *bodyPart, MessageViewer::HtmlWriter *writer, QObject* asyncResultObserver ) const
+    Result format( BodyPart *bodyPart, MessageViewer::HtmlWriter *writer ) const
     {
       if ( !writer ) {
-        return Ok;
-      }
-
-      const QString vCard = bodyPart->asText();
-      if ( vCard.isEmpty() ) {
         return AsIcon;
       }
 
       KABC::VCardConverter vcc;
-      const KABC::Addressee::List al = vcc.parseVCards( vCard.toUtf8() );
-
-      MessageViewer::VcardMemento *memento = dynamic_cast<MessageViewer::VcardMemento*>( bodyPart->memento() );
-      QStringList lst;
-
-      // Pre-count the number of non-empty addressees
-      int count = 0;
-      foreach ( const KABC::Addressee &a, al ) {
-        if ( a.isEmpty() ) {
-          continue;
-        }
-        if(!memento) {
-          if(!a.emails().isEmpty()) {
-            lst.append(a.emails().first());
-            count++;
-          }
-        }
+      const QString vCard = bodyPart->asText();
+      if ( vCard.isEmpty() ) {
+        return AsIcon;
       }
-      if ( !count ) {
+      KABC::Addressee::List al = vcc.parseVCards( vCard.toUtf8() );
+      if ( al.empty() ) {
         return AsIcon;
       }
 
-      writer->queue( QLatin1String("<div align=\"center\"><h2>") +
-                     i18np( "Attached business card", "Attached business cards", count ) +
-                     QLatin1String("</h2></div>") );
-
-      count = 0;
-      static QString defaultPixmapPath = QLatin1String("file:///") + KIconLoader::global()->iconPath( QLatin1String("user-identity"), KIconLoader::Desktop );
-      static QString defaultMapIconPath = QLatin1String("file:///") + KIconLoader::global()->iconPath( QLatin1String("document-open-remote"), KIconLoader::Small );
-
-
-      if ( !memento ) {
-        MessageViewer::VcardMemento *memento = new MessageViewer::VcardMemento(lst);
-        bodyPart->setBodyPartMemento( memento );
-
-        if ( asyncResultObserver ) {
-          QObject::connect( memento, SIGNAL(update(MessageViewer::Viewer::UpdateMode)),
-                            asyncResultObserver, SLOT(update(MessageViewer::Viewer::UpdateMode)) );
-        }
-      }
-
+      writer->queue( "<div align=\"center\"><h2>" +
+                     i18n( "Attached business cards" ) +
+                     "</h2></div>" );
 
+      int count = 0;
       foreach ( const KABC::Addressee &a, al ) {
         if ( a.isEmpty() ) {
-          continue;
-        }        
+          return AsIcon;
+        }
+
         Akonadi::StandardContactFormatter formatter;
         formatter.setContact( a );
-        formatter.setDisplayQRCode(false);
-        QString htmlStr = formatter.toHtml( Akonadi::StandardContactFormatter::EmbeddableForm );
-        const KABC::Picture photo = a.photo();
-        htmlStr.replace(QLatin1String("<img src=\"map_icon\""),QString::fromLatin1("<img src=\"%1\"").arg(defaultMapIconPath));
-        if(photo.isEmpty()) {
-          htmlStr.replace(QLatin1String("img src=\"contact_photo\""),QString::fromLatin1("img src=\"%1\"").arg(defaultPixmapPath));
-        } else {
-          QImage img = a.photo().data();
-          const QString dir = bodyPart->nodeHelper()->createTempDir( QLatin1String("vcard-") + a.uid() );
-          const QString filename = dir + QDir::separator() + a.uid();
-          img.save(filename,"PNG");
-          bodyPart->nodeHelper()->addTempFile( filename );
-          const QString href = QLatin1String("file:") + QLatin1String(KUrl::toPercentEncoding( filename ));
-          htmlStr.replace(QLatin1String("img src=\"contact_photo\""),QString::fromLatin1("img src=\"%1\"").arg(href));
-        }
-        writer->queue( htmlStr );
 
-        if(!memento ||
-                (memento && !memento->finished()) ||
-                (memento && memento->finished() && !memento->vcardExist(count)) ) {
-          const QString addToLinkText = i18n( "[Add this contact to the address book]" );
-          QString op = QString::fromLatin1( "addToAddressBook:%1" ).arg( count );
-          writer->queue( QLatin1String("<div align=\"center\"><a href=\"") +
-                         bodyPart->makeLink( op ) +
-                         QLatin1String("\">") +
-                         addToLinkText +
-                         QLatin1String("</a></div><br><br>") );
-        } else {
-            if(memento->address(count) != a) {
-              const QString addToLinkText = i18n( "[Update this contact to the address book]" );
-              QString op = QString::fromLatin1( "updateToAddressBook:%1" ).arg( count );
-              writer->queue( QLatin1String("<div align=\"center\"><a href=\"") +
-                             bodyPart->makeLink( op ) +
-                             QLatin1String("\">") +
-                             addToLinkText +
-                            QLatin1String("</a></div><br><br>") );
-            } else {
-                const QString addToLinkText = i18n( "[This contact is already in addressbook]" );
-                writer->queue( QLatin1String("<div align=\"center\">") +
-                               addToLinkText +
-                              QLatin1String("</a></div><br><br>") );
-            }
-        }
+        writer->queue( formatter.toHtml( Akonadi::StandardContactFormatter::EmbeddableForm ) );
+
+        QString addToLinkText = i18n( "[Add this contact to the address book]" );
+        QString op = QString::fromLatin1( "addToAddressBook:%1" ).arg( count );
+        writer->queue( "<div align=\"center\"><a href=\"" +
+                       bodyPart->makeLink( op ) +
+                       "\">" +
+                       addToLinkText +
+                       "</a></div><br><br>" );
         count++;
       }
 
@@ -197,24 +120,18 @@ class UrlHandler : public MessageViewer::Interface::BodyPartURLHandler
         return true;
       }
       KABC::VCardConverter vcc;
-      const KABC::Addressee::List al = vcc.parseVCards( vCard.toUtf8() );
-      const int index = path.right( path.length() - path.lastIndexOf( QLatin1Char(':') ) - 1 ).toInt();
+      KABC::Addressee::List al = vcc.parseVCards( vCard.toUtf8() );
+      int index = path.right( path.length() - path.lastIndexOf( ":" ) - 1 ).toInt();
       if ( index == -1 || index >= al.count() ) {
         return true;
       }
-      const KABC::Addressee a = al.at(index);
+      KABC::Addressee a = al[index];
       if ( a.isEmpty() ) {
         return true;
       }
 
-      if(path.startsWith(QLatin1String("addToAddressBook"))) {
-
-        KPIM::AddContactJob *job = new KPIM::AddContactJob( a, 0 );
-        job->start();
-      } else if( path.startsWith(QLatin1String("updateToAddressBook"))) {
-        UpdateContactJob *job = new UpdateContactJob(a.emails().first(), a, 0);
-        job->start();
-      }
+      KPIM::AddContactJob *job = new KPIM::AddContactJob( a, 0 );
+      job->start();
 
       return true;
     }
@@ -224,10 +141,10 @@ class UrlHandler : public MessageViewer::Interface::BodyPartURLHandler
       const QString vCard = part->asText();
       if ( !vCard.isEmpty() ) {
         KABC::VCardConverter vcc;
-        const KABC::Addressee::List al = vcc.parseVCards( vCard.toUtf8() );
-        const int index = path.right( path.length() - path.lastIndexOf( QLatin1Char(':') ) - 1 ).toInt();
+        KABC::Addressee::List al = vcc.parseVCards( vCard.toUtf8() );
+        const int index = path.right( path.length() - path.lastIndexOf( ":" ) - 1 ).toInt();
         if ( index >= 0 && index < al.count() ) {
-          return al.at(index);
+          return al[index];
         }
       }
       return KABC::Addressee();
@@ -246,9 +163,9 @@ class UrlHandler : public MessageViewer::Interface::BodyPartURLHandler
 
       KMenu *menu = new KMenu();
       QAction *open =
-        menu->addAction( KIcon( QLatin1String("document-open") ), i18n( "View Business Card" ) );
+        menu->addAction( KIcon( "document-open" ), i18n( "View Business Card" ) );
       QAction *saveas =
-        menu->addAction( KIcon( QLatin1String("document-save-as") ), i18n( "Save Business Card As..." ) );
+        menu->addAction( KIcon( "document-save-as" ), i18n( "Save Business Card As..." ) );
 
       QAction *action = menu->exec( point, 0 );
       if ( action == open ) {
@@ -263,11 +180,10 @@ class UrlHandler : public MessageViewer::Interface::BodyPartURLHandler
     QString statusBarMessage( BodyPart *part, const QString &path ) const
     {
       KABC::Addressee a = findAddressee( part, path );
-      const bool addToAddressBook = path.startsWith(QLatin1String("addToAddressBook"));
       if ( a.realName().isEmpty() ) {
-        return addToAddressBook ? i18n( "Add this contact to the address book." ) : i18n("Update this contact to the address book.");
+        return i18n( "Add this contact to the address book." );
       } else {
-        return addToAddressBook ? i18n( "Add \"%1\" to the address book.", a.realName() ) : i18n("Update \"%1\" to the address book.", a.realName());
+        return i18n( "Add \"%1\" to the address book.", a.realName() );
      }
     }
 
@@ -283,13 +199,8 @@ class UrlHandler : public MessageViewer::Interface::BodyPartURLHandler
 
     bool saveAsVCard( const KABC::Addressee &a, const QString &vCard ) const
     {
-      QString fileName;
-      const QString givenName(a.givenName());
-      if(givenName.isEmpty()) {
-        fileName = a.familyName() + QLatin1String(".vcf");
-      } else {
-        fileName = givenName + QLatin1Char('_') + a.familyName() + QLatin1String(".vcf");
-      }
+      QString fileName = a.givenName() + QLatin1Char('_') + a.familyName() + QLatin1String(".vcf");
+
       // get the saveas file name
       KUrl saveAsUrl =
         KFileDialog::getSaveUrl( fileName,
@@ -359,7 +270,7 @@ extern "C"
 KDE_EXPORT MessageViewer::Interface::BodyPartFormatterPlugin *
 messageviewer_bodypartformatter_text_vcard_create_bodypart_formatter_plugin()
 {
-  KGlobal::locale()->insertCatalog( QLatin1String("messageviewer_text_vcard_plugin") );
+  KGlobal::locale()->insertCatalog( "messageviewer_text_vcard_plugin" );
   return new Plugin();
 }
 
